****************************
* primary outcomes, heterogeneity analysis
****************************

eststo clear
clear
use "$panel/ready.dta"

local ffx strat_pmt strat_vill_size cohort
local controls i.surveyed_twice

gen tmpvar = proxycon_mt
replace tmpvar = proxycon_mt_compare if svyround == 2 | svyround == 4
label variable tmpvar "\makecell{Food \\ consumption}"

local primary_panel fcs tmpvar cantril

forval i = 1/4 {
foreach depvar in `primary_panel' {
    foreach dimension in liquid diverse {
    quietly {
    reghdfe `depvar' `controls' i.treatment i.treatment#i.`dimension' i.`dimension' if svyround == `i', absorb(`ffx') vce(cluster vid)
    eststo `depvar'_`i'_`dimension'
    test 1.treatment == 2.treatment
    estadd scalar equals = r(p)
    test 1.treatment + 1.treatment#1.`dimension' == 0
    estadd scalar tfe = r(p)
    test 2.treatment + 2.treatment#1.`dimension' == 0
    estadd scalar mfe = r(p)
    estadd local ffx = "Yes"
    estadd scalar ar2 = e(r2_a)
    forval k = 0/2 {
        sum `depvar' if treatment == `k' & e(sample) == 1
        estadd scalar mean_`k' = r(mean)
    }
    }
    }
}
}

foreach dimension in liquid diverse {
    
    if "`dimension'" == "liquid" {
        local tbl "Liquid"
    }
    
    if "`dimension'" == "diverse" {
        local tbl "Off-farm work"
    }

    esttab fcs_*_`dimension' ///
    using "$csae/primary-panel-`dimension'.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment 1.treatment#1.`dimension' 2.treatment#1.`dimension') ///
    booktabs ///
    varlabel(1.treatment "Early short ($\beta_1$)" 2.treatment "Early long( $\beta_2$)" ///
    1.treatment#1.`dimension' "Early short $\times$ `tbl' ($\beta_3$)" 2.treatment#1.`dimension' "Early long $\times$ `tbl' ($\beta_4$)") ///
    stats(tfe mfe N, ///
    labels("$\beta_1 + \beta_3$ = 0" "$\beta_2 + \beta_4$ = 0" "Observations") fmt(2 2 0)) ///
    substitute(\_ _) ///
    posthead( ///
    \midrule ///
    \it{Food Consumption Score} \\ ///
    \midrule ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    replace
        
esttab tmpvar_*_`dimension' ///
    using "$csae/primary-panel-`dimension'.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment 1.treatment#1.`dimension' 2.treatment#1.`dimension') ///
    booktabs ///
    varlabel(1.treatment "Early short ($\beta_1$)" 2.treatment "Early long( $\beta_2$)" ///
    1.treatment#1.`dimension' "Early short $\times$ `tbl' ($\beta_3$)" 2.treatment#1.`dimension' "Early long $\times$ `tbl' ($\beta_4$)") ///
    stats(tfe mfe N, ///
    labels("$\beta_1 + \beta_3$ = 0" "$\beta_2 + \beta_4$ = 0" "Observations") fmt(2 2 0)) ///
    substitute(\_ _) ///
    prehead( ///
    \midrule ///
    \it{Food Consumption} \\ ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    append
    
    esttab cantril_*_`dimension' ///
    using "$csae/primary-panel-`dimension'.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment 1.treatment#1.`dimension' 2.treatment#1.`dimension') ///
    booktabs ///
    varlabel(1.treatment "Early short ($\beta_1$)" 2.treatment "Early long( $\beta_2$)" ///
    1.treatment#1.`dimension' "Early short $\times$ `tbl' ($\beta_3$)" 2.treatment#1.`dimension' "Early long $\times$ `tbl' ($\beta_4$)") ///
    stats(tfe mfe N, ///
    labels("$\beta_1 + \beta_3$ = 0" "$\beta_2 + \beta_4$ = 0" "Observations") fmt(2 2 0)) ///
    substitute(\_ _) ///
    prehead( ///
    \midrule ///
    \it{Life Satisfaction} \\ ///
    ) ///
    append

}
*/
