eststo clear
clear
use "$panel/ready.dta"

local ffx strat_pmt strat_vill_size cohort
local controls surveyed_twice

gen tmpvar = proxycon_mt
replace tmpvar = proxycon_mt_compare if svyround == 2 | svyround == 4
label variable tmpvar "\makecell{Food \\ consumption}"

capture rename saved_binary_ saved_binary
capture rename trans_fam trans_rec

egen nonlabour = rowtotal(crop_seed_purch30 crop_fert_purch30) if svyround < 4
egen temp = rowtotal(fert_purch prod_purch) if svyround == 4
replace nonlabour = temp if !missing(temp)
drop temp
label variable nonlabour "Input expenses, see note" // past 30 days for pre-lean, lean, and post-lean, and all rainy season for endline

egen nonlabour_endline = rowtotal(crop_seed_purch30 crop_fert_purch30) if svyround == 4
label variable nonlabour_endline "Input expenses, see note" // past 30 days at endline

local primary_panel fcs tmpvar
local mentalhealth_panel cantril mentalhealth 
local cohesion_panel vperception socialcohesion

local loans_panel loans_twelve_mo loans_amt 
local savings_panel saved_binary saved_total
local remittances_panel trans_rec remittance_amt

* create mean effects index

local idx_business bus_asset_value bus_revenue nbusiness n_days_business
local idx_wage agri_wages agri_emp non_agri_wages non_agri_emp
local idx_livestock livestock_tlu n_days_livestock ani_value ani_prod_value30
local idx_inputs nonlabour n_days_cultivate totalplotsize ncrops ag_asset_value
local idx_endline_inputs nonlabour_endline plot_n30 totalplotsize30 
local idx_endline_outputs rcropvalharvest

local indices idx_business idx_wage idx_livestock idx_inputs idx_endline_inputs idx_endline_outputs
local indices_all_rounds idx_business idx_wage idx_livestock idx_inputs
local indices_endline_only idx_endline_inputs idx_endline_outputs

tempfile vhs 
save "`vhs'"

forval i = 1/4 {
    clear
    use "`vhs'"
    quietly keep if svyround == `i'
        
    foreach group in `indices' {

    local group_ ""
    foreach var in ``group'' {
    local l_`var' : variable label `var'
    quietly sum `var' if treatment == 0
        if r(sd) > 0 & !missing(r(sd)) {
            quietly gen st_`var' = (`var' - `r(mean)')/`r(sd)'
            label variable st_`var' "Standardised `l_`var''"
            local group_ "`group_' st_`var'"
            }
            }
    
    local counter : list sizeof group_
    
    if `counter' > 0 {
    quietly egen `group' = rowtotal(`group_'), missing
    quietly replace `group' = `group'/`counter'
    quietly drop `group_'
    }
    
    }
    
    keep hhid idx* svyround
    tempfile temp`i'
    save "`temp`i''"
}

clear
use "`temp1'"
append using "`temp2'"
append using "`temp3'"
append using "`temp4'"

merge 1:1 hhid svyround using "`vhs'"
drop _merge
sum `indices' if svyround == 1 & treatment == 0
sum `indices' if svyround == 2 & treatment == 0
sum `indices' if svyround == 3 & treatment == 0
sum `indices' if svyround == 4 & treatment == 0

eststo clear

forval i = 1/4 {
foreach depvar in `indices_all_rounds' {
    {
    reghdfe `depvar' i.treatment `controls' if svyround == `i', absorb(`ffx') vce(cluster vid)
    eststo `depvar'_`i'
    test 1.treatment == 2.treatment
    estadd scalar equals = r(p)
    estadd local ffx = "Yes"
    estadd scalar ar2 = e(r2_a)
    forval k = 0/2 {
        sum `depvar' if treatment == `k' & e(sample) == 1
        estadd scalar mean_`k' = r(mean)
    }
    }
}
}

forval i = 4/4 {
foreach depvar in `indices_endline_only' {
    {
    reghdfe `depvar' i.treatment `controls' if svyround == `i', absorb(`ffx') vce(cluster vid)
    eststo `depvar'_`i'
    test 1.treatment == 2.treatment
    estadd scalar equals = r(p)
    estadd local ffx = "Yes"
    estadd scalar ar2 = e(r2_a)
    forval k = 0/2 {
        sum `depvar' if treatment == `k' & e(sample) == 1
        estadd scalar mean_`k' = r(mean)
    }
    }
}
}

esttab idx_business_* ///
    using "$csae/business-index.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    replace
    
esttab idx_wage_* ///
    using "$csae/wage-index.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    replace
    
esttab idx_livestock_* ///
    using "$csae/livestock-index.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    replace
   
esttab idx_inputs_* ///
    using "$csae/inputs-index.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    replace
    
esttab idx_endline_inputs_* ///
    using "$csae/inputs-endline-index.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    replace    
    
esttab idx_endline_outputs_* ///
    using "$csae/outputs-index.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    replace

eststo clear

tempname rgcoef
postfile `rgcoef' b se str40 depvar str50 coefficient round using "${endline_final}/niger-csae-coefs.dta", replace

forval i = 1/4 {
foreach depvar in `indices_all_rounds' {
    {
        
    mean `depvar' if treatment == 0 & svyround == `i'
    post `rgcoef' (_b[`depvar']) (_se[`depvar']) ("`depvar'") ("0") (`i')
    
    reghdfe `depvar' i.treatment `controls' if svyround == `i', absorb(`ffx') vce(cluster vid)
    
    post `rgcoef' (_b[1.treatment]) (_se[1.treatment]) ("`depvar'") ("1") (`i')
    post `rgcoef' (_b[2.treatment]) (_se[2.treatment]) ("`depvar'") ("2") (`i')  

    eststo `depvar'_`i'
    test 1.treatment == 2.treatment
    estadd scalar equals = r(p)
    estadd local ffx = "Yes"
    estadd scalar ar2 = e(r2_a)
    forval k = 0/2 {
        sum `depvar' if treatment == `k' & e(sample) == 1
        estadd scalar mean_`k' = r(mean)
    }
    }
}
}

forval i = 4/4 {
foreach depvar in `indices_endline_only' {
    {
        
    mean `depvar' if treatment == 0 & svyround == `i'
    post `rgcoef' (_b[`depvar']) (_se[`depvar']) ("`depvar'") ("0") (`i')
    
    reghdfe `depvar' i.treatment `controls' if svyround == `i', absorb(`ffx') vce(cluster vid)
    
    post `rgcoef' (_b[1.treatment]) (_se[1.treatment]) ("`depvar'") ("1") (`i')
    post `rgcoef' (_b[2.treatment]) (_se[2.treatment]) ("`depvar'") ("2") (`i')  

    eststo `depvar'_`i'
    test 1.treatment == 2.treatment
    estadd scalar equals = r(p)
    estadd local ffx = "Yes"
    estadd scalar ar2 = e(r2_a)
    forval k = 0/2 {
        sum `depvar' if treatment == `k' & e(sample) == 1
        estadd scalar mean_`k' = r(mean)
    }
    }
}
}

postclose `rgcoef'

eststo clear

forval i = 1/4 {
foreach depvar in `idx_business' {
    {
    reghdfe `depvar' i.treatment `controls' if svyround == `i', absorb(`ffx') vce(cluster vid)
    eststo `depvar'_`i'
    test 1.treatment == 2.treatment
    estadd scalar equals = r(p)
    estadd local ffx = "Yes"
    estadd scalar ar2 = e(r2_a)
    forval k = 0/2 {
        sum `depvar' if treatment == `k' & e(sample) == 1
        estadd scalar mean_`k' = r(mean)
    }
    }
}
}

esttab bus_asset_value_* ///
    using "$csae/business-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    posthead( ///
    \midrule ///
    \it{Business assets} \\ ///
    \midrule ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    replace
   
    
esttab bus_revenue_* ///
    using "$csae/business-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Business revenue} \\ ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    append
    
    
esttab nbusiness_* ///
    using "$csae/business-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Number of businesses} \\ ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    append    
    
esttab n_days_business_* ///
    using "$csae/business-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Days worked} \\ ///
    ) ///
    append

eststo clear

forval i = 1/4 {
foreach depvar in `idx_wage' {
    {
    reghdfe `depvar' i.treatment `controls' if svyround == `i', absorb(`ffx') vce(cluster vid)
    eststo `depvar'_`i'
    test 1.treatment == 2.treatment
    estadd scalar equals = r(p)
    estadd local ffx = "Yes"
    estadd scalar ar2 = e(r2_a)
    forval k = 0/2 {
        sum `depvar' if treatment == `k' & e(sample) == 1
        estadd scalar mean_`k' = r(mean)
    }
    }
}
}

esttab agri_wages_* ///
    using "$csae/wage-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    posthead( ///
    \midrule ///
    \it{Ag wage} \\ ///
    \midrule ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    replace
  
esttab agri_emp_* ///
    using "$csae/wage-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Days in ag employment} \\ ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    append
    
esttab non_agri_wages_* ///
    using "$csae/wage-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Non ag wage} \\ ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    append    

esttab non_agri_emp_* ///
    using "$csae/wage-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Days in non ag employment} \\ ///
    ) ///
    append



eststo clear

replace ani_prod_value30 = 0 if missing(ani_prod_value30) & svyround < 4
replace ani_value = 0 if missing(ani_value) & svyround < 4

forval i = 1/4 {
foreach depvar in `idx_livestock' {
    {
    reghdfe `depvar' i.treatment `controls' if svyround == `i', absorb(`ffx') vce(cluster vid)
    if r(table)["pvalue", "1.treatment"] == . {
    mata : st_numscalar("e(N)", -999)
    }
    eststo `depvar'_`i'
    test 1.treatment == 2.treatment
    
    if r(p) != . {
    estadd scalar equals = r(p)
    estadd local ffx = "Yes"
    estadd scalar ar2 = e(r2_a)
    forval k = 0/2 {
        sum `depvar' if treatment == `k' & e(sample) == 1
        estadd scalar mean_`k' = r(mean)
    }
    }
    }
}
}

esttab livestock_tlu_* ///
    using "$csae/livestock-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    posthead( ///
    \midrule ///
    \it{Livestock TLU} \\ ///
    \midrule ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    replace ///
    substitute("(.)" "     " "0.00" "     " "-999" "")
  
esttab n_days_livestock_* ///
    using "$csae/livestock-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Days worked} \\ ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    append ///
    substitute("(.)" "     " "0.00" "     " "-999" "")
    
esttab ani_value_* ///
    using "$csae/livestock-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Value of livestock} \\ ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    append ///
    substitute("(.)" "     " "0.00" "     " "-999" "")

esttab ani_prod_value30_* ///
    using "$csae/livestock-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Revenue} \\ ///
    ) ///
    append ///
    substitute("(.)" "     " "0.00" "     " "-999" "")




eststo clear

replace totalplotsize = 0 if missing(totalplotsize) & (svyround == 1 | svyround == 3)
replace ncrops = 0 if missing(ncrops) & svyround < 4
replace ag_asset_value = 0 if missing(ag_asset_value) & svyround < 4

// nonlabour n_days_cultivate totalplotsize ncrops ag_asset_value

forval i = 1/4 {
foreach depvar in `idx_inputs' {
    {
    reghdfe `depvar' i.treatment `controls' if svyround == `i', absorb(`ffx') vce(cluster vid)
    if r(table)["pvalue", "1.treatment"] == . {
    mata : st_numscalar("e(N)", -999)
    }
    eststo `depvar'_`i'
    test 1.treatment == 2.treatment
    estadd scalar equals = r(p)
    estadd local ffx = "Yes"
    estadd scalar ar2 = e(r2_a)
    forval k = 0/2 {
        sum `depvar' if treatment == `k' & e(sample) == 1
        estadd scalar mean_`k' = r(mean)
    }
    }
}
}

esttab nonlabour_* ///
    using "$csae/inputs-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    posthead( ///
    \midrule ///
    \it{Input expenses} \\ ///
    \midrule ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    replace ///
    substitute("(.)" "     " "0.00" "     " "-999" "")

esttab n_days_cultivate_* ///
    using "$csae/inputs-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Days worked} \\ ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    append ///
    substitute("(.)" "     " "0.00" "     " "-999" "")
    
esttab totalplotsize_* ///
    using "$csae/inputs-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Total plot size} \\ ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    append ///
    substitute("(.)" "     " "0.00" "     " "-999" "")
    
esttab ncrops_* ///
    using "$csae/inputs-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{\# of crops} \\ ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    append  ///
    substitute("(.)" "     " "0.00" "     " "-999" "")

esttab ag_asset_value_* ///
    using "$csae/inputs-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Value of assets} \\ ///
    ) ///
    append ///
    substitute("(.)" "     " "0.00" "     " "-999" "")



eststo clear

forval i = 4/4 {
foreach depvar in `idx_endline_outputs' {
    {
    reghdfe `depvar' i.treatment `controls' if svyround == `i', absorb(`ffx') vce(cluster vid)
    if r(table)["pvalue", "1.treatment"] == . {
    mata : st_numscalar("e(N)", -999)
    }
    eststo `depvar'_`i'
    test 1.treatment == 2.treatment
    estadd scalar equals = r(p)
    estadd local ffx = "Yes"
    estadd scalar ar2 = e(r2_a)
    forval k = 0/2 {
        sum `depvar' if treatment == `k' & e(sample) == 1
        estadd scalar mean_`k' = r(mean)
    }
    }
}
}


esttab rcropvalharvest_* ///
    using "$csae/outputs-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Endline") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    posthead( ///
    \midrule ///
    \it{Harvest value} \\ ///
    \midrule ///
    ) ///
    replace ///
    substitute("(.)" "     " "0.00" "     " "-999" "")

eststo clear
    
forval i = 4/4 {
foreach depvar in `idx_endline_inputs' {
    {
    reghdfe `depvar' i.treatment `controls' if svyround == `i', absorb(`ffx') vce(cluster vid)
    eststo `depvar'_`i'
    test 1.treatment == 2.treatment
    estadd scalar equals = r(p)
    estadd local ffx = "Yes"
    estadd scalar ar2 = e(r2_a)
    forval k = 0/2 {
        sum `depvar' if treatment == `k' & e(sample) == 1
        estadd scalar mean_`k' = r(mean)
    }
    }
}
}

// nonlabour_endline plot_n30 totalplotsize30

esttab nonlabour_endline_* ///
    using "$csae/inputs-endline-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Endline") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    posthead( ///
    \midrule ///
    \it{Input expenses} \\ ///
    \midrule ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    replace
  
esttab plot_n30_* ///
    using "$csae/inputs-endline-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{\# of plots} \\ ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    append
    
esttab totalplotsize30_* ///
    using "$csae/inputs-endline-index-components.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Total plot size} \\ ///
    ) ///
    append
    
eststo clear

eststo clear

forval i = 1/4 {
foreach depvar in `cohesion_panel' {
    {
    reghdfe `depvar' i.treatment `controls' if svyround == `i', absorb(`ffx') vce(cluster vid)
    eststo `depvar'_`i'
    test 1.treatment == 2.treatment
    estadd scalar equals = r(p)
    estadd local ffx = "Yes"
    estadd scalar ar2 = e(r2_a)
    forval k = 0/2 {
        sum `depvar' if treatment == `k' & e(sample) == 1
        estadd scalar mean_`k' = r(mean)
    }
    }
}
}
   
foreach depvar in `cohesion_panel' {
reghdfe `depvar' i.treatment##i.svyround `controls' if svyround < 3, absorb(strat_pmt strat_vill_size) vce(cluster vid)
eststo nested_`depvar'

test (2.svyround = 0)
estadd scalar fpval0 = r(p)

test (1.treatment = 1.treatment + 2.svyround + 1.treatment#2.svyround)
estadd scalar fpval1 = r(p)

test (2.treatment = 2.treatment + 2.svyround + 2.treatment#2.svyround)
estadd scalar fpval2 = r(p)

test 1.treatment + (1.treatment + 1.treatment#2.svyround) = 0
estadd scalar int1 = r(p)
scalar int1 = r(p)

test 2.treatment + (2.treatment + 2.treatment#2.svyround) = 0
estadd scalar int2 = r(p)
scalar int2 = r(p)

matrix b = (int1, int2)
mat colnames b = 1.treatment 2.treatment
ereturn post b
*eststo `depvar'_int												// Phyllisa may 1st 2025 commenting this based on ashley comment no need of col 5 prelean +lean = 0 test
}
    
esttab vperception_* ///
    using "$csae/cohesion-panel.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline" ) ///		// Phyllisa may 1st 2025 removing "\shortstack{Pre-lean + Lean \\ = 0}"col 5 not needed
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    posthead( ///
    \midrule ///
    \it{Perception of violence index} \\ ///
    \midrule ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    replace
  
esttab socialcohesion_* ///
    using "$csae/cohesion-panel.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Social cohesion} \\ ///
    ) ///
    append

/*
esttab nested_vperception ///
using "$csae/nested-vperception.tex", ///
keep(1.treatment 2.treatment ///
2.svyround ///
1.treatment#2.svyround ///
2.treatment#2.svyround ///
) ///
cells( ///
"b(pattern() fmt(%12.2f) star pvalue(p))" ///
"se(pattern() fmt(%12.2f) par)" ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
mtitle("Perceptions of violence index") ///
nonumbers ///
collabels(none) ///
stats(fpval0 fpval1 fpval2 N, labels() fmt(2 2 2 0)) ///
booktab ///
replace

esttab nested_socialcohesion ///
using "$csae/nested-cohesion.tex", ///
keep(1.treatment 2.treatment ///
2.svyround ///
1.treatment#2.svyround ///
2.treatment#2.svyround ///
) ///
cells( ///
"b(pattern() fmt(%12.2f) star pvalue(p))" ///
"se(pattern() fmt(%12.2f) par)" ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
mtitle("Social cohesion") ///
nonumbers ///
collabels(none) ///
stats(fpval0 fpval1 fpval2 N, labels() fmt(2 2 2 0)) ///
booktab ///
replace
*/

eststo clear

forval i = 1/4 {
foreach depvar in `loans_panel' `savings_panel' `remittances_panel' {
    {
    reghdfe `depvar' i.treatment `controls' if svyround == `i', absorb(`ffx') vce(cluster vid)
    eststo `depvar'_`i'
    test 1.treatment == 2.treatment
    estadd scalar equals = r(p)
    estadd local ffx = "Yes"
    estadd scalar ar2 = e(r2_a)
    forval k = 0/2 {
        sum `depvar' if treatment == `k' & e(sample) == 1
        estadd scalar mean_`k' = r(mean)
    }
    }
}
}


foreach depvar in `loans_panel' `savings_panel' `remittances_panel' {
reghdfe `depvar' i.treatment##i.svyround `controls' if svyround < 3, absorb(strat_pmt strat_vill_size) vce(cluster vid)
eststo nested_`depvar'

test (2.svyround = 0)
estadd scalar fpval0 = r(p)

test (1.treatment = 1.treatment + 2.svyround + 1.treatment#2.svyround)
estadd scalar fpval1 = r(p)

test (2.treatment = 2.treatment + 2.svyround + 2.treatment#2.svyround)
estadd scalar fpval2 = r(p)

test 1.treatment + (1.treatment + 1.treatment#2.svyround) = 0
estadd scalar int1 = r(p)
scalar int1 = r(p)

test 2.treatment + (2.treatment + 2.treatment#2.svyround) = 0
estadd scalar int2 = r(p)
scalar int2 = r(p)

matrix b = (int1, int2)
mat colnames b = 1.treatment 2.treatment
ereturn post b
*eststo `depvar'_int												// Phyllisa may 1st 2025 commenting this based on ashley comment no need of col 5 prelean +lean = 0 test
}
/*
* run regressions by treatment arm

foreach depvar in loans_twelve_mo loans_amt saved_binary saved_total {
forval i = 0/2 {
    reghdfe `depvar' i.svyround `controls' if treatment == `i' & svyround < 3, absorb(`subffx') vce(cluster vid)
    eststo arm_`depvar'_`i'
    
    test 2.svyround = 0 = 1.svyround
    estadd scalar veq = r(p)
    scalar sv_`depvar'_`i' = r(p)
    
//     test 1.svyround + 2.svyround = 0
//     estadd scalar ieq = r(p)
//     test 1.svyround = 2.svyround
//     estadd scalar seq = r(p)
//     test 1.svyround = 2.svyround = 0
//     estadd scalar deq = r(p)
}
}

foreach depvar in loans_twelve_mo loans_amt saved_binary saved_total {
    regress hhid
    eststo `depvar'_empty
    estadd local N = "", replace
    estadd scalar mean_0 = sv_`depvar'_0
    estadd scalar mean_1 = sv_`depvar'_1
    estadd scalar mean_2 = sv_`depvar'_2
}
*/
esttab loans_twelve_mo_* ///
    using "$csae/loans-panel.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline") /// 				// Phyllisa may 1st 2025 removing "\shortstack{Pre-lean + Lean \\ = 0}"col 5 not needed
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 mean_1 mean_2 N, ///
    labels("Early short = Early long" "Trad. response mean" "Early short mean" "Early long mean" "Observations") fmt(2 2 2 2 0)) ///
    posthead( ///
    \midrule ///
    \it{Borrowed (0, 1)} \\ ///
    \midrule ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    replace
    
esttab loans_amt_* ///
    using "$csae/loans-panel.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 mean_1 mean_2 N, ///
    labels("Early short = Early long" "Trad. response mean" "Early short mean" "Early long mean" "Observations") fmt(2 2 2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Amount borrowed} \\ ///
    ) ///
    append
    
esttab saved_binary_* ///
    using "$csae/savings-panel.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline") ///							// Phyllisa may 1st 2025 removing "\shortstack{Pre-lean + Lean \\ = 0}"col 5 not needed
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 mean_1 mean_2 N, ///
    labels("Early short = Early long" "Trad. response mean" "Early short mean" "Early long mean" "Observations") fmt(2 2 2 2 0)) ///
    posthead( ///
    \midrule ///
    \it{Saved (0, 1)} \\ ///
    \midrule ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    replace
    
esttab saved_total_* ///
    using "$csae/savings-panel.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 mean_1 mean_2 N, ///
    labels("Early short = Early long" "Trad. response mean" "Early short mean" "Early long mean" "Observations") fmt(2 2 2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Amount saved} \\ ///
    ) ///
    append     

esttab trans_rec_* ///
    using "$csae/remittances-panel.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline") ///							// Phyllisa may 1st 2025 removing "\shortstack{Pre-lean + Lean \\ = 0}"col 5 not needed
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    posthead( ///
    \midrule ///
    \it{Received remittance?} \\ ///
    \midrule ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    replace
    
esttab remittance_amt_* ///
    using "$csae/remittances-panel.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 N, ///
    labels("Early short = Early long" "Trad. response mean" "Observations") fmt(2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Remittance amount} \\ ///
    ) ///
    append
/*
esttab nested_loans_twelve_mo ///
using "$csae/nested-loans.tex", ///
keep(1.treatment 2.treatment ///
2.svyround ///
1.treatment#2.svyround ///
2.treatment#2.svyround ///
) ///
cells( ///
"b(pattern() fmt(%12.2f) star pvalue(p))" ///
"se(pattern() fmt(%12.2f) par)" ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
mtitle("Borrowed (0, 1)") ///
nonumbers ///
collabels(none) ///
stats(fpval0 fpval1 fpval2 N, labels() fmt(2 2 2 0)) ///
booktab ///
replace

esttab nested_loans_amt ///
using "$csae/nested-loans-amt.tex", ///
keep(1.treatment 2.treatment ///
2.svyround ///
1.treatment#2.svyround ///
2.treatment#2.svyround ///
) ///
cells( ///
"b(pattern() fmt(%12.2f) star pvalue(p))" ///
"se(pattern() fmt(%12.2f) par)" ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
mtitle("Amount borrowed") ///
nonumbers ///
collabels(none) ///
stats(fpval0 fpval1 fpval2 N, labels() fmt(2 2 2 0)) ///
booktab ///
replace

esttab nested_saved_binary ///
using "$csae/nested-saved.tex", ///
keep(1.treatment 2.treatment ///
2.svyround ///
1.treatment#2.svyround ///
2.treatment#2.svyround ///
) ///
cells( ///
"b(pattern() fmt(%12.2f) star pvalue(p))" ///
"se(pattern() fmt(%12.2f) par)" ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
mtitle("Saved (0, 1)") ///
nonumbers ///
collabels(none) ///
stats(fpval0 fpval1 fpval2 N, labels() fmt(2 2 2 0)) ///
booktab ///
replace

esttab nested_saved_total ///
using "$csae/nested-saved-amt.tex", ///
keep(1.treatment 2.treatment ///
2.svyround ///
1.treatment#2.svyround ///
2.treatment#2.svyround ///
) ///
cells( ///
"b(pattern() fmt(%12.2f) star pvalue(p))" ///
"se(pattern() fmt(%12.2f) par)" ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
mtitle("Amount saved") ///
nonumbers ///
collabels(none) ///
stats(fpval0 fpval1 fpval2 N, labels() fmt(2 2 2 0)) ///
booktab ///
replace

esttab nested_trans_rec ///
using "$csae/nested-remittance.tex", ///
keep(1.treatment 2.treatment ///
2.svyround ///
1.treatment#2.svyround ///
2.treatment#2.svyround ///
) ///
cells( ///
"b(pattern() fmt(%12.2f) star pvalue(p))" ///
"se(pattern() fmt(%12.2f) par)" ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
mtitle("Received remittance?") ///
nonumbers ///
collabels(none) ///
stats(fpval0 fpval1 fpval2 N, labels() fmt(2 2 2 0)) ///
booktab ///
replace

esttab nested_remittance_amt ///
using "$csae/nested-remittance-amt.tex", ///
keep(1.treatment 2.treatment ///
2.svyround ///
1.treatment#2.svyround ///
2.treatment#2.svyround ///
) ///
cells( ///
"b(pattern() fmt(%12.2f) star pvalue(p))" ///
"se(pattern() fmt(%12.2f) par)" ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
mtitle("Remittance amount") ///
nonumbers ///
collabels(none) ///
stats(fpval0 fpval1 fpval2 N, labels() fmt(2 2 2 0)) ///
booktab ///
replace
*/

