clear

set scheme s1mono
local earlyshort blue%75
local earlylong green%75

use "${endline_final}/niger-csae-coefs.dta"

destring coefficient, replace
drop if se == 0
drop if coefficient == 0

compress
count
local original = r(N)

set obs 38
replace depvar = "idx_endline_inputs" if missing(depvar)
replace round = 1 if missing(round)
sort depvar round, stable
by depvar round: replace coefficient = _n if missing(coefficient)

set obs 40
replace depvar = "idx_endline_inputs" if missing(depvar)
replace round = 2 if missing(round)
sort depvar round, stable
by depvar round: replace coefficient = _n if missing(coefficient)

set obs 42
replace depvar = "idx_endline_inputs" if missing(depvar)
replace round = 3 if missing(round)
sort depvar round, stable
by depvar round: replace coefficient = _n if missing(coefficient)

set obs 44
replace depvar = "idx_endline_outputs" if missing(depvar)
replace round = 1 if missing(round)
sort depvar round, stable
by depvar round: replace coefficient = _n if missing(coefficient)

set obs 46
replace depvar = "idx_endline_outputs" if missing(depvar)
replace round = 2 if missing(round)
sort depvar round, stable
by depvar round: replace coefficient = _n if missing(coefficient)

set obs 48
replace depvar = "idx_endline_outputs" if missing(depvar)
replace round = 3 if missing(round)
sort depvar round, stable
by depvar round: replace coefficient = _n if missing(coefficient)

tempfile base
save "`base'"

clear
use "`base'"

gen lorder = 6 if depvar == "idx_business"
replace lorder = 5 if depvar == "idx_wage"
replace lorder = 4 if depvar == "idx_livestock"
replace lorder = 3 if depvar == "idx_inputs"
replace lorder = 2 if depvar == "idx_endline_inputs"
replace lorder = 1 if depvar == "idx_endline_outputs"

sort lorder depvar round, stable

gen upper = b + 1.96*se
gen lower = b - 1.96*se

replace round = -round
replace coefficient = -coefficient
sort lorder round coefficient, stable

gen counter = _n

sum lorder

forval i = 1/`r(max)' {
    local j = `i' - 1
    replace counter = counter + (3 * `j') if lorder == `i'
}

// replace counter = counter + 3 if lorder == 2
// replace counter = counter + 6 if lorder == 3
// replace counter = counter + 9 if lorder == 4

replace round = -round
replace coefficient = -coefficient
gen hcounter = counter
replace counter = -counter
sort counter, stable
order depvar coefficient round b se lower upper

drop hcounter
sort round counter, stable
by round: gen hcounter = _n
replace hcounter = 15 - hcounter

replace hcounter = hcounter + 0.25 if coefficient == 2
replace hcounter = hcounter - 0.25 if coefficient == 1

drop if inlist(depvar, "idx_endline_outputs", "idx_endline_inputs") & round < 4

forval rno = 1/3 {

twoway ///
    (rspike upper lower hcounter if coefficient == 1 & round == `rno', lcolor(`earlyshort') horizontal) ///
    (rspike upper lower hcounter if coefficient == 2 & round == `rno', lcolor(`earlylong') horizontal) ///
    ///
    (scatter hcounter b if coefficient == 1 & round == `rno', msymbol(O) msize(small) mcolor(`earlyshort')) ///
    (scatter hcounter b if coefficient == 2 & round == `rno', msymbol(O) msize(small) mcolor(`earlylong')) ///
     , ///
    ytitle("", size(small)) ///
    yscale() ///
    xlab(-0.200(0.1)0.2600, angle(0) labsize(small)) ///
    xtitle("Treatment effect on standardised indices, relative to traditional response", size(small)) ///
    plotr(margin(3 3 3 3)) ///
    xline(0, lcolor(gs3) lwidth(thin)) ///
    xsize(6) ysize(4) ///
    legend(size(small) ///
    label(1 "") ///
    label(2 "") ///
    label(3 "Early short") ///
    label(4 "Early long") ///
    order(3 4) colfirst symx(3) rowg(1) colg() ///
    region(lstyle(none) fcolor(none)) position(5) ring(0) cols(1) ///
    keygap(4) ///
    ) ///
    ylab( ///
    13.5 "Business index" ///
    11.5 "Wage index" ///
    9.5 "Livestock index" ///
    7.5 "Ag inputs index" ///
    , angle(0) labsize(small) notick ///
    ) 
    
    graph export "$csae/indices-plot-`rno'.pdf", replace
    
    }

forval rno = 4/4 {

twoway ///
    (rspike upper lower hcounter if coefficient == 1 & round == `rno', lcolor(`earlyshort') horizontal) ///
    (rspike upper lower hcounter if coefficient == 2 & round == `rno', lcolor(`earlylong') horizontal) ///
    ///
    (scatter hcounter b if coefficient == 1 & round == `rno', msymbol(O) msize(small) mcolor(`earlyshort')) ///
    (scatter hcounter b if coefficient == 2 & round == `rno', msymbol(O) msize(small) mcolor(`earlylong')) ///
     , ///
    ytitle("", size(small)) ///
    yscale() ///
    xlab(-0.200(0.1)0.2600, angle(0) labsize(small)) ///
    xtitle("Treatment effect on standardised indices, relative to traditional response", size(small)) ///
    plotr(margin(3 3 3 3)) ///
    xline(0, lcolor(gs3) lwidth(thin)) ///
    xsize(6) ysize(4) ///
    legend(size(small) ///
    label(1 "") ///
    label(2 "") ///
    label(3 "Early short") ///
    label(4 "Early long") ///
    order(3 4) colfirst symx(3) rowg(1) colg() ///
    region(lstyle(none) fcolor(none)) position(5) ring(0) cols(1) ///
    keygap(4) ///
    ) ///
    ylab( ///
    13.5 "Business index" ///
    11.5 "Wage index" ///
    9.5 "Livestock index" ///
    7.5 "Ag inputs index" ///
    5.5 "Ag inputs index (endline)" ///
    3.5 "Ag outputs index" ///
    , angle(0) labsize(small) notick ///
    ) 
    
    graph export "$csae/indices-plot-`rno'.pdf", replace
    
    }
