clear
use "$panel/ready.dta"

gen tmpvar = proxycon_mt
replace tmpvar = proxycon_mt_compare if svyround == 2 | svyround == 4
label variable tmpvar "\makecell{Food \\ consumption}"

order proxy_*
rename proxy_* *
rename *_win_mt *

local components ///
mais ///
mil ///
riz ///
sorgho ///
pates ///
mouton ///
sel ///
sucre ///
huile_palme ///
huile_arachide ///
noix ///
haricots


local binaries ""

sum `components'


foreach var in `components' {
    quietly {
    clonevar dum_`var' = `var'
    replace dum_`var' = 1 if !missing(`var') // note
    replace dum_`var' = 0 if missing(`var') // note
    local binaries "`binaries' dum_`var'"
    replace `var' = 0 if missing(`var') // note        
    }
}


eststo clear
/*
forval z = 1/4 {
    
    foreach var in `binaries' {
    reghdfe `var' i.treatment if svyround == `z', absorb(strat_pmt strat_vill_size cohort) vce(cluster vid)
    eststo `var'_`z'
    sum `var' if treatment == 0 & e(sample) == 1
    estadd scalar depmean = r(mean)
}

}

forval z = 1/4 {

esttab *_`z' ///
    using "$csae/fcons-comp-binaries-`z'.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    order(`binaries') ///
    booktabs ///
    stats(depmean N, labels("Trad. response mean" "Observations") fmt(2 0)) ///
    replace
}
*/
eststo clear

forval z = 1/4 {
    
    foreach var in `components' {
    reghdfe `var' i.treatment if svyround == `z', absorb(strat_pmt strat_vill_size cohort) vce(cluster vid)
    eststo `var'_`z'
    sum `var' if treatment == 0 & e(sample) == 1
    estadd scalar depmean = r(mean)
}

}

forval z = 1/4 {

esttab *_`z' ///
    using "$csae/fcons-comp-`z'.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    order(`components') ///
    booktabs ///
    stats(depmean N, labels("Trad. response mean" "Observations") fmt(2 0)) ///
    replace
}

eststo clear

local binaries ""
local components div_cereal div_pulse div_veg div_fruit div_meat div_milk div_oil div_sugar

sum div_cereal div_pulse div_veg div_fruit div_meat div_milk div_oil div_sugar

foreach var in `components' {
    clonevar dum_`var' = `var'
    replace dum_`var' = 1 if `var' > 0 & !missing(`var')
    replace dum_`var' = 0 if `var' == 0
    local binaries "`binaries' dum_`var'"
}

eststo clear
/*
forval z = 1/4 {
    
    foreach var in `binaries' {
    reghdfe `var' i.treatment if svyround == `z', absorb(strat_pmt strat_vill_size cohort) vce(cluster village)
    eststo `var'_`z'
    sum `var' if treatment == 0 & e(sample) == 1
    estadd scalar depmean = r(mean)
}

}

forval z = 1/4 {

esttab *_`z' ///
    using "$csae/fcs-comp-binaries-`z'.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(depmean N, labels("Trad. response mean" "Observations") fmt(2 0)) ///
    replace
}
*/
eststo clear

forval z = 1/4 {
    
    foreach var in `components' {
    reghdfe `var' i.treatment if svyround == `z', absorb(strat_pmt strat_vill_size cohort) vce(cluster village)
    eststo `var'_`z'
    sum `var' if treatment == 0 & e(sample) == 1
    estadd scalar depmean = r(mean)
}

}

forval z = 1/4 {

esttab *_`z' ///
    using "$csae/fcs-comp-`z'.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(depmean N, labels("Trad. response mean" "Observations") fmt(2 0)) ///
    replace
}

drop `binaries'

eststo clear

local primary fcs tmpvar cantril

foreach depvar in `primary' {
forval i = 1/12 {
    reghdfe `depvar' i.treatment i.surveyed_twice if roundcohort == `i', absorb(strat_pmt strat_vill_size) vce(cluster vid)
    eststo `depvar'`i'
forval k = 0/2 {
        quietly sum `depvar' if treatment == `k' & e(sample) == 1
        quietly estadd scalar mean_`k' = r(mean)
    }
}
}

esttab fcs* ///
    using "$csae/fcs-cohortwise.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(mean_0 N, labels("Trad. response mean" "Observations") fmt(2 0)) ///
    replace ///
    mgroups(Pre-lean Lean Post-lean Endline, pattern(1 0 0 0 1 0 0 1 0 0 0 1) ///
    prefix(\multicolumn{@span}{c}{) suffix(})   ///
    span erepeat(\cmidrule(lr){@span}))
    
    
 esttab tmpvar* ///
    using "$csae/fcons-cohortwise.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(mean_0 N, labels("Trad. response mean" "Observations") fmt(2 0)) ///
    replace ///
    mgroups(Pre-lean Lean Post-lean Endline, pattern(1 0 0 0 1 0 0 1 0 0 0 1) ///
    prefix(\multicolumn{@span}{c}{) suffix(})   ///
    span erepeat(\cmidrule(lr){@span}))   
    
    
 esttab cantril* ///
    using "$csae/cantril-cohortwise.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(mean_0 N, labels("Trad. response mean" "Observations") fmt(2 0)) ///
    replace ///
    mgroups(Pre-lean Lean Post-lean Endline, pattern(1 0 0 0 1 0 0 1 0 0 0 1) ///
    prefix(\multicolumn{@span}{c}{) suffix(})   ///
    span erepeat(\cmidrule(lr){@span}))      
