
clear
eststo clear
use "$baseline_final/baseline_niger_outcomes.dta"

gen food_monthly = food_1_week_xof * 4
label variable food_monthly "Monthly food consumption"

gen nonfood_monthly = nonfood_day_xof * 30
label variable nonfood_monthly "Monthly non-food consumption"

replace tot_hh_rev12 = tot_hh_rev12 * 1000 // 
replace tot_harvest_xof_98 = tot_harvest_xof_98 * 1000

*replace loan_xof = loan_xof * 1000													// phyllisa April 29 2025 commenting this because need to show in same units as table B30

assert !missing(fcs)																		// phyllisa April 29 2025
gen fcs_less21 = (fcs<21)																	// phyllisa April 29 2025
label variable fcs_less21	"Food Consumption Score less than 21"							// phyllisa April 29 2025

gen tot_consumption = food_monthly + nonfood_monthly										// phyllisa April 29 2025
label variable tot_consumption "Total monthly consumption (food and non-food)"				// phyllisa April 29 2025

gen tot_consumption_percap = tot_consumption/adult_n										// phyllisa April 29 2025
label variable tot_consumption_percap "Total monthly per capita consumption (adult equiv)"  // phyllisa April 29 2025

label variable accesstofunds "Confident of raising 40000 FCFA" // actually different amount // phyllisa April 29 2025
label values accesstofunds 																	// phyllisa April 29 2025

recode accesstofunds (1 = 1) (2 = 1) (3 = 0) (4 = 0)										// phyllisa April 29 2025
label define accesstofunds 0 "Not likely" 1 "Likely", replace								// phyllisa April 29 2025

label variable mem_n "Household size"
label variable hhh_fem "Female Head of Household (HHH)"
label variable poly "Polygamous HHH"
label variable hhh_prim "HHH completed primary school"
label variable fcs "Food Consumption Score"
label variable fies_rvrs_raw "Food Security"
label variable bus2_dum "Business in past 12 months"
label variable act_n "Number of businesses"
label variable tot_hh_rev12 "Annual business revenues"
label variable ag_any "Cultivated land in past 12 months"
label variable ag_plot_ha "Area cultivated (in ha)"
label variable ani_hh_dum "Currently owns livestock"
label variable tot_ani_count_tlu "Number of livestock"
label variable saving_d "Has savings"
label variable saving_xof "Total savings"
label variable loan_d "Took loan in past 12 months"
label variable food_1_day_eq_xof "Daily food consumption"
label variable nonfood_day_eq_xof "Daily non-food consumption"
label variable loan_xof "Outstanding loans"
label variable shock1 "Drought in past 12 months"
label variable hh_ass_index "Household assets index"
label variable mentalhealth "Mental health index"


// phyllisa April 29 2025- removes fies_rvrs_raw, adding fcs_less21, tot_consumption, tot_consumption_percap, loan_xof, accesstofunds
local subset mem_n hhh_fem poly hhh_prim food_monthly nonfood_monthly tot_consumption tot_consumption_percap fcs /*fies_rvrs_raw*/ fcs_less21 cantril mentalhealth hh_ass_index ag_any ag_plot_ha ag_input_index ani_hh_dum tot_ani_count_tlu bus2_dum act_n tot_hh_rev12 empl_d12_chef saving_d saving_xof loan_d aloan_xof loan_xof accesstofunds shock1 	


forval k = 1/1 {

estpost sum `subset'
eststo samplen

estpost sum `subset'
eststo full

estpost sum `subset' if treatment == 0
eststo t0

estpost sum `subset' if treatment == 1
eststo t1

estpost sum `subset' if treatment == 2
eststo t2

foreach var in `subset' {
    *** run/modify regression and save result ***
    reghdfe `var' i.treatment, absorb() vce(cluster village)
    eststo `var'
    test (0.treatment = 1.treatment) (1.treatment = 2.treatment)
    local fpval : di  %8.2f `r(p)'
    quietly estadd scalar fpval = `fpval'
    
    * save control mean
    quietly sum `var' if treatment == 0 & e(sample) == 1
    local size : di  %8.2f `r(mean)'
    quietly estadd local depmean = "`size'"
    
    local displaylab : variable label `var'
    di "`displaylab'"
    }

* report each model by row, not column
esttab `subset', se nostar keep(1.treatment) stats(fpval)

matrix C = r(coefs)
matrix fpval = r(stats)

mat list C
mat list fpval

local rnames : rownames C
local equations : coleq C

local equations : list uniq equations

local i 0
foreach name of local rnames {
    local ++i
    local j 0
    capture matrix drop b
    capture matrix drop se
        foreach model of local equations {
            local ++j
            matrix tmp = C[`i', 2*`j'-1]
                if tmp[1, 1] < . {
                    matrix colnames tmp = `model'
                    matrix b = nullmat(b), tmp
                    matrix tmp[1, 1] = C[`i', 2*`j']
                    matrix se = nullmat(se), tmp
    }
}
* save results
ereturn post b
estadd matrix se
estadd matrix fpval
eststo model
}

esttab full t0 t1 t2 model ///
using "$csae/baseline-balance.tex", ///
cells( ///
"mean(pattern(1 1 1 1 0) fmt(2)) fpval(pattern(0 0 0 0 1) fmt(2))" ///
) ///
mtitle( ///
"Full" ///
"Trad. response" ///
"Early short" ///
"Early long" ///
"p-val" ///
) ///
collabels(none) ///
label ///
keep() ///
order(`subset') ///
booktabs ///
noobs numbers ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
replace

eststo clear

}

clear
use "${baseline_intermediate}/finance"

estpost sum saving_xof saving_d saving_inf_xof saving_for_xof saved_bank loan_d loan_inf loan_for aloan_xof loan_xof gross_saving accesstofunds
eststo finbase

esttab finbase ///
using "$csae/financial-behaviours-baseline.tex", ///
cells( ///
"mean(pattern(1) fmt(2)) sd(pattern(1) fmt(2)) min(pattern(1) fmt(2)) max(pattern(1) fmt(2)) count(pattern(1) fmt(0))" ///
) ///
nomtitle nonumbers ///
collabels("Mean" "SD" "Min" "Max" "N") ///
label ///
keep() ///
order() ///
booktabs ///
noobs ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
replace

