* edited phyll 2025 to change orderof bars first bar to trad response
clear

use "${community_raw}/community_analysis_panel_final.dta"

gen year = 2022 if round == "baseline"
replace year = 2022 if inlist(round, "HF1_cohorte1", "HF1_cohorte2", "HF1_cohorte3", "HF1_cohorte4")
replace year = 2022 if inlist(round, "Midline_cohorte1", "Midline_cohorte2", "Midline_cohorte3")
replace year = 2022 if inlist(round, "HF2_cohorte1", "HF2_cohorte2", "HF2_cohorte3", "HF2_cohorte4")
replace year = 2023 if year == 2022 & month == "January"
replace year = 2023 if inlist(round, "endline")
replace month = "June" if month == "June23"

gen monthnum = month(date(month, "M"))
drop month

rename monthnum month

* note control group
label values treatment .
recode treatment (0 = 2) (2 = 0) (1 = 1)
label define treatment 0 "Traditional response" 1 "Early short" 2 "Early long", replace
label values treatment treatment

keep prixkg_* treatment year month round

keep round treatment prixkg_1_clean prixkg_2_clean prixkg_3_clean prixkg_4_clean year month

sort treatment year month, stable
order treatment year month

local i = 1

foreach crop in maize millet sorghum rice {
    by treatment year month: egen `crop' = mean(prixkg_`i'_clean)
    by treatment year month: egen `crop'sd = sd(prixkg_`i'_clean)
    by treatment year month: egen `crop'n = count(prixkg_`i'_clean)
    gen `crop'se = `crop'sd/sqrt(`crop'n)
    gen `crop'upper = `crop' + 1.96*`crop'se
    gen `crop'lower = `crop' - 1.96*`crop'se
    local ++i
}

drop prix*

egen tag = tag(treatment year month)
keep if tag == 1
drop tag

label define label_mon 1 "Jan" 2 "Feb" 3 "Mar" 4  "Apr" 5 "May" 6 "Jun" 7 "Jul" 8 "Aug" 9 "Sep" 10 "Oct" 11 "Nov" 12 "Dec"
label values month label_mon

gen yearmonth = ym(year, month)
order treatment year month yearmonth
sort treatment year month, stable
replace yearmonth = yearmonth - 743
replace yearmonth = yearmonth - 4 if yearmonth == 18

label define yearmonth 2 "Feb" 3 "Mar" 4  "Apr" 5 "May" 6 "Jun" 7 "Jul" 8 "Aug" 9 "Sep" 10 "Oct" 11 "Nov" 12 "Dec" 13 "Jan" 14 "Jun 23", replace
label values yearmonth yearmonth

gen monthr = yearmonth + 0.2
gen monthl = yearmonth - 0.2
set scheme s1mono

twoway ///
(bar maize yearmonth if treatment == 1, barw(0.2) color(blue%75)) ///
(bar maize monthl if treatment == 0, barw(0.2) color(gs10)) ///
(bar maize monthr if treatment == 2, barw(0.2) color(green%75)) ///
(rcap maizeupper maizelower yearmonth if treatment == 1, lcolor(gs2)) ///
(rcap maizeupper maizelower monthl if treatment == 0, lcolor(gs2)) ///
(rcap maizeupper maizelower monthr if treatment == 2, lcolor(gs2)) ///
, ///
ytitle("Price per kg (CFA)", size(medsmall)) ///
ylabel(200(50)400, angle(0) labsize(medsmall)) ///
xtitle("", size(medsmall)) ///
xlabel(2/14, valuelabel angle(0) labsize(medsmall)) /// 
plotr(margin(2 2 2 2)) ///
xsize(5) ysize(3) ///
legend(size(small) label(1 "Early short") label(3 "Early long") label(2 "Trad. response") ///
symx(7) order(2 1 3) region(lstyle(none)) margin(zero) position(2) ring(0) rows(3))


graph export "$csae/maize-price.pdf", replace


twoway ///
(bar millet yearmonth if treatment == 1, barw(0.2) color(blue%75)) ///
(bar millet monthl if treatment == 0, barw(0.2) color(gs10)) ///
(bar millet monthr if treatment == 2, barw(0.2) color(green%75)) ////
(rcap milletupper milletlower yearmonth if treatment == 1, lcolor(gs2)) ///
(rcap milletupper milletlower monthl if treatment == 0, lcolor(gs2)) ///
(rcap milletupper milletlower monthr if treatment == 2, lcolor(gs2)) ///
, ///
ytitle("Price per kg (CFA)", size(medsmall)) ///
ylabel(200(50)400, angle(0) labsize(medsmall)) ///
xtitle("", size(medsmall)) ///
xlabel(2/14, valuelabel angle(0) labsize(medsmall)) /// 
plotr(margin(2 2 2 2)) ///
xsize(5) ysize(3) ///
legend(size(small) label(1 "Early short") label(3 "Early long") label(2 "Trad. response") ///
symx(7) order(2 1 3) region(lstyle(none)) margin(zero) position(2) ring(0) rows(3))

graph export "$csae/millet-price.pdf", replace


twoway ///
(bar rice yearmonth if treatment == 1, barw(0.2) color(blue%75)) ///
(bar rice monthl if treatment == 0, barw(0.2) color(gs10)) ///
(bar rice monthr if treatment == 2, barw(0.2) color(green%75)) ////
(rcap riceupper ricelower yearmonth if treatment == 1, lcolor(gs2)) ///
(rcap riceupper ricelower monthl if treatment == 0, lcolor(gs2)) ///
(rcap riceupper ricelower monthr if treatment == 2, lcolor(gs2)) ///
, ///
ytitle("Price per kg (CFA)", size(medsmall)) ///
ylabel(400(50)525, angle(0) labsize(medsmall)) ///
xtitle("", size(medsmall)) ///
xlabel(2/14, valuelabel angle(0) labsize(medsmall)) /// 
plotr(margin(2 2 2 2)) ///
xsize(5) ysize(3) ///
legend(size(small) label(1 "Early short") label(3 "Early long") label(2 "Trad. response") ///
symx(7) order(2 1 3) region(lstyle(none)) margin(zero) position(2) ring(0) rows(3))

graph export "$csae/rice-price.pdf", replace
