log close _all
log using "mysession.smcl", replace

* endline results but with smoothing test across three rounds, instead of two, and with household fixed effects

* fdr adjustment within survey round *

eststo clear
clear

use "$panel/ready.dta"

local ffx strat_pmt strat_vill_size roundcohort
local subffx strat_pmt strat_vill_size
local controls i.surveyed_twice

gen tmpvar = proxycon_mt
replace tmpvar = proxycon_mt_compare if svyround == 2 | svyround == 4
label variable tmpvar "\makecell{Food \\ consumption}"

local primary_panel fcs tmpvar
local mentalhealth_panel stair_satis_today mentalhealth vperception socialcohesion

capture rename saved_binary_ saved_binary

local finance_panel loans_twelve_mo loans_amt saved_binary saved_total remittance_amt risk_sharing

capture rename trans_fam trans_rec

local remittances_panel trans_rec remittance_amt trans_fam_send remittance_sent_amt risk_sharing

local bus_panel nbusiness bus_asset_value bus_profit

local wage_panel non_agri_emp_binary non_agri_wages

local agri_panel hasplots30 crop_seed30 agri_wages livestock_tlu
// local agri_panel livestock_tlu agri_emp_binary 
// tlu index livestock count TLU livestock_tlu

forval i = 1/4 {
    mat def pvalue_index_`i' = J(6, 4, .)
    local counter_index 1
    foreach depvar in fcs tmpvar cantril {
        {
        reghdfe `depvar' i.treatment `controls' if svyround == `i', absorb(`ffx') vce(cluster vid)
        eststo `depvar'_`i'
        mat def pvalue_index_`i'[`counter_index', 4] = r(table)["pvalue", "1.treatment"]
        local ++counter_index
        mat def pvalue_index_`i'[`counter_index', 4] = r(table)["pvalue", "2.treatment"]
        local ++counter_index
    
        test 1.treatment = 2.treatment
        estadd scalar equals = r(p)
        estadd local ffx = "Yes"
        estadd scalar ar2 = e(r2_a)
    
        forval k = 0/2 {
            sum `depvar' if treatment == `k' & e(sample) == 1
            estadd scalar mean_`k' = r(mean)
            }
            }
            }
            }

di `counter_index'
mat list pvalue_index_1
mat list pvalue_index_2
mat list pvalue_index_3
mat list pvalue_index_4

forval i = 1/4 {
global group "pvalue_index_`i'" // define global which accepts the matrix of pvalues
FDR_LATE // apply false discovery rate adjustment
mat Q`i' = (Qval)'
}

local topnames 1.treatment 2.treatment 1.treatment 2.treatment 1.treatment 2.treatment

forval i = 1/4 {
mat colnames Q`i' = `topnames'    
}

* collect values for first outcome for each round

forval i = 1/4 {
di as error "`i'"
local j = 1
local k = `j' + 1

matrix qval = Q`i'[1, `j'..`k']
mat rownames qval = y1
mat list qval
estadd matrix qval: fcs_`i'

}

* collect values for second outcome for each round

forval i = 1/4 {
local j = 3
local k = `j' + 1

matrix qval = Q`i'[1, `j'..`k']
mat rownames qval = y1
mat list qval
estadd matrix qval: tmpvar_`i'

}

* collect values for third outcome for each round

forval i = 1/4 {
local j = 5
local k = `j' + 1

matrix qval = Q`i'[1, `j'..`k']
mat rownames qval = y1
mat list qval
estadd matrix qval: cantril_`i'

}

reghdfe fcs i.treatment##i.svyround `controls', absorb(`subffx') vce(cluster vid)
eststo nested_fcs

* pre-lean + lean = 0
test 1.treatment + (1.treatment + 1.treatment#2.svyround) = 0
estadd scalar int1 = r(p)
scalar int1 = r(p)

test 2.treatment + (2.treatment + 2.treatment#2.svyround) = 0
estadd scalar int2 = r(p)
scalar int2 = r(p)

* pre-lean = endline
test 1.treatment#4.svyround = 0
estadd scalar wan1 = r(p)
scalar wan1 = r(p)

test 2.treatment#4.svyround = 0
estadd scalar wan2 = r(p)
scalar wan2 = r(p)

matrix b = (int1, int2)
mat colnames b = 1.treatment 2.treatment
ereturn post b
eststo fcs_int

// matrix b = (wan1, wan2)
// mat colnames b = 1.treatment 2.treatment
// ereturn post b
// eststo fcs_wan

quietly reghdfe tmpvar i.treatment##i.svyround `controls', absorb(`subffx') vce(cluster vid)
eststo nested_tmpvar

test 1.treatment + (1.treatment + 1.treatment#2.svyround) = 0
estadd scalar int1 = r(p)
scalar int1 = r(p)

test 2.treatment + (2.treatment + 2.treatment#2.svyround) = 0
estadd scalar int2 = r(p)
scalar int2 = r(p)

test 1.treatment#4.svyround = 0
estadd scalar wan1 = r(p)
scalar wan1 = r(p)

test 2.treatment#4.svyround = 0
estadd scalar wan2 = r(p)
scalar wan2 = r(p)

matrix b = (int1, int2)
mat colnames b = 1.treatment 2.treatment
ereturn post b
eststo tmpvar_int

// matrix b = (wan1, wan2)
// mat colnames b = 1.treatment 2.treatment
// ereturn post b
// eststo tmpvar_wan

quietly reghdfe cantril i.treatment##i.svyround `controls', absorb(`subffx') vce(cluster vid)
eststo nested_cantril

test 1.treatment + (1.treatment + 1.treatment#2.svyround) = 0
estadd scalar int1 = r(p)
scalar int1 = r(p)

test 2.treatment + (2.treatment + 2.treatment#2.svyround) = 0
estadd scalar int2 = r(p)
scalar int2 = r(p)

test 1.treatment#4.svyround = 0
estadd scalar wan1 = r(p)
scalar wan1 = r(p)

test 2.treatment#4.svyround = 0
estadd scalar wan2 = r(p)
scalar wan2 = r(p)

matrix b = (int1, int2)
mat colnames b = 1.treatment 2.treatment
ereturn post b
eststo cantril_int

// matrix b = (wan1, wan2)
// mat colnames b = 1.treatment 2.treatment
// ereturn post b
// eststo cantril_wan

esttab fcs_* ///
    using "$csae/annex-primary-panel.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    "qval(pattern() fmt(%12.2f) par([ ]))" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline" "\shortstack{Pre-lean + Lean \\ = 0}") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 mean_1 mean_2 N, ///
    labels("Early short = Early long" "Trad. response mean" "Early short mean" "Early long mean" "Observations") fmt(2 2 2 2 0)) ///
    posthead( ///
    \midrule ///
    \it{Food Security} \\ ///
    \midrule ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    replace
    
esttab tmpvar_* ///
    using "$csae/annex-primary-panel.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    "qval(pattern() fmt(%12.2f) par([ ]))" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 mean_1 mean_2 N, ///
    labels("Early short = Early long" "Trad. response mean" "Early short mean" "Early long mean" "Observations") fmt(2 2 2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Food Consumption} \\ ///
    ) ///
    append

forval i = 1/4 {
foreach depvar in mentalhealth {
    {
    reghdfe `depvar' i.treatment `controls' if svyround == `i', absorb(`ffx') vce(cluster vid)
    eststo `depvar'_`i'
    test 1.treatment == 2.treatment
    estadd scalar equals = r(p)
    estadd local ffx = "Yes"
    estadd scalar ar2 = e(r2_a)
    forval k = 0/2 {
        sum `depvar' if treatment == `k' & e(sample) == 1
        estadd scalar mean_`k' = r(mean)
    }
    }
}
}


foreach depvar in mentalhealth {
reghdfe `depvar' i.treatment##i.svyround `controls', absorb(strat_pmt strat_vill_size) vce(cluster vid)
eststo nested_`depvar'

test (2.svyround = 0)
estadd scalar fpval0 = r(p)

test (1.treatment = 1.treatment + 2.svyround + 1.treatment#2.svyround)
estadd scalar fpval1 = r(p)

test (2.treatment = 2.treatment + 2.svyround + 2.treatment#2.svyround)
estadd scalar fpval2 = r(p)

test 1.treatment + (1.treatment + 1.treatment#2.svyround) = 0
estadd scalar int1 = r(p)
scalar int1 = r(p)

test 2.treatment + (2.treatment + 2.treatment#2.svyround) = 0
estadd scalar int2 = r(p)
scalar int2 = r(p)

test 1.treatment#4.svyround = 0
estadd scalar wan1 = r(p)
scalar wan1 = r(p)

test 2.treatment#4.svyround = 0
estadd scalar wan2 = r(p)
scalar wan2 = r(p)

matrix b = (int1, int2)
mat colnames b = 1.treatment 2.treatment
ereturn post b
eststo `depvar'_int

// matrix b = (wan1, wan2)
// mat colnames b = 1.treatment 2.treatment
// ereturn post b
// eststo `depvar'_wan

}

esttab cantril_* ///
    using "$csae/annex-mhealth-panel.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline" "\shortstack{Pre-lean + Lean \\ = 0}") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 mean_1 mean_2 N, ///
    labels("Early short = Early long" "Trad. response mean" "Early short mean" "Early long mean" "Observations") fmt(2 2 2 2 0)) ///
    posthead( ///
    \midrule ///
    \it{Life Satisfaction} \\ ///
    \midrule ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    replace
  
esttab mentalhealth_* ///
    using "$csae/annex-mhealth-panel.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 mean_1 mean_2 N, ///
    labels("Early short = Early long" "Trad. response mean" "Early short mean" "Early long mean" "Observations") fmt(2 2 2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Mental health index} \\ ///
    ) ///
    append

eststo clear

* smoothing test run regressions by treatment arm

local xip fcs tmpvar cantril mentalhealth loans_twelve_mo loans_amt saved_binary saved_total

foreach depvar in `xip' {
forval i = 0/2 {
    reghdfe `depvar' i.svyround `controls' if treatment == `i', absorb(hhid) vce(cluster vid)
    eststo arm_`depvar'_`i'
    
    test 2.svyround = 0
    scalar s1_`depvar'_`i' = r(p)
    
    test 2.svyround = 0 = 3.svyround
    scalar s2_`depvar'_`i' = r(p)
    
    test 4.svyround = 0
    scalar s3_`depvar'_`i' = r(p)
    
}
}

forval k = 1/3 {
   foreach depvar in `xip' {
    quietly {
        regress hhid
    eststo `depvar'_empty`k'
    estadd local N = "", replace
    estadd scalar t_0 = s`k'_`depvar'_0
    estadd scalar t_1 = s`k'_`depvar'_1
    estadd scalar t_2 = s`k'_`depvar'_2
}
}
}

eststo drop arm_*
/*	//Phyllisa April 30th 2025 commenting and replacing with updated smoothing test tables
esttab fcs_* ///
using "$csae/annex-smoothing-ate.tex", ///
drop(*) stats(t_0 t_1 t_2, fmt(3) ///
labels("Trad. response" "Early short" "Early long") ///
) ///
cells( ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
mtitle("Pre-lean = Lean" "Pre-lean = Lean = Post-lean" "Pre-lean = Endline") ///
nonumbers ///
collabels(none) ///
booktabs ///
posthead( ///
\midrule ///
\it{Food Security} \\ ///
) ///
postfoot( ///
/// 
) ///
replace

esttab tmpvar_* ///
using "$csae/annex-smoothing-ate.tex", ///
drop(*) stats(t_0 t_1 t_2, fmt(3) ///
labels("Trad. response" "Early short" "Early long") ///
) ///
cells( ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
nomtitle ///
nonumbers ///
collabels(none) ///
booktabs ///
prehead( ///
\midrule ///
\it{Food Consumption} \\ ///
) ///
posthead( ///
) ///
postfoot( ///
/// 
) ///
append

esttab cantril_* ///
using "$csae/annex-smoothing-ate.tex", ///
drop(*) stats(t_0 t_1 t_2, fmt(3) ///
labels("Trad. response" "Early short" "Early long") ///
) ///
cells( ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
nomtitle ///
nonumbers ///
collabels(none) ///
booktabs ///
prehead( ///
\midrule ///
\it{Life Satisfaction} \\ ///
) ///
posthead( ///
) ///
postfoot( ///
/// 
) ///
append

esttab mentalhealth_* ///
using "$csae/annex-smoothing-ate.tex", ///
drop(*) stats(t_0 t_1 t_2, fmt(3) ///
labels("Trad. response" "Early short" "Early long") ///
) ///
cells( ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
nomtitle ///
nonumbers ///
collabels(none) ///
booktabs ///
prehead( ///
\midrule ///
\it{Mental health index} \\ ///
) ///
posthead( ///
) ///
postfoot( ///
/// 
) ///
append

esttab loans_twelve_mo_* ///
using "$csae/annex-smoothing-ate.tex", ///
drop(*) stats(t_0 t_1 t_2, fmt(3) ///
labels("Trad. response" "Early short" "Early long") ///
) ///
cells( ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
nomtitle ///
nonumbers ///
collabels(none) ///
booktabs ///
prehead( ///
\midrule ///
\it{Borrowed (0, 1)} \\ ///
) ///
posthead( ///
) ///
postfoot( ///
/// 
) ///
append

esttab loans_amt_* ///
using "$csae/annex-smoothing-ate.tex", ///
drop(*) stats(t_0 t_1 t_2, fmt(3) ///
labels("Trad. response" "Early short" "Early long") ///
) ///
cells( ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
nomtitle ///
nonumbers ///
collabels(none) ///
booktabs ///
prehead( ///
\midrule ///
\it{Amount borrowed} \\ ///
) ///
posthead( ///
) ///
postfoot( ///
/// 
) ///
append

esttab saved_binary_* ///
using "$csae/annex-smoothing-ate.tex", ///
drop(*) stats(t_0 t_1 t_2, fmt(3) ///
labels("Trad. response" "Early short" "Early long") ///
) ///
cells( ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
nomtitle ///
nonumbers ///
collabels(none) ///
booktabs ///
prehead( ///
\midrule ///
\it{Saved (0, 1)} \\ ///
) ///
posthead( ///
) ///
postfoot( ///
/// 
) ///
append

esttab saved_total_* ///
using "$csae/annex-smoothing-ate.tex", ///
drop(*) stats(t_0 t_1 t_2, fmt(3) ///
labels("Trad. response" "Early short" "Early long") ///
) ///
cells( ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
nomtitle ///
nonumbers ///
collabels(none) ///
booktabs ///
prehead( ///
\midrule ///
\it{Amount saved} \\ ///
) ///
posthead( ///
) ///
append
*/

//phyllisa April 30 2025 new updated smoothing table
esttab fcs_empty1 ///
using "$csae/annex-smoothing-ate.tex", ///
drop(*) stats(t_0 t_1 t_2, fmt(3) ///
labels("Trad. response" "Early short" "Early long") ///
) ///
cells( ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
mtitle("Pre-lean = Lean" "Pre-lean = Lean = Post-lean" "Pre-lean = Endline") ///
nonumbers ///
collabels(none) ///
booktabs ///
posthead( ///
\midrule ///
\it{Food Security} \\ ///
) ///
postfoot( ///
/// 
) ///
replace

esttab tmpvar_empty1 ///
using "$csae/annex-smoothing-ate.tex", ///
drop(*) stats(t_0 t_1 t_2, fmt(3) ///
labels("Trad. response" "Early short" "Early long") ///
) ///
cells( ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
nomtitle ///
nonumbers ///
collabels(none) ///
booktabs ///
prehead( ///
\midrule ///
\it{Food Consumption} \\ ///
) ///
posthead( ///
) ///
postfoot( ///
/// 
) ///
append

esttab cantril_empty1 ///
using "$csae/annex-smoothing-ate.tex", ///
drop(*) stats(t_0 t_1 t_2, fmt(3) ///
labels("Trad. response" "Early short" "Early long") ///
) ///
cells( ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
nomtitle ///
nonumbers ///
collabels(none) ///
booktabs ///
prehead( ///
\midrule ///
\it{Life Satisfaction} \\ ///
) ///
posthead( ///
) ///
postfoot( ///
/// 
) ///
append

esttab mentalhealth_empty1 ///
using "$csae/annex-smoothing-ate.tex", ///
drop(*) stats(t_0 t_1 t_2, fmt(3) ///
labels("Trad. response" "Early short" "Early long") ///
) ///
cells( ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
nomtitle ///
nonumbers ///
collabels(none) ///
booktabs ///
prehead( ///
\midrule ///
\it{Mental health index} \\ ///
) ///
posthead( ///
) ///
append

/*
esttab fcs_empty1 fcs_empty2 fcs_empty3 ///
using "$csae/annex-fcs-smoothing-ate.tex", ///
drop(*) stats(t_0 t_1 t_2, fmt(3) ///
labels("Trad. response" "Early short" "Early long") ///
) ///
cells( ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
mtitle("Pre-lean = Lean" "Pre-lean = Lean = Post-lean" "Pre-lean = Endline") ///
nonumbers ///
collabels(none) ///
booktabs ///
posthead( ///
) ///
replace


esttab tmpvar_empty1 tmpvar_empty2 tmpvar_empty3 ///
using "$csae/annex-fconsumption-smoothing-ate.tex", ///
drop(*) stats(t_0 t_1 t_2, fmt(3) ///
labels("Trad. response" "Early short" "Early long") ///
) ///
cells( ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
mtitle("Pre-lean = Lean" "Pre-lean = Lean = Post-lean" "Pre-lean = Endline") ///
nonumbers ///
collabels(none) ///
booktabs ///
posthead( ///
) ///
replace

esttab cantril_empty1 cantril_empty2 cantril_empty3 ///
using "$csae/annex-cantril-smoothing-ate.tex", ///
drop(*) stats(t_0 t_1 t_2, fmt(3) ///
labels("Trad. response" "Early short" "Early long") ///
) ///
cells( ///
) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
label ///
mtitle("Pre-lean = Lean" "Pre-lean = Lean = Post-lean" "Pre-lean = Endline") ///
nonumbers ///
collabels(none) ///
booktabs ///
posthead( ///
) ///
replace
*/

eststo clear

gen prevend = 1 if svyround == 4
replace prevend = 0 if svyround == 1


gen fcstrad = fcs if treatment == 0
label variable fcstrad "Trad. response"
gen fcsearly = fcs if treatment == 1
label variable fcsearly "Early short"
gen fcslate = fcs if treatment == 2
label variable fcslate "Late short"

estpost ttest fcstrad fcsearly fcslate, by(prevend)
eststo fcs

esttab fcs ///
using "$csae/annex-fcs-pre-lean-v-endline.tex", ///
cells("p(fmt(3))") label mtitle("Pre-lean = Endline") ///
noobs booktabs collabels(none) ///
replace


gen fconstrad = tmpvar if treatment == 0
label variable fconstrad "Trad. response"
gen fconsearly = tmpvar if treatment == 1
label variable fconsearly "Early short"
gen fconslate = tmpvar if treatment == 2
label variable fconslate "Late short"

estpost ttest fconstrad fconsearly fconslate, by(prevend)
eststo fcons

esttab fcons ///
using "$csae/annex-fcons-pre-lean-v-endline.tex", ///
cells("p(fmt(3))") label mtitle("Pre-lean = Endline") ///
noobs booktabs collabels(none) ///
replace



gen cantriltrad = cantril if treatment == 0
label variable cantriltrad "Trad. response"
gen cantrilearly = cantril if treatment == 1
label variable cantrilearly "Early short"
gen cantrillate = cantril if treatment == 2
label variable cantrillate "Late short"

estpost ttest cantriltrad cantrilearly cantrillate, by(prevend)
eststo cantril

esttab cantril ///
using "$csae/annex-cantril-pre-lean-v-endline.tex", ///
cells("p(fmt(3))") label mtitle("Pre-lean = Endline") ///
noobs booktabs collabels(none) ///
replace


eststo clear
clear
use "$panel/ready.dta"

local ffx strat_pmt strat_vill_size cohort
local controls surveyed_twice

gen tmpvar = proxycon_mt
replace tmpvar = proxycon_mt_compare if svyround == 2 | svyround == 4
label variable tmpvar "\makecell{Food \\ consumption}"

capture rename saved_binary_ saved_binary
capture rename trans_fam trans_rec

egen nonlabour = rowtotal(crop_seed_purch30 crop_fert_purch30) if svyround < 4
egen temp = rowtotal(fert_purch prod_purch) if svyround == 4
replace nonlabour = temp if !missing(temp)
drop temp
label variable nonlabour "Input expenses, see note" // past 30 days for pre-lean, lean, and post-lean, and all rainy season for endline

egen nonlabour_endline = rowtotal(crop_seed_purch30 crop_fert_purch30) if svyround == 4
label variable nonlabour_endline "Input expenses, see note" // past 30 days at endline

local primary_panel fcs tmpvar
local mentalhealth_panel cantril mentalhealth 
local cohesion_panel vperception socialcohesion

local loans_panel loans_twelve_mo loans_amt 
local savings_panel saved_binary saved_total
local remittances_panel trans_rec remittance_amt


eststo clear

forval i = 1/4 {
foreach depvar in `loans_panel' `savings_panel' `remittances_panel' {
    {
    reghdfe `depvar' i.treatment `controls' if svyround == `i', absorb(`ffx') vce(cluster vid)
    eststo `depvar'_`i'
    test 1.treatment == 2.treatment
    estadd scalar equals = r(p)
    estadd local ffx = "Yes"
    estadd scalar ar2 = e(r2_a)
    forval k = 0/2 {
        sum `depvar' if treatment == `k' & e(sample) == 1
        estadd scalar mean_`k' = r(mean)
    }
    }
}
}


foreach depvar in `loans_panel' `savings_panel' `remittances_panel' {
reghdfe `depvar' i.treatment##i.svyround `controls' if svyround < 3, absorb(strat_pmt strat_vill_size) vce(cluster vid)
eststo nested_`depvar'

test (2.svyround = 0)
estadd scalar fpval0 = r(p)

test (1.treatment = 1.treatment + 2.svyround + 1.treatment#2.svyround)
estadd scalar fpval1 = r(p)

test (2.treatment = 2.treatment + 2.svyround + 2.treatment#2.svyround)
estadd scalar fpval2 = r(p)

test 1.treatment + (1.treatment + 1.treatment#2.svyround) = 0
estadd scalar int1 = r(p)
scalar int1 = r(p)

test 2.treatment + (2.treatment + 2.treatment#2.svyround) = 0
estadd scalar int2 = r(p)
scalar int2 = r(p)

matrix b = (int1, int2)
mat colnames b = 1.treatment 2.treatment
ereturn post b
eststo `depvar'_int
}

esttab loans_twelve_mo_* ///
    using "$csae/annex-loans-panel.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline" "\shortstack{Pre-lean + Lean \\ = 0}") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 mean_1 mean_2 N, ///
    labels("Early short = Early long" "Trad. response mean" "Early short mean" "Early long mean" "Observations") fmt(2 2 2 2 0)) ///
    posthead( ///
    \midrule ///
    \it{Borrowed (0, 1)} \\ ///
    \midrule ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    replace
    
esttab loans_amt_* ///
    using "$csae/annex-loans-panel.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 mean_1 mean_2 N, ///
    labels("Early short = Early long" "Trad. response mean" "Early short mean" "Early long mean" "Observations") fmt(2 2 2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Amount borrowed} \\ ///
    ) ///
    append
    
esttab saved_binary_* ///
    using "$csae/annex-savings-panel.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline" "\shortstack{Pre-lean + Lean \\ = 0}") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 mean_1 mean_2 N, ///
    labels("Early short = Early long" "Trad. response mean" "Early short mean" "Early long mean" "Observations") fmt(2 2 2 2 0)) ///
    posthead( ///
    \midrule ///
    \it{Saved (0, 1)} \\ ///
    \midrule ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    replace
    
esttab saved_total_* ///
    using "$csae/annex-savings-panel.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 mean_1 mean_2 N, ///
    labels("Early short = Early long" "Trad. response mean" "Early short mean" "Early long mean" "Observations") fmt(2 2 2 2 0)) ///
    prehead( ///
    \midrule ///
    \it{Amount saved} \\ ///
    ) ///
    append     


* smoothing test run regressions by treatment arm

foreach depvar in loans_twelve_mo loans_amt saved_binary saved_total {
forval i = 0/2 {
    reghdfe `depvar' i.svyround `controls' if treatment == `i' & svyround < 4, absorb(hhid) vce(cluster vid)
    eststo arm_`depvar'_`i'
    
    test 2.svyround = 0 = 1.svyround
    estadd scalar veq = r(p)
    scalar sv_`depvar'_`i' = r(p)
}
}

foreach depvar in loans_twelve_mo loans_amt saved_binary saved_total {
    regress hhid
    eststo `depvar'_empty
    estadd local N = "", replace
    estadd scalar mean_0 = sv_`depvar'_0
    estadd scalar mean_1 = sv_`depvar'_1
    estadd scalar mean_2 = sv_`depvar'_2
}

* additional heterogeneity by baseline median PMT * 
    
clear
eststo clear
use "$baseline_final/baseline_niger_outcomes.dta"
keep hhid treatment fu_score_pmt
sum fu_score_pmt, d

gen p50pmt = 1 if fu_score_pmt < r(p50)
replace p50pmt = 0 if missing(p50pmt)
drop fu_score_pmt

tempfile pmtscores
save "`pmtscores'"

clear
use "$panel/ready.dta"
merge m:1 hhid using "`pmtscores'"
drop if _merge == 1
drop _merge

local ffx strat_pmt strat_vill_size cohort
local controls i.surveyed_twice

gen tmpvar = proxycon_mt
replace tmpvar = proxycon_mt_compare if svyround == 2 | svyround == 4
label variable tmpvar "\makecell{Food \\ consumption}"

local primary_panel fcs tmpvar cantril

forval i = 1/4 {
foreach depvar in `primary_panel' {
    foreach dimension in p50pmt {
    quietly {
    reghdfe `depvar' `controls' i.treatment i.treatment#i.`dimension' i.`dimension' if svyround == `i', absorb(`ffx') vce(cluster vid)
    eststo `depvar'_`i'_`dimension'
    test 1.treatment == 2.treatment
    estadd scalar equals = r(p)
    test 1.treatment + 1.treatment#1.`dimension' == 0
    estadd scalar tfe = r(p)
    test 2.treatment + 2.treatment#1.`dimension' == 0
    estadd scalar mfe = r(p)
    estadd local ffx = "Yes"
    estadd scalar ar2 = e(r2_a)
    forval k = 0/2 {
        sum `depvar' if treatment == `k' & e(sample) == 1
        estadd scalar mean_`k' = r(mean)
    }
    }
    }
}
}

foreach dimension in p50pmt {
    
    if "`dimension'" == "liquid" {
        local tbl "Liquid"
    }
    
    if "`dimension'" == "diverse" {
        local tbl "Off-farm work"
    }
    
    if "`dimension'" == "p50pmt" {
        local tbl "Below median PMT"
    }

    esttab fcs_*_`dimension' ///
    using "$csae/primary-panel-`dimension'.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment 1.treatment#1.`dimension' 2.treatment#1.`dimension') ///
    booktabs ///
    varlabel(1.treatment "Early short ($\beta_1$)" 2.treatment "Early long( $\beta_2$)" ///
    1.treatment#1.`dimension' "Early short $\times$ `tbl' ($\beta_3$)" 2.treatment#1.`dimension' "Early long $\times$ `tbl' ($\beta_4$)") ///
    stats(tfe mfe N, ///
    labels("$\beta_1 + \beta_3$ = 0" "$\beta_2 + \beta_4$ = 0" "Observations") fmt(2 2 0)) ///
    substitute(\_ _) ///
    posthead( ///
    \midrule ///
    \it{Food Consumption Score} \\ ///
    \midrule ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    replace
        
esttab tmpvar_*_`dimension' ///
    using "$csae/primary-panel-`dimension'.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment 1.treatment#1.`dimension' 2.treatment#1.`dimension') ///
    booktabs ///
    varlabel(1.treatment "Early short ($\beta_1$)" 2.treatment "Early long( $\beta_2$)" ///
    1.treatment#1.`dimension' "Early short $\times$ `tbl' ($\beta_3$)" 2.treatment#1.`dimension' "Early long $\times$ `tbl' ($\beta_4$)") ///
    stats(tfe mfe N, ///
    labels("$\beta_1 + \beta_3$ = 0" "$\beta_2 + \beta_4$ = 0" "Observations") fmt(2 2 0)) ///
    substitute(\_ _) ///
    prehead( ///
    \midrule ///
    \it{Food Consumption} \\ ///
    ) ///
    postfoot( ///
    /// 
    ) ///
    append
    
    esttab cantril_*_`dimension' ///
    using "$csae/primary-panel-`dimension'.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    nomtitle ///
    nonumbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment 1.treatment#1.`dimension' 2.treatment#1.`dimension') ///
    booktabs ///
    varlabel(1.treatment "Early short ($\beta_1$)" 2.treatment "Early long( $\beta_2$)" ///
    1.treatment#1.`dimension' "Early short $\times$ `tbl' ($\beta_3$)" 2.treatment#1.`dimension' "Early long $\times$ `tbl' ($\beta_4$)") ///
    stats(tfe mfe N, ///
    labels("$\beta_1 + \beta_3$ = 0" "$\beta_2 + \beta_4$ = 0" "Observations") fmt(2 2 0)) ///
    substitute(\_ _) ///
    prehead( ///
    \midrule ///
    \it{Life Satisfaction} \\ ///
    ) ///
    append

}


clear
eststo clear
use "$baseline_final/baseline_niger_outcomes.dta"
keep hhid treatment fu_score_pmt
sum fu_score_pmt, d

drop if fu_score_pmt < 11

twoway ///
(histogram fu_score_pmt, color(green%40) width(0.02)) ///
, ///
scheme(s1mono) ylab(, angle(0)) ///
xtitle("PMT scores at baseline", size())

graph export "$csae/pmt-baseline.pdf", replace

clear
eststo clear
use "$panel/ready.dta"

keep if svyround == 4

// foreach var in sbalance saved_binary_ sbalance_inf sbalance_for s_bank loans_twelve_mo loans_informal loans_formal loans_amt accesstofunds {
//     capture noisily sum `var'
// }

label variable loans_twelve_mo "Took loan in past 12 months"
label variable loans_amt "Amount borrowed"
label variable saved_binary_ "Saved in past three months"

estpost sum sbalance saved_binary_ sbalance_inf sbalance_for s_bank loans_twelve_mo loans_informal loans_formal loans_amt accesstofunds
eststo finbase

esttab finbase ///
using "$csae/financial-behaviours-endline.tex", ///
cells( ///
"mean(pattern(1) fmt(2)) sd(pattern(1) fmt(2)) min(pattern(1) fmt(2)) max(pattern(1) fmt(2)) count(pattern(1) fmt(0))" ///
) ///
nomtitle nonumbers ///
collabels("Mean" "SD" "Min" "Max" "N") ///
label ///
keep() ///
order() ///
booktabs ///
noobs ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
replace


clear
eststo clear
use "$panel/ready.dta"

local ffx strat_pmt strat_vill_size roundcohort
local subffx strat_pmt strat_vill_size
local controls i.surveyed_twice

forval i = 1/4 {
    mat def pvalue_index_`i' = J(6, 4, .)
    local counter_index 1
    foreach depvar in fcs_above_poor {
        {
        reghdfe `depvar' i.treatment `controls' if svyround == `i', absorb(`ffx') vce(cluster vid)
        eststo `depvar'_`i'
        test 1.treatment = 2.treatment
        estadd scalar equals = r(p)
        estadd local ffx = "Yes"
        estadd scalar ar2 = e(r2_a)
    
        forval k = 0/2 {
            sum `depvar' if treatment == `k' & e(sample) == 1
            estadd scalar mean_`k' = r(mean)
            }
            }
            }
            }

reghdfe fcs_above_poor i.treatment##i.svyround `controls' if svyround < 3, absorb(`subffx') vce(cluster vid)
eststo nested_fcs

test (1.treatment = 1.treatment + 2.svyround + 1.treatment#2.svyround)
estadd scalar fpval1 = r(p)

test (2.treatment = 2.treatment + 2.svyround + 2.treatment#2.svyround)
estadd scalar fpval2 = r(p)

test 1.treatment + (1.treatment + 1.treatment#2.svyround) = 0
estadd scalar int1 = r(p)
scalar int1 = r(p)

test 2.treatment + (2.treatment + 2.treatment#2.svyround) = 0
estadd scalar int2 = r(p)
scalar int2 = r(p)

matrix b = (int1, int2)
mat colnames b = 1.treatment 2.treatment
ereturn post b
eststo fcs_above_poor_int

esttab fcs_* ///
    using "$csae/fcs-above-poor.tex", ///
    cells( ///
    "b(pattern() fmt(%12.2f) star pvalue(p))" ///
    "se(pattern() fmt(%12.2f) par)" ///
    "qval(pattern() fmt(%12.2f) par([ ]))" ///
    ) ///
    starlevels(* 0.10 ** 0.05 *** 0.01) ///
    label ///
    mtitle("Pre-lean" "Lean" "Post-lean" "Endline" "\shortstack{Pre-lean + Lean \\ = 0}") ///
    numbers ///
    collabels(none) ///
    keep(1.treatment 2.treatment) ///
    booktabs ///
    stats(equals mean_0 mean_1 mean_2 N, ///
    labels("Early short = Early long" "Trad. response mean" "Early short mean" "Early long mean" "Observations") fmt(2 2 2 2 0)) ///
    posthead( ///
    \midrule ///
    \it{Food Security} \\ ///
    \midrule ///
    ) ///
    replace

* smoothing test run regressions by treatment arm

foreach depvar in fcs_above_poor {
forval i = 0/2 {
    reghdfe `depvar' i.svyround `controls' if treatment == `i' & svyround < 4, absorb(hhid) vce(cluster vid)
    eststo arm_`depvar'_`i'
    
    test 2.svyround = 0 = 1.svyround
    estadd scalar veq = r(p)
    scalar sv_`depvar'_`i' = r(p)
    
//     test 1.svyround + 2.svyround = 0
//     estadd scalar ieq = r(p)
//     test 1.svyround = 2.svyround
//     estadd scalar seq = r(p)
//     test 1.svyround = 2.svyround = 0
//     estadd scalar deq = r(p)
}
}

foreach depvar in fcs_above_poor {
    regress hhid
    eststo `depvar'_empty
    estadd local N = "", replace
    estadd scalar mean_0 = sv_`depvar'_0
    estadd scalar mean_1 = sv_`depvar'_1
    estadd scalar mean_2 = sv_`depvar'_2
}

log close

translate "mysession.smcl" "mysession.pdf", replace
