  ****************************************************************************
*----------------- IIIIb. PREPARE HOUSEHOLD BUSINESS DATA ------------------- *

*Input: ${baseline_intermediate}/niger_business.dta; ${baseline_intermediate}/demographics.dta ; "${baseline_intermediate}/niger_main_2021.dta

*Output: ${baseline_intermediate}/${baseline_intermediate}/business

global phase "Baseline"

*** B.3 Business types
clear
use "${baseline_intermediate}/niger_business.dta"

preserve
keep hhid agr_key_rpos act_n bus_d
tempfile bus_actn
save `bus_actn'
restore

preserve

**Gen number of household business

*Two differnt appoaches to caluculated this

**Method 1 -recomneded (likly to undercount number of businesses)
foreach var of varlist bus1_food bus1_tail bus1_constr bus1_comm bus1_prof bus1_serv bus1_trans bus1_art {
bysort hhid: egen hh_`var' =max(`var')
}
egen  business_num = rowtotal(hh_bus1_tail hh_bus1_constr hh_bus1_comm hh_bus1_prof hh_bus1_serv hh_bus1_trans hh_bus1_art) , missing
    label variable business_num "total number of household businesses, conservative counting approach"

**Method 2 (likly to double count businesses)
bysort hhid: egen hh_act_n = total(act_n) // number of business at HH level assuming househol members didn'y vomanaged any reported businesses
label variable hh_act_n "total number of household businesses, non conservative approach to counting"


keep hhid business_num hh_act_n
duplicates drop

tempfile hh_bus_num
save `hh_bus_num'

/*

* reshape
rename activity?_type activity_type?

global long_vars activity* bus_def_type_list?
*keep hhid agr_key_rpos $long_vars


ds hhid agr_key_pos agr_key_rpos, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

ds hhid agr_key_pos agr_key_rpos, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid agr_key_pos) j(agr_key_rpos)




*/

restore

* reshaping long

* id: hhid, agr_key_pos (respondent pos) but some respondents have several businesses

* split variable on business type:
split bus_def_type_list
destring bus_def_type_list*, replace

global long_vars activity* bus_def_type_list?
keep hhid agr_key_rpos $long_vars

local xtemp activity1 activity2 activity3 activity4 activity5 activity6 activity7 activity8 activity9 activity10 activity11 activity12 activity13 activity14 activity15

tostring activity1 activity2 activity3 activity4 activity5 activity6 activity7 activity8 activity9 activity10 activity11 activity12 activity13 activity14 activity15, replace force

foreach var in `xtemp' {
    replace `var' = "" if `var' == "."
}

rename activity*_type activity_type*
reshape long activity activity_type bus_def_type_list, i(hhid agr_key_rpos) j(bus_pos)

gen act_pos = bus_pos

drop if bus_def_type_list == .

gen bus1_food = bus_def_type_list == 1
gen bus1_tail = bus_def_type_list == 2
gen bus1_constr = bus_def_type_list == 3
gen bus1_comm = bus_def_type_list == 4
gen bus1_prof = bus_def_type_list == 5
gen bus1_serv = bus_def_type_list == 6
gen bus1_trans = bus_def_type_list == 7
gen bus1_art = bus_def_type_list == 8
gen bus1_extra = bus_def_type_list == 9


merge m:1 hhid agr_key_rpos using `bus_actn', gen(m_actn)
* unmatched because these respondents don't have any businesses
keep if m_actn == 3
drop m_actn


*** Business types (descriptive Stats--hh shares)
// This program fixes BL variables from cty_business since this module was moved into main.dta
// It generates a hh-level dataset showing total number of busineses per household
// and type of business

** bus_food
gen bus_food_d = bus1_food > 0
** bus_maker
gen bus_tail_d = bus1_tail > 0
** bus_constr
gen bus_constr_d = bus1_constr > 0
** bus_comm
gen bus_comm_d = bus1_comm > 0
** bus_prof
gen bus_prof_d = bus1_prof > 0
** bus_trans
gen bus_trans_d =  bus1_trans > 0
** bus_serv
gen bus_serv_d =  bus1_serv > 0
** bus_art
gen bus_art_d = bus1_art > 0
** bus_extra
gen bus_extra_d = bus1_extra > 0

    rename act_n bus_n // (number of activities at individual level)

bysort hhid: egen act_n = total(bus_n) // number of business at HH level -Use above coding rather than this



// same variabel is "act_n" at FU


// number of business of each type at HH level (at FU these HH level vars are surveyed directly)
foreach type in food tail constr comm prof trans serv art extra {
bysort hhid: egen bus1_hh_`type' = max(bus_`type'_d ) // rename bus_tpe to bus1_type to make consistent with raw FU Vars
}

// label HH-level dummy vars
label var bus1_hh_food    "HH business at ${phase}: transformation of food, 12 months"
label var bus1_hh_tail    "HH business at ${phase}: clothes or shoes, 12 months"
label var bus1_hh_constr  "HH business at ${phase}: construction, carpentry, 12 months"
label var bus1_hh_comm    "HH business at ${phase}: petty trade, 12 months"
label var bus1_hh_prof    "HH business at ${phase}: liberal profession, 12 months"
label var bus1_hh_trans   "HH business at ${phase}: transport, 12 months"
label var bus1_hh_serv    "HH business at ${phase}: other services, 12 months"
label var bus1_hh_art     "HH business at ${phase}: artisan, 12 months"
label var bus1_hh_extra   "HH business at ${phase}: other, 12 months"


// step aside to collect: hhid bus2_pos activity activity_type at BL
preserve

keep if bus_d != 0

gen agrd_key_rpos = agr_key_rpos
merge 1:1 hhid agrd_key_rpos act_pos using "${baseline_intermediate}/business_long.dta", keepusing(bus2_name)


replace activity = strlower(activity)
replace activity = itrim(activity)
assert activity == bus2_name // they all match



keep hhid  agrd_key_rpos act_pos activity activity_type
order hhid agrd_key_rpos act_pos activity activity_type

tempfile bus_types
save `bus_types' // ID = hhid bus2_pos
restore


keep hhid act_n bus1_hh_food bus1_hh_tail bus1_hh_constr ///
  bus1_hh_comm bus1_hh_prof bus1_hh_trans bus1_hh_serv bus1_hh_art bus1_hh_extra

duplicates drop
isid hhid


* grouped enterprise variables (required in survey)
gen bus_group_1 = (bus1_hh_trans == 1 | bus1_hh_serv == 1)
label var bus_group_1 "Household activity: transport + other services, 12 months"

gen bus_group_2 = (bus1_hh_art == 1 | bus1_hh_tail == 1 | bus1_hh_food == 1 | bus1_hh_comm == 1)
label var bus_group_2 "Household activity: artisan + clothes/shoes + food transformation + petty trade, 12 months"

gen bus_group_3 = (bus1_hh_constr == 1)
label var bus_group_3 "Household activity: construction/carpentry, 12 months"

gen bus_group_4 = (bus1_hh_prof == 1)
label var bus_group_4 "Household activity: liberal profession, 12 months"

gen bus_group_5 = (bus1_hh_extra == 1)
label var bus_group_5 "Household activity: other, 12 months"

/* NOTE: there are 1478 households who do not have a household enterprise --- is this still true? */

** div_n_na_12
egen div_n_na_12 = rowtotal(bus_group_1 bus_group_2 bus_group_3 bus_group_4 bus_group_5)
label var div_n_na_12 "B.3.3 Count of HH business types [0-5] at ${phase} last 12 months"
assert div_n_na_12 >= 0 & div_n_na_12 <= 5

keep  hhid act_n bus1_hh_food - bus1_hh_extra div_n_na_12 bus_group_*
order hhid act_n bus1_hh_food - bus1_hh_extra div_n_na_12 bus_group_*

// generate dummies for business vars
foreach var of varlist bus1_hh_food - bus1_hh_extra {
gen `var'_d = `var' // copy var
replace `var'_d = 1 if (`var' >= 1 & !missing(`var')) // make dummy
}

duplicates drop
isid hhid


tempfile bus1_outcomes
save `bus1_outcomes'

***/



********************************************************************************
*** bus2: Revenues and Profits, HH and beneficiary level, 30 days and 12 months
********************************************************************************

// import data
clear
use "${baseline_intermediate}/business_long.dta"

gen bus2_pos = act_pos
sort hhid
merge m:1 hhid using "${baseline_intermediate}/demographics.dta", ///
keepusing(hhid chef_pos) gen(_mdemog)

drop if _mdemog == 2 // drop households outside the repeat group for now

drop if bus2_active == .     // ignore businesses with missing (not 0 or 1) here.
       // These have no other info besides bus2_name and ownership

drop if bus2_own == "0" // drop businesses owned entirely outside the HH. zero dropped


**Household Business revenue  Profit and Assets

bysort hhid: egen business_rev30= total(bus2_rev30), missing
label var business_rev30 "business revenue, monthly local prices"

bysort hhid: egen  business_pft30= total(bus2_pro30), missing
label var  business_pft30 "business profit, monthly local prices"

bysort hhid: egen  business_assval30= total(bus2_assval), missing
label var  business_assval30 "business asset value, monthly local prices"


**Business Future investment (still need to decide how to agregate this)

gen business_invest= 0 if !missing(bus_future)
replace business_invest=1 if bus_future==2
label var business_invest "planning to invest in the business in future"

**Other members from household involved in business  (still need to agregate this)

label var bus2_outworkers "number of non household members involved in business"
replace bus2_outworkers=. if bus2_outworkers>100 //Some extrely big reported values

**reshape to the household level

preserve

keep hhid business_rev30 business_pft30 business_assval30
duplicates drop

tempfile bus_secondaryvar
save `bus_secondaryvar'

restore

/*
ds hhid act_pos agrd_key_rpos, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

ds hhid act_pos agrd_key_rpos, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid act_pos) j(agrd_key_rpos)

ds bus2_name*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label var `varstub'`i' "`l_`varstub''"
}
}
*/


*** divide by number of owners (no managers at BL)
local string_vars chef_pos bus2_workers bus2_own
tostring chef_pos, replace

foreach var in `string_vars' {
replace `var' = " " + `var' + " "
}


    gen my_chef_ownman = strpos(bus2_own, chef_pos) > 0

// test ben_ownmanager variable with actual benef position
capture confirm var chef_ownmanager
if _rc != 0 { // variable DNE at BL
rename my_chef_ownman chef_ownmanager  // (BL)
}
else if _rc == 0 { // variable only exists at FU
capture assert chef_ownmanager == my_chef_ownman // ben_ownmanager is good at FU1 not FU2
if _rc == 0 {
drop my_chef_ownman // if ben_ownmanager is correct, drop the new one (FU1)
}
else {
drop chef_ownmanager
rename my_chef_ownman chef_ownmanager  // if not, replace the two and continue (FU2)
}
}

*** divide by number of owner/managers
gen n_ownman = 0 // number of owners and managers excluding non-HH members
gen n_ownman_original = 0 // // number of owners and managers regardless of HH membership


gen bus2_ownmanage = bus2_own
gen bus2_people    = bus2_own + bus2_workers

gen bus2_people_uniq = "" // List of owners, managers, and workers regardless of HH membership

forval i = 1/`=_N' {

// count number of owners/managers for each business
local all
local all  `"`=bus2_ownmanage[`i']'"'
local all : list uniq all
replace n_ownman_original = `: list sizeof all' in `i'
local zeros "0"
local all : list all - zeros // remove if position = "0". Person not in HH
replace n_ownman = `: list sizeof all' in `i'

// fix months (1/2)
// count number of months at FU1 and Fu2

// find business size using number of owners, managers, and workers
local ppl
local ppl `"`=bus2_people[`i']'"'
local ppl : list uniq ppl
replace bus2_people_uniq = "`ppl'" in `i'

}
preserve
keep hhid agrd_key_rpos `alsokeep' bus2_pos bus2_people_uniq
isid hhid agrd_key_rpos `alsokeep' bus2_pos // confirm unique businesses

keep hhid agrd_key_rpos bus2_people_uniq // keep people list
gen n = _n
byso hhid: egen bus2_posnew = rank(n) // count businesses (j in reshape)
drop n

reshape wide bus2_people_uniq , i(hhid agrd_key_rpos ) j(bus2_posnew)


foreach var of varlist bus2_people_uniq* { // insert space after
replace `var' = `var' + " "
}
egen hh_ppl = concat(bus2_people_uniq*)
gen tot_bus2_ppl_uniq = . // uniq people
forval i = 1/`=_N' {
// find business size using number of owners, managers, and workers
local ppl
local ppl `"`=hh_ppl[`i']'"'
local ppl : list uniq ppl
replace tot_bus2_ppl_uniq =`: list sizeof ppl' in `i'

}

label var tot_bus2_ppl_uniq "No. of unique people working in business"

* this was done at respondent level
keep hhid agrd_key_rpos tot_bus2_ppl_uniq
isid hhid agrd_key_rpos

tempfile buspeople
save `buspeople'


by hhid: egen tot_bus2_ppl_uniq_hh = max(tot_bus2_ppl_uniq)
keep hhid tot_bus2_ppl_uniq_hh
label var tot_bus2_ppl_uniq_hh "No. of unique people working in HH business"
duplicates drop
isid hhid
tempfile buspeople_hh
save `buspeople_hh'
restore

merge m:1 hhid agrd_key_rpos using `buspeople', gen(_mppl)
merge m:1 hhid using `buspeople_hh', gen(_mppl_hh)


/* fix months (2/2)
at baseline, we asked for integer no. of months <=12 (bus2_months)
at Followup 1, we asked for list of months active in the last 12 and provided 24 options (bus2_mos12)
at Followup 2, we asked for list of months active in the last 12 and provided 14 options
    constrained to 12 choices (bus2_mos12)
*/

* creating number of months business was in operation in the last year variable
egen bus2_months = rowtotal(bus2_mos12_2*)
// sanity checks
assert bus2_months != . if bus2_active == 1



// merge in activity types (created above)
merge 1:1 hhid agrd_key_rpos`alsokeep' act_pos using `bus_types', gen(_mbus2)
drop if _mbus2 == 2 // these are for businesses not owned or managed by hh members
// _mbus2 == 1 will be handled below. These are businesses with revenues but not type info. Mark as "other"

// some businesses have no names... mark them as "other"
*assert bus2_name == "" if activity_type == . //something wrong with activity_type variable

gen misshere = activity_type == .
byso hhid : egen prob = max(misshere)
replace activity_type = 9 if prob == 1


foreach type in pro rev {


*winsorize
_pctile bus2_`type'30 , p(98)
gen bus_`type'30_win = bus2_`type'30
replace bus_`type'30_win = `r(r1)' if !missing(bus_`type'30_win) & bus_`type'30_win > `r(r1)'



// CHEF-level
gen chef_`type'30 = bus_`type'30_win / n_ownman_original if chef_ownmanager == 1 // pp only in ben-owned/managed bus


gen chef_`type'12 = chef_`type'30 * bus2_months // compute yearly ben total


replace chef_`type'30 = 0 if bus2_active == 0 // for monthly rev, drop business that were not active in last 30 days

// HH
gen hh_`type'30 = bus_`type'30_win * n_ownman / n_ownman_original // exclude share of non-hh-member
gen hh_`type'12 = hh_`type'30 * bus2_months // compute yearly ben total


replace hh_`type'30 = 0 if bus2_active == 0 // drop business that were not active in last 30 days

// note that some businesses have revenues despite not operating in last year
// hence those observations get a yearly value of zero

// CHEF
byso hhid: egen tot_chef_`type'30 = total(chef_`type'30)
replace tot_chef_`type'30 = tot_chef_`type'30 / 1000 // scale
label var tot_chef_`type'30 "B.2.1 (1) Chef bus `type' winsorized, 30 days (1000 FCFA)"
// these tot_*rev30 vars are used in employment to get profit margins

byso hhid: egen tot_chef_`type'12 = total(chef_`type'12)
replace tot_chef_`type'12 = tot_chef_`type'12 / 1000 // scale
label var tot_chef_`type'12 "B.2.1 (1) Chef bus `type' winsorized, 1 year (1000 FCFA)"

// HH
byso hhid : egen tot_hh_`type'30 = total(hh_`type'30) // sum across HH excluding that non-hh-member
replace tot_hh_`type'30 = tot_hh_`type'30 / 1000 // scale
label var tot_hh_`type'30 "B.2.1 (1) HH bus `type' winsorized, 30 days (1000 FCFA)"

byso hhid : egen tot_hh_`type'12 = total(hh_`type'12) // sum across HH excluding that non-hh-member
replace tot_hh_`type'12 = tot_hh_`type'12 / 1000 // scale
label var tot_hh_`type'12 "B.2.1 (1) HH bus `type' winsorized, 1 year (1000 FCFA)"



// HH and benef level by activity type:
foreach lev in chef hh {
capture confirm var activity_type
if _rc == 0 {
levelsof activity_type, local(acts)
foreach act in `acts' {

if "`lev'" == "chef" local yearlyrevvar chef_`type'12
if "`lev'" == "hh"  local yearlyrevvar  hh_`type'12

// activity `act' share of yearly pro/rev at business level
gen `type'_`lev'_`act' = `yearlyrevvar' if activity_type == `act'
byso hhid : egen bus_`type'12_`lev'_`act' = total(`type'_`lev'_`act')
}

ds bus_`type'12_`lev'_? // only 9. can't do double question mark
local bus`type'_`lev'_by_act `r(varlist)'
}
}
}


// count nonoverlapping months across all of a HH's businesses
byso hhid : egen tot_busmths_uniq = total(bus2_months)
assert tot_busmths_uniq != .
replace tot_busmths_uniq = min(tot_busmths_uniq, 12)

// get unique months of beneficiary-run business
gen bus2_months_chef = bus2_months if chef_ownmanager == 1 // business level
byso hhid : egen tot_busmths_uniq_chef = total(bus2_months_chef)
assert tot_busmths_uniq_chef != .
replace tot_busmths_uniq_chef = min(tot_busmths_uniq_chef, 12)



// redo business diversification to get beneficiary businesses only
* grouped enterprise variables (required in survey)
gen bus_5acts = 1 if inlist(activity_type, 6, 7) // trans serv
replace bus_5acts = 2 if inlist(activity_type, 1, 2, 4, 8) // food tailoring commerce and artisanship
replace bus_5acts = 3 if inlist(activity_type, 3) // construction
replace bus_5acts = 4 if inlist(activity_type, 5) // professions
replace bus_5acts = 5 if inlist(activity_type, 9) // other

** div_n_na_12_hh
byso hhid bus_5acts : gen div_n_na_12_hh = _n == 1
byso hhid : replace div_n_na_12_hh = sum(div_n_na_12_hh)
byso hhid : replace div_n_na_12_hh = div_n_na_12_hh[_N]

** div_n_na_12_chef
gen bus_5acts_chef = bus_5acts if chef_ownmanager == 1
byso hhid bus_5acts_chef : gen div_n_na_12_chef = _n == 1
replace div_n_na_12_chef = . if chef_ownmanager != 1
byso hhid : replace div_n_na_12_chef = sum(div_n_na_12_chef)
byso hhid : replace div_n_na_12_chef = div_n_na_12_chef[_N]


** business assets
// fix negative, 888 and 999 responses to continuous, positive variables - thease don't appear to be an issue?
*fix_continuous bus2_assval
*assert bus2_assval >= 0 | missing(bus2_assval)

foreach pp in 95 98 {

** all HH businesses
gen bus2_assval_win`pp' = bus2_assval
_pctile bus2_assval, p(`pp')
replace bus2_assval_win`pp' = `r(r1)' if bus2_assval >`r(r1)'  & !missing(bus2_assval)

bysort hhid : egen bus_assval_`pp' = total(bus2_assval_win`pp')
label var bus_assval_`pp' "B.5.3 Direct business asset value, wins. at `pp'p"

** chef businesses only
gen bus2_assval_win`pp'_chef = bus2_assval_win`pp' if chef_ownmanager == 1
bysort hhid : egen bus_assval_`pp'_chef = total(bus2_assval_win`pp'_chef)
label var bus_assval_`pp'_chef "B.5.3 Direct business asset value (chef), wins. at `pp'p"




// scale up
foreach var of varlist bus_assval_`pp' bus_assval_`pp'_chef {
replace `var' = `var' / 1000
local this_lab : variable label `var'
label var `var' "(1000 FCFA) `this_lab'"
}

}


preserve

local keeporder_hh tot_chef_rev30 tot_chef_pro30 ///
   tot_chef_rev12 tot_chef_pro12 ///
   tot_hh_rev30  tot_hh_pro30  ///
   tot_hh_rev12  tot_hh_pro12 ///
   `busrev_chef_by_act' `buspro_chef_by_act' ///
   `busrev_hh_by_act'  `buspro_hh_by_act' ///
   tot_busmths_uniq tot_busmths_uniq_chef ///
   tot_bus2_ppl_uniq_hh ///
   div_n_na_12_hh div_n_na_12_chef ///
   bus_assval_98 bus_assval_95 ///
   bus_assval_98_chef bus_assval_95_chef


// by default we don't have all hhs at FU because we drop households without businesses
// replace with zeros later after merging in with all other datasets



keep hhid `keeporder_hh'
duplicates drop
isid hhid

tempfile bus2_outcomes
save `bus2_outcomes'
restore




*************************************************************************************
*** Secondary B.8.1 Count of household non-agricultural business in last 12 months
*************************************************************************************

// bring in: submissiondate list_chef consent
merge m:1 hhid using "${baseline_intermediate}/niger_main_2021.dta", ///
keepusing (submissiondate list_chef consent) gen(_mdate)
drop if _mdate == 2 // HHs not in non-ag dataset

assert consent == 1

// this dataset describes HH non-ag activities that were operational over the last 12 months
// bus2_mos12 captures months in which business was active in last 12 months

sort hhid bus2_pos

// count no. of na bus in operation within last 12 months
byso hhid : egen na_bus2_op_wn_12 = count(bus2_pos)
label var na_bus2_op_wn_12 "B.8.1 (1) no. of HH NA bus in operation within last 12 months"

// count no. of na bus in operation within last 12 months owned/mngd by beneficiary
gen bus2_pos_chef = bus2_pos if chef_ownmanager
byso hhid : egen na_bus2_op_wn_12_chef = count(bus2_pos_chef)
label var na_bus2_op_wn_12_chef "B.8.2 (1) no. of CHEF NA bus in operation within last 12 months"


********************************************************************************
*** Secondary B.8.2 Whether household has any non-agricultural business
********************************************************************************

** 1 year
// dummy for having any na bus in operation within last 12 months
assert bus2_active != . & bus2_years != .
gen bus2_dum = 1 // all HHs in this dataset run a non-ag business of some sort.
 // FU1: HHs listed in act_n in main.dta miss 5 HHs mentioned here.
label var bus2_dum "B.8.1 (2) HH has any na bus in operation within last 12 months"

// dummy for having any na bus in operation within last 12 months
// only for businesses owned/managed by beneficiary
byso hhid : egen bus2_chef_dum = max(chef_ownmanager)
label var bus2_chef_dum "B.8.2 (2) CHEF has any na bus in operation within last 12 months"

gen chef_ownerman = strpos(bus2_own, string(list_chef)) > 0  | ///
strpos(bus2_manage, string(list_chef)) > 0
byso hhid : egen chef_ownmanage = max(chef_ownerman)


** 1 month
gen bus2_dum30_temp = bus2_active == 1 // full dummy w. no missings
assert bus2_months > 0 | !missing(bus2_months) if bus2_dum30_temp == 1 // bus2_months generated at FU
byso hhid : egen bus2_dum30 = max(bus2_dum30_temp)
label var bus2_dum30 "HH has any na bus in operation within last 1 month at ${phase}"
drop bus2_dum30_temp

gen bus2_30_chef = bus2_dum30 == 1 & chef_ownmanager == 1
byso hhid : egen bus2_chef_dum30 = max(bus2_30_chef)
label var bus2_chef_dum30 "CHEF has any na bus in operation within last 1 month at ${phase}"
drop bus2_30_chef

// B.8.2 by activity type (beneficiary's business extensive margins)
levelsof activity_type, local(types)
foreach type in `types' {
gen bus1_chef_`type' = 1 if activity_type == `type' & chef_ownmanager == 1
replace bus1_chef_`type' = 0 if missing(bus1_chef_`type')

byso hhid : egen bus1_chef_`type'_d = max(bus1_chef_`type')
label var bus1_chef_`type'_d "B.8.2 (2) CHEF has type `type' bus in operation within last 12 months"
}

********************************************************************************
*** Secondary B.8.3 HH started a business within the last 12 months
********************************************************************************

*fix_continuous bus2_years - doesn't seem to be an issue

tab bus2_years, m

 replace bus2_years = 2021 - bus2_years if bus2_years == 1991 | bus2_years == 1995 | bus2_years == 1997 | bus2_years == 1998 | bus2_years == 1999 |  bus2_years == 2000 | bus2_years == 2005 | bus2_years == 2010 | bus2_years == 2011 | bus2_years == 2013 | bus2_years == 2015 | bus2_years == 2016 | bus2_years == 2017 | bus2_years == 2018 | bus2_years == 2019 | bus2_years == 2020 | bus2_years == 2021

replace bus2_years = 50 if bus2_years > 50


// some years assumed sticky fingers (following approach in survey corrections)

// sanity check on years
assert bus2_years <= 100 | missing(bus2_years) // assume 100-year cutoff for reasonable tenure



local fu_date_var bus2_date
order hhid bus2_pos submissiondate `fu_date_var' bus2_years bus2_name
sort hhid bus2_pos


// capture actual survey date
gen survey_date = dofc(submissiondate), after(submissiondate)
format survey_date %td
drop submissiondate


// generate new date based on years and fill missing bus2_date
gen bus2_date_temp = survey_date - 365 * bus2_years, after(bus2_date)
format bus2_date_temp %td
replace bus2_date = bus2_date_temp if missing(bus2_date)
drop bus2_date_temp

*br if bus2_years != 0 & bus2_date > survey_date-365 & !missing(bus2_date) // some messy cases.

// generate dummy indicating if entered years of operation < year
gen na_within_12_by_year = (bus2_years < 1), after(bus2_years)

// generate dummy indicating if start date is within a year


gen na_within_12_by_date = (bus2_date > survey_date-365), after(na_within_12_by_year)

// capture overlap between these since it appears neither are very accurate
gen within_12_mnths = (na_within_12_by_date | na_within_12_by_year), after(na_within_12_by_year)
drop na_within_12_by_date na_within_12_by_year



// dummy for HHs tha started an activity in last 12 months
byso hhid : egen bus2_within_12_dum = max(within_12_mnths)
label var bus2_within_12_dum "B.8.1 (3) Whether HH started NA business in last 12 months at ${phase}"

// dummy for HHs where beneficiary started an activity in last 12 months
gen within_12_mnths_chef = within_12_mnths
replace within_12_mnths_chef = 0 if chef_ownmanager == 0

byso hhid : egen bus2_within_12_dum_chef = max(within_12_mnths_chef)
label var bus2_within_12_dum_chef "B.8.2 (3) Whether CHEF started NA business in last 12 months at ${phase}"







********************************************************************************
**** Secondary B.8.4 Abandoned a non-agricultural activity in last 24 months
********************************************************************************


order bus2_abandon, after(bus2_years)

// dummy capturing whether a HH abandoned a na business
byso hhid : egen bus2_abandon_24_dum = max(bus2_abandon) // generate dummy. ignores missing values
order bus2_abandon_24_dum, after (bus2_abandon)
label var bus2_abandon_24_dum "B.8.1 (4) whether HH abandoned NA business in last 24 months at ${phase}"

// sum abandoned businesses only by beneficiary in household
gen bus2_abandon_chef = bus2_abandon
replace bus2_abandon_chef = 0 if chef_ownmanager == 0
byso hhid : egen bus2_abandon_24_dum_chef = max(bus2_abandon_chef) // generate dummy
label var bus2_abandon_24_dum_chef "B.8.2 (4) whether Chef abandoned NA business in last 24 months at ${phase}"

order bus2_abandon_chef, after(bus2_abandon_24_dum)
order bus2_abandon_24_dum_chef, after (bus2_abandon_chef)




local keeporder_B81_B84 na_bus2_op_wn_12 na_bus2_op_wn_12_chef /// B8(1)
bus2_dum bus2_chef_dum bus1_chef_*_d /// B8(2)
bus2_dum30 bus2_chef_dum30 /// 1 month extras (for telephone FU)
bus2_abandon_24_dum bus2_abandon_24_dum_chef ///
chef_ownmanage

preserve
keep hhid `keeporder_B81_B84'
order hhid `keeporder_B81_B84'
duplicates drop
isid hhid

tempfile bus1_outcomes_B81_B84
save `bus1_outcomes_B81_B84'
restore




********************************************************************************
**** Secondary B.8.5 Total investments in non-agricultural businesses, beneficiary
********************************************************************************

********************************************************************************


preserve
keep hhid `keeporder_invest'
duplicates drop
isid hhid

tempfile bus1_outcomes_invest
save `bus1_outcomes_invest'
restore



********************************************************************************
**** Secondary B.8.6 Estimated business profits, household level
********************************************************************************


// winsorize
foreach var of varlist bus_most_xof bus_least_xof {
_pctile `var' , p(98)
gen `var'_w = `var'
replace `var'_w  = `r(r1)' if !missing(`var'_w ) & `var'_w  > `r(r1)'
}


// calculate average profits (highest + lowest)/2
egen month_average_xof = rowmean(bus_most_xof_w bus_least_xof_w)

// Calculate estimated business profits, household level
gen bus2_pro_active_mnths = bus2_months * month_average_xof

// scale to exclude share for non-HH member
replace bus2_pro_active_mnths = bus2_pro_active_mnths * n_ownman / n_ownman_original


capture confirm var amt_curr
if _rc == 0 { // if currency var exists
foreach var of varlist bus2_pro_active_mnths bus_most_xof_w bus_least_xof_w {
scale_cur `var' amt_curr
}
}

// sum monthly low profits at HH level
byso hhid : egen tot_bus_least = total(bus_least_xof_w)
replace tot_bus_least = tot_bus_least / 1000
label var tot_bus_least "estimated HH lowest monthly profits (1000 FCFA)"

byso hhid : egen tot_bus_most = total(bus_most_xof_w)
replace tot_bus_most = tot_bus_most / 1000
label var tot_bus_most "estimated HH hightest monthly profits (1000 FCFA)"

// sum estimated profits at HH level
byso hhid : egen bus2_profits_hh_xof = total(bus2_pro_active_mnths)
replace bus2_profits_hh_xof = bus2_profits_hh_xof / 1000
label var bus2_profits_hh_xof "B.8.1 (8) estimated HH business profits at ${phase} (1000 FCFA)"

// repeat for beneficiary-owned only
gen bus2_pro_active_mnths_chef = bus2_pro_active_mnths
replace bus2_pro_active_mnths_chef = 0 if chef_ownmanager == 0

byso hhid : egen bus2_profits_hh_xof_chef = total(bus2_pro_active_mnths_chef) // sum profits at HH level
replace bus2_profits_hh_xof_chef = bus2_profits_hh_xof_chef / 1000
label var bus2_profits_hh_xof_chef "B.8.2 (8) estimated chef business profits at ${phase} (1000 FCFA)"

local keeporder_estim tot_bus_least tot_bus_most bus2_profits_hh_xof bus2_profits_hh_xof_chef


preserve
keep hhid `keeporder_estim'
duplicates drop
isid hhid

tempfile bus1_outcomes_estim
save `bus1_outcomes_estim'
restore


********************************************************************************
**** Outworkers
********************************************************************************


// gen dummy for employing outworkers
gen has_bus_empl = bus2_outworkers > 0 & !missing(bus2_outworkers)
label variable has_bus_empl "Has employees in non-farm activity"
byso hhid : egen hh_has_bus_empl = max(has_bus_empl)

preserve
keep hhid hh_has_bus_empl
duplicates drop
isid hhid
// empty file

tempfile bus2_workers
save `bus2_workers'
restore



********************************************************************************
*** Bring it all together
********************************************************************************

use  `bus1_outcomes', clear // extensive margins (full sample)
merge 1:1 hhid using `bus_secondaryvar' , gen(_mSec) //added later by desmond coveres secondary business outcomes specified in PAP
merge 1:1 hhid using `hh_bus_num' , gen(_mbusnum) //added later by desmond coveres number of household businesses
merge 1:1 hhid using `bus2_outcomes', gen(_mBus2) // intensive margins (pro, rev: only households w/ businesses)
merge 1:1 hhid using `bus1_outcomes_B81_B84', gen(_mBus_B81_84)
merge 1:1 hhid using `bus1_outcomes_invest', gen(_mBus_invest)
merge 1:1 hhid using `bus1_outcomes_estim', gen(_mBus_estim)
cap merge 1:1 hhid using `bus2_workers', gen(_mBus_workers)



********************************************************************************
*** a few extras
********************************************************************************

// b2 extra: HH profits per adult equivalent
merge 1:1 hhid using "${baseline_intermediate}/demographics.dta", keepusing(equiv_n) gen(_madult)
gen tot_hh_pro30_actual = tot_hh_pro30 * 1000 // monthly profit in FCFA
gen tot_hh_pro_day_eq = tot_hh_pro30_actual / 30 / equiv_n // daily profit per adult equivalent
replace tot_hh_pro_day_eq = 0 if tot_hh_pro_day_eq == .
label var tot_hh_pro_day_eq "B.2.1 (1) HH bus pro winsorized, (daily FCFA/adult eq.)"

// 04/07/2021 request to add household's share of revenues excluding benef's
foreach term in 12 30 {
if `term' == 30 local unit day  // 30 day
if `term' == 12 local unit month // 12 month

foreach type in pro rev {

gen tot_hhlb_`type'`term' = tot_hh_`type'`term' - tot_chef_`type'`term' // hh less ben
label var tot_hhlb_`type'`term' "Business `type' winsorized, household less benef, `term'-`unit' term (1000 FCFA)"

// 04/08/2021 request to benef's share of hh rev
gen tot_bohh_`type'`term' = tot_chef_`type'`term' / tot_hh_`type'`term' // ben over hh
label var tot_bohh_`type'`term' "Business `type' winsorized, `term'-`unit' term, fraction: chef/household"
}
}



********************************************************************************
*** insert true zeros
********************************************************************************


 local bus_vars na_bus2_op_wn_12 bus2_dum bus2_dum30   /// B8.1, B8.2, B8.3
   na_bus2_op_wn_12_chef bus2_chef_dum bus2_chef_dum30   ///
   tot_hhlb_rev12 tot_hhlb_rev30 ///
   tot_hhlb_pro12 tot_hhlb_pro30 ///
   tot_chef_pro30* tot_chef_rev30* ///
   tot_hh_pro30*  tot_hh_rev30* ///
   tot_chef_rev12* tot_chef_pro12* ///
   tot_hh_rev12*  tot_hh_pro12* ///
   bus2_abandon_24_dum bus2_abandon_24_dum_chef chef_ownmanage /// B8.4
   bus2_profits_hh_xof bus2_profits_hh_xof_chef /// B8.8
   tot_bus_least tot_bus_most ///
   tot_busmths_uniq tot_busmths_uniq_chef ///
   tot_bus2_ppl_uniq ///
   bus2_divrse bus2_profits_btm ///
   div_n_na_12_hh div_n_na_12_chef ///
   bus_assval_98 bus_assval_95  bus_assval_98_chef ///
   bus_assval12_98 bus_assval12_98_ben ///
   hh_has_bus_empl

ds bus1_chef_*_d
local chef_dum_bytype `r(varlist)' // benef ext mgns

ds bus_rev12_* bus_pro12_* // split revenues and profits by activity
local revsplit `r(varlist)'

capture ds tot_cost_*
if _rc local costs // empty
else local costs `r(varlist)'


// insert true zeros
foreach var in `bus_vars' `revsplit' `costs' `chef_dum_bytype' {
capture confirm var `var'
if _rc == 0 { // if the variable exists, insert zeros. Variables vary between phases
replace `var' = 0 if `var' == .
}
}

isid hhid
compress
save "${baseline_intermediate}/business", replace




