********************************************************************************
* Employment   *
*******************************************************************************
clear
use "${baseline_intermediate}/salary_long.dta"

drop if empl_type == .
*fix_continuous empl_rev30 empl_rev12
global id_var hhid mem_pos
keep $id_var empl_pos empl_rev30 empl_rev12

rename empl_rev?? empl_rev??_

reshape wide empl_rev30_ empl_rev12_, j(empl_pos) i($id_var)

egen div_empl_n = rownonmiss(empl_rev12*) // count at 12 months only
isid $id_var

* merging with demographics data to get chef position in the household
merge m:1 hhid using "${baseline_intermediate}/demographics.dta", keepusing(chef_pos) gen(_mdem)
keep if _mdem == 3
drop _mdem

****************************************************
// HH-level and chef outcomes
****************************************************


rename empl_rev* rev*


* employment revenues in entire household

foreach term in 30 12 {


egen rev`term' = rowtotal(rev`term'_1 rev`term'_2 rev`term'_3 rev`term'_4 rev`term'_5)
gen rev`term'_win = rev`term'
_pctile rev`term' , p(98)
replace rev`term'_win  = `r(r1)' if !missing(rev`term') & rev`term' > `r(r1)'
drop rev`term'

if `term' == 30 local unit day
if `term' == 12 local unit month

bysort hhid : egen tot_empl_rev`term'_xof = total(rev`term'_win)
replace tot_empl_rev`term'_xof = tot_empl_rev`term'_xof / 1000
label var tot_empl_rev`term'_xof "B.2.2  HH Total `term'-`unit' Income from salaried job wins. (1000 FCFA) at ${phase}"

// HH HEAD/CHEF ONLY
gen rev`term'_chef_win = rev`term'_win if mem_pos == chef_pos
by hhid:  egen tot_empl_rev`term'_chef_xof = total(rev`term'_chef_win)
replace tot_empl_rev`term'_chef_xof = tot_empl_rev`term'_chef_xof / 1000
label var tot_empl_rev`term'_chef_xof "B.2.2  Chef `term'-`unit' Income from salaried job wins. (1000 FCFA) at ${phase}"


***** -----| Secondary B.3.5
gen div_empl`term'_n = 1
replace div_empl`term'_n = 2 if !missing(rev`term'_2)
replace div_empl`term'_n = 3 if !missing(rev`term'_3)
replace div_empl`term'_n = 4 if !missing(rev`term'_4)
replace div_empl`term'_n = 5 if !missing(rev`term'_5)

label var div_empl`term'_n "B.3.5 HH Member No. of `term'-`unit' Salaried jobs at ${phase}"

bysort hhid: egen div_empl`term'_hh_n = total(div_empl`term'_n )
label var div_empl`term'_hh_n "B.3.5 HH Total No. of `term'-`unit' Salaried jobs at ${phase}"

gen  empl`term'_chef_n =  div_empl`term'_n if mem_pos == chef_pos
bysort hhid: egen div_empl`term'_chef_n = total(empl`term'_chef_n)
label var div_empl`term'_hh_n "B.3.5 Chef No. of `term'-`unit' Salaried jobs at ${phase}"


if `term' == 30 local unit day
if `term' == 12 local unit month
}

gen PAP_b2_2 = "PAP B2.2"
gen PAP_b3_5 = "PAP B3.5"


local salaryvars PAP_b3_5 div_empl12_chef_n  div_empl30_chef_n  div_empl12_hh_n  div_empl30_hh_n     ///
PAP_b2_2 tot_empl_rev12_xof tot_empl_rev30_xof tot_empl_rev12_chef_xof tot_empl_rev12_chef_xof

keep hhid   `salaryvars'
order hhid  `salaryvars'

duplicates drop
isid hhid

// Generate monthly and yearly dummies for beneficiary
// wrk_sal30 and wrk_sal12 are not aligned with div_*
gen empl_d30_chef = 1 if div_empl30_chef_n > 0 & !missing(div_empl30_chef_n), before(div_empl30_chef_n)
gen empl_d12_chef = 1 if div_empl12_chef_n > 0 & !missing(div_empl12_chef_n), before(div_empl12_chef_n)
label variable empl_d30_chef "Wage-employed in past 30 days"
label variable empl_d12_chef "Wage-employed in past 12 months"

compress
save "${baseline_intermediate}/employment", replace
