global cty NER

* Set datasets
if "${cty}" == "NER" loc varlist_NER hhid region_ department_ commune_ village_ // from R_*

clear
use "${baseline_intermediate}/foodconsumption_long.dta"

merge m:1 hhid using "${baseline_intermediate}/identification.dta", keepusing(`varlist_${cty}' consent) gen(_mID)

// drop _mID

merge m:1 hhid using "${baseline_intermediate}/demographics.dta", keepusing(mem_n equiv_n)

drop if consent == 0 & _merge == 2
label var mem_n "Number of members in household"
label var equiv_n "Number of adult equivalents in household"

drop _merge consent

order `varlist_${cty}', first

* Rename and label variables
*translate_food

capture confirm var gp_consum_bot
if _rc == 0 {
rename gp_consum_bot consum_bot_qty// mistake in SurveyCTO variable name
}
capture confirm var consum_bot
if _rc == 0 {
rename consum_bot consum_bot_qty
}

rename consum_u_bot_name consum_bot_u_name

label define yes1no0 0 "no" 1 "yes"
label values consum_ate yes1no0
label values consum_bot_u consum_u // SurveyCTO generates different value labels for each variable, but consum_u and consum_bot_u have the same value labels

order consum_bot_u_o consum_bot_u_name, after(consum_bot_u)

*** Label Variables
label var hhid"id du menage"
label var consum_pos"position du produit dans la liste"
label var consum_name"nom du produit"
label var consum_ate"11.01: Votre menage a-t-il consomme [] au cours des 7 derniers jours?"
label var consum_qty"11.02: Quelle est la quantite totale du [] consomme par le menage au cours des 7 derniers jours?"
label var consum_u"11.02: Unite"
label var consum_u_o"11.02: Autre unite a specifier"
label var consum_u_name"11.02: Unite (string)"
label var consum_prod"11.03: Parmi cette quantite consommee, quelle est celle qui provient de la production propre du menage?"
label var consum_gift"11.04: Parmi cette quantite consommee, quelle est celle qui provient d'autres sources (non-achete, cadeau, paiement en nature, etc.)?"
label var consum_bot_freq"11.05: Quelle est la derniere fois que [] a ete achete dans le menage?"
label var consum_bot_qty"11.06: Quelle est la quantite du [] achete la derniere fois?"
label var consum_bot_u"11.06: Unite"
label var consum_bot_u_o"11.06: Autre unite a specifier"
label var consum_bot_u_name "11.06: Unite (string)"
label var consum_bot_val"11.07: Quelle est la valeur du [] achete la derniere fois?"
label var consum_in_bot"11.08: Si unite d'achat est different du unite de consommation (consum_bot_u / consum_u)"



****************************e****************************************************
***** 1. Define problem food types for later

#delimit ;
label define prob_food
1 "undefined consumed quantity - don't know, refused"
2 "outlier consumed food/unit qty"
4 "undefined consumed unit"
5 "unconvertible consumed unit";
#delimit cr

gen prob_food:prob_food  = 0


********************************************************************************
***** 2. Recode missing values
recode consum_qty consum_prod consum_gift consum_bot_qty consum_bot_val consum_in_bot ///
(-777 = .o) (888 = .d) (999 = .r) (555 = .r) (1234 = .d) (9999 = .r)

// remove 99999 and 88888 etc
*fix_continuous consum_qty consum_prod consum_gift consum_bot_qty consum_bot_val consum_in_bot

* consum_in_bot cannot be 0 and consum_bot_qty should be missing if 0
replace consum_bot_freq = .m if consum_bot_qty == 0
replace consum_bot_u = .m if consum_bot_qty == 0


********************************************************************************
***** 3. Standardize "specify other" consumption units (consum_u, consum_bot_u)
*We manually standardized the "specify other" units and attribute new codes in the excel file. Add these new codes to a new value labels, consum_u_extend.
*see data_cleaning_otherunits.xls

label copy consum_u consum_u_extend

*** Consumption units
gen consum_u_recode:consum_u_extend = consum_u, after(consum_u)
replace consum_u_o = trim(itrim(lower(consum_u_o)))
replace consum_u_o = subinstr(consum_u_o, " ", "", .)



*** Purchase units
gen consum_bot_u_recode:consum_u_extend = consum_bot_u, after(consum_bot_u)
replace consum_bot_u_o = trim(itrim(lower(consum_bot_u_o)))
* remove all spaces in string:
replace consum_bot_u_o = subinstr(consum_bot_u_o, " ", "", .)


if "${cty}" == "NER" {
*We manually standardized the "specify other" units and attribute new codes in the excel file. Add these new codes to a new value labels, consum_u_extend.


/* Original
1 Botte
14 Assiette
15 Calebasse
16 Verre
17 Gramme
18 Kg
19 Litre
20 Panier
21 Sac de 100 Kg
22 Sac de 50 kg
23 Sachet
24 Tas
25 Tia
26 Tongolo
27 Unité
-777 Autre
*/

/* NOTE: "boite" given two different codes (61/74) -- keep 74 */
#delimit ;
label define consum_u_extend
28 "bidon"
29 "brochette"
30 "carreaux"
31 "cube"
32 "louche"
33 "tasse"
34 "paquet"

, add ;
#delimit cr


loc recodes 14 15 17 19 22 23 25 26 27 28 29 30 31 32 33 34




loc consum_17 `"milligrams"'
loc consum_18 `"quartdekilo"'
loc consum_19 `"deuxcentcinquantecentilitre demilitre quartdelitre"'
loc consum_22 `"demisac"'
loc consum_23 `"sachet"'
loc consum_24 `"demitas"'
loc consum_25 `"demitia tiyaenpoudre"'
loc consum_26 `"toglo"'
# delimit ;
loc consum_27 `"chevre lot enmoitier noix noixdedoumier tige unpoulet paumedemain"' ;
# delimit cr
loc consum_28 `"bidon"'
loc consum_29 `"brochette brochettes"'
loc consum_30 `"carreaux"'
loc consum_31 `"cube"'
loc consum_32 `"louche louchemoyen"'
loc consum_33 `"tasse"'
loc consum_34 `"packet paquet paquetpetit paquets"'


replace consum_u_recode  = .d if consum_u_o == "nsp"
replace consum_u_recode  = .d if consum_u_o == "non"


}


* Recode based on survey's specify other values and value labels
foreach num in `recodes' {
foreach string in `consum_`num'' {
replace consum_u_recode     = `num' if consum_u_o     == "`string'"
replace consum_bot_u_recode = `num' if consum_bot_u_o == "`string'"
}
}


* fixing quantities for some recoded units

replace consum_qty = consum_qty/1000 if consum_u_o == "milligrams"
replace consum_qty = consum_qty/4 if consum_u_o == "quartdekilo"
replace consum_qty = consum_qty/4 if consum_u_o == "quartdelitre"
replace consum_qty = consum_qty/2 if consum_u_o == "demilitre"
replace consum_qty = consum_qty*2.5 if consum_u_o == "deuxcentcinquantecentilitre"
replace consum_qty = consum_qty/2 if consum_u_o == "demisac"
replace consum_qty = consum_qty/2 if consum_u_o == "demitas"




* Fix consum_in_bot if other was chosen
replace consum_in_bot = 1 if consum_u_recode == consum_bot_u_recode & consum_ate == 1

********************************************************************************
***** 4. Identify problem entries, where consumed but not purchases units in dataset // the below is no longer doing this

replace prob_food = 1 if consum_qty == .o | consum_qty == .r | consum_qty == .d
replace prob_food = 4 if consum_u_recode == .o | consum_u_recode == .r | consum_u_recode == .d
replace consum_ate = 0 if missing(consum_ate) & missing(consum_u_recode)

********************************************************************************
***** 5. Identify problem entries based on IQR

*** Identify outliers as observations outside 10 IQR of p75 and p25 for unit of per capita consumption
gen consum_qty_pc = consum_qty / mem_n
byso consum_pos consum_u_recode : egen p75_qty_pc = pctile(consum_qty_pc) if !missing(consum_qty_pc) , p(75)
byso consum_pos consum_u_recode : egen p25_qty_pc = pctile(consum_qty_pc) if !missing(consum_qty_pc), p(25)
byso consum_pos consum_u_recode : egen iqr_qty_pc = iqr(consum_qty_pc) if !missing(consum_qty_pc)

*** set as prob_food = 2 if weird consumed quantity here
replace prob_food = 2 if (consum_qty_pc > (p75_qty_pc + (10*iqr_qty_pc)) | ///
  consum_qty_pc < (p25_qty_pc - (10*iqr_qty_pc))) & ///
  !missing(consum_qty_pc)


// people report to eat and buy in different units but report same quantity
// e.g. in SEN 300 grams of peanut butter purchased and 300 units consumed
tab consum_bot_u_recode prob_food // "grams" is especially a problem in SEN
tab consum_u_recode prob_food // "grams" is especially a problem in SEN
foreach var of varlist consum_u_recode consum_bot_u_recode {
dis ""
dis ""
dis as result "Check for outliers in `var'"
qui levelsof `var', local(`var'_levs)
foreach lev in ``var'_levs' {
qui count if `var' == `lev' & prob_food == 2 // weird consumed quantity
local freq : di %9.0fc `r(N)'
if `r(N)' > 0 dis as error "`freq' outliers for food pos = `lev'"
else dis as text "`freq' outliers for food pos = `lev'"

if `r(N)' > 100 dis as error "^ many outliers for food units = `lev'"
}
}

// see where most quantity outliers exist
egen unitmismatch = group(consum_u_recode consum_bot_u_recode) if consum_u_recode != consum_bot_u_recode
tab unitmismatch prob_food
egen unitmatch = group(consum_u_recode consum_bot_u_recode) if consum_u_recode == consum_bot_u_recode
tab unitmatch prob_food

********************************************************************************
***** 6. Median price by unit by food for each locality

// currency info only available after BL in NER
capture confirm var consum_bot_val_cur
if _rc == 0 { // if currency var exists
scale_cur consum_bot_val consum_bot_val_cur
}

gen bot_unit_price = consum_bot_val / consum_bot_qty
label variable bot_unit_price "purchased unit price"

replace consum_in_bot = 1 if consum_u_recode == consum_bot_u_recode & !missing(consum_bot_u_recode)

gen ate_unit_price = (consum_bot_val / consum_bot_qty) / consum_in_bot
label variable ate_unit_price "consumed unit price, using conversion"
// some consum_in_bots are really large. Those make ate_unit_price smaller

* important that these go from smallest to largest geographic location
loc locations_NER region_ department_ commune_ village_




* Create median price units for each location
assert "`locations_$cty'" != ""
foreach loc in `locations_$cty' {
display "`loc'"
byso `loc' consum_pos consum_bot_u_recode: egen bot_mp_`loc' = median(bot_unit_price)
byso `loc' consum_pos consum_bot_u_recode: egen bot_mp_`loc'_n = count(bot_unit_price)
label var bot_mp_`loc' "median price of this purchased food/unit at `loc' level"
*
label var bot_mp_`loc'_n "count of this purchased food/unit at `loc' level"
byso `loc' consum_pos : egen bot_mp_`loc'_n2 = count(bot_unit_price)
label var bot_mp_`loc'_n2 "count of this purchased food at `loc' level"

}

* overall median unit price
byso consum_pos consum_bot_u_recode: egen bot_mp_country = median(bot_unit_price)
label var bot_mp_country "median price of this purchased unit"

preserve
keep hhid `locations_$cty' *name* consum_bot_u bot_mp* consum_name consum_pos
save "${baseline_intermediate}/median_food_prices.dta", replace
restore

********************************************************************************
***** 7. Replace median unit prices to correct consumed unit

** where bot and consumed units are the same, assign bought median prices to ate prices
assert "`locations_$cty'" != ""
foreach loc in `locations_$cty' country {
gen ate_mp_`loc' =  bot_mp_`loc' if consum_u_recode == consum_bot_u_recode

label var ate_mp_`loc' "median price of this consum food/unit at `loc' level"
}


** where bot and consumed units are different, i.e.: consum_in_bot != 1
                                    // and where consum_in_bot == . (not purchased)
foreach loc in `locations_$cty' {
display "`loc'"
sort `loc' consum_pos consum_u_recode  (ate_mp_`loc'), stable
by `loc' consum_pos consum_u_recode  (ate_mp_`loc') : replace ate_mp_`loc' = ate_mp_`loc'[_n-1] if missing(ate_mp_`loc')
}

sort consum_pos consum_u_recode (ate_mp_country), stable
by consum_pos consum_u_recode (ate_mp_country) : replace ate_mp_country = ate_mp_country[_n-1] if missing(ate_mp_country)

* observations that are still missing the unit price
gen missing_unit_price = missing(ate_mp_country) & consum_ate == 1
tab consum_name missing_unit_price //if missing_unit_price

****
/***
Different methods for getting consumption
1) Method 1: always try to used median prices when can (eat_value_1)
2) Method 2: only use median prices when have to - try to get as much information from the survey as possible
3) Only include food *purchases* in the last 7 days  (bot_food7)
***/

** loop over both methods. Consumption aggregates sum all consumption vars seperately for each method. see below
local consum_methods 1 2

foreach meth in `consum_methods'{

sort hhid consum_pos
gen eat_value_`meth' = .

*** Method 1
if "`meth'" == "1" {


*** replace by median in progressively larger locality
assert "`locations_$cty'" != ""
foreach loc in `locations_$cty' country {
replace eat_value_`meth' = consum_qty * ate_mp_`loc' if missing(eat_value_`meth')
}

*** if eat_value missing, but have a survey conversion (ie, no unit price in data set but have a conversion in survey for this unit
replace eat_value_`meth' = (consum_qty/consum_in_bot)*(consum_bot_val/consum_bot_qty) if eat_value_`meth' == .

}



*** Method 2
// If we have the purchase price of a food product, and consumption units are the
// same as purchase units, then we use the purchase price to compute the consumption
// value for each food product. If these units are different, we first rescale
// purchased quantities using a reported conversion factor. Finally, if a product
// was consumed but not purchased (i.e. we do not have its price), we use median
// purchase prices. We then sum over products within the household.
if "`meth'" == "2" {
*use each item's price (val/qty)
** first, if bot and conusme units are the same
replace eat_value_`meth' = consum_qty*consum_bot_val/consum_bot_qty if consum_u_recode == consum_bot_u_recode // same units

*** if eat_value missing, but have a survey conversion (ie, not unit price in data set but have a conversion in survey for this unit
replace eat_value_`meth' = (consum_qty/consum_in_bot)*(consum_bot_val/consum_bot_qty) if eat_value_`meth' == . & !missing(consum_in_bot)

*** replace by median in progressively larger locality
assert "`locations_$cty'" != ""
foreach loc in `locations_$cty' country {
replace eat_value_`meth' = consum_qty * ate_mp_`loc' if missing(eat_value_`meth')
}
}

gen prob_food_`meth' = prob_food
replace prob_food_`meth' = 5  if eat_value_`meth' == . & consum_ate == 1



* count if eat_value == . & consum_ate == 1 // prob foods == 5
* NER 85



********************************************************************************
/***** 8. Establish "food importance" of each food type and use to address problem foods
*generate a temp value for weekly food consumption
*get total value for household
*excluding households that have problem food, non-important foods are foods
*that are less than 10% of food consumption for 90% of households
*if important & problem -> set to missing and total food consumption will also be missing
*if unimportant & problem -> set to 0
*/

// br hhid consum_pos consum_name consum_ate consum_qty consum_qty_pc consum_u_recode ///
// consum_bot_qty consum_bot_qty_pc consum_bot_u_recode prob_food  consum_qty_pc_cap swaps_dummy ///
// eat_value_* ///
// if consum_u_recode == 4 & consum_bot_u_recode == 17
// sort consum_name swaps_dummy consum_qty_pc consum_bot_qty_pc

sort hhid consum_pos
** set problem foods to missing for now, will decide whether 0 or missing based on next step
replace eat_value_`meth' = .p if prob_food_`meth' != 0


// generate hh-dummy for problem foods
byso hhid : egen has_prob_`meth' = total(prob_food_`meth')
replace has_prob_`meth' = 1 if has_prob_`meth' >= 1 & !missing(has_prob_`meth')

// previous command is: recode eat_value (. = 0) but this leaves eat_value = .p if minor problem food
recode eat_value_`meth' (. = 0)

byso hhid : egen total_value_`meth' = total(eat_value_`meth')
gen share_`meth' = eat_value_`meth' / total_value_`meth'

// minor food for household
gen minor_hh_`meth' = (share_`meth' < 0.1)

// don't include households with problematic foods in the calculation
replace minor_hh_`meth' = . if has_prob_`meth' == 1

byso consum_pos : egen mean_minor_`meth' = mean(minor_hh_`meth')
gen is_minor_`meth' = (mean_minor_`meth' >= 0.9)

drop total_value_`meth'


*** tag if a major food/minor food is also a problem food
gen major_prob_`meth' = (prob_food_`meth' != 0 & is_minor_`meth' == 0)
bysort hhid: egen has_major_prob_`meth' = total(major_prob_`meth')
replace has_major_prob_`meth' = 1 if (has_major_prob_`meth' >= 1 )

gen minor_prob_`meth' =  ( prob_food_`meth' != 0 & is_minor_`meth' == 1 )
bysort hhid: egen has_minor_prob_`meth' = total(minor_prob_`meth')
replace has_minor_prob_`meth' = 1 if has_minor_prob_`meth' >= 1

********************************************************************************
***** 9. generate per capita value of food, with 0s. removed gift variables


*** set to 0s if minor food and problem (same as has_minor_prob_`meth' == 1)
replace eat_value_`meth' = 0 if prob_food_`meth' !=0 & is_minor_`meth' ==1




*** winsorize within each food item (smallest component type possible)
levelsof consum_pos, local(consum_pos)
foreach pos in `consum_pos' {

_pctile eat_value_`meth' if consum_pos == `pos' & !missing(eat_value_`meth') , p(98)
replace eat_value_`meth' = `r(r1)' if consum_pos == `pos' & eat_value_`meth' > `r(r1)' & !missing(eat_value_`meth')
}

bysort hhid: egen food_`meth'_week_xof = total(eat_value_`meth')

*** set to missing if major problem or no reported consumption
replace food_`meth'_week_xof = .m if has_major_prob_`meth' == 1 | food_`meth'_week_xof == 0 // if report no consumption, set to .m
label var food_`meth'_week_xof "Total food consumption (week)"


*** food_day_xof
gen food_`meth'_day_xof = food_`meth'_week_xof / 7
label var food_`meth'_day_xof "Total food consumption (day)"

*** food_year_xof
gen food_`meth'_year_xof = food_`meth'_week_xof * 52
label var food_`meth'_year_xof "Total food consumption (year)"

*** food_day_pc_xof
gen food_`meth'_day_pc_xof = food_`meth'_day_xof / mem_n
label variable food_`meth'_day_pc_xof "Total value: Food consumption (day) (per capita)"

*** food_day_eq_xof
gen food_`meth'_day_eq_xof = food_`meth'_day_xof / equiv_n
label variable food_`meth'_day_eq_xof "Total value: Food consumption (day) (adult equiv)"

    order hhid consum_pos consum1_name eat_value_*
    sort hhid consum_pos, stable
    tempfile byfood_`meth'
    save "`byfood_`meth''"

preserve

keep hhid food_*_xof mem_n equiv_n
duplicates drop
isid hhid

gen __FOOD_`meth'__ = "FOOD CONSUMPTION `meth'", after(hhid)

tempfile food_consumption_`meth'
save   "`food_consumption_`meth''"

restore



}



clear
use "`byfood_1'"
sum eat_value_1

clear
use "`byfood_2'"
sum eat_value_1 eat_value_2

order commune_ hhid eat_value_1 eat_value_2 consum1_name consum_pos
keep if inlist(consum1_name, "Mais", "Mil", "Riz")

sort commune_ consum_pos, stable
by commune_ consum_pos: egen comp = total(eat_value_2)
keep commune_ consum_pos consum1_name comp
duplicates drop

sort commune_, stable
by commune_: egen denom = total(comp)
format comp %12.0g
format denom %12.0g

gen share = comp/denom

drop comp
drop denom

gen commune = "Tagazar" if commune_ == 49
replace commune = "Imanan" if commune_ == 9223
replace commune = "Dantchandou" if missing(commune)

drop commune_
rename commune commune_name

replace consum1_name = lower(consum1_name)
replace consum1_name = "maize" if consum1_name == "mais"
replace consum1_name = "millet" if consum1_name == "mil"
replace consum1_name = "rice" if consum1_name == "riz"

drop consum_pos
reshape wide share, i(commune_name) j(consum1_name) string
rename share* *_share

save "${baseline_final}/staples-shares.dta", replace


********************************************************************************
********************************************************************************
* NONFOOD
********************************************************************************
********************************************************************************

use "${baseline_intermediate}/nonfood_consumption_wide.dta", clear

merge m:1 hhid using "${baseline_intermediate}/demographics", ///
keepus(mem_n equiv_n)

capture prog drop clean_nonfood
program define clean_nonfood

// set consumption value to "0" if item not consumed
qui ds consum_nf_val*
forvalues i = 1 / `:word count `r(varlist)'' {
replace consum_nf_val_`i' = 0 if consum_nf_`i' == 0
capture confirm var consum_nf_cur_`i'
if _rc == 0 { // if currency var exists
scale_cur consum_nf_val_`i' consum_nf_cur_`i'
}
}
// if a component is missing, this effectively sets to 0
egen missing = anycount(consum_nf_val*), v(888 999)

order consum_nf_val_*, after(hhid)

*winsorize within component, at hh level

qui ds consum_nf_val*
forvalues i = 1 / `:word count `r(varlist)'' {
_pctile consum_nf_val_`i' if consum_nf_val_`i' > 0  , p(98)
replace consum_nf_val_`i' = `r(r1)' if consum_nf_val_`i' > `r(r1)' & !missing(consum_nf_val_`i')

drop if consum_nf_val_`i' < 0
// 2 values at FU2 in NER
// 1 value  at FU1 in MRT
}
end
clean_nonfood // I use this program again below when preparing repairs for SEN


if "${cty}" == "NER" {


*** 7 days
egen con_7days_day  = rowtotal(consum_nf_val_1 - consum_nf_val_7), m
replace con_7days_day = con_7days_day / 7

*** 30 days
egen con_30days_day = rowtotal(consum_nf_val_8 - consum_nf_val_19), m
replace con_30days_day = con_30days_day / 30

*** 6 mos
egen con_6months_day = rowtotal(consum_nf_val_20 - consum_nf_val_43), m
replace con_6months_day = con_6months_day / 182.5


*** 12 mos
egen con_12months_day = rowtotal(consum_nf_val_44 - consum_nf_val_45), m
replace con_12months_day = con_12months_day / 365
}



** per day
egen   nonfood_day_xof = rowtotal(con_*_day)
label var nonfood_day_xof "Total value: Nonfood consumption (day)"

** per year
gen   nonfood_year_xof = nonfood_day_xof * 365
label var nonfood_year_xof "Total value: Nonfood consumption (year)"

*** per day per capita
gen   nonfood_day_pc_xof = nonfood_day_xof / mem_n
label var nonfood_day_pc_xof "Total value: Nonfood consumption (day) (per capita)"

** per day per adult eq.
gen   nonfood_day_eq_xof = nonfood_day_xof / equiv_n
label var nonfood_day_eq_xof "Total value: Nonfood consumption (day) (adult equivalent)"


// save
keep hhid nonfood_*_xof mem_n

gen __NONFOOD__ = "NONFOOD CONSUMPTION", after(hhid)

tempfile nonfood_consumption
save "`nonfood_consumption'"



********************************************************************************
********************************************************************************
* EDUCATION
********************************************************************************
********************************************************************************


use "${baseline_intermediate}/niger_main_2021.dta", clear

merge 1:1 hhid using "${baseline_intermediate}/demographics.dta", keepusing(mem_n equiv_n)

drop if consent == 0
drop _merge

recode edu_fee* (999 = .o) (888 = .o) (555 = .o)

// tag missing
egen missing = rowmiss(edu_fee*)

// winsorize
foreach var of varlist edu_fee? {
capture confirm var edu_fee_cur
if _rc == 0 { // if currency var exists
scale_cur `var' edu_fee_cur
}

// _pctile `var' if `var'  > 0  , p(98)
_pctile `var'  , p(98)
replace `var'  = `r(r1)' if !missing(`var' )  & `var' >`r(r1)'
}

drop missing

// only account for positive expenditures
if "$cty" == "NER" local educ_exp edu_fee1 edu_fee2 edu_fee3 edu_fee4 edu_fee5 // ignore edu_fee6 cause scholarship



*** edu_year_xof
egen   edu_year_xof = rowtotal(`educ_exp')

*** edu_day_xof
gen   edu_day_xof = edu_year_xof / 365

**** per capita
*** edu_year_pc_xof
gen   edu_year_pc_xof = edu_year_xof / mem_n

*** edu_day_pc_xof
gen   edu_day_pc_xof = edu_day_xof / mem_n

*** edu_day_eq_xof
gen   edu_day_eq_xof = edu_day_xof / equiv_n

// save
keep hhid edu_*_xof


foreach v in edu_year_xof edu_day_xof edu_year_pc_xof edu_day_pc_xof edu_day_eq_xof {
bysort hhid: egen `v'_total = total(`v')
drop `v'
rename `v'_total `v'
}

duplicates drop

gen __EDUCATION__ = "EDUCATION", after(hhid)
label var edu_year_xof "Total value: Education consumption (year)"
label var edu_day_xof "Total value: Education consumption (day)"
label var edu_year_pc_xof "Total value: Education consumption (year) (per capita)"
label var edu_day_pc_xof "Total value: Education consumption (day) (per capita)"
label var edu_day_eq_xof "Total value: Education consumption (day) (adult equivalent)"


tempfile education_consumption
save "`education_consumption'"


********************************************************************************
********************************************************************************
* HEALTH
********************************************************************************
********************************************************************************

use "${baseline_intermediate}/niger_main_2021.dta", clear


local list a b c d e f g

merge 1:1 hhid using "${baseline_intermediate}/demographics.dta", keepusing(mem_n equiv_n)



// households that did not consent
drop if consent == 0
drop _merge

// set consumption value to zero if the item is not consumed
recode health_*_amt (999 = .m) (888 = .d)


foreach i in `list' { // no cur info in SEN (all in FCFA)
dis "`i'"
capture confirm var health_`i'_amt_cur
if _rc == 0 { // if currency var exists
nois scale_cur health_`i'_amt health_`i'_amt_cur
}
}

// tag missing
egen missing = rowmiss(health_*_amt) // effectively treats as 0

// winsorize
foreach var of varlist health_*_amt {
_pctile `var' if `var'  > 0  , p(98)
replace `var'  = `r(r1)' if `var' > `r(r1)' & !missing(`var' )
}


** 4 weeks
egen health_4weeks_day_xof = rowtotal(health_a_amt health_b_amt health_c_amt)
replace health_4weeks_day_xof = health_4weeks_day_xof / 28

** 12 months
egen health_12months_day_xof = rowtotal(health_d_amt health_e_amt health_f_amt health_g_amt)
replace health_12months_day_xof = health_12months_day_xof / 365


** Per day
egen    health_day_xof = rowtotal(health_*_day_xof)
label var health_day_xof "Total value: Health consumption (day)"

** per year
gen   health_year_xof = health_day_xof * 365
label var health_year_xof "Total value: Health consumption (year)"

** per day per capita
gen   health_day_pc_xof = health_day_xof / mem_n
label var health_day_pc_xof "Total value: Health consumption (day) (per capita)"

** Per day per adult eq.
gen   health_day_eq_xof = health_day_xof / equiv_n
label var health_day_eq_xof "Total value: Health consumption (day) (adult equivalent)"


// save
keep hhid health_*_xof

local health_vars  health_4weeks_day_xof health_day_xof health_year_xof health_day_pc_xof health_day_eq_xof
foreach v in `health_vars' {
bysort hhid: egen `v'_total = total(`v')
drop `v'
rename `v'_total `v'
}

label var health_day_xof "Total value: Health consumption (day)"
label var health_year_xof "Total value: Health consumption (year)"
label var health_day_pc_xof "Total value: Health consumption (day) (per capita)"
label var health_day_eq_xof "Total value: Health consumption (day) (adult equivalent)"

duplicates drop

gen __HEALTH__ = "HEALTH", after(hhid)

sort hhid
tempfile health_consumption
save "`health_consumption'"




********************************************************************************
********************************************************************************
* CELEBRATIONS
********************************************************************************
********************************************************************************


use "${baseline_intermediate}/nf_celebrations_long.dta", clear
merge m:1 hhid using "${baseline_intermediate}/demographics.dta", keepusing(mem_n equiv_n)
drop _merge

assert cel_food == . if cel == 0 // check no spending if no celebration

order cel_food cel_drink cel_cloth cel_nonfood, after (cel)

* winsorize without adjusting for currency differences
foreach item in food drink cloth nonfood {
display "`item'"
capture confirm var cel_`item'_cur
if _rc == 0 { // if currency var exists
scale_cur cel_`item' cel_`item'_cur
}
// winsorize at smallest component (spending types)
_pctile cel_`item' if cel_`item' > 0  , p(98)
replace cel_`item' = `r(r1)' if cel_`item' > `r(r1)' & !missing(cel_`item')
}

* flag missing values
egen missing = anycount(cel_food cel_drink cel_cloth cel_nonfood), values(888 999)
tab missing // no celeb values == 888 or 999

* total spending on each celebration
egen cel_items_year  = rowtotal(cel_food - cel_nonfood), m


* household spending
*** cel_year_xof
bysort hhid: egen cel_year_xof = total(cel_items_year)
label var cel_year_xof "Total value: Celebration consumption (year)"

*** cel_day_xof
gen   cel_day_xof = cel_year_xof / 365
label var cel_day_xof "Total value: Celebration consumption (day)"

*** cel_day_pc_xof
gen   cel_day_pc_xof = cel_day_xof / mem_n
label var cel_day_pc_xof "Total value: Celebration consumption (day) (per capita)"

*** cel_day_eq_xof
gen   cel_day_eq_xof = cel_day_xof / equiv_n
label var cel_day_eq_xof "Total value: Celebration consumption (day) (adult equivalent)"


// save
keep hhid cel_*_xof mem_n
duplicates drop

gen __CELEBRATION__ = "CELEBRATIONS", after(hhid)

tempfile celeb_consumption
save "`celeb_consumption'"


********************************************************************************
********************************************************************************
* Eating Out
********************************************************************************
********************************************************************************


use "${baseline_intermediate}/niger_main_2021.dta", clear
order hhid


merge m:1 hhid using "${baseline_intermediate}/demographics.dta", keepusing(mem_n equiv_n)

// households that did not consent
drop if consent == 0
drop _merge

// set consumption value to zero if the item is not consumed
recode eat_out_xof (999 = .m) (888 = .d)


capture confirm var eat_out_xof_mon
if _rc == 0 { // if currency var exists
scale_cur eat_out_xof eat_out_xof_mon
}
// wins
_pctile eat_out_xof if eat_out_xof > 0  , p(98)
replace eat_out_xof = `r(r1)' if eat_out_xof > `r(r1)' & !missing(eat_out_xof)

replace eat_out_xof = 0 if eat_out_xof == .


** per day
gen   eatout_day_xof = eat_out_xof / 7
label var eatout_day_xof "Total value: eating out (day)"

** per year
gen   eatout_year_xof = eatout_day_xof * 365
label var eatout_year_xof "Total value: eating out (year)"

*** per day per capita
gen   eatout_day_pc_xof = eatout_day_xof / mem_n
label var eatout_day_pc_xof "Total value: eating out (day) (per capita)"

** per day per adult eq.
gen   eatout_day_eq_xof = eatout_day_xof / equiv_n
label var eatout_day_eq_xof "Total value: eating out (day) (adult equivalent)"


// save
keep hhid eatout_*_xof
duplicates drop

gen __EATOUT__ = "EAT OUT", after(hhid)



foreach v in eatout_day_xof eatout_year_xof eatout_day_pc_xof eatout_day_eq_xof {
bysort hhid: egen `v'_total = total(`v')
drop `v'
rename `v'_total `v'
}

duplicates drop

label var eatout_day_xof "Total value: eating out (day)"
label var eatout_year_xof "Total value: eating out (year)"
label var eatout_day_pc_xof "Total value: eating out (day) (per capita)"
label var eatout_day_eq_xof "Total value: eating out (day) (adult equivalent)"


tempfile eatout_consumption
save "`eatout_consumption'"

local eatout_switch 1




********************************************************************************
* MERGE   *
********************************************************************************
use "`food_consumption_1'", clear
merge 1:1 hhid using "`food_consumption_2'", keep(match) gen(_mfoodMeth2)
merge 1:1 hhid using "`nonfood_consumption'", keep(match) gen(_mnonfood)
merge 1:1 hhid using "`celeb_consumption'", keep(match) gen(_mceleb)
merge 1:1 hhid using "`education_consumption'", keep(match) gen(_meduc)
merge 1:1 hhid using "`health_consumption'", keep(match) gen(_mhealth)

if `eatout_switch' == 1 ///
merge 1:1 hhid using "`eatout_consumption'", keep(match) gen(_meatout)



********************************************************************************
*** d. total consumption



// consum_methods defined in food section above. Aggregate variables into two diff. vars.
foreach meth in `consum_methods' {

gen __TOTAL_CONSUMPTION_`meth'__ = "TOTAL CONSUMPTION `meth'"

foreach type in year_xof day_xof day_pc_xof day_eq_xof {

local suffix // empty at FU

// add datasets where present
if `eatout_switch' == 1 local fu_extra2 eatout_`type'

egen consum_`meth'_`type' = rowtotal(food_`meth'_`type' ///
 nonfood_`type' ///
 cel_`type' ///
 edu_`type' ///
 health_`type'`suffix' /// health at BL exclude health_g
 `fu_extra1'   /// BL and SEN data excludes repair costs
 `fu_extra2') //   BL   data excludes eating out

*** set total consumption to missing if a component is missing
foreach var of varlist food_`meth'_`type' ///
   nonfood_`type' ///
   cel_`type' ///
   edu_`type' ///
   health_`type'`suffix' ///
   `fu_extra1' ///
   `fu_extra2' {
replace consum_`meth'_`type' = . if missing(`var')
}
}

label var consum_`meth'_day_xof    "Total consumption `meth' (day)"
label var consum_`meth'_year_xof   "Total consumption `meth' (year)"
label var consum_`meth'_day_pc_xof "Total consumption `meth' (daily, per capita)"
label var consum_`meth'_day_eq_xof "Total consumption `meth' (daily, per adult equivalent)"

}



// scale down yearly values by 1000
ds *_year_*
foreach var in `r(varlist)' {
replace `var' = `var' / 1000
local lab : var label `var' // dep var label
label variable `var' "`lab' (1000 FCFA)"
}

// Save
order hhid mem_n equiv_n, first
sort hhid
save "${baseline_intermediate}/consumption.dta", replace



