clear
use "${baseline_intermediate}/assets_ag_long"

rename ag_ass_pos ag_asset_pos
rename ass_ag_val ag_ass_val

replace ag_asset_name = "Wheelbarrow" if ag_asset_name == "Brouette"
replace ag_asset_name = "Cart" if ag_asset_name == "Charrette"
replace ag_asset_name = "Plow" if ag_asset_name == "Charrue"
replace ag_asset_name = "Dehulled (peanut, corn)" if ag_asset_name == "Décortiquese (d'arachide, maïs)"
replace ag_asset_name = "Ax / Hoe" if ag_asset_name == "Hache/Houe"
replace ag_asset_name = "Canoe" if ag_asset_name == "Pirogue"
replace ag_asset_name = "Sprayer" if ag_asset_name == "Pulvérisateur"
replace ag_asset_name = "Seed drill" if ag_asset_name == "Semoir"
replace ag_asset_name = "Tractor" if ag_asset_name == "Tracteur"

// get number of ag assets (13 in MRT, 11 in NER, 9 in SEN)
byso hhid : egen ag_n = count(ag_asset_pos)
levelsof ag_n, local(ag_count)
assert ag_n == `ag_count'
drop ag_n

// fix negative, 888 and 999 responses to continuous, positive variables

*check this
foreach var in ag_ass_val {
codebook `var'
*fix_continuous `var'
*assert `var' >= 0 | missing(`var')
}

// problematic asset count numbers
replace ag_asset_n = 1 if ag_asset_n > 1000 & !missing(ag_asset_n) & ag_asset_n == ag_ass_val
// assume sticky fingers
replace ag_asset_n = ag_asset_n / 1000 if ag_asset_n > 10000 // some obvious cases

replace ag_ass_val = .m if ag_ass_val > 1000000 & !missing(ag_ass_val)

gen ass_ag_val_unit = ag_ass_val / ag_asset_n // compute value per unit to be winsorized below


// check for outliers
byso ag_asset_pos : egen p75_assval = pctile(ass_ag_val_unit) if !missing(ass_ag_val_unit) , p(75)
byso ag_asset_pos : egen p25_assval = pctile(ass_ag_val_unit) if !missing(ass_ag_val_unit) , p(25)
byso ag_asset_pos : egen iqr_assval = iqr(ass_ag_val_unit)    if !missing(ass_ag_val_unit)

local factor 10
gen outlier_assval = .
replace outlier_assval = 1 if ass_ag_val_unit > (p75_assval + (`factor'*iqr_assval)) & !missing(ass_ag_val_unit)
replace outlier_assval = 1 if ass_ag_val_unit < (p25_assval - (`factor'*iqr_assval)) & !missing(ass_ag_val_unit)


// initialize asset values to winsorize
gen ass_ag_val_unit_win98 = ass_ag_val_unit
gen ass_ag_val_unit_win95 = ass_ag_val_unit

// 98 p winsorization
foreach pp in 95 98 {

forvalues i = 1/`ag_count' {
qui count if ag_asset_pos == `i' & ass_ag_val_unit != .
if `r(N)' > 0 & `r(N)' != . { // wins. if possible within that asset category (if values exist)
_pctile ass_ag_val_unit if ag_asset_pos == `i', p(`pp')
replace ass_ag_val_unit_win`pp' = `r(r1)' if !missing(ass_ag_val_unit_win`pp') & ass_ag_val_unit_win`pp' > `r(r1)' & ag_asset_pos == `i'
}
}
gen ass_ag_val_win`pp' = ag_asset_n * ass_ag_val_unit_win`pp' // scale back to overall value (not per unit)
bysort hhid : egen ag_val_`pp' = total(ass_ag_val_win`pp')
label var ag_val_`pp' "B.5.1 Direct agricultural asset value, wins. at `pp'p"

replace ag_val_`pp' = ag_val_`pp' / 1000
local this_lab : variable label ag_val_`pp'
label var ag_val_`pp' "(1000 FCFA) `this_lab'"
}

gen probs = ag_ass_val == .m
byso hhid : egen prob_hh = max(probs)
replace ag_val_98 = .m if prob_hh == 1
replace ag_val_95 = .m if prob_hh == 1 // 6 obs for SEN FU

keep hhid ag_val_9? // 95 and 98
duplicates drop
isid hhid

tempfile b5_1_ass_ag_val
save `b5_1_ass_ag_val'



********************************************************************************
**** Secondary B.5.2 Livestock asset values


use "${baseline_intermediate}/livestock_long.dta", clear

rename livestock_pos ani1_pos


sort hhid ani1_pos


// get number of livestock animals (8 in MRT and SEN, 11 in NER)
byso hhid : egen ani_n = count(ani1_pos)
levelsof ani_n, local(ani_count)
assert ani_n == `ani_count'
drop ani_n

// fix negative, 888 and 999 responses to continuous, positive variables
foreach var in ani_count ani_value {
*fix_continuous `var'
recode `var' (-99 = .r) // refused (SEN, FU)
assert `var' >= 0 | missing(`var')
}


    *Double check this not sure what issue tht was being corrected is
*livestock_count_correction // removes 4 issues in ani_val_issue at FU2 and 17 issues at FU1

gen ani_val_issue = 0
replace ani_val_issue = 1 if ani_value < 100 // said value of animals was under 100
replace ani_val_issue = 1 if ani_count > 100 & !missing(ani_count) // said owned over 100


gen ani_val_unit = ani_value / ani_count
replace ani_val_unit = . if ani_val_issue == 1

sort hhid ani1_pos
foreach pp in 95 98 {
gen ani_val_unit_win`pp' = ani_val_unit

forvalues i = 1/`ani_count' { // 11 in NER, 8 in MRT and SEN
qui count if ani == 1 & ani1_pos == `i'
if `r(N)' > 0 & `r(N)' != . { // if obs exist for this animal
_pctile  ani_val_unit if ani1_pos == `i', p(`pp')
replace ani_val_unit_win`pp' = `r(r1)' if !missing(ani_val_unit_win`pp') & ani_val_unit_win`pp' > `r(r1)' &  ani1_pos  == `i'
}
}
gen ani_val_win`pp' = ani_count * ani_val_unit_win`pp'
bysort hhid : egen ani_val_`pp' = total(ani_val_win`pp')
label var ani_val_`pp' "B.5.2 Direct livestock asset value, wins. at `pp'p"

replace ani_val_`pp' = ani_val_`pp' / 1000
local this_lab : variable label ani_val_`pp'
label var ani_val_`pp' "(1000 FCFA) `this_lab'"
}

bysort hhid : egen ani_issue_n = total(ani_val_issue)

keep hhid ani_val_98 ani_val_95 ani_issue_n
duplicates drop
isid hhid
replace ani_val_98 = .m  if ani_issue_n !=0
replace ani_val_95 = .m  if ani_issue_n !=0
drop ani_issue_n
** do not set these .m to 0, but leave as missing
sort hhid


tempfile b5_2_ani_val
save `b5_2_ani_val'



********************************************************************************
**** Secondary B.5.3 Business asset values (see clean_business_joint.do)


********************************************************************************
**** Secondary B.5.4 Household asset count (BL and FU)

use "${baseline_intermediate}/assets_hh_long", clear

codebook hh_asset_n
*fix_continuous hh_asset_n

// fat fingers outliers
if "$cty" == "SEN" & "$ph" == "bl" replace hh_asset_n = 0 if hh_asset_n == 21 & ///
 hh_asset_pos == 28



// get number of assets (17 in MRT, 11 in NER, 46 in SEN)
byso hhid : egen ass_n = count(hh_asset_pos)
levelsof ass_n, local(asset_count)
assert ass_n == `asset_count'
drop ass_n

**some have values - assume 1
replace hh_asset_n = 1 if hh_asset_n > 100000 & !missing(hh_asset_n) // telephone numbers, values

foreach pp in 95 98 {

// wins
gen hh_asset_n_w`pp' = hh_asset_n // initialize asset values to winsorize
forvalues i = 1/`asset_count' {
qui count if hh_asset == 1 & hh_asset_pos == `i'
if `r(N)' > 0 & `r(N)' != . { // if there are any observations in that category
_pctile hh_asset_n if hh_asset_pos == `i', p(`pp')
 replace hh_asset_n_w`pp' = `r(r1)' if !missing(hh_asset_n_w`pp') & hh_asset_n_w`pp' > `r(r1)' & hh_asset_pos == `i'
}
}

bysort hhid : egen hh_ass_count_hh_`pp' = total(hh_asset_n_w`pp')
label var hh_ass_count_hh_`pp' "Count of household assets owned by hh mems (`pp'p wins.)"
}

// calculate number of assets in set of assets overlapping b/n NER

// overlapping HH assets SEN & NER
#delimit ;
local items `""Téléphone portable"
  "Telephone portable"
  "Bicyclette"
  "Radio/Radiocassette"
  "Radio simple/Radiocassette"
  "Télévision"
  "Appareil TV"
  "Motocyclette"
  "Cyclomoteur/Vélomoteur, motocyclette"
  "Matelas éponge"
  "Lit + Matelas"
  "Matelas ressort"
  "Lit simple"
  "Lit"
  "Matelas simple"
  "Table"
  "Chaise"
  "' ;
local tv `""Télévision"
  "Appareil TV"
  "' ;
#delimit cr

gen overlap = .
foreach item in `items' {
replace overlap = 1 if hh_asset_name == "`item'"
}
gen tv = .
foreach item in `tv' {
replace tv = 1 if hh_asset_name == "`item'"
}


// calculate winsorize count of overlapping assets b/n NER
gen hh_asset_n_ovr = hh_asset_n_w98 if overlap == 1
bysort hhid : egen hh_ass_count_ovr_98 = total(hh_asset_n_ovr)
label var hh_ass_count_ovr_98 "Count of overlapping household assets (98p wins.)"

gen hh_asset_n_tv = hh_asset_n_w98 if tv == 1
bysort hhid : egen hh_ass_count_tv_98 = total(hh_asset_n_tv)
label var hh_ass_count_tv_98 "Count of TVs (98p wins.)"





// calculate chef's share


merge m:1 hhid using "${baseline_intermediate}/demographics", keepusing(chef_pos)
assert _merge == 3
drop _merge


tostring chef_pos, replace

foreach var of varlist chef_pos hh_asset_who {
replace `var' = " " + `var' + " "
}
gen chef_owns = strpos(hh_asset_who, chef_pos) > 0





foreach pp in 95 98 {
gen hh_asset_n_chef_w`pp' = hh_asset_n_w`pp' if chef_owns == 1
bysort hhid : egen hh_ass_count_chef_`pp' = total(hh_asset_n_chef_w`pp')
label var hh_ass_count_chef_`pp' "Count of household assets owned by dhef (`pp'p wins.)"
}

// calculate hh-less-chef share
foreach pp in 95 98 {
gen hh_asset_n_hhlb_w`pp' = hh_asset_n_w`pp' if chef_owns != 1
bysort hhid : egen hh_ass_count_hhlb_`pp' = total(hh_asset_n_hhlb_w`pp')
label var hh_ass_count_hhlb_`pp' "Count of household assets owned by all hh mems but chef (`pp'p wins.)"

assert hh_ass_count_hhlb_`pp' + hh_ass_count_chef_`pp' == hh_ass_count_hh_`pp' // assert additive
}


/* Sort this when we need asset categorisation
// calculate ownership by asset category not type (1-5)
categorize_hhass, gen(category) // categorize items in hh_asset_name
levelsof category, local(cats)
foreach pp in 95 98 {
foreach i in `cats' {

if `i' == 1 local catname "furniture assets"
if `i' == 2 local catname "mobility assets"
if `i' == 3 local catname "cooking assets"
if `i' == 4 local catname "appliances"
if `i' == 5 local catname "other assets"

gen hh_asset_n_w`pp'_`i' = hh_asset_n_w`pp' if category == `i'

// calculate hh totals
bysort hhid : egen hh_ass_count_hh_`pp'_`i' = total(hh_asset_n_w`pp'_`i')

label var hh_ass_count_hh_`pp'_`i' "Count of household `catname' owned by all hh mems but benef (`pp'p wins.)"
}

ds hh_ass_count_hh_`pp'_*
egen tot_`pp' = rowtotal(`r(varlist)')
*assert tot_`pp' == hh_ass_count_hh_`pp' // assert components add up to hh total
drop tot_`pp'
}
*/


drop hh_asset_n_* // drop all asset-level vars keeping hh-level ones
// vars needed: hh_ass_count_*

********************************************************************************
**** Secondary B.5.4.1 Household asset count PCA on HH asset dummies

// generate hh level dummies for each asset type
levelsof hh_asset_pos, local(ass_levs)
foreach i in `ass_levs' {
gen ass_`i'_d = (hh_asset_n != .) & hh_asset_pos == `i'
byso hhid : egen ass_`i' = max(ass_`i'_d)
drop ass_`i'_d
}

preserve
keep hhid ass_*
duplicates drop
isid hhid

pca ass_*
predict hh_ass_index
label var hh_ass_index "Household and non-livestock assets, pca index"

tempfile pca_index
save `pca_index'
restore

merge m:1 hhid using `pca_index', keepusing(hh_ass_index) gen(_m)
assert _m == 3

keep hhid hh_ass_count_* hh_ass_index
duplicates drop
isid hhid





********************************************************************************
****** Merge all together

// starting with B5_4_asset count
merge 1:1 hhid using `b5_1_ass_ag_val', gen(_mfu_b51)
merge 1:1 hhid using `b5_2_ani_val', gen(_mfu_b52)

// merge 1:1 hhid using `b5_3_bus_val', gen(_mfu_b53)


// insert true zeros
local asset_vars ag_val_98 ag_val_95 ani_val_98 ani_val_95

foreach var in `asset_vars' {
replace `var' = 0 if `var' == .
}

// ensure monetary variables are either xof or ppp
foreach var in `r(varlist)' {
rename `var' `var'_xof
}

// don't compress
save "${baseline_intermediate}/assets.dta", replace


