********************************************************************************
* LIVESTOCK    *
********************************************************************************
clear
use "${baseline_intermediate}/livestock_wide"

********************************************************************************
*** B.3.4 Livestock Type Count (owned in last 12 months: ani_* not ani_live_*)


drop *who*
rename ani1_name_* ani_name_*


label variable ani_name_1"Boeuf / Taureau"
label variable ani_name_2"Vache / Genisse"
label variable ani_name_3"Veau / Velle"
label variable ani_name_4"Mouton / Belier"
label variable ani_name_5"Brebis"
label variable ani_name_6"Bouc / Chevre"
label variable ani_name_7"Chameau / Chamelle"
label variable ani_name_8"Anes / Anesses"
label variable ani_name_9"Chevaux / Juments"
label variable ani_name_10"Poules / poulets locaux"
label variable ani_name_11"Pintades"

ds ani_name_*
local ani_count : word count `r(varlist)'

label define yn 0 "non" 1 "oui", replace
forvalues i = 1/`ani_count' {
  gen ani_yn_`i' = (ani_`i' == 1)
  // deleted old comment saying individual or joint ownership
  // since that referes to ani_live_* not ani_* and label below is for ani_* not ani_live_*
  label variable ani_yn_`i' "Owned in last 12 months"
  order ani_yn_`i', after(ani_`i')
  label val ani_yn_`i' yn
}

* drop ani_? ani_??

** div_ani_*
gen div_ani_bov = 0
gen div_ani_equi = 0
gen div_ani_ovi = 0
gen div_ani_avi = 0
gen div_ani_o = 0


label var div_ani_bov "Household works with cows/bulls, 12 months "
label var div_ani_equi "Household works with horses/donkeys/camels, 12 months"
label var div_ani_ovi "Household works with sheep/goats,  12 months"
label var div_ani_avi "Household works with poultry,  12 months"
label var div_ani_o "Household works with other animals,  12 months"



if "${cty}" == "NER" {
replace div_ani_bov = 1 if (ani_yn_1 == 1)
replace div_ani_bov = 1 if  (ani_yn_2 == 1)
replace div_ani_bov = 1 if  (ani_yn_3 == 1)

replace div_ani_equi = 1 if  (ani_yn_7 == 1)
replace div_ani_equi = 1 if  (ani_yn_8 == 1)
replace div_ani_equi = 1 if  (ani_yn_9 == 1)

replace div_ani_ovi = 1 if  (ani_yn_4 == 1)
replace div_ani_ovi = 1 if  (ani_yn_5 == 1)
replace div_ani_ovi = 1 if  (ani_yn_6 == 1)

replace div_ani_avi = 1 if  (ani_yn_10 == 1)
replace div_ani_avi = 1 if  (ani_yn_11 == 1)

}



egen div_ani  = rowtotal(div_ani_*)
label variable div_ani "B.3.4 Count of livestock types"


// list ani_? ani_?? vars. some ctys don't have ani_??
local ani_list
forvalues i = 1/`ani_count' {
rename ani_`i' ani12_`i' // ownership in last 12 months
local addvar ani12_`i'
local ani_list : list ani_list | addvar
}

gen PAP_b3 = "PAP B3"
keep hhid PAP_b3 div* `ani_list'
order hhid PAP_b3 div* `ani_list'
isid hhid

tempfile b3_4_ben_liv_count
save `b3_4_ben_liv_count'


********************************************************************************
**** Livestock ownership
**** B.10.3.4 Beneficiary owns livestock (ani_who conditional on ani_live)

use "${baseline_intermediate}/livestock_long", clear

*fix_continuous ani_count ani_bot ani_botval ani_sold ani_soldval
codebook ani_count ani_bot ani_botval ani_sold ani_soldval

label var ani "7.05: During the past 12 months, has any member of the hh owned or raised x not belonging to him? "
*caplab ani_live "7.05a: Does any member of the household own x alive?" // label if exists (not at BL)
label var ani_count "13.02 Today, how many x belong to the household itself?"

// gateway var sanity check:
// In SEN at FU, there was an error in the survey. count, value, etc are conditional
// on ani == 1 even though ani and ani_live labels were incorrectly reversed.
// Therefore respondents who said they owned an animal jointly ani == 2) in the last
// 12 months were not shown the questions on count, value, etc.

// Same issue in BFA FU for joint ownership but for 1445/1660 responses where ani == 2
// Unsure why some respondents reporting ani == 2 were shown the other questions while the majority of them weren't

*assert ani_count != . if ani != 0


count if ani_count == 0 & ani != 0 // ani_count is regarding today. Some zeros may exist


levelsof ani, local(ownership_values)
levelsof ani_live, local(alivenow_values)

assert "`ownership_values'" == "0 1 2"
assert "`alivenow_values'"  == "0 1"

assert inlist(ani_live, 0, 1, .) if ani == 1 | ani == 2 //
assert inlist(ani_live,  .) if ani == 0 //


capture rename livestock_pos ani1_pos



// merging chef position
merge m:1 hhid using "${baseline_intermediate}/demographics.dta", ///
keepusing(chef_pos) gen(_mergCHEF)
drop if _mergCHEF == 2
drop _mergCHEF



// generate one ani_who var for FU1 and FU2


label drop ani_who1 ani_who2 ani_who3
desc ani_who*
format ani_who* %4.0f

assert substr("`: type ani_who1'", 1, 3) == "byt" // assert numeric var

// confirm that ownership info only exists when animal is alive
assert (ani_who1 >0 | ani_who2 >0 | ani_who3 > 0) & ///
(!missing(ani_who1) | !missing(ani_who2) | !missing(ani_who3)) if ///
ani_live ==1 | ani_live == 2

sort hhid ani1_pos

// count beneficiaries who own livestock
label values *who*
foreach var in ani_who1 ani_who2 ani_who3 {
tostring `var', replace
replace `var' = " " + `var' + " "
replace `var' = "" if `var' == " . "
}
gen ani_who = ani_who1 + ani_who2 + ani_who3


assert substr("`: type ani_who'", 1, 3) == "str" // assert string var
replace ani_who = itrim(ani_who)


// all ctys: count number of owners per animal
gen own_n = .
forval i = 1/`=_N' {
local ani_who_i
local ani_who_i `"`=ani_who[`i']'"'
local uniq_who : list uniq ani_who_i     // collect unique owners only
local who_num : list sizeof uniq_who // count how many
qui replace own_n = `who_num' in `i'
}
replace own_n = 99 if strpos(ani_who, "-1") > 0 // to construct who_is_benef_sole



// space out position lists for strpos below
tostring chef_pos, replace
replace chef_pos = " " + chef_pos + " "
replace ani_who = " " + ani_who + " "



gen who_is_chef = strpos(ani_who, chef_pos) > 0
// some special entries
replace who_is_chef = 1 if strpos(ani_who, " -1 ") > 0  // -1 = everyone in the HH
replace who_is_chef = 0 if ani_who == " 0 " // 0 = people outside HH (no changes made)


// chef owns only if animal is alive
assert inlist(ani_live, 1) if who_is_chef == 1


**---| 1 household level
// BENEF DUMMY create dummy variable for each animal if beneficiary is among owners
byso hhid : egen ani_chef_dum = max(who_is_chef)
label var ani_chef_dum "B.10.3 (4) Chef currently owns livestock at $phase"

// BENEF SOLE DUMMY
gen who_is_chef_sole = who_is_chef
replace who_is_chef_sole = 0 if own_n > 1 // more than one owner
byso hhid : egen ani_sole_dum = max(who_is_chef_sole)
label var ani_sole_dum "CHEF  is currently sole owner of livestock at $phase"


// HH ownership (ani_live = {0,1} not {0,1,2} in SEN at FU but this line still works as intended)
gen hh_owns = 1 if ani_live == 1 | ani_live == 2 // fixed 8/13/2021: changed from ani to ani_live to match benef
replace hh_owns = 0 if strpos(ani_who, " 0 ") > 0 // 0 = people outside HH (no changes made)
replace hh_owns = 0 if hh_owns == .
byso hhid : egen ani_hh_dum = max(hh_owns)
label var ani_hh_dum "HH currently owns livestock at $phase"


preserve
gen PAP_b10_3_4 = "PAP B10.3.4"
keep  hhid PAP_b10_3_4  ani_sole_dum ani_chef_dum ani_hh_dum // keep livestock ownership dummy
order hhid PAP_b10_3_4  ani_sole_dum ani_chef_dum ani_hh_dum // keep livestock ownership dummy
duplicates drop
isid hhid


tempfile 10_3_4
save    `10_3_4', replace
restore




********************************************************************************
**** B.10.3.5 Chef controls revenues from sale of livestock (ani_control)
**** B.2.4    Livestock sale revenue, beneficiary, (last 12 months)

// ani_control and ani_soldval DNE at BL


**** B.10.3.5 Beneficiary controls revenues from sale of livestock (ani_control)
label drop ani_control1 ani_control2
desc ani_control*
format ani_control1 ani_control2 %4.0f



order hhid chef_pos ani_control1 ani_control2

* Generate beneficiary control dummy
foreach var in ani_control1 ani_control2 {
gen `var'_txt = string(`var')
replace `var'_txt = "" if `var'_txt == "."
}

gen ani_control = " " + ani_control1_txt + " " + ani_control2_txt + " "
gen chef_control = strpos(ani_control, chef_pos) > 0


sort hhid ani1_pos

// count number of livestock-controlling chefs per household
// need not be beneficiary-owned or -managed
bysort hhid : egen ani_contr_chef_dum = max(chef_control)
order ani_contr_chef_dum, after (hhid)
label var ani_contr_chef_dum "B.10.3 (5) Chef controls revenue from the sale of livestock at $phase"




**** B.2.4    Livestock sale revenue, chef, (last 12 months)

// currency conversion
gen ani_soldval_xof = ani_soldval
// scale for currency if currency var exists
capture confirm var ani_soldval_curr
if _rc == 0 {
scale_cur ani_soldval_xof ani_soldval_curr
}
drop ani_soldval // for safety

// winsorize livestock sale values at livestock type-level
// but first, generate gateway variable to use as condition
gen gate = ani_slau | ani_sold // sale value only asked if animal was sold or slaughtered
assert ani_soldval_xof != . if gate == 1 & ani == 1 // could still be .d or .r though

gen ani_soldval_w = ani_soldval_xof
levelsof ani1_pos, local(animal_pos)
foreach pos in `animal_pos' {

count if gate == 1 & ani1_pos == `pos' & !missing(ani_soldval_xof)

if `r(N)' != 0 { // if values to be winsorized exist for that ani1_pos
_pctile ani_soldval_xof if ani1_pos == `pos' & !missing(ani_soldval_xof) , p(98)
replace ani_soldval_w = `r(r1)' if ani1_pos == `pos' & ///
   ani_soldval_xof > `r(r1)' & ///
   !missing(ani_soldval_xof)
}
}

gen count_control = 0
replace count_control = 1 if ani_control_ano == 0
replace count_control = 2 if ani_control_ano == 1


// chef revenues
gen ani_chef_contr_win = ani_soldval_w / count_control if chef_control == 1
bysort hhid : egen tot_ani_chef_contr = total(ani_chef_contr_win)
replace tot_ani_chef_contr = tot_ani_chef_contr / 1000

// HH revenues
bysort hhid : egen tot_ani_hh_contr = total(ani_soldval_w)
replace tot_ani_hh_contr = tot_ani_hh_contr / 1000

label var tot_ani_chef_contr "B.2.4 Chef Livestock Sale value (wins. 1000 FCFA last 12 months)"
label var tot_ani_hh_contr  "B.2.4 HH Livestock Sale value (wins. 1000 FCFA last 12 months)"

// hh less chef
gen tot_ani_hhlb_contr = tot_ani_hh_contr - tot_ani_chef_contr
label var tot_ani_hhlb_contr  "B.2.4 HH less chef livestock Sale value (wins. 1000 FCFA last 12 months)"

// chef/hh
gen tot_ani_bohh_contr = tot_ani_chef_contr / tot_ani_hh_contr
label var tot_ani_bohh_contr  "B.2.4 chef/HH fraction livestock sale value"


preserve
gen PAP_b2_b1035 = "PAP B2 B10.3.5"
local thesevars hhid PAP_b2_b1035 tot_ani_chef_contr tot_ani_hh_contr ///
tot_ani_hhlb_contr tot_ani_bohh_contr ///
ani_contr_chef_dum
keep  `thesevars'
order `thesevars'
duplicates drop
isid hhid

tempfile b2_4_ben_liv_rev12
save `b2_4_ben_liv_rev12'
restore







********************************************************************************
*** D.5 Livestock
// Value of Livestock
// Value of animal purchases
// HH animal count (scaled by TLU)
// Increase/decrease in animal (TLU) in the last 12 months
// Value of Livestock Stock







// recode ani_count (missing = 0)
label variable ani_count "Quantity currently owned"

byso ani1_pos : egen ani_count_high = pctile(ani_count) if ani_count > 0, p(99)
byso ani1_pos : egen ani_count_low  = pctile(ani_count) if ani_count > 0, p(1)
byso ani1_pos : gen outlier = ((ani_count > ani_count_high & !missing(ani_count)) | ///
   ((ani_count < ani_count_low) & ani_count != 0))
count if outlier == 1

keep if ani == 1 // removes missings turned into zeros that we used in outlier calc

// purchase values DNE at BL (+ value of livestock)

sort ani_bot ani_botval
replace ani_botval = ani_bot if ani_botval == 0 & ani_bot > 100
// 3 cases at FU1 where responses likely reversed
// 2 at FU2

foreach var in ani_botval ani_value {

// scale for currency if currency var exists
capture confirm var `var'_cur
if _rc == 0 { // if currency var exists
scale_cur `var' `var'_cur
}

// winsorize bot values within each animal type
// but first
gen `var'_w = `var'
levelsof ani1_pos, local(animal_pos)
foreach pos in `animal_pos' {

count if ani1_pos == `pos' & !missing(`var')
if `r(N)' != 0 { // if values to be winsorized exist for that ani1_pos
_pctile `var' if ani1_pos == `pos' & !missing(`var') , p(98)
replace `var'_w = `r(r1)' if ani1_pos == `pos' & ///
`var' > `r(r1)' & ///
!missing(`var')
}
}
byso hhid : egen tot_`var' = total(`var'_w) // 1,000 FCFA
replace tot_`var' = tot_`var' / 1000
}
label variable tot_ani_botval  "D.5.2 Value of animal purchases (wins. 1000 FCFA last 12 months)"
label variable tot_ani_value  "D.5.2 Value of livestock (wins. 1000 FCFA last 12 months)"





//manual corrections to livestock counts what needs to be corrected here??
*livestock_count_correction

/*
The TLU conversion factors used are as follows:
cattle = 0.70,
sheep and goats = 0.10,
pigs = 0.20,
chicken = 0.01

Source: Cattle and Small Ruminant Production Systems in sub-Saharan Africa
Table 1. Tropical livestock units
http://www.fao.org/3/Y4176E/y4176e04.htm
*/

*translate_livestock


local tlu_vars ani_count ani_ago


foreach var in `tlu_vars' {
gen `var'_tlu = `var'
replace `var'_tlu = `var'_tlu * 0.5  if ani1_name == "Bulls"
replace `var'_tlu = `var'_tlu * 0.7  if ani1_name == "Cows or Heifers"
replace `var'_tlu = `var'_tlu * 0.7  if ani1_name == "Calves"
replace `var'_tlu = `var'_tlu * 0.8  if ani1_name == "Donkeys"       // corrected 8/24/2020
replace `var'_tlu = `var'_tlu * 1.1  if ani1_name == "Camels"  // corrected 8/24/2020
replace `var'_tlu = `var'_tlu * 0.8  if ani1_name == "Horses or Mares"
replace `var'_tlu = `var'_tlu * 0.1  if ani1_name == "Goats"
replace `var'_tlu = `var'_tlu * 0.1  if ani1_name == "Sheep"
replace `var'_tlu = `var'_tlu * 0.1  if ani1_name == "Mutton"
replace `var'_tlu = `var'_tlu * 0.03 if ani1_name == "Guinea Fowls"  // corrected 8/24/2020
replace `var'_tlu = `var'_tlu * 0.01 if ani1_name == "Hens or Chickens"
replace `var'_tlu = `var'_tlu * 0.2  if ani1_name == "Pork"

// compute HH totals
byso hhid : egen tot_`var' = total(`var')
label var tot_`var' "HH animal count (not scaled by TLU)"

byso hhid : egen tot_`var'_tlu = total(`var'_tlu)
label var tot_`var'_tlu "HH animal count (scaled by TLU)"
}

// generate chef ownership. Assume chef's animal if they're listed among the owners
gen ani_count_tlu_chef = ani_count_tlu if who_is_chef == 1
byso hhid : egen tot_ani_count_tlu_chef = total(ani_count_tlu_chef)
label var tot_ani_count_tlu_chef "Chef animal count (scaled by TLU)"



// generate hh-less-chef ownership
gen ani_count_tlu_hhlb = ani_count_tlu if who_is_chef != 1
byso hhid : egen tot_ani_count_tlu_hhlb = total(ani_count_tlu_hhlb)
label var tot_ani_count_tlu_hhlb "HH less Benef. animal count (scaled by TLU)"
assert tot_ani_count_tlu_hhlb + tot_ani_count_tlu_chef - tot_ani_count_tlu < 0.0001 // assert animals add up by owner


// generate animal type dummy
gen ani_type = 1 if ani1_name == "Boeuf / Taureau" | ///
ani1_name == "Vache / Genisse" | ///
ani1_name == "Veau / Velle"
replace ani_type = 2 if ani1_name == "Anes / Anesses"
replace ani_type = 3 if ani1_name == "Chameau / Chamelle"
replace ani_type = 4 if ani1_name == "Chevaux / Juments"
replace ani_type = 5 if ani1_name == "Bouc / Chevre"
replace ani_type = 6 if ani1_name == "Mouton / Belier" | ///
ani1_name == "Brebis"
replace ani_type = 7 if ani1_name == "Pintades" | ///
ani1_name == "Poules / poulets locaux"
replace ani_type = 8 if ani1_name == "Other" | ///
ani1_name == "Cochons/truies" | ///
ani1_name == "Autres animaux"

label define ani_type 1 "bov" 2 "ane" 3 "cham" 4 "chev" ///
   5 "cap"  6 "ov"  7 "vol" 8 "other", replace
label values ani_type ani_type

// calculate household totals by animal type
byso hhid ani_type : egen liv_tot = total(ani_count)

preserve

// collect type values and labels
keep hhid ani_type liv_tot
duplicates drop

*ani_type all missing??
isid hhid ani_type

label list ani_type
local ani_labs `r(labels)'
levelsof ani_type, local(i_types)

reshape wide liv_tot, i(hhid) j(ani_type)


/*
// rename type values as labels (not always the entire set 1-8)
foreach i in `i_types' {
local ani_type : word `i' of "`ani_labs'"
rename liv_tot`i' liv_`ani_type'
}
*/

// above not working - renaming variable manually

rename liv_tot1 liv_bov
rename liv_tot2 liv_ane
rename liv_tot3 liv_cham
rename liv_tot4 liv_chev
rename liv_tot5 liv_cap
rename liv_tot6 liv_ov
rename liv_tot7 liv_vol


// fill in zeros
ds hhid, not
foreach var of varlist `r(varlist)' {
replace `var' = 0 if `var' == .
}

tempfile ani_counts_bytype
save `ani_counts_bytype'
restore


// calcualte change in TLU over the year
gen ani_n_diff_tlu = ani_count_tlu - ani_ago_tlu // examined extreme values. Seem to be justified by flows
byso hhid : egen tot_ani_n_diff_tlu = total(ani_n_diff_tlu)
label var tot_ani_n_diff_tlu "D.5.1 Increase/decrease in animal (TLU) in the last 12 months"

** Wrap it up

local keep_vars tot_ani_count tot_ani_count_tlu tot_ani_count_tlu_chef tot_ani_count_tlu_hhlb tot_ani_botval tot_ani_value tot_ani_n_diff_tlu

tempfile ago
save "`ago'"

gen PAP_d5 = "PAP D5"
keep hhid PAP_d5 `keep_vars'
order hhid PAP_d5 `keep_vars'
duplicates drop

tempfile d5_count_and_botval
save `d5_count_and_botval'

clear

********************************************************************************
*** merge livestock outcomes

use `d5_count_and_botval', clear
merge 1:1 hhid using `ani_counts_bytype',  gen(_mCounts)
merge 1:1 hhid using `b3_4_ben_liv_count', gen(_mDiv) // all phases
merge 1:1 hhid using `10_3_4' , gen(_mown)  // all phases
merge 1:1 hhid using `b2_4_ben_liv_rev12', gen(_mRev)




merge 1:1 hhid using "${baseline_intermediate}/demographics.dta", ///
keepusing(chef_pos) gen(_mergCHEF)




// trim chef vars since some HHs still don't have benefs 06112020
foreach var in ani_chef_dum ///
   ani_sole_dum ///
   ani_contr_chef_dum ///
   tot_ani_chef_contr {
dis "`var'"
assert inlist(`var', ., 0) if chef_pos == .
replace `var' = .m if chef_pos == .
}
replace tot_ani_hhlb_contr = .m if chef_pos == .

drop chef_pos _mergCHEF



// insert true zeros after bringing in all consenting hhs
merge 1:1 hhid using "${baseline_intermediate}/identification.dta", ///
keepusing(consent) gen(_mconsent)
assert inlist(_mconsent, 2, 3)
drop consent _mconsent


qui ds liv_* ani12_* // originally ani_i in wide format (now ani12_* to avoid using ani_? and _??
local zeros_vars `r(varlist)' ///
 tot_ani_count ///
 tot_ani_count_tlu ///
 tot_ani_count_tlu_chef ///
 tot_ani_count_tlu_hhlb ///
 ani_chef_dum ///
 ani_sole_dum ///
 ani_hh_dum ///
 div_ani_bov ///
 div_ani_equi ///
 div_ani_ovi ///
 div_ani_avi ///
 div_ani_o ///
 div_ani


local addtl_vars `r(varlist)' ///
 tot_ani_botval ///
 tot_ani_value ///
 tot_ani_n_diff_tlu ///
 tot_ani_chef_contr ///
 tot_ani_hh_contr ///
 tot_ani_hhlb_contr ///
 ani_contr_chef_dum ///


local zeros_vars `zeros_vars' `addtl_vars'


foreach var in `zeros_vars' {
replace `var' = 0 if `var' == .
}

sort hhid
merge 1:1 hhid using "${baseline_intermediate}/identification.dta", keepusing(village_ treatment) gen(mId)
keep if mId == 3
drop mId

save "${baseline_intermediate}/livestock", replace





