*if "${cty}" == "NER"
global locations village_ commune_ department_ region_


********************************************************************************
*** 1. Prep member data
do "${do_baseline_cleaning}/08b_clean_ag_mem_prep.do"

********************************************************************************
*** 2. Add household member and community-level data to "${intermediate_${phase}_${cty}}/main_plotlist_long.dta"

use "${baseline_intermediate}/main_plotlist_long", clear

merge m:1 hhid using "${baseline_intermediate}/identification", keepus(hhid ${locations} consent)
confirm var ${locations} // confirm locations were defined and merged in
drop _merge

merge m:1 hhid using "${baseline_intermediate}/demographics.dta", keepusing(mem_n)


drop if consent == 0 & _merge == 2 // consent only == 1 or == .
assert consent == 1

// add leading + trailing space
ds, has(type string)
foreach var in `r(varlist)' {
replace `var' = trim(itrim(`var'))
}


ds plot_man plot_owner plot_worked


foreach var in `r(varlist)' {
replace `var' = trim(itrim(`var'))

replace `var' = " "+`var'+" "
}



// merge hh member data
merge m:1 hhid using "${baseline_intermediate}/member_data_ag", gen(_merge_ag)
so hhid plot_pos
* assert _merge_ag == 3 // can't == 3 because some HHs have no plots... /?\
drop _merge _merge_ag



// order variables
order consent mem_n chef_pos  female_list male_list adult_list ///
adult_f_list adult_m_list child_list child_f_list child_m_list hasplots, after(hhid)

// clean up community variables : order drop rename label variables
order hhid consent ${locations}, first


********************************************************************************
*** 3. Outcome variables from plot-level dataset

/***
hhid ag_any, ag_plot_n, ag_r_grew, ag_d_grew, ag_plot_ha, ag_plot_own_ha ///
ag_d_plot_cult_n, ag_r_plot_cult_n ag_irrig ///
ag_r_plot_chef ag_d_plot_chef ag_r_plot_benef ag_d_plot_benef ag_r_plot_fem ///
ag_d_plot_fem
***/

gen ag_any = hasplots
label var ag_any "owns or cultivates any plot in last 12 months" // this  is not a farmer indicator !!

/** ag_plot_n **/
// main datase

merge m:1 hhid using "${baseline_intermediate}/niger_main_2021.dta", keepus(hhid plot_n)

keep if _merge == 3
drop _merge
gen ag_plot_n = plot_n
replace ag_plot_n = 0 if hasplots == 0
label var ag_plot_n "total plots owned or cultivated in last 12 months"
drop plot_n


/** ag_plot_ha **/
gen plot_hectares = plot_size
replace plot_hectares = 0 if hasplots == 0


// convert sq. meters to hectares
replace plot_hectares = plot_size * (1/10000) if plot_size_u == 2


// cleaning: set plot_hectares = . if plot_size < 50 sq meters or > 6 hectares
replace plot_hectares = .m if (plot_size < 50 & plot_size_u == 2)
replace plot_hectares = .m if (plot_size > 6 & plot_size_u == 1)

gen plot_ha_miss = (plot_hectares == .)
byso hhid : egen plot_size_missing = max(plot_ha_miss)

byso hhid : egen ag_plot_ha = total(plot_hectares)
label var ag_plot_ha "total area of plots owned or cultivated in last 12 months"



// benef and chef shares of land

gen plot_ownmanage = plot_man + plot_owner
gen uniq_ownman = ""
gen n_ownman_plot = 0
forval i = 1/`=_N' {
local all
local all  `"`=plot_ownmanage[`i']'"'
local unique_ownman : list uniq all
replace uniq_ownman = "`unique_ownman'" in `i'
replace n_ownman_plot = `: list sizeof unique_ownman' in `i'
}

// generate ownership dummies

** chef
tostring chef_pos, replace
replace uniq_ownman = " " + uniq_ownman + " "
gen chef_is_plotownman = .
replace chef_is_plotownman  = strpos(uniq_ownman, chef_pos) > 0


foreach stub in chef {
// plot ownership
byso hhid : egen ownman_`stub'_d  = max(`stub'_is_plotownman)
label var ownman_`stub'_d "Chef owns a plot dummy"

// plot areas
gen plot_hectares_`stub' = plot_hectares if `stub'_is_plotownman == 1
byso hhid : egen ag_plot_ha_`stub' = total(plot_hectares_`stub')
label var ag_plot_ha_`stub' "total area of plots owned or cultivated by chef in last 12 months"
drop plot_hectares_`stub'
}

drop *_is_plotownman

// cultivates crops not owned by HH
gen outown = 1 if plot_owner == " 0 ", after(plot_owner)
replace outown = 0 if outown == .
byso hhid : egen ag_plotnotown = max(outown)
label var ag_plotnotown "Cultivates a plot not owned by HH"


// Where one of the plots owned by the household has missing size, set total plot area owned by the household to missing
foreach var of varlist ag_plot_ha ag_plot_ha_chef {
replace `var' = .m if plot_size_missing == 1
}


/** ag_plot_own_ha **/
gen plot_own_ha = 0
replace plot_own_ha = plot_hectares if strpos(" 0 ", plot_owner) == 0
byso hhid : egen ag_plot_own_ha = total(plot_own_ha)
label var ag_plot_own_ha "total area of plots owned in last 12 months"

replace ag_plot_own_ha = . if plot_size_missing == 1
drop plot_ha_miss plot_size_missing plot_hectares


/** ag_*_plot_cult_n **/
gen tag_rain_cult = (plot_israin == 1 & plot_key == 1)
byso hhid : egen ag_r_plot_cult_n = total(tag_rain_cult)
label var ag_r_plot_cult_n "total key plots cultivated in the rainy season"

gen tag_dry_cult = (plot_isdry == 1 & plot_key == 1)
byso hhid : egen ag_d_plot_cult_n = total(tag_dry_cult)
label var ag_d_plot_cult_n "total key plots cultivated in the dry season"

drop tag_rain_cult tag_dry_cult

#delimit ;
label define plot_water
6 "Tap water"
7 "Container/reservoir"
8 "Pompe", add;
# delimit cr

/** ag_irrig **/
/* NOTE: creating dummy if household has an irrigated plot -- first need to clean plot_water/plot_water_o */


** in Niger, didn't ask separately for rainy and dry season.
gen plot_water_recode = plot_water, after(plot_water)
label val plot_water_recode plot_water

replace plot_water_recode = 1 if plot_water_o == "Forage" | plot_water_o == "Pluie et forage" | plot_water_o == "Pluie et puitq" | plot_water_o == "Pluie et puits" | plot_water_o == "Pluviale et puits"  | plot_water_o == "Puis du ravin" | plot_water_o == "Puits"  | plot_water_o == "forage"
replace plot_water_recode = 2 if plot_water_o == "Irrigation avec panneau" | plot_water_o == "Irrigation par panneau"
replace plot_water_recode = 5 if plot_water_o == "Pluvial et marais"
replace plot_water_recode = 6 if plot_water_o == "Eau de robinet" | plot_water_o == "Robinet" | plot_water_o == "Robinet à panneau solaire"
replace plot_water_recode = 7 if plot_water_o == "Chateau"
replace plot_water_recode = 8 if plot_water_o == "Autopompe" | plot_water_o == "Moto pompe" | plot_water_o == "Eau tiré avec motopompe" | plot_water_o == "Motopompe" | plot_water_o == "Pluviales et eau tiré par motopompe" |  plot_water_o == "Pompe" |  plot_water_o == "Pompe manuelle" |  plot_water_o == "Pompe motorisé" |  plot_water_o == "Puit tiré de motopompe" |  plot_water_o == "Tirage avec motopompe" | plot_water_o == "Pluie et pompt"


gen irrig = (plot_water_recode != . & plot_water_recode != 4)
byso hhid : egen ag_irrig = max(irrig)
label var ag_irrig "HH irrigates its own crops (not rain irrig)"

drop irrig



// confirm all "other" responses are handled

assert !missing(plot_water_recode) if plot_water_o != ""


label var ag_irrig "has (at least one) irrigated plot"


/** ag_*_plot_chef **/


gen rplot_chef = 0
replace rplot_chef = 1 if plot_israin == 1 & regexm(plot_owner, chef_pos)
replace rplot_chef = 1 if plot_israin == 1 & regexm(plot_man, chef_pos)
byso hhid : egen ag_r_plot_chef = max(rplot_chef)
label var ag_r_plot_chef "head of household owns or manages a rain plot"

gen dplot_chef = 0
replace dplot_chef = 1 if plot_isdry == 1 & regexm(plot_owner, chef_pos)
replace dplot_chef = 1 if plot_isdry == 1 & regexm(plot_man, chef_pos)
byso hhid : egen ag_d_plot_chef = max(dplot_chef)
label var ag_d_plot_chef "head of household owns or manages a dry plot"

drop rplot_chef dplot_chef


****

/** ag_*_plot_fem **/
split female_list, parse(" ") gen(female_)
gen r_plot_fem = 0
gen d_plot_fem = 0

ds female_*
foreach var in `r(varlist)' {
replace `var' = " "+`var'+" "

replace r_plot_fem = 1 if plot_israin == 1 & strpos(plot_owner, `var') > 0
replace r_plot_fem = 1 if plot_israin == 1 & strpos(plot_man, `var') > 0

replace d_plot_fem = 1 if plot_isdry == 1 & strpos(plot_owner, `var') > 0
replace d_plot_fem = 1 if plot_isdry == 1 & strpos(plot_man, `var') > 0

}

byso hhid : egen ag_r_plot_fem = max(r_plot_fem)
byso hhid : egen ag_d_plot_fem = max(d_plot_fem)
label var ag_r_plot_fem "women own or manages a rain plot in household"
label var ag_d_plot_fem "women own or manages a dry plot in household"

drop female_* r_plot_fem d_plot_fem

/** ag_*_grew **/
gen rgrew = (rcrop_n > 0 & !missing(rcrop_n))
byso hhid : egen ag_r_grew = max(rgrew)
label var ag_r_grew "grew at least one annual crop in the rainy season (key plots)"

gen dgrew = (dcrop_n > 0 & !missing(dcrop_n))
byso hhid : egen ag_d_grew = max(dgrew)
label var ag_d_grew "grew at least one annual crop in the dry season (key plots)"

drop rgrew dgrew

keep hhid ag_any ag_plot_n ag_r_grew  ag_d_grew ag_plotnotown ///
  ag_plot_ha  ag_plot_ha_chef ag_plot_own_ha ///
  ag_d_plot_cult_n ag_r_plot_cult_n ag_irrig ///
  ag_r_plot_chef ag_d_plot_chef  ag_r_plot_fem ///
  ag_d_plot_fem
duplicates drop
isid hhid

save "${baseline_intermediate}/temp_agric_plots", replace


********************************************************************************
***4. Crop type counts

use"${baseline_intermediate}/main_plotlist_long.dta", clear

global cropname_vars dcropname1 dcropname2 dcropname3 dcropname4 dcropname5 dcropname6 dcropname7 dcropname8 dcropname9 dcropname10 ///
rcropname1 rcropname2 rcropname3 rcropname4 rcropname5 rcropname6 rcropname7 rcropname8 rcropname9 rcropname10


foreach v in $cropname_vars{
replace `v' =subinstr(`v'," ","",.)
}

local veg "Aubergine" "hibiscu" "bicep" "bissap" "Calebassier" "Carotte" ///
"Céleri""Chou""Courge" "Epinard""Gombo""gombo" "Haricot-vert" ///
"Laitue/salade""lamti""moringa" "morainga" "moranga" "moringua" "moriga" "Oignon" ///
"Oseille" "osseille" "oseille" "Persil" "Pastèque""Piment""Poivron" ///
"Radis""Tomate" "Jaxatu" "Melon" /// FU2 starts here
"waraou" "waraw" "warow" "warraw" "waro" "warao" "moriga" ///
"gneret" "guisima" "yakoiwa" "mangue" "haricot" "jissima"  /// temporarily placed with veggies /!\
"citrouille" "cytruil" "labtanda" "oignonchoupiment" "salade"

local tuber "Igname""Manioc""Pomme-de-terre" "patatedouce" ///
"Patate-douce""Souchet""Taro" "paille" /// FU2 starts here
"rama" "pommedeterre" "manioc" "tubercule"
local pulse "Arachide" "arachide" "arachides" "Navet" "Niébé" "Voandzou" "dawda" "dawdawa"
local cereal "Amarante-(Tchapata)""autretypedemil""Fonio""Maïs" ///
"Mil""riz""Riz-Paddy""sesame""Sésame""riddi" "Sorgho" /// FU2 starts here
"Blé" "ridi" "milniebe" "milniebeoseille" "miloseille" ///
"milsorghoniebe" "milsorghoniebearrachide"
local cash  "canneasucre""Girofle""soumbala""taba" "tabac" "tabba" /// FU2 starts here
 "canne" "tabasa" "canna" "cigarette"





foreach type in tuber pulse cereal veg cash { // loop over categories

gen c_div_`type' = 0
// dis "type: ``type''"
local n: word count "``type''"
display "n = `n'"

forvalues i = 1/`n' { // loop over crop types in name variables
local v1 : word `i' of "``type''"
// dis "``type''"
qui ds rcropname? rcropname??
local crops: word count `r(varlist)'
if "`v1'" != "" { // if there is a crop in this category
forvalues p = 1/`crops' { // loop over cropname variables
qui replace rcropname`p' = "" if rcropname`p' == "."
replace c_div_`type' = c_div_`type' + 1 if rcropname`p' == "`v1'"
}
}
}

gen div_any_temp = c_div_`type' > 0
byso hhid: egen div_`type' = max(div_any_temp)
label variable div_`type' "Household grew `type'"
drop div_any_temp
}

// assert raincrops were categorized and no overcounting
// for given dataset (b/c code is conditional on country)
egen temp_total_types = rowtotal(c_div_*) // 5 types
egen temp_total_crops = rownonmiss(rcropname*), strok // 10 crop vars
*assert temp_total_types == temp_total_crops
drop temp_total*

gen c_div_dry = 0
replace c_div_dry = 1 if dcrop1 != .
bysort hhid: egen div_dry = max(c_div_dry)
label variable div_dry "Household grew in dry season"

drop c_*
keep hhid div_*
duplicates drop hhid div_*, force
isid hhid


save"${baseline_intermediate}/crop_types", replace


********************************************************************************
*** 5. Agreggated crop statuses
do "${do_baseline_cleaning}/08c_clean_ag_cropstatus.do"

********************************************************************************
*** 6. Harvest value
do "${do_baseline_cleaning}/08d_clean_ag_value.do"

********************************************************************************
*** 7. Inputs
do "${do_baseline_cleaning}/08e_clean_ag_inputs.do"


********************************************************************************
*** 8. Merge

use "${baseline_intermediate}/temp_agric_plots", clear


foreach var of varlist  ag_any - ag_d_grew {
replace `var' = 0 if `var' == .
}




merge 1:1 hhid using "${baseline_intermediate}/temp_agric_valueandstatus", gen(_m2)

foreach var of varlist ag_r_harvest_xof_imp - ag_d_comm {
recode `var' (.=0)
}

// commercialization conditional on harvesting
replace ag_r_comm = . if ag_r_harvest_xof_imp == 0 | missing(ag_r_harvest_xof_imp)
replace ag_d_comm = . if ag_d_harvest_xof_imp == 0 | missing(ag_d_harvest_xof_imp)


foreach var of varlist ag_d_harv - ag_r_sold div_rain_n div_dry_n {
recode `var' (.=0)
}


merge 1:1 hhid using "${baseline_intermediate}/temp_agric_inputs", gen(_m3)


foreach var of varlist ag_r_hhh_days - ag_r_income_xof {
recode `var' (.=0)
}


merge 1:1 hhid using "${baseline_intermediate}/crop_types", gen(_m4)

foreach var of varlist div_* {
recode `var' (.=0)
}

egen div_crop_types = rsum(div_tuber div_pulse div_cereal div_veg div_cash div_dry)
label variable div_crop_types "B.3.2 Crop types grown (1-5): cereals, pulses, tubers, vegetables/fruits, other cash"

drop _*



********************************************************************************
** Assertions

replace ag_any = 1 if ag_plot_n > 0
assert ag_any == 1 if ag_plot_n > 0
assert ag_any == 0 if ag_plot_n == 0
assert ag_plot_ha >= ag_plot_own_ha

assert ag_plot_n >= ag_r_plot_cult_n
assert ag_plot_n >= ag_d_plot_cult_n

assert ag_any == 1 if ag_irrig == 1

foreach s in r d  {


assert ag_`s'_plot_cult_n != 0 if ag_`s'_grew == 1

}

assert ag_r_plot_cult_n != 0 if div_rain_n  != 0
assert ag_d_plot_cult_n != 0 if div_dry_n  != 0


gen test = 0
ds ag_r_harvest_*_imp_xof
local count : word count(`r(varlist)')
forvalues i = 1/`count' {
replace test = test + ag_r_harvest_`i'_imp_xof if !missing(ag_r_harvest_`i'_imp_xof)
}

*assert round(ag_r_harvest_xof_imp_98,1) == round(test,1)  if !missing(ag_r_harvest_xof_imp_98)

drop test

gen test = 0
ds ag_d_harvest_*_imp_xof
local count : word count(`r(varlist)')
forvalues i = 1/`count' {
replace test = test + ag_d_harvest_`i'_imp_xof if !missing(ag_d_harvest_`i'_imp_xof)
}

*assert round(ag_d_harvest_xof_imp_98,1) == round(test,1)  if !missing(ag_d_harvest_xof_imp_98)

drop test

assert ag_r_comm == . if ag_r_harvest_xof_imp_98 == 0
assert ag_d_comm == . if ag_d_harvest_xof_imp_98 == 0



foreach s in r d {
display "`s' - 1"
*assert ag_`s'_plot_cult_n !=0  if  ag_`s'_control == 1
*assert ag_`s'_plot_cult_n !=0 if ag_`s'_harv == 1

display "`s' - 2"
assert ag_`s'_plot_cult_n !=0  if  ag_`s'_partial == 1
assert ag_`s'_plot_cult_n !=0 if ag_`s'_lost == 1

display "`s' - 3"
assert ag_`s'_plot_cult_n !=0 if ag_`s'_field == 1
assert ag_`s'_harv == 1 if ag_`s'_sold == 1 // only sold if harvested

display "`s' - 4"
assert ag_`s'_comm == . if ag_`s'_harv == 0
assert (ag_`s'_comm == . | ag_`s'_comm == 0) if ag_`s'_sold == 0

}

assert div_rain_n == 0 if ag_r_harv == 0
assert div_dry_n  == 0 if ag_d_harv == 0

drop had*

********************************************************************************
*** 9. Final outcomes

local crops
ds ag_r_*_harvest_imp_xof ag_d_*_harvest_imp_xof
foreach var in `r(varlist)' {
local stub = substr("`var'", 7, strlen("`var'")-7+1)
local stub = substr("`stub'", 1, strlen("`stub'")-16)

local crops : list crops | stub
local crops : list uniq crops
}
foreach i in `crops' {
// if that crop DNE, generate an empty variable for the summation later
capture confirm var ag_r_c`i'_harvest_imp_xof
if (_rc != 0) gen ag_r_c`i'_harvest_imp_xof = 0
capture confirm var ag_d_c`i'_harvest_imp_xof
if (_rc != 0) gen ag_d_c`i'_harvest_imp_xof = 0

egen ag_c`i'_harvest_imp_xof = rowtotal(ag_r_c`i'_harvest_imp_xof ag_d_c`i'_harvest_imp_xof)
label var ag_c`i'_harvest_imp_xof "imputed harvest, crop `i' on plots own/mngd by ben/chef, both seasons"
}
drop ag_r_c*_harvest_imp_xof ag_d_c*_harvest_imp_xof

{
// order crop-specific harvest values by crop id
// fetch largest crop number from crop list
drop ag_cterre_harvest_imp_xof

ds ag_c*_harvest_imp_xof
local mylist `r(varlist)'

local max_num 0 // initiate max_num to collect max crop num
local remove ag_cother_harvest_imp_xof
local mylist : list mylist - remove
foreach var in `mylist' {
local stub = substr("`var'", 5, strlen("`var'")-5+1)
local num = substr("`stub'", 1, strlen("`stub'")-16)
dis "`num'"
if (`num' > `max_num') local max_num `num' // collect max num
}
dis "`max_num'"

// create sorted list

forval j = 1/`max_num' {
capture confirm var ag_c`j'_harvest_imp_xof
if (_rc == 0) local neworder `neworder' ag_c`j'_harvest_imp_xof
}
dis "`neworder'"
local neworder `neworder' ag_cother_harvest_imp_xof
order `neworder', before(ag_r_sale_xof)
}

// sum values across seasons (method 1)
egen ag_harvest_12_xof_imp = rowtotal(ag_r_harvest_xof_imp ag_d_harvest_xof_imp)
label var ag_harvest_12_xof_imp "imputed harvest, plots owned or managed by beneficiary or household head, both seasons"

foreach p in 95 98 99 {
egen ag_harvest_12_xof_imp_`p' = rowtotal(ag_r_harvest_xof_imp_`p' ag_d_harvest_xof_imp_`p')
label var ag_harvest_12_xof_imp_`p' "wins(`p') & imputed harvest, plots owned or managed by chef or household head, both seasons"
}

egen ag_harvest_12_chef_xof_imp = rowtotal(ag_r_harvest_chef_xof_imp_98 ag_d_harvest_chef_xof_imp_98)
label var ag_harvest_12_chef_xof_imp "imputed harvest, plots owned or managed by chef, both seasons (98 p wins.)"



*** hh less benef ***
gen ag_harvest_12_hhlb_xof_imp = ag_harvest_12_xof_imp_98 - ag_harvest_12_chef_xof_imp
label var ag_harvest_12_hhlb_xof_imp "imputed harvest, plots owned or managed by all but chef., both seasons (98 p wins.)"
*** hh less benef ***

*** benef over hh ***
gen ag_harvest_12_bohh_xof_imp = ag_harvest_12_chef_xof_imp / ag_harvest_12_xof_imp_98
label var ag_harvest_12_bohh_xof_imp "imputed harvest, chef./hh share, both seasons (98 p wins.)"
*** benef over hh ***

// sum values across seasons (method 2)
egen ag_harvest_12_xof = rowtotal(ag_r_harvest_xof ag_d_harvest_xof)
label var ag_harvest_12_xof "harvest (method 2), plots owned or managed by beneficiary or household head, both seasons"

foreach p in 95 98 99 {
egen ag_harvest_12_xof_`p' = rowtotal(ag_r_harvest_xof_`p' ag_d_harvest_xof_`p')
label var ag_harvest_12_xof_`p' "wins(`p') harvest (method 2), plots owned or managed by beneficiary or household head, both seasons"
}



// confirm chef value is always <= total hh value
*assert ag_harvest_12_chef_xof_imp > 0 | !missing(ag_harvest_12_ben_xof_imp) if chef_owns_d == 1
*assert chef_owns_d == 1 if ag_harvest_12_ben_xof_imp > 0 & !missing(ag_harvest_12_chef_xof_imp)

egen ag_sale_xof_imp = rowtotal(ag_r_sale_imp_xof ag_d_sale_imp_xof)
label var ag_sale_xof_imp "imputed sale value, plots owned or managed by chef or household head, both seasons"


foreach p in 95 98 99 {
egen ag_sale_xof_imp_`p' = rowtotal(ag_r_sale_imp_xof_`p' ag_d_sale_imp_xof_`p')
label var ag_sale_xof_imp_`p' "imputed sale value, plots owned or managed by chef or household head (wins. `p'p), both seasons"
}

** yield
// some denominators DNE because of the area trim.
// These areas are also trimmed when computing beneficiary share of crop harvest value
gen yield_12_xof = (ag_harvest_12_xof_imp) / ag_plot_ha
label var yield_12_xof "harvest value per hectare"

recode div_ag_n (. = 0)

ds div_ag_n hhid ag_d_comm ag_r_comm, not
foreach var in `r(varlist)' {
replace `var' = 0 if `var' == . & div_ag_n == 0
}


** inputs index
merge 1:1 hhid using "${baseline_intermediate}/identification", gen(_mtreat) keepusing(treatment)
assert _mtreat == 3
drop _mtreat

local inputdummies ag_r_seeds_d ag_r_fert_d ag_r_pest_d ag_r_paidlab_d

egen ag_input_index = rowtotal(ag_r_seeds_d ag_r_fert_d ag_r_pest_d ag_r_paidlab_d), missing
sum ag_input_index if treatment == 0
replace ag_input_index = ag_input_index - r(mean)
replace ag_input_index = ag_input_index/r(sd)
label variable ag_input_index "Agricultural inputs index"

********************************************************************************

save "${baseline_intermediate}/agriculture", replace
