clear
use "${baseline_intermediate}/demographics"
keep hhid chef_pos

merge 1:m hhid using "${baseline_intermediate}/members_long", keepusing(mem_pos sex age)
assert _merge ==3
sort hhid

gen female_pos = mem_pos if sex == 1
label var female_pos "position of women in household roster"
gen male_pos = mem_pos if sex == 0
label var male_pos "position of men in household roster"

gen adult_pos = mem_pos if !missing(age) & age >= 15
label var adult_pos "position of adults in household roster (age: 15+)"
gen adult_f_pos = mem_pos if !missing(age) & age >= 15 & sex == 1
label var adult_f_pos "position of female adults in household roster (age: 15+)"
gen adult_m_pos = mem_pos if !missing(age) & age >= 15 & sex == 0
label var adult_m_pos "position of male adults in household roster (age: 15+)"

gen child_pos = mem_pos if !missing(age) & age <= 14
label var child_pos "position of children in household roster (age: 0-14)"
gen child_f_pos = mem_pos if !missing(age) & age <= 14 & sex == 1
label var child_f_pos "position of female children in household roster (age: 0-14)"
gen child_m_pos = mem_pos if !missing(age) & age <= 14 & sex == 0
label var child_m_pos "position of male children in household roster (age: 0-14)"

so hhid mem_pos

drop sex age _merge

// convert position variable to string and reshape dataset wide
ds hhid mem_pos chef_pos, not
foreach var in `r(varlist)' {
tostring `var', replace
replace `var' = "" if `var' == "."
}


reshape wide  female* male* adult* child*, i(hhid) j(mem_pos)
// benef and chef pushed to end of dataset




ds female_pos*
egen female_list = concat(`r(varlist)'), punct(" ")
label var female_list "Females position in roster"

ds male_pos*
egen male_list = concat(`r(varlist)'), punct(" ")
label var male_list "Males position in roster"

ds adult_f_pos*
egen adult_f_list = concat(`r(varlist)'), punct(" ")
label var adult_f_list "Adult females position in roster"

ds adult_m_pos*
egen adult_m_list = concat(`r(varlist)'), punct(" ")
label var adult_m_list "Adult males position in roster"

ds child_f_pos*
egen child_f_list = concat(`r(varlist)'), punct(" ")
label var child_f_list "Female childrens position in roster"

ds child_m_pos*
egen child_m_list = concat(`r(varlist)'), punct(" ")
label var child_m_list "Male childrens position in roster"

egen adult_list = concat(adult_f_list adult_m_list), punct(" ")
label var adult_list "Adults position in roster"

egen child_list = concat(child_f_list child_m_list), punct(" ")
label var child_list "Childrens position in roster"




keep hhid chef_pos female_list male_list ///
adult_f_list adult_m_list child_f_list child_m_list adult_list child_list


ds, has(type string)
foreach var in `r(varlist)' {
replace `var' = trim(itrim(`var'))

replace `var' = " "+`var'+" "
}

order hhid chef_pos
order adult_list, before(adult_f_list)
order child_list, before(child_f_list)

// merge 'consent' variable
merge 1:1 hhid using "${baseline_intermediate}/niger_main_2021.dta", keepus(consent hasplots)


order consent hasplots, after(hhid)
keep if _merge ==3 // removes non-consenting HHs (because members_long is consenting people only)
assert consent == 1
drop _merge consent


compress
save "${baseline_intermediate}/member_data_ag", replace
