capture program drop cropstatus
program cropstatus
syntax, season(string) data(name)

use "${baseline_intermediate}/`data'.dta", clear
merge m:1 hhid using "${baseline_intermediate}/member_data_ag" // change from _wide. Same datasets

drop if _merge == 2
drop _merge


/** ag2_*_harv **/
gen harvested = (`season'crop_status == 1 | `season'crop_status == 2)
byso hhid : egen ag_`season'_harv = max(harvested)
label var ag_`season'_harv "harvested (fully or partially) at least one annual crop (key plots)"
drop harvested

gen partial = (`season'crop_status == 2)
byso hhid : egen ag_`season'_partial = max(partial)
label var ag_`season'_partial "partially harvested at least one annual crop (key plots)"
drop partial


/** ag_*_lost **/
gen lost = (`season'crop_status == 0)
byso hhid : egen ag_`season'_lost = max(lost)
label var ag_`season'_lost  "lost at least one full annual crop harvest (key plots)"
drop lost


gen field = (`season'crop_status == 3)
byso hhid : egen ag_`season'_field = max(field)
label var ag_`season'_field "at least one annual crop still entirely in field (key plots)"
drop field


/** ag_*_sold **/
gen sold = (`season'crop_didsell == 1)
byso hhid : egen ag_`season'_sold = max(sold)
label var ag_`season'_sold "sold at least one annual crop (key plots)"
drop sold

// drop duplicates, clean and save
keep hhid ag_`season'_*
duplicates drop

end



cropstatus, season(r) data(raincrops_1_long)

tempfile r_cropstatus // temporarily save hhid and ag_r_*
save `r_cropstatus'


cropstatus, season(d) data(drycrops_1_long) // run same code for dry crops


merge 1:1 hhid using `r_cropstatus' // merge rain into dry status
drop _merge

recode * (. = 0)


compress
save "${baseline_intermediate}/temp_agric_cropstatuses", replace // save intermediate file

prog drop cropstatus


