********************************************************************************

capture prog drop scale_chef_share
prog define scale_chef_share

syntax, season(string)



/*
// setting locals to test program
 local string d
 local s d
 local season_full dry
 local season d
 */
*syntax, season(string)

if "`season'" == "r" {
local s r
local season_full rain

}
else if "`season'" == "d" {
local s d
local season_full dry
}


use "${baseline_intermediate}/`season_full'crops_2_long", clear

/* In BFA at FU, harvest variables are in `season_full'crops_1 file instead of `season_full'crops_2
Need to merge `season_full'crops_1  to `season_full'crops_2

*/




merge m:1 hhid using "${baseline_intermediate}/demographics", keepusing(chef_pos) gen(_mChefPos)


drop if _mChefPos == 2
drop _mChefPos

tempfile `season_full'crops_2
save ``season_full'crops_2'



/* In BFA at FU, harvest variables are in `season_full'crops_1 file instead of `season_full'crops_2
Need to merge `season_full'crops_1  to `season_full'crops_2
Also creating `${season_full}crops_2' tempfile
*/






********************************************************************************
*** Diverge to adjust crop harvest values by number of owners
********************************************************************************


use "${baseline_intermediate}/main_plotlist_long", clear
order hhid plot_pos plot_rain_harv
keep if plot_is`season_full' // drop off season plots

// merge in chef


merge m:1 hhid using "${baseline_intermediate}/demographics", keepusing(chef_pos) gen(_mChefPos)


tostring chef_pos, replace
drop if _mChefPos == 2
drop _mChefPos

** ------| A. create list of plot sizes within each HH
// tempfile: plotSizeList

// trim plot sizes
/** ag_plot_ha **/



preserve
keep hhid plot_pos plot_size plot_size_u
sort hhid plot_pos

merge m:1 hhid using "$baseline_intermediate/niger_main_2021.dta", keepus(consent hasplots) gen(_m)


keep if _m == 3 //
assert consent == 1
gen plot_hectares = plot_size
replace plot_hectares = 0 if hasplots == 0

// convert sq. meters to hectares
replace plot_hectares = plot_size * (1/10000) if plot_size_u == 2

// cleaning: set plot_hectares = . if plot_size < 50 sq meters or > 6 hectares
replace plot_hectares = .m if (plot_size < 50 & plot_size_u == 2)
replace plot_hectares = .m if (plot_size > 6 & plot_size_u == 1)

keep plot_hectares hhid plot_pos
reshape wide plot_hectares, i(hhid) j(plot_pos)

// bring all into one var
gen plot_sizelist = ""
ds hhid plot_sizelist, not
foreach var in `r(varlist)'{
replace plot_sizelist = plot_sizelist + " " + string(`var')
}
label var plot_sizelist "List of plot sizes for chef owned/managed plots"
keep hhid plot_sizelist

tempfile  plotSizeList
save  `plotSizeList'
restore


** ------| B. Count number of owners/managers per plot (chef plots only)
// tempfile: plot_ownmanage

// ignore plots not owned or managed by anyone in the HH


drop if plot_owner == "0" & plot_man == "0" // no observations

gen n_ownman_plot = 0
replace plot_owner = " " + plot_owner + " "
replace plot_man = " " + plot_man + " "
gen plot_ownmanage = plot_owner + plot_man
gen uniq_ownman = ""

// count number of owners/managers for each plot
forval i = 1/`=_N' {
local all
local all  `"`=plot_ownmanage[`i']'"'
dis "`all'"
local unique_ownman : list uniq all
dis "`unique_ownman'"
replace uniq_ownman = "`unique_ownman'" in `i'
replace n_ownman_plot = `: list sizeof unique_ownman' in `i'
local all
}
drop plot_ownmanage

// tag plot if chef is among owners/managers
replace uniq_ownman = " " + uniq_ownman + " "
replace chef_pos = " " + chef_pos + " "
gen chef_is_plotownman = .

replace chef_is_plotownman = 1 if strpos(uniq_ownman, chef_pos) > 0


order chef_is_plotownman, after (chef_pos)
// keep number of owners/managers only for chef owned plots
replace n_ownman_plot = . if chef_is_plotownman != 1
label variable n_ownman_plot "number of owners/managers of a plot if chef is among them"

// generate ownership dummy
gen chef_owner_dum = chef_is_plotownman
replace chef_owner_dum = 0 if missing(chef_owner_dum)
byso hhid : egen `s'_chef_ownman_d  = max(chef_owner_dum)
label var `s'_chef_ownman_d "Crop is owned/managed by chef (HH-level)"




preserve
keep hhid `s'_chef_ownman_d
duplicates drop
sort hhid

save "${baseline_intermediate}/temp_agric_`s'_chef_owns", replace
restore

count if chef_is_plotownman == 1

preserve
keep if chef_is_plotownman == 1
keep hhid
duplicates drop
dis _N // 1,112 unique HHs have plots owned/managed by chef
restore


// keep needed into n_ownman per plot
keep hhid plot_pos n_ownman_plot
sort hhid plot_pos
reshape wide n_ownman_plot, i(hhid) j(plot_pos)

// bring all into one vara
gen plot_ownermanager = ""
ds hhid plot_ownermanager, not
foreach var in `r(varlist)'{
replace plot_ownermanager = plot_ownermanager + " " + string(`var')
*format `var' %9.3fc
*tostring `var', gen(`var'_str) format("%9.4f")
*replace plot_ownermanager = subinstr(plot_ownermanager, ".", "", .)
}

label var plot_ownermanager "List of no. of owners in chef owned/managed plots"
keep hhid plot_ownermanager

tempfile plot_ownmanage
save `plot_ownmanage'


** ------| C. Merge plot size and plot owner lists into crop-level dataset
// (keep chef-owned plots only)


* In BFA at FU, harvest variables are in `season_full'crops_1 file instead of `season_full'crops_2
* that is at the plot crop level dataset with one observation representing one crop on one plot
* in  `season_full'crops_2 one observation represent a crop on one or several plots


use ``season_full'crops_2', clear


merge m:1 hhid using `plot_ownmanage', gen(_mown) // chef-owned plots
merge m:1 hhid using `plotSizeList', gen(_msize) // all plots
keep if _mown == 3 // keep only chef owned/managed plots


** ------| D. Split list variables
// D.1 split plot owners list
split plot_ownermanager, parse(" ")
drop plot_ownermanager  // drop old variable
ds plot_ownermanager*
foreach var in `r(varlist)' {
destring `var', replace
}

// D.2 split plot sizes list
gen plot_size_ = plot_sizelist
split plot_size_, parse(" ")
ds plot_size_*
foreach var in `r(varlist)' {
destring `var', replace
}



* number of plots
if "`season'" == "r" {
local n_pl 10

}
else if "`season'" == "d" {
local n_pl 14
}



// D.3 split and sort plot position list
replace plot_no = " " + plot_no + " "
ds plot_size_*
local n_plots : word count `r(varlist)'
forval i = 1/`n_pl' {
gen     plot_no_`i' = `i' if strpos(plot_no, " `i' ") > 0
}


// assert owner, size, and position lists include all plots
ds plot_ownermanager*
local plot_own_max : word count `r(varlist)'
ds plot_size_*
local plot_size_max : word count `r(varlist)'
ds plot_no_*
local plot_no_max : word count `r(varlist)''

// all must be equal
*assert `plot_own_max' == `plot_size_max'
*assert `plot_own_max' == `plot_no_max'
*assert `plot_no_max'  == `plot_size_max'


** ------| E. Divide harvest evenly among owners/managers and proportionate to plot sizes



* E.1 prepare ratios to scale down harvest value by ownership and plot size
// replace plot_ownmanager with . if plot doesn't exist

ds plot_ownermanager*
local vars `r(varlist)'
local all : list sizeof vars
forval i = 1/`n_pl' {
replace plot_ownermanager`i' = . if plot_no_`i' == .
assert plot_ownermanager`i' == . if plot_no_`i' == .



// take reciprocal to compute chef's share
gen plot_own_ratio_`i' = 1/plot_ownermanager`i'
label var plot_own_ratio_`i' "Chef ownership ratio for plot `i'"
}
egen crop_owner_count   = rownonmiss(plot_ownermanager*) // count no. of owners on that crop


// replace plot_sizes with . if plot doesn't exist
ds plot_size_*
local vars `r(varlist)'
local all : list sizeof vars
forval i = 1/`n_pl' {
replace plot_size_`i' = . if plot_no_`i' == .
assert plot_size_`i' == . if plot_no_`i' == .
}

// loop over plots again
rename plot_size_ plot_size
egen plot_tot_size = rowtotal(plot_size_*) // total plot area on which crop is grown

forval i = 1/`n_pl' {
// ratio of each plot's size to total size
// ignores .m sizes
gen plot_size_ratio_`i' = plot_size_`i' / plot_tot_size
assert plot_size_ratio_`i' <= 1 | missing(plot_size_ratio_`i')
}

// prepare aggregate ratio across all plots (within a crop/observation)
// loop over plots once more
forval i = 1/`n_pl' {
gen chef_share_`i' = plot_own_ratio_`i' * plot_size_ratio_`i'
assert chef_share_`i' <= 1 | missing(chef_share_`i')
}

// logic test for ratios
egen chef_share_crop = rowtotal(chef_share_*)
label var chef_share_crop "Chef's share of crop given plot size and ownership"
replace chef_share_crop = 1 if chef_share_crop > 1 & chef_share_crop < 1.001
assert chef_share_crop <= 1







* E.2 adjust harvest value based on ownership
// confirm calculation scales down not up before replacing actual harvest value
// not using this scaled raw harvest value anywhere except to check calculation later
// I used the same scaling below after outliers and problematic crops are removed
gen `s'crop_harv_chef = `s'crop_harv * chef_share_crop

assert `s'crop_harv_chef <= `s'crop_harv  if !missing(`s'crop_harv_chef) /**/
count if `s'crop_harv_chef == . & `s'crop_harv != . // 918 crops which the chef owns none of

// count no of HHs with no chef owned crops with harvest values

byso hhid : egen tot_`s'crop_harv_chef = total(`s'crop_harv_chef)
preserve
keep hhid tot_`s'crop_harv_chef
duplicates drop

count if tot_`s'crop_harv_chef == 0 // 10 HHs where chef owns no rain plots
restore


keep hhid crop_pos chef_share_crop
duplicates drop
isid hhid crop_pos
sort hhid crop_pos

save "${baseline_intermediate}/temp_agric_`s'_chef_shares", replace

end






capture prog drop recode_crops
prog define recode_crops
syntax, season(string)

/*
// setting locals to test program
 local string d
 local s d
 local season_full dry
 local season d
 */


if "`season'" == "r" {
local s r
local season_full rain

}
else if "`season'" == "d" {
local s d
local season_full dry
}

use "${baseline_intermediate}/`season_full'crops_2_long", clear


merge m:1 hhid using "${baseline_intermediate}/identification.dta", keepus(hhid consent ${locations} )
drop if `s'crop_harv == .
drop _merge

/***
merge m:1 hhid using "${intermediate_${cty}}/temp_agric_outcomes_1", keepusing(ag_any ag_plot_n)
drop _merge
merge m:1 hhid using "${intermediate_${cty}}/temp_agric_outcomes_1b", keepusing(harv_all harv_rain)
recode harv_rain (. =0 )
recode harv_all (.=0)
***/
/***
* drop _merge // some don't have crops
assert consent == 1

order hhid consent ${locations} crop_pos ag_any ag_plot_n harv_all harv_rain, first
sort hhid crop_pos
recode crop_pos (. = 0) // no crops
assert harv_rain == 0 if crop_pos == 0
****/


replace `season_full'codeorother = trim(itrim(lower(`season_full'codeorother)))
gen `season_full'codeorother_recode = `season_full'codeorother, after(`season_full'codeorother)



*Recode missing - shouldnt have used these
replace `season'crop_harv = .d if `season'crop_harv == 888
replace `season'crop_harv = .r if `season'crop_harv == 999
/*
replace `season'crop_sold = .d if `season'crop_sold == 888
replace `season'crop_sold = .r if `season'crop_sold == 999
replace `season'crop_rev  = .d if `season'crop_rev == 888
replace `season'crop_rev  = .r if `season'crop_rev == 999
*/


// `s'codeorother_recode at FU


*** Rain Crop code replacements
if "`season_full'" == "rain" {
replace raincodeorother_recode = "1" if raincodeorother == "mil"
replace raincodeorother_recode = "2" if raincodeorother == "sorgho"
replace raincodeorother_recode = "8" if raincodeorother == "niebe"
replace raincodeorother_recode = "9" if raincodeorother == "loubbatou"
replace raincodeorother_recode = "10" if raincodeorother == "arachide" | raincodeorother == "arrachide"
replace raincodeorother_recode = "11" if raincodeorother == "gombo" // FU2
replace raincodeorother_recode = "12" if raincodeorother == "bissap"
replace raincodeorother_recode = "12" if raincodeorother == "hibiscuss" | raincodeorother == "hibiscu" | raincodeorother == "hibiscuit" |  raincodeorother == "hibiscus"
replace raincodeorother_recode = "12" if raincodeorother == "guisima" | raincodeorother == "jissima"
replace raincodeorother_recode = "12" if raincodeorother == "oseille"
replace raincodeorother_recode = "12" if raincodeorother == "osseille"
replace raincodeorother_recode = "13" if raincodeorother == "riddi"

replace raincodeorother_recode = "3" if raincodeorother == "riz"
replace raincodeorother_recode = "13" if raincodeorother == "sesame"
replace raincodeorother_recode = "15" if raincodeorother == "patatedouce"
replace raincodeorother_recode = "12" if raincodeorother == "warao"



replace raincodeorother_recode = "16" if raincodeorother == "pomme" | raincodeorother == "de"
replace raincodeorother_recode = "27" if raincodeorother == "salade"
replace raincodeorother_recode = "28" if raincodeorother == "choux"
replace raincodeorother_recode = "37" if raincodeorother == "haricot"


** other


replace raincodeorother_recode = "other" if raincodeorother == "moriga" | raincodeorother == "morainga" | raincodeorother == "moringa" | raincodeorother == "moringua"

}

else if "`season_full'" == "dry" {
replace drycodeorother_recode = "14" if drycodeorother == "manioc"
replace drycodeorother_recode = "27" if drycodeorother == "salade" | drycodeorother == "salades"
replace drycodeorother_recode = "28" if drycodeorother == "chou" | drycodeorother == "choux"
replace drycodeorother_recode = "35" if drycodeorother == "citrouille" | drycodeorother == "cytruil"
replace drycodeorother_recode = "33" if drycodeorother == "oignon"
replace drycodeorother_recode = "3" if drycodeorother == "riz"
replace drycodeorother_recode = "29" if drycodeorother == "tomate"
replace drycodeorother_recode = "24" if drycodeorother == "piment"

replace drycodeorother_recode = "other" if drycodeorother == "canneasucre"
replace drycodeorother_recode = "other" if drycodeorother == "de"
replace drycodeorother_recode = "other" if drycodeorother == "henne"
replace drycodeorother_recode = "other" if drycodeorother == "labtanda"
replace drycodeorother_recode = "other" if drycodeorother == "laptanda"
replace drycodeorother_recode = "other" if drycodeorother == "mangue"
replace drycodeorother_recode = "other" if drycodeorother == "moriga"
replace drycodeorother_recode = "other" if drycodeorother == "moringa"
replace drycodeorother_recode = "other" if drycodeorother == "moringua"
replace drycodeorother_recode = "other" if drycodeorother == "moringa"
replace drycodeorother_recode = "other" if drycodeorother == "moringa"
// FU2 onward
replace drycodeorother_recode = "other" if drycodeorother == "pomme"
replace drycodeorother_recode = "other" if drycodeorother == "pommedusahel"
replace drycodeorother_recode = "other" if drycodeorother == "rogo"
replace drycodeorother_recode = "other" if drycodeorother == "tubercule"
replace drycodeorother_recode = "other" if drycodeorother == "yalo"
}


// assert all items were recoded
gen real = real(`season_full'codeorother_recode)
replace real = 999 if `season_full'codeorother_recode == "other"
*assert real != .
drop real

** 2. Add unit labels `season'crop_harv_u
order `season'crop_harv_u_o, after(`season'crop_harv_u)
replace `season'crop_harv_u_o = trim(itrim(lower(`season'crop_harv_u_o)))
label copy `season'crop_harv_u `season'crop_harv_u_extend

// crop_harv_u_extend at BL

// crop_harv_u_extend at FU
#delimit;
label define `season'crop_harv_u_extend
11 "Litre"
12 "Boule"
13 "Golo"
14 "Mana"
15 "Planche"
16 "Tia"
17 "Taka"
18 "Tas"
19 "Tasse"
20 "Tete"
21 "Bidon"
22 "Feuille"
23 "Pied"
24 "Sac"
25 "Botte de paille"
26 "Caisse"
27 "Calebasse"
28 "Plat"
29 "Sceau"
30 "Basine"
31 "Boko"
32 "Centure"
33 "Fales"
34 "Carton"
35 "Nothing"
36 "Santolo"
37 "Grenier"
38 "Nez"
39 "Seau"
40 "Natte"
41 "Range"
42 "Louche"
43 "Paquet"

, replace;
#delimit cr


** 3. Recoding of units
gen `season'crop_harv_u_recode = `season'crop_harv_u, after(`season'crop_harv_u_o)
label values `season'crop_harv_u_recode `season'crop_harv_u_extend


// rcrop_harv_u_recode at FU
if "`season'" == "r" {

// A. Already existing units
replace rcrop_harv_u_recode = 1 if rcrop_harv_u_o == "20kg"
replace rcrop_harv_u_recode = 1 if rcrop_harv_u_o == "sac 25"
replace rcrop_harv_u_recode = 1 if rcrop_harv_u_o == "sacs de 40"
replace rcrop_harv_u_recode = 1 if rcrop_harv_u_o == "sac"
replace rcrop_harv_u_recode = 5 if rcrop_harv_u_o == "tige"
replace rcrop_harv_u_recode = 5 if rcrop_harv_u_o == "tiya"
replace rcrop_harv_u_recode = 9 if rcrop_harv_u_o == "panier"
// FU2
replace rcrop_harv_u_recode = 1 if rcrop_harv_u_o == "30kg"
replace rcrop_harv_u_recode = 1 if rcrop_harv_u_o == "35kg"
replace rcrop_harv_u_recode = 5  if rcrop_harv_u == 3000 // Maraba (1.5 tia)
replace rcrop_harv_u_recode = 42 if rcrop_harv_u == 3001 // Louche
replace rcrop_harv_u_recode = 43 if rcrop_harv_u == 3002 // Paquet

// B. New units
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "1  bidon de 25 litre"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "1 bidon de 25 litre"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "5 bidon de 25 litres"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "bibon de 25 litre"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "bidon  de 25 litre"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "bidon 25 litre"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "bidon 25l"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "bidon de 20l"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "bidon de 25 litre"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "bidon de 25 litres"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "bidon de 25l"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "bidon de 25litres"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "bidon de 5l"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "bidon de 5litres"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "bidon25l"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "bidons 25"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "idons de 25litres"
replace rcrop_harv_u_recode = 14 if rcrop_harv_u_o == "mana"
replace rcrop_harv_u_recode = 14 if rcrop_harv_u_o == "manana"
replace rcrop_harv_u_recode = 15 if rcrop_harv_u_o == "planche"
replace rcrop_harv_u_recode = 15 if rcrop_harv_u_o == "planches"
replace rcrop_harv_u_recode = 17 if rcrop_harv_u_o == "taka"
replace rcrop_harv_u_recode = 18 if rcrop_harv_u_o == "tas"
replace rcrop_harv_u_recode = 19 if rcrop_harv_u_o == "tasses"
// FU2
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "1 bidon de 25 litre d'huile"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "1 bidon de 25 litres d'huile"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "bibon 25l"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "bibon de 25litre"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "bidon de 25 litre d'huile"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "bidon"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "bibon de 25 littre"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "binon de 25l"
replace rcrop_harv_u_recode = 11 if rcrop_harv_u_o == "bidons de 25litres"

// FU1
replace rcrop_harv_u_recode = 23 if rcrop_harv_u_o == "pieds"
replace rcrop_harv_u_recode = 30 if rcrop_harv_u_o == "BASINE"
replace rcrop_harv_u_recode = 30 if rcrop_harv_u_o == "BASSINE"
replace rcrop_harv_u_recode = 30 if rcrop_harv_u_o == "bassine"
replace rcrop_harv_u_recode = 31 if rcrop_harv_u_o == "boko"
replace rcrop_harv_u_recode = 27 if rcrop_harv_u_o == "calebasse"
replace rcrop_harv_u_recode = 27 if rcrop_harv_u_o == "celebasses"
replace rcrop_harv_u_recode = 32 if rcrop_harv_u_o == "centure"
replace rcrop_harv_u_recode = 33 if rcrop_harv_u_o == "fales de niebe"
replace rcrop_harv_u_recode = 34 if rcrop_harv_u_o == "gros carton"
replace rcrop_harv_u_recode = 35 if rcrop_harv_u_o == "rien recolte"
replace rcrop_harv_u_recode = 36 if rcrop_harv_u_o == "santolo"
// FU2
replace rcrop_harv_u_recode = 40 if rcrop_harv_u_o == "natte(tabarma)"
replace rcrop_harv_u_recode = 40 if rcrop_harv_u_o == "natte"
replace rcrop_harv_u_recode = 40 if rcrop_harv_u_o == "natte (tabarma)"


// C. Convert quantities
// convert quantities
// standard units
replace rcrop_harv = rcrop_harv * 20 if rcrop_harv_u_o == "20kg"
replace rcrop_harv = rcrop_harv * 25 if rcrop_harv_u_o == "sac 25"
// FU2 standard units
replace rcrop_harv = rcrop_harv * 25 if rcrop_harv_u_o == "sacs de 40"
replace rcrop_harv = rcrop_harv * 30 if rcrop_harv_u_o == "30kg"
replace rcrop_harv = rcrop_harv * 35 if rcrop_harv_u_o == "35kg"

// other units: liters
replace rcrop_harv = rcrop_harv * 25 if inlist(rcrop_harv_u_o, ///
   "1  bidon de 25 litre", ///
   "1 bidon de 25 litre", ///
   "bibon de 25 litre", ///
   "bidon  de 25 litre", ///
   "bidon 25 litre", ///
   "bidon 25l") //, ///
replace rcrop_harv = rcrop_harv * 25 if inlist(rcrop_harv_u_o, ///
   "bidon de 25 litre", ///
   "bidon de 25 litres", ///
   "bidon de 25l", ///
   "bidon de 25litres", ///
   "bidon25l", ///
   "bidons 25", ///
   "idons de 25litres")
replace rcrop_harv = rcrop_harv * 5 * 25 if rcrop_harv_u_o == "5 bidon de 25 litres"
replace rcrop_harv = rcrop_harv * 20 if rcrop_harv_u_o == "bidon de 20l"
replace rcrop_harv = rcrop_harv * 5 if rcrop_harv_u_o == "bidon de 5l"
replace rcrop_harv = rcrop_harv * 5 if rcrop_harv_u_o == "bidon de 5litres"
replace rcrop_harv = rcrop_harv / 5 if rcrop_harv_u_o == "tasse"
replace rcrop_harv = rcrop_harv * 0 if rcrop_harv_u_o == "rien recolte" // no harvest
// FU2
replace rcrop_harv = rcrop_harv * 25 if inlist(rcrop_harv_u_o, ///
"1 bidon de 25 litre d'huile", ///
"1 bidon de 25 litres d'huile", ///
"bibon 25l", ///
"bibon de 25litre", ///
"bidon de 25 litre d'huile", ///
"bibon de 25 littre", ///
"binon de 25l", ///
"bidons de 25litres")


}

if "`season'" == "d" {
// New units
replace dcrop_harv_u_recode = 11 if dcrop_harv_u_o == "3 bidon 25 litre"
replace dcrop_harv_u_recode = 15 if dcrop_harv_u_o == "Planche"
replace dcrop_harv_u_recode = 15 if dcrop_harv_u_o == "plan"
replace dcrop_harv_u_recode = 19 if dcrop_harv_u_o == "tasse"
replace dcrop_harv_u_recode = 23 if dcrop_harv_u_o == "pieds"
replace dcrop_harv_u_recode = 28 if dcrop_harv_u_o == "plat"
// New in Follow up
replace dcrop_harv_u_recode = 37 if dcrop_harv_u_o == "Grenier"
replace dcrop_harv_u_recode = 38 if dcrop_harv_u_o == "Nez"
replace dcrop_harv_u_recode = 35 if dcrop_harv_u_o == "recolte en cours" // inprogress
replace dcrop_harv_u_recode = 35 if dcrop_harv_u_o == "récolte en cours"
replace dcrop_harv_u_recode = 39 if dcrop_harv_u_o == "seau"
// new in FU 2
replace dcrop_harv_u_recode = 15 if dcrop_harv_u_o == "planche"
replace dcrop_harv_u_recode = 15 if dcrop_harv_u_o == "planches"
replace dcrop_harv_u_recode = 18 if dcrop_harv_u_o == "tas"
replace dcrop_harv_u_recode = 41 if dcrop_harv_u_o == "range"
replace dcrop_harv_u_recode = 41 if dcrop_harv_u_o == "ranges"
replace dcrop_harv_u_recode = 5  if dcrop_harv_u == 3000 // Maraba (1.5 tia)


// C. Convert quantities
// convert quantities
replace dcrop_harv = dcrop_harv * 3 * 25 if dcrop_harv_u_o == "3 bidon 25 litre"
replace dcrop_harv = dcrop_harv / 5 if dcrop_harv_u_o == "tasse"
replace dcrop_harv = dcrop_harv * 0 if dcrop_harv_u_o == "recolte en cours" // no harvest
replace dcrop_harv = dcrop_harv * 0 if dcrop_harv_u_o == "récolte en cours" // no harvest

}


// confirm all recoded successfully
*if "`season'" == "r" assert rcrop_harv_u_recode != . if rcrop_harv_u == .o
*if "`season'" == "d" assert dcrop_harv_u_recode != . if dcrop_harv_u == .o

end


********************************************************************************
*** PROGRAM: qty_outliers
********************************************************************************


capture program drop qty_outliers
program define qty_outliers

syntax, season(string)  factor(integer)


// setting locals to test program

/*
 local string d
 local s d
 local season_full dry
 local season d
 local factor 10
 */



if "`season'" == "r" {
local s r
local season_full rain

}
else if "`season'" == "d" {
local s d
local season_full dry
}

rename `season_full'* *
rename `season'* *
capture confirm variable egion_
if _rc== 0 {
rename egion_ region_
}
capture confirm variable epartment_
if _rc== 0 {
rename epartment_ department_
}

// harvest quantities
byso codeorother_recode crop_harv_u_recode : egen p75_harv = pctile(crop_harv) if !missing(crop_harv) , p(75)
byso codeorother_recode crop_harv_u_recode : egen p25_harv = pctile(crop_harv) if !missing(crop_harv), p(25)
byso codeorother_recode crop_harv_u_recode : egen iqr_harv = iqr(crop_harv) if !missing(crop_harv)

gen outlier_harv = .
replace outlier_harv = 1 if crop_harv > (p75_harv + (`factor'*iqr_harv)) & !missing(crop_harv)
replace outlier_harv = 1 if crop_harv < (p25_harv - (`factor'*iqr_harv)) & !missing(crop_harv)


// sold quantities

byso codeorother_recode crop_harv_u_recode : egen p75_sold = pctile(crop_sold) if !missing(crop_sold), p(75)
byso codeorother_recode crop_harv_u_recode : egen p25_sold = pctile(crop_sold) if !missing(crop_sold), p(25)
byso codeorother_recode crop_harv_u_recode : egen iqr_sold = iqr(crop_sold) if !missing(crop_sold)

gen outlier_sold = .
replace outlier_sold = 1 if crop_sold > (p75_sold + (`factor'*iqr_sold)) & !missing(crop_sold)
replace outlier_sold = 1 if crop_sold < (p25_sold - (`factor'*iqr_sold)) & !missing(crop_sold)


end



********************************************************************************
*** PROGRAM: median_sale_price
********************************************************************************


capture program drop median_sale_price
program define median_sale_price
syntax, season(string)


preserve

/*
local string r
 local s r
 local season_full rain
 local season r
 local factor 10
*/


if "`season'" == "r" {
local season_full rain
}

if "`season'" == "d" {
local season_full dry
}

** Create median sale price
gen sale_price = crop_rev / crop_sold

** obtain median sale price at each localiy,  village, commune, department, region
foreach type in $locations  {
display "`type'"

byso `type' codeorother_recode crop_harv_u_recode : egen mp_`type' = median(sale_price)
label var mp_`type' "median sale price for this crop-unit at the `type'-level"
}

** overall median unit price
byso codeorother_recode crop_harv_u_recode: egen mp_country = median(sale_price)
label var mp_country "median price for this crop-unit"

*** PRICE DATASET
keep ${locations} mp_* codeorother_recode crop_harv_u_recode
so ${locations} codeorother_recode crop_harv_u_recode
duplicates drop

ren mp* mp*_harv
drop if mp_country_harv == .
gen country = 1

tempfile price_dataset_harv_`season'
save `price_dataset_harv_`season''

restore


** merge on harvested crop and unit

gen country = 1
foreach t in country $locations {
preserve
use `price_dataset_harv_`season'', clear
keep `t' codeorother_recode crop_harv_u_recode mp_`t'_harv
duplicates drop
tempfile tempfile
save `tempfile'
restore

merge m:1 codeorother_recode crop_harv_u_recode `t' using `tempfile', keepus(mp_`t'_harv)
gen mp_`t' = mp_`t'_harv
tab _merge
drop if _merge == 2
drop _merge
}

end



********************************************************************************
*** PROGRAM: crop_importance
********************************************************************************


capture program drop crop_importance
program define crop_importance
syntax, season(string)

/*

local string r
 local s r
 local season_full rain
 local season r
*/

if "`season'" == "r" {
local season_full rain
}

if "`season'" == "d" {
local season_full dry
}

** Imputed harvest values -- multiply harvest quantity and median sale price
gen harvest_value_imp = .

foreach t in $locations country {
display "`t'"
replace harvest_value_imp = crop_harv * mp_`t' if missing(harvest_value_imp)
}


**set problem crops to missing while understanding importance of crops
replace harvest_value_imp = .p if prob_crop != 0



********************************************************************************
* CROP  IMPORTANCE   *
********************************************************************************
/*** if eat value is missing, if the crop is a minor crop (i.e. makes up less than 10% consum ption
in 90% of households, we set harvest_value to zero. Otherwise, set harvest_value to missing ***/


*** don't include households with problem foods in calculations
byso hhid : egen has_prob = total(prob_crop)
replace has_prob = 1 if has_prob >= 1 & !missing(has_prob)


byso hhid : egen total_value = total(harvest_value_imp)
gen share_within_hh = harvest_value_imp / total_value

// major crop for household
gen major_within_hh = (share_within_hh > 0.1)

// don't include HHS with problematic foods in the calculation
replace major_within_hh = . if has_prob == 1


// count number of HHs without problem crops (no outliers, no missing prices)
count if has_prob == 0  & tag_hhid == 1
local total `r(N)'

gen share_major = .
levelsof codeorother_recode, local(crops)
foreach crop in `crops' {
// Within each crop type, count number of HHs without problem crops & harvest values ^ 10%
count if major_within_hh == 1 & has_prob == 0  & codeorother_recode == "`crop'"
local count_major `r(N)'
// compute share HHs growing major crops by crop type
replace share_major = `count_major' / `total' if codeorother_recode== "`crop'"
}
label var share_major "Share of HHs for which this crop type is a major (non-problematic) crop"

// create dummy for major crop types
gen is_major = 0
replace is_major = 1 if share_major > .1
label var is_major "Dummy for major (non-problematic) crop type"



** HH has a problem with a major crop
gen major_prob = (prob_crop != 0 & is_major == 1)
label var major_prob "Crop level dummy for HH having a problem with crop that's a major crop for 90% of HHs"
byso hhid  :egen has_major_prob = total(major_prob)
replace has_major_prob = 1 if has_major_prob >= 1
label var has_major_prob "Same dummy at HH level"

gen minor_prob = (prob_crop != 0 & is_major == 0)
label var minor_prob "Crop level dummy for HH having a problem with crop that's NOT a major crop for 90% of HHs"
byso hhid  :egen has_minor_prob = total(minor_prob)
replace has_minor_prob = 1 if has_minor_prob >= 1
label var has_minor_prob "Same dummy at HH level"

drop total_value

end


********************************************************************************
*** PROGRAM: make_totals
********************************************************************************


capture program drop make_totals
program define make_totals
syntax, season(name)


/*
local string r
 local s r
 local season_full rain
 local season r
*/


if "`season'" == "r" {
local s r
local season_full rain
}

if "`season'" == "d" {
local s d
local season_full dry
}

capture rename `season'crop_harv crop_harv
capture rename `season'crop_rev crop_rev
capture rename `season'crop_sold crop_sold

*Adjustments: if major problem, later set to missing; if minor problem, set to 0s  here

drop harvest_value_imp // from above crop_importance


****************************************************************************
** Approach 1: Imputed harvest values (quantity harvested * median price)

** generating ag_*_harvest_xof_imp
gen harvest_value = (crop_harv * crop_rev) / crop_sold
gen harvest_value_imp = .


sort hhid crop2name
foreach t in $locations country {
display "`t'"
replace harvest_value_imp = crop_harv * mp_`t' if missing(harvest_value_imp)
}

// replace harvest values based on dummies created above minor_prob major_prob
replace harvest_value_imp = .p if (prob_crop != 0 & is_major == 0) // set to 0 if minor crop
replace harvest_value_imp = .m if (prob_crop != 0 & is_major == 1) // set to missing if major, and fix below
replace harvest_value_imp = .l if harvest_value == 0 // assume lost, shouldnt even have made it to this section


// compute HH totals (we show the 98 p winsorization in our results)
byso hhid : egen ag_`season'_harvest_xof_imp = total(harvest_value_imp ), m
label variable ag_`season'_harvest_xof_imp "Harvest value using prices, `season_full' season"
replace ag_`season'_harvest_xof_imp = .m if has_major_prob == 1

// winsorize harvest and sale values within each recoded crop type
sort hhid crop2name
levelsof codeorother_recode, local (crop_type)

foreach p in 95 98 99 {
gen harvest_value_imp_`p' = harvest_value_imp // prepare var to wins

foreach type in `crop_type' {
count if codeorother_recode == "`type'" & !missing(harvest_value_imp)
if `r(N)' == 0 { // if there are no non-missing observations, do nothing
dis "can't winsorize"
}
else if `r(N)' > 0 { // otherwise, winsorize
_pctile harvest_value_imp_`p' if codeorother_recode == "`type'" & !missing(harvest_value_imp_`p') , p(`p')
replace harvest_value_imp_`p' = `r(r1)' if codeorother_recode == "`type'" & ///
   harvest_value_imp_`p' > `r(r1)' & ///
   !missing(harvest_value_imp_`p')
}
}

// compute HH totals
byso hhid : egen ag_`season'_harvest_xof_imp_`p' = total(harvest_value_imp_`p'), m
label variable ag_`season'_harvest_xof_imp_`p' "Harvest value using prices, `season_full' season"
replace ag_`season'_harvest_xof_imp_`p' = .m if has_major_prob == 1
}


// calculate chef's share of harvest value (98 p wins.)
merge 1:1 hhid crop_pos using "${baseline_intermediate}/temp_agric_`s'_chef_shares", gen(_mChefShares)



drop if _mChefShares == 2 // drop 84 crops with chef share but no harvest value

// scale imputed harvest value by plot and owner count
gen harvest_value_chef_imp_98 = harvest_value_imp_98 * chef_share_crop // ignores non-chef crops

assert harvest_value_chef_imp_98 <= harvest_value_imp_98 if !missing(harvest_value_chef_imp_98) /**/
assert missing( harvest_value_chef_imp_98) if missing(harvest_value_imp_98)
count if harvest_value_chef_imp_98 == . & harvest_value_imp_98 != .

// compute HH totals for chef plots
byso hhid : egen ag_`s'_harvest_chef_xof_imp_98 = total(harvest_value_chef_imp_98), m
label variable ag_`s'_harvest_chef_xof_imp_98 "Chef harvest value using prices, `season_full' season (98 p wins.)"
replace ag_`s'_harvest_chef_xof_imp_98 = .m if has_major_prob == 1


// compute number of crops within HH
byso hhid : egen ag_`s'_harvest_n = count(harvest_value_imp)




****************************************************************************
** Approach 2: harvest values (1st: quantity harvested * unit   price where revenues are reported)
**  (2nd: quantity harvested * median price where revenues NOT reported)

** generating ag_*_harvest_xof
*gen harvest_value = (crop_harv * crop_rev) / crop_sold

sort hhid crop2name

foreach t in $locations country{
display "`t'"
replace harvest_value = crop_harv * mp_`t' if missing(harvest_value)
}

replace harvest_value = .p if prob_crop != 0 & is_major == 0 // set to 0 if minor crop
replace harvest_value = .m if prob_crop != 0 & is_major == 1 // set to missing if major, and fix below
replace harvest_value = .l if harvest_value == 0 // assume lost, shouldn't even have made it to this section

// compute hh totals
byso hhid : egen ag_`season'_harvest_xof = total(harvest_value), m
label var ag_`season'_harvest_xof "Harvest value (key plots) (reported) `season_full' season"
replace   ag_`season'_harvest_xof = .m if has_major_prob == 1

// winsorize harvest and sale values with each recoded crop type
sort hhid crop_pos
levelsof codeorother_recode, local (crop_type)
foreach p in 95 98 99 {
gen harvest_value_`p' = harvest_value // prepare var to wins

foreach type in `crop_type' {
count if codeorother_recode == "`type'" & !missing(harvest_value)
if `r(N)' == 0 { // if there are no non-missing observations, do nothing
dis "can't winsorize"
}
else if `r(N)' > 0 { // otherwise, winsorize
_pctile harvest_value_`p' if codeorother_recode == "`type'" & !missing(harvest_value_`p') , p(`p')
replace harvest_value_`p' = `r(r1)' if codeorother_recode == "`type'" & ///
   harvest_value_`p' > `r(r1)' & ///
   !missing(harvest_value_`p')
}
}

// compute HH totals
byso hhid : egen ag_`season'_harvest_xof_`p' = total(harvest_value_`p'), m
label variable ag_`season'_harvest_xof_`p' "Harvest value using prices, `season_full' season"
replace ag_`season'_harvest_xof_`p' = .m if has_major_prob == 1
}


// calculate chef's share of harvest value
gen harvest_value_chef_98 = harvest_value_98 * chef_share_crop

assert harvest_value_chef_98 <= harvest_value_98 if !missing(harvest_value_chef_98) /**/
assert missing(harvest_value_chef_98) if missing(harvest_value_98)
count if harvest_value_chef_98 == . & harvest_value_98 != .

byso hhid : egen ag_`s'_harvest_chef_xof_98 = total(harvest_value_chef_98), m
label variable ag_`s'_harvest_chef_xof_98 "Chef harvest value (key plots) (reported) `season_full' season"
replace ag_`s'_harvest_chef_xof_98 = .m if has_major_prob == 1



****************************************************************************
** crop harvest value, for diversification measure (approach 1 only)

sort hhid crop2name
levelsof crop_pos, local(crop_no)
foreach cno in `crop_no' {
// Imputed only
gen t_ag_harvest_`cno'_imp_xof = harvest_value_imp_98 if crop_pos == `cno'
recode t_ag_harvest_`cno'_imp_xof (. = -999)
bysort hhid (t_ag_harvest_`cno'_imp_xof) : gen  ag_`season'_harvest_`cno'_imp_xof = t_ag_harvest_`cno'_imp_xof[_N]
drop t_ag_harvest_`cno'_imp_xof

label var ag_`season'_harvest_`cno'_imp_xof "Crop `cno' imputed harvest value, `season_full' season (98 p wins.)"
recode ag_`season'_harvest_`cno'_imp_xof (-999 = 0)
}

** crop harvest value (crop level)
sort hhid crop2name
levelsof codeorother_recode, local(crop_types)
foreach ctype in `crop_types' {
dis "`ctype'"
gen c_ag_harvest_`ctype'_imp_xof = harvest_value_imp_98 if codeorother_recode == "`ctype'"
recode c_ag_harvest_`ctype'_imp_xof (. = -999)
bysort hhid (c_ag_harvest_`ctype'_imp_xof) : gen ag_`season'_c`ctype'_harvest_imp_xof = c_ag_harvest_`ctype'_imp_xof[_N]
drop c_ag_harvest_`ctype'_imp_xof

label var ag_`season'_c`ctype'_harvest_imp_xof "Crop `ctype' imputed harvest value, `season_full' season (98 p wins.)"
recode ag_`season'_c`ctype'_harvest_imp_xof (-999 = 0)
}



****************************************************************************
** crop sale value


// drop problematic sales and revenues
foreach var in crop_rev crop_sold {
replace `var' = .p if prob_crop != 0 & is_major == 0 // set to 0 if minor crop
replace `var' = .m if prob_crop != 0 & is_major == 1 // set to missing if major, and fix below
}


** Approach 1: ag_r_sale_imp_xof (using median prices)
sort hhid crop2name
gen harvest_sales_imp = .


foreach t in $locations country{
display "`t'"
replace harvest_sales_imp = mp_`t' * crop_sold if missing(harvest_sales_imp)
}

** calculate hh totals
byso hhid : egen ag_`season'_sale_imp_xof = total(harvest_sales_imp), m
label var ag_`season'_sale_imp_xof "Total sale value, imputed (key plots), `season_full' season"


** Approach 2: ag_*_sale_xof (using reported revenues)
byso hhid : egen ag_`season'_sale_xof = total(crop_rev), m
label var ag_`season'_sale_xof "Total sale value, reported (key plots), `season_full' season" // wtf check: checked. Used same method as harvest_value

// winsorize
sort hhid crop2name
levelsof codeorother_recode, local (crop_type)
foreach p in 95 98 99 {
gen harvest_sales_imp_`p' = harvest_sales_imp // prepare var to wins

foreach type in `crop_type' {
count if codeorother_recode == "`type'" & !missing(harvest_sales_imp)
if `r(N)' == 0 { // if there are no non-missing observations, do nothing
dis "can't winsorize"
}
else if `r(N)' > 0 { // otherwise, winsorize
_pctile harvest_sales_imp_`p' if codeorother_recode == "`type'" & !missing(harvest_sales_imp_`p') , p(`p')
replace harvest_sales_imp_`p' = `r(r1)' if codeorother_recode == "`type'" & ///
   harvest_sales_imp_`p' > `r(r1)' & ///
   !missing(harvest_sales_imp_`p')
}
}

// compute HH totals
byso hhid : egen ag_`season'_sale_imp_xof_`p' = total(harvest_sales_imp_`p'), m
label variable ag_`season'_sale_imp_xof_`p' "Total sale value, imputed wins. at `p'p(key plots), `season_full' season"
replace ag_`season'_sale_imp_xof_`p' = .m if has_major_prob == 1
}

end





*******/


********************************************************************************
********************************************************************************
********************************************************************************



********************************************************************************
*** PUT IT ALL TOGETHER
********************************************************************************


*** Define problem crop types - to be determined if major or minor

#delimit ;
label define prob_crop
1 "undefined harvest quantity - don't know, refused"
2 "very unlikely, impossible harvest quantity"
3 "unlikely, impossible sold quantity"
4 "undefined harvest unit"
5 "unconvertible harvest unit";
#delimit cr




******************
foreach s in r d {


// 0. create tempfile `chef_shares'
scale_chef_share, season(`s')



recode_crops, season(`s')


** A. some manual issues


gen prob_crop = 0






******************

qty_outliers, season(`s') factor(10)


** set as prob_crop = 3 if outlier sold quantity
replace prob_crop = 3 if outlier_sold == 1 // unlikely sold quantity
** set as prob_crop = 2 if outlier harvested quantity
replace prob_crop = 2 if outlier_harv == 1 // unlikely harvest quantity

replace crop_harv = .r if crop_harv == 888
replace crop_sold = .r if crop_sold == 888
replace crop_rev  = .r if crop_rev == 888
replace prob_crop = 1 if missing(crop_harv) & crop_harv != .

** B. assert harvest quantity >= sold quantity, which wasnt required in some surveys
*assert rcrop_harv >= rcrop_sold if !missing(rcrop_sold), rc0

replace prob_crop = 2 if crop_harv <crop_sold & !missing(crop_sold)  // unnlikely harvest quantity
replace prob_crop = 4 if missing(crop_harv_u_recode) & crop_harv_u_recode != .




******************

median_sale_price, season(`s')



replace prob_crop = 5 if mp_country == . & !missing(crop_harv) // no price for this harvest unit/crop combination
// prob_crop == 1 DNE in the data yet


// prob_crop and has_prob_ are defined at crop level
// while has_prob is dummy for prob_crop at HH level
levelsof prob_crop, local(levels)
foreach level in `levels' {
gen has_prob_`level' = (prob_crop == `level')
}
// replaced this with tab, gen because that command doesn't see that there is no "1" in prob_crop
capture confirm var has_prob_0
if (_rc == 0) drop has_prob_0


egen tag_hhid = tag(hhid)

******************
crop_importance, season(`s') // excludes households with problem crops

******************


make_totals, season(`s')



local seeds

if "`s'" == "r" { // rainy season only
/** ag_r_seeds_d **/

// raincrops_2_long.dta (other input vars, inp*, are in `main'.dta)


byso hhid : egen ag_r_seeds_d = max(crop_seedbot) // crop_seedbot: dummy for seed purchase
label var ag_r_seeds_d "purchased seeds"
local seeds ag_r_seeds_d

// we don't have purchased value of seeds
}



** ag_*_comm
gen ag_`s'_comm = ag_`s'_sale_imp_xof_98 / ag_`s'_harvest_xof_imp_98
replace ag_`s'_comm = 1 if ag_`s'_comm > 1 & ag_`s'_comm !=.
label var ag_`s'_comm "Commericialisation % of crops (key plots), `s' season "


** generate extensive margins by crop type for hh shares table
ds ag_`s'_c*_harvest_imp_xof
foreach var in `r(varlist)' {
gen `var'_temp = (`var' > 0 & !missing(`var')) // crop level dummy
byso hhid codeorother_recode : egen `var'_d = max(`var'_temp) // hh level dummy
drop `var'_temp
}
rename ag_`s'_c*_harvest_imp_xof_d ag_`s'_c*_d


keep hhid ag_`s'_harvest_xof_imp ///
  ag_`s'_harvest_xof_imp_9? ///
  ag_`s'_harvest_chef_xof_imp_98 ///
  ag_`s'_harvest_xof ///
  ag_`s'_harvest_xof_9? ///
  ag_`s'_harvest_chef_xof_98 ///
  ag_`s'_harvest_*_imp_xof /// crop no.
  ag_`s'_*_harvest_imp_xof /// crop type
  ag_`s'_sale_xof ///
  ag_`s'_sale_imp_xof ///
  ag_`s'_sale_imp_xof_9? ///
  ag_`s'_comm `seeds' ///
  ag_`s'_c*_d // dummy vars (ext. mgns.)

 duplicates drop
 bysort hhid: assert _N == 1

 tempfile `s'_value
 save ``s'_value', replace



}

use `r_value', clear
merge 1:1 hhid using `d_value', gen(_mseason)


// diverge to extract chef and hh-head ownership of plots
preserve

use "${baseline_intermediate}/temp_agric_r_chef_owns", clear
merge 1:1 hhid using "${baseline_intermediate}/temp_agric_d_chef_owns"

gen chef_owns_d   = (r_chef_ownman_d == 1   | d_chef_ownman_d == 1)

keep hhid chef_owns_d
isid hhid

tempfile temp_agric_chef_owns
save `temp_agric_chef_owns'

restore


merge 1:1 hhid using `temp_agric_chef_owns', gen (_mchefowns)
drop if _mchefowns == 2
drop _mchefowns


merge 1:1 hhid using "${baseline_intermediate}/temp_agric_cropstatuses"

assert ag_d_harv == 0 if _merge == 2
assert ag_r_harv == 0 if _merge == 2



*********************************************************************************
**** assign 0 harvests : missing from only one season or no harvests at all
foreach var of varlist ag_r_harvest_xof_imp - ag_r_sale_imp_xof ag_d_harvest_xof_imp - ag_d_sale_imp_xof ///
   ag_?_harvest_xof_imp_9? ag_?_harvest_xof_9? {
replace `var' = 0 if `var' == . // not m, which are missing bc can't compute
}

assert ag_r_harvest_xof_imp == 0 if ag_r_harv == 0
assert ag_r_harvest_xof_imp_95 == 0 if ag_r_harv == 0
assert ag_d_harvest_xof_imp == 0 if ag_d_harv == 0
assert ag_d_harvest_xof_imp_95 == 0 if ag_d_harv == 0

*** deal later
*** said harvested, but 0 reported, assumed lost, so  must fix crop statuses

foreach s in r d {

gen had_lost_wrongplace_`s' = 0
gen had_big_prob_`s' = 0
gen had_min_prob_`s' = 0
gen had_harv_`s' = 0

ds ag_`s'_harvest_*_imp_xof
local count : word count(`r(varlist)')
forvalues i = 1/`count' {
display "here `count'"
 * lost counted in wrong place
replace had_lost_wrongplace_`s' = 1 if ag_`s'_harvest_`i'_imp_xof == .l
replace had_big_prob_`s' = 1 if ag_`s'_harvest_`i'_imp_xof == .m
replace had_min_prob_`s' = 1 if ag_`s'_harvest_`i'_imp_xof == .p
replace had_harv_`s' = 1 if ag_`s'_harvest_`i'_imp_xof == .m | ///
   ag_`s'_harvest_`i'_imp_xof == .p | ///
  (ag_`s'_harvest_`i'_imp_xof > 0 & ag_`s'_harvest_`i'_imp_xof != .l)
}
}
quietly {
replace ag_r_lost = 1 if had_lost_wrongplace_r == 1
replace ag_r_harv = 0 if had_harv_r == 0
replace ag_r_sold = 0 if had_harv_r == 0 // if not harvested, then also not sold
drop had_harv_r

replace ag_d_lost = 1 if had_lost_wrongplace_d == 1
replace ag_d_harv = 0 if had_harv_d == 0
replace ag_d_sold = 0 if had_harv_d == 0 // if not harvested, then also not sold
drop had_harv_d
}

assert ag_r_harvest_xof_imp != 0 if ag_r_harv == 1 & had_min_prob_r != 1
assert ag_d_harvest_xof_imp != 0 if ag_d_harv == 1 & had_min_prob_d != 1

************************ number of harvested crops

gen div_rain_n = 0
label variable div_rain_n "number of rain crops harvested" // includes minor and major problems

ds ag_r_harvest_*_imp_xof
local count : word count(`r(varlist)')
forvalues i = 1/`count' {
replace div_rain_n = div_rain_n + 1 if ag_r_harvest_`i'_imp_xof > 0 & (ag_r_harvest_`i'_imp_xof != . & ag_r_harvest_`i'_imp_xof != .l)
}


gen div_dry_n = 0
label variable div_dry_n "number of dry crops harvested"
ds ag_d_harvest_*_imp_xof

local count : word count(`r(varlist)')
forvalues i = 1/`count' {
replace div_dry_n = div_dry_n + 1 if ag_d_harvest_`i'_imp_xof > 0 & (ag_d_harvest_`i'_imp_xof != . & ag_d_harvest_`i'_imp_xof != .l )
}

gen div_ag_n = 0
replace div_ag_n = div_dry_n + div_rain_n
label variable div_ag_n  "Total crop types harvested (key plots), 12 months"

save "${baseline_intermediate}/temp_agric_valueandstatus", replace