*** Agricultural inputs 
clear
use "${baseline_intermediate}/niger_main_2021.dta"
keep hhid consent hasplots inp_* *_purch *_purch
merge 1:1 hhid using "${baseline_intermediate}/temp_agric_valueandstatus", keepus(ag_r_harvest_xof_imp ag_r_harvest_xof)

/** ag_r_waste **/
gen ag_r_waste = 0
replace ag_r_waste = 1 if inp_comp == 1
label var ag_r_waste "use of household waste on plots owned or managed by beneficiary or head of household"

/** ag_r_fert_d **/
gen ag_r_fert_d = 0
replace ag_r_fert_d = 1 if inp_fert == 1
label var ag_r_fert_d "use of chemical fertilizer"

/** ag_r_fert_xof **/
gen ag_r_fert_xof = fert_purch
replace ag_r_fert_xof = 0 if ag_r_fert_d == 0
label var ag_r_fert_xof "chemical fertilizer value at purchase"

/** ag_r_pest_d **/
gen ag_r_pest_d = 0
replace ag_r_pest_d = 1 if inp_prod == 1
label var ag_r_pest_d "use of phytosanitaire products"

/** ag_r_pest_xof **/
gen ag_r_pest_xof = prod_purch
replace ag_r_pest_xof = 0 if ag_r_pest_d == 0
label var ag_r_pest_xof "phytosanitaire value at purchase"

/** ag_r_entraide_d **/
gen ag_r_entraide_d = 0
replace ag_r_entraide_d = 1 if inp_group == 1
label var ag_r_entraide_d "used work groups"

/** ag_r_paidlab_d **/
gen ag_r_paidlab_d = 0
replace ag_r_paidlab_d = 1 if inp_paidlab == 1
label var ag_r_paidlab_d "used paid labor"

/** ag_r_paidlab_xof **/
gen ag_r_paidlab_xof = inp_paidlabamt
replace ag_r_paidlab_xof = 0 if ag_r_paidlab_d == 0
label var ag_r_paidlab_xof "paid labour amount paid"




/** ag_r_inputs_xof **/
egen ag_r_inputs_xof = rowtotal(ag_r_fert_xof ag_r_pest_xof ag_r_paidlab_xof)
//note: we do not have seeds expenditure to include as an input
label var ag_r_inputs_xof "input expenditure: chemical fertilizer + phytosanitaire products + paid labor (value at purchase)"

** ag_r_income_xof
gen ag_r_income_xof = ag_r_harvest_xof_imp - ag_r_inputs_xof
label var ag_r_income_xof "ag income proxy: harvest value - input expenditure"


// remove duplicates, clean and save
keep if consent == 1
drop consent

keep hhid ag_r_* 
drop ag_r_harvest_xof


compress
tempfile inputs
save `inputs', replace 








*****
********************************************************************************
/** DATA ON DAYS WORKED FOR EACH HOUSEHOLD MEMBER ARE IN MAIN_PLOTLIST **/




use "${baseline_intermediate}/main_plotlist_long", clear
drop if missing(plot_israin)

keep hhid plot_pos plot_israin days_mem*

// To generate number of days hh member worked on plot, we will need to reshape long 'days_mem'
reshape long days_mem, i(hhid plot_pos) j(mem_pos)

// merge
merge m:1 hhid mem_pos using "${baseline_intermediate}/members_long", keepus(hhid mem_pos is_chef sex age)
drop if _merge == 1
drop _merge

// keeping only rain plots
keep if plot_israin == 1

// topcode days_mem
gen days_mem_tc = days_mem
replace days_mem_tc = 120 if days_mem > 120 & !missing(days_mem)

** days_male
gen days_male = days_mem if sex == 0 & (!missing(age) & age >= 15)
gen days_male_tc = days_male
replace days_male_tc = 120 if (days_male > 120 & !missing(days_male))

** days_female
gen days_female = days_mem if sex == 1 & (!missing(age) & age >= 15)
gen days_female_tc = days_female
replace days_female_tc = 120 if (days_female > 120 & !missing(days_female))

** days_child
gen days_child = days_mem if age < 15
gen days_child_tc = days_child
replace days_child_tc = 120 if (days_child > 120 & !missing(days_child))

** days_chef
gen days_chef = days_mem if is_chef == 1
gen days_chef_tc = days_chef
replace days_chef_tc = 120 if (days_chef > 120 & !missing(days_chef))



** ag_r_hhh_days
byso hhid : egen ag_r_hhh_days = total(days_chef)
byso hhid : egen ag_r_hhh_days_tc = total(days_chef_tc)
label var ag_r_hhh_days "number of days household head worked on plots during rainy season"
label var ag_r_hhh_days_tc "number of days household head worked on plots during rainy season (top coded)"


** ag_r_days
byso hhid : egen ag_r_days = total(days_mem) if plot_israin == 1, m
label var ag_r_days "number of days household members work on rain plots"
byso hhid : egen ag_r_days_tc = total(days_mem_tc) if plot_israin == 1, m
label var ag_r_days_tc "number of days household members work on rain plots (top coded)"

** ag_r_days_mal
byso hhid : egen ag_r_days_mal = total(days_male) if plot_israin == 1, m
label var ag_r_days_mal "number of days household men work on rain plots"
byso hhid : egen ag_r_days_mal_tc = total(days_male_tc) if plot_israin == 1, m
label var ag_r_days_mal_tc "number of days household men work on rain plots (top coded)"

** ag_r_days_fem
byso hhid : egen ag_r_days_fem = total(days_female) if plot_israin == 1, m
label var ag_r_days_fem "number of days women work on rain plots"
byso hhid : egen ag_r_days_fem_tc = total(days_female_tc) if plot_israin == 1, m
label var ag_r_days_fem_tc "number of days women work on rain plots (top coded)"

** ag_r_days_child
byso hhid : egen ag_r_days_child = total(days_child) if plot_israin == 1, m
label var ag_r_days_child "number of days household children work on rain plots"
byso hhid : egen ag_r_days_child_tc = total(days_child_tc) if plot_israin == 1, m
label var ag_r_days_child_tc "number of days household children work on rain plots (top coded)"


// remove duplicates, clean and save
keep hhid ag_r_*_days ag_r_days*
duplicates drop

ds hhid, not
foreach var in `r(varlist)' {
recode `var' (. = 0)
}



merge 1:1 hhid using `inputs', gen(_minputs) 
drop _minputs




compress
save "${baseline_intermediate}/temp_agric_inputs", replace


