****************************************************************************
*---------------------------- SAVINGS  ------------------------------------*
****************************************************************************

clear
use "${baseline_intermediate}/savings_long"

// recode missing
recode sav_bal (888 = .) (999 = .)

*** saving_xof
sort hhid, stable
winsor2 sav_bal, cut(0 98) replace
replace sav_bal = 0 if missing(sav_bal)
by hhid : egen saving_xof = total(sav_bal)
label var saving_xof "Savings balance" // hhd level total savings

** saving_d

gen init = (saving_xof > 0) // includes .r and .d
bysort hhid : egen saving_d = max(init)
label var saving_d "Saved in past 12 months"
drop init

** recode saves_loc_name
#delimit;
label define saves_loc
1 "Bank, formal institution" // F
2 "Savings group" // I
3 "Family outside HH" // I
4 "Friends, neighbours" // I
5 "Shopkeeper" // I
6 "At home"  // I
7 "On person" // U
8 "Other" // I
9 "Agri co-operative" // I
10 "Mobile Money" // I
11 "Jewellery"; // I
#delimit cr

gen saves_loc = __key__, after(saves_loc_name)
label val saves_loc saves_loc

**saving_inf_xof
gen informal_saving = sav_bal if (inrange(saves_loc, 2, 11))
by hhid : egen saving_inf_xof = total(informal_saving)
label var saving_inf_xof "Savings balance, informal"

**saving_for_xof
gen formal_saving = sav_bal if (saves_loc == 1)
by hhid : egen saving_for_xof = total(formal_saving)
label var saving_for_xof "Savings balance, formal"

gen init = (saving_d == 1) & (saves_loc == 1) & sav_bal > 0
byso hhid : egen saved_bank = max(init)
label var saved_bank "Saved in bank in last 12 months"
drop init

keep hhid saving_d saving_xof saving_inf_xof saving_for_xof saved_bank
duplicates drop

tempfile savings
save "`savings'"

****************************************************************************
*------------------------------ LOANS  ------------------------------------*
****************************************************************************
clear
use "${baseline_intermediate}/credit_long"

label variable cred_amt "Loan amount"
label variable cred_int "Interest on loan?"
label variable cred_dur "Loan duration in months"
label variable cred_out "Outstanding loan amount"

sum cred_amt
winsor2 cred_amt, cut(0 98) replace
sum cred_amt

sum cred_out
winsor2 cred_out, cut(0 98) replace
sum cred_out

replace cred_amt = 0 if missing(cred_amt)
replace cred_out = 0 if missing(cred_out)

gen loan = (cred_amt > 0) & (cred_amt < .)
bysort hhid : egen loan_d = max(loan)
label var loan_d "Took loan in last 12 months"
drop loan

#delimit ;
label def cred_loc
1   "association/groupe d'épargne"
2   "un ami / voisin"
3   "famille hors du ménage"
4   "un prêteur / usurier"
5   "un commerçant"
6   "une banque / une insitution de microcrédit / une ONG / autre institution formelle"
7   "Autre personne ou groupe a specifier"
;
#delimit cr

rename __key__ cred_pos
label values cred_pos cred_loc

gen loan_inf_d = (loan_d == 1) & (cred_pos != 6) & cred_amt > 0
byso hhid : egen loan_inf = max(loan_inf_d)
label var loan_inf"Took informal loan in last 12 months"
drop loan_inf_d

gen loan_for_d = (loan_d == 1) & (cred_pos == 6) & cred_amt > 0
byso hhid : egen loan_for = max(loan_for_d)
label var loan_for "Took formal loan in last 12 months"
drop loan_for_d

**loan_xof
sort hhid, stable
by hhid : egen loan_xof = total(cred_out)
label var loan_xof "Loans outstanding"

by hhid : egen aloan_xof = total(cred_amt)
label var aloan_xof "Amount borrowed"

keep hhid loan_d loan_inf loan_for loan_xof aloan_xof
duplicates drop
bysort hhid : assert _N == 1

tempfile credit
save `credit'

****************************************************************************
*------------------------- ACESS TO FUNDS  --------------------------------*
****************************************************************************
clear
use "${baseline_intermediate}/niger_main_2021"
keep if consent == 1
keep hhid accesstofunds*

bysort hhid: assert _N == 1

label var accesstofunds "Confident of raising 40000 FCFA" // actually different amount

label values accesstofunds .
recode accesstofunds (1 = 1) (2 = 1) (3 = 0) (4 = 0)
label define accesstofunds 0 "Not likely" 1 "Likely", replace

****************************************************************************
*------------------------- MERGE DATASETS  --------------------------------*
****************************************************************************

merge 1:1 hhid using `savings', gen(_msav)
* assert _msav == 3
* assertion is false
merge 1:1 hhid using `credit', gen(_mcre)
assert _mcre == 3

drop _m*

** gross_saving
gen gross_saving = saving_xof - loan_xof
label var gross_saving "Savings minus outstanding loans"

****************************************************************************
*------------------------- SAVING DATASET  --------------------------------*
****************************************************************************

save "${baseline_intermediate}/finance", replace
