
********************************************************************************
* PSYCHOLOGY/MENTAL HEALTH    *
********************************************************************************
clear
use "${baseline_intermediate}/niger_main_2021.dta"
merge 1:1 hhid using "${baseline_intermediate}/identification.dta", ///
gen(_mtreatment) keepusing(treatment)
keep if consent == 1
drop consent
keep if _mtreatment == 3

// keep $id_vars treatment consent start_mental - end_mental
// drop consent

// assertions ******************************************************************
foreach var of varlist cd1 cd2 cd3_new cd4 cd5 cd6_new cd7 cd8 cd9 cd10_new {
// not recoded as mentioned in PAP (from 0-7 to 1-4)
// MRT at FU has -999 and -888 as options for cd questions
assert inrange(`var', 0, 7) | missing(`var')
}

foreach var of varlist stair* { // includes stairs_peace at FU
assert inrange(`var', 0, 10) | missing(`var') // .g at BL and . normal at FU2
}

// Some vars have 1-4 at BL and 5-8 at FU
foreach var in gse* ros4 ///
   scs3_new scs5_new ///
   tg1_new tg4_new2 ///
   worktogether_new {

// if var exists (not all vars exist in each survey)
capture confirm var `var'
if _rc == 0 {
assert inrange(`var', 5, 8) | missing(`var') // missings allowed at FU
}
}


********************************************************************************
**************   Secondary B.4. Psycho social well being      ******************
********************************************************************************
**** Secondary B.4.1 Mental health and well-being
* Factor z-score index of 5 components
// reverse depression and disability so that all variables are increasing in wellbeing
// reverse using revrs package from SSC
// no missing values across all components


label variable cd1 "More disturbed than usual"
label variable cd2 "Trouble focusing"
label variable cd3_new "Felt sad"
label variable cd4 "Taking more energy than usual"
label variable cd5 "Felt confident about future"
label variable cd6_new "Felt nervous or tense"
label variable cd7 "Had trouble sleeping"
label variable cd8 "Felt happy"
label variable cd9 "Felt alone"
label variable cd10_new "Too tired to do anything"
label variable useless "Felt unproductive"

replace cd5 = 7 - cd5
replace cd8 = 7 - cd8
egen mentalhealth = rowtotal(cd1 cd2 cd3_new cd4 cd5 cd6_new cd7 cd8 cd9 cd10_new useless), missing

/* Phyllisa march 19th 2025 we standardise other rounds using baseline values.
sum mentalhealth if treatment == 0
replace mentalhealth = mentalhealth - r(mean)
replace mentalhealth = mentalhealth/r(sd)

replace mentalhealth = -mentalhealth */ // higher values mean better health

label variable mentalhealth "\makecell{Mental \\ health}"

****************************************************************************
**** Secondary B.4.2 Self and social worth

// social standing, (1-10)
egen socstanding = rowtotal(stair_status_today stair_good_today stair_respect_new stair_opinion_new), missing

sum socstanding if treatment == 0
replace socstanding = socstanding - r(mean)
replace socstanding = socstanding/r(sd)
sum socstanding
label variable socstanding "\makecell{Social \\ standing}"

********************************************************************************
**** Secondary B.4.3 Future expectations index

* future expectations index
label variable stair_satis_future "Life satisfaction in two years"
label variable stair_status_future "Status in two years"

egen futureexp = rowtotal(stair_satis_future stair_status_future), missing

sum futureexp if treatment == 0
replace futureexp = futureexp - r(mean)
replace futureexp = futureexp/r(sd)
sum futureexp
label variable futureexp "Expectations"

keep hhid ///
mentalhealth socstanding futureexp

// SAVE
compress
save "${baseline_intermediate}/psychology.dta", replace






