********************************************************************************
* FOOD SECURITY    *
********************************************************************************

********************************************************************************

clear
use "${baseline_intermediate}/niger_main_2021.dta"

********************************************************************************
***  Secondary B.1.1 (and Primary A.1.1) Food Insecurity

// set up


capture program drop setup_and_reverse
program setup_and_reverse


keep if consent == 1
drop consent

rename food* hunger*

// Label
label var hunger1 "Dummy: Household/members worried about not having enough food"
label var hunger2 "Dummy: Household/members unable to eat nutritious and healthy foods"
label var hunger3 "Dummy: Household/members had to eat a smaller variety of foods"
label var hunger4 "Dummy: Household/members had to skip a meal"
label var hunger5 "Dummy: Household/members ate less than they thought they should"
label var hunger6 "Dummy: Household ran out of food"
label var hunger7 "Dummy: Household/members were hungry but did not eat"
label var hunger7b "Frequency: Household/members were hungry but did not eat"
label var hunger8 "Dummy: Household/members went an entire day without eating"
label var hunger8b "Frequency that household/members went an entire day without eating"

// recode missing
replace hunger8b = 0 if missing(hunger8b) & hunger8 == 0
replace hunger7b = 0 if missing(hunger7b) & hunger7 == 0

sort hhid
keep hhid hunger?

ds hunger1 hunger2 hunger3 hunger4 hunger5 hunger6 hunger7 hunger8
foreach var in `r(varlist)' {
gen `var'_rvrs = `var'
recode `var'_rvrs (0=1) (1=0)

local lab : var label `var'
label var `var'_rvrs "Reversed, `lab'"
}
keep hhid hunger?_rvrs
rename hunger*_rvrs hunger_rvrs*

********************************************************************************
***  Secondary B.1.1 (and Primary A.1.1) Food Insecurity -- Raw sum
ds hunger_rvrs*
egen FIES_rvrs_raw = rowtotal(`r(varlist)'), m // no missing values in Niger as food* vars were required
label var FIES_rvrs_raw "A.1 REVERSED food insecurity experience scale, raw score [0-8], 12 months"
assert inrange(FIES_rvrs_raw, 0, 8) | missing(FIES_rvrs_raw)
// higher is less insecure (better)

end


setup_and_reverse // execute program above

drop if hunger_rvrs1 == .



keep hhid hunger_rvrs* FIES_rvrs_raw
order hhid hunger_rvrs* FIES_rvrs_raw
tempfile fies_results
save `fies_results'






********************************************************************************
**** Secondary B.1.2 FCS(for Secondary B.1.2, see Primary A.1.2)
use "${baseline_intermediate}/niger_main_2021.dta", clear
keep if consent == 1
drop consent

drop if div_cereal == .

gen div_veg_all = div_veg+div_veg_vita+div_vega
replace div_veg_all = 7 if !missing(div_veg_all) & div_veg_all > 7 // top code if greater than 7

gen div_fruit_all = div_fruit+div_fruit_vita
replace div_fruit_all = 7 if !missing(div_fruit_all) & div_fruit_all > 7 // top code if greater than 7


gen div_meat_all =  div_meat+div_meat2+div_meat_org+div_fish+div_egg
replace div_meat_all = 7 if !missing(div_meat_all) & div_meat_all > 7 // top code if greater than 7


gen FCS = div_cereal*2 + div_pulse*3 + div_veg_all + div_fruit_all + div_meat_all*4 + div_milk*4 + div_oil * 0.5 + div_sugar *0.5
label var FCS "B.1.2 Beneficiary Food Consumption Score FU only"





********************************************************************************
**** merge results


merge 1:1 hhid using `fies_results'
global extra _
global id_vars hhid


drop _merge
// FIES only defined where treatment is defined




********************************************************************************
**** Secondary B.1.3 Child Wasting
// see clean_children_joint. This variable is at child level



********************************************************************************
**** Wrap up

capture confirm variable FCS
if _rc == 0 {
keep $id_vars FIES_* FCS* hunger${extra}rvrs*

}
else if _rc != 0 {
keep $id_vars FIES_* hunger${extra}rvrs*
}

sort hhid

compress
save "${baseline_intermediate}/foodsecurity.dta", replace



