
********************************************************************************
* TRANSFERS    *
********************************************************************************

use "${baseline_intermediate}/demographics", clear
keep hhid chef_pos

merge 1:m hhid using "${baseline_intermediate}/transfers_long"
assert _merge == 3
drop _merge

tostring chef_pos, replace

**** Secondary B.6.5 Gross inter-household transfers

*** convert remmitance amount (trans_amt) to yearly amount
gen trans_in_xof = trans_amt
// replace trans_in_xof = 0 if trans_amt == .
*fix_continuous trans_in_xof

// scale for currency if currency var exists. Var seems to be misnamed
capture confirm var consum_nf_val_cur
if _rc == 0 { // if currency var exists
scale_cur trans_in_xof consum_nf_val_cur
}

// annual remittance for frequencies less than one year
replace trans_in_xof = trans_in_xof * 12 if trans_freq == 1 // monthly
replace trans_in_xof = trans_in_xof * 4 if trans_freq == 2 // trimester
replace trans_in_xof = trans_in_xof * 2 if trans_freq == 3 // semester
replace trans_in_xof = trans_in_xof * 1 if trans_freq == 4 // yearly
replace trans_in_xof = trans_in_xof * 2 if trans_freq == 5 // irregular, assume 2x year


** remit_12_xof
// winsorize at 1st/99th percentile
_pctile trans_in_xof , p(98)
gen trans_in_xof_w = trans_in_xof
replace trans_in_xof_w  = `r(r1)' if !missing(trans_in_xof_w ) & trans_in_xof_w  > `r(r1)'

// hh totals
byso hhid : egen tot_trans_in_xof = total(trans_in_xof_w) // missings automatically go to zero
replace tot_trans_in_xof = tot_trans_in_xof / 1000
label var tot_trans_in_xof "Remittances received in last 12 months wins. (1000 FCFA)"


// transfer received by chef
replace trans_who = " " + trans_who + " "


replace chef_pos = " " + chef_pos + " "
gen chef_in_recipient = strpos(trans_who, chef_pos) > 0 & trans_who != "  " & chef_pos != "  "
replace chef_in_recipient = 0 if chef_in_recipient == .


// chef totals
gen trans_in_chef_xof_w = trans_in_xof_w if chef_in_recipient == 1
byso hhid: egen tot_trans_in_chef_xof = total(trans_in_chef_xof_w)
replace tot_trans_in_chef_xof = tot_trans_in_chef_xof / 1000
label var tot_trans_in_chef_xof "Remittances received by chef in last 12 months wins. (1000 FCFA)"

keep hhid tot_trans_in_xof tot_trans_in_chef_xof
duplicates drop
isid hhid


***** --------------| OUT

tempfile trans_in
save `trans_in'

** transfers out
use "${baseline_intermediate}/transfers_sent_long.dta", clear

gen trans_out_xof = trans_amt_send
// scale for currency if currency var exists. Var seems to be misnamed
capture confirm var trans_amt_cur
if _rc == 0 { // if currency var exists
scale_cur trans_out_xof trans_amt_cur
}

rename trans_freq_send trans_freq


replace trans_out_xof = trans_out_xof*12 if trans_freq ==  1 // month
replace trans_out_xof = trans_out_xof*4 if trans_freq ==  2  // trimestre
replace trans_out_xof = trans_out_xof*2 if trans_freq ==  3  // semestre
replace trans_out_xof = trans_out_xof*1 if trans_freq ==  4  // année
replace trans_out_xof = trans_out_xof*2 if trans_freq ==  5  // irrégulier , assume 2x year

// winsorize at 2nd/98th percentile
_pctile trans_out_xof , p(98)
gen trans_out_xof_w = trans_out_xof
dis "`r(r1)'"
replace trans_out_xof_w  = `r(r1)' if !missing(trans_out_xof_w ) & trans_out_xof_w  > `r(r1)'

// compute hh total
bysort hhid : egen tot_trans_out_xof =  total(trans_out_xof_w)
replace tot_trans_out_xof = tot_trans_out_xof / 1000
label var tot_trans_out_xof "Remittances sent out in last 12 months wins. (1000 FCFA)"

keep hhid tot_trans_out_xof
duplicates drop

merge 1:1 hhid using `trans_in', gen(_m_transin)

// compute gross transfers
egen gross_trans_xof = rsum(tot_trans_in_xof tot_trans_out_xof)
label var gross_trans_xof "B.6.5 sum of remittances going in and out, winsorized separately (1000 FCFA)"



local trans_dummies trans_fam trans_fam_send

// whether hh recieved any transfer

merge 1:1 hhid using "${baseline_intermediate}/niger_main_2021.dta", ///
keepusing(`trans_dummies' consent) // trans_fam_send not available everywhere


drop if consent != 1
drop consent _merge

label variable trans_fam "hh received private money"
capture label variable trans_fam_send "hh sent private money"

compress
save "${baseline_intermediate}/transfers", replace


