********************************************************************************
* Loans   *
********************************************************************************
clear
use "${baseline_intermediate}/niger_main_2021.dta"
keep if consent == 1

// benef_pos already in main dataset
merge 1:1 hhid using "${baseline_intermediate}/demographics", keepusing(chef_pos) gen(_mben)
global id_var hhid
global id_vars hhid


keep $id_vars lend_* resp_finance chef_pos
order $id_vars lend_* resp_finance chef_pos


****------------|
// confirm beneficiary is answering
split resp_finance, parse(" ")
qui count if !inlist(string(chef_pos), resp_finance1, resp_finance2) //
local ratio = (1 - `r(N)'/`=_N') * 100
local ratio : di %9.2fc `ratio'
dis as error "`ratio'% of HHs had chef responding to these Qs"



label var lend_mem "4.37 In the past 3 months, have you personally loaned money to a household member?"
label var lend_mem_times "4.38 How many times in total in the past 3 months?"
label var lend_mem_still "4.39 How much money do household members still owe you today?"
capture label var lend_mem_still_curr "4.39 Currency"
label var lend_out "4.40 In the past 12 months, have you personally loaned money to a friend or family member outside the household?"
label var lend_out_times "4.41 How many times in total in the past 12 months?"
label var lend_out_still "4.42 How much money do people outside the household still owe you today?"
capture label var lend_out_curr"4.42 Currency"


********************************************************************************
**** Secondary B.6.4 Outstanding loans (outside household)

*fix_continuous lend_out_still
gen loan_out_xof = lend_out_still

// scale for currency if currency var exists (NER, FU2)
capture confirm var lend_out_curr
if _rc == 0 { // if currency var exists
scale_cur loan_out_xof lend_out_curr
}

// winsorize
replace loan_out_xof = 0 if loan_out_xof == . // because at HH level
_pctile loan_out_xof, p(98)
replace loan_out_xof  = `r(r1)' if !missing(loan_out_xof) & loan_out_xof  > `r(r1)'

// scale to K FCFA
replace loan_out_xof = loan_out_xof / 1000
label var loan_out_xof "B.6.4 Outstanding loans outside HH wins. (1000 FCFA)"


********************************************************************************
* Descriptive Section 6. Lending to household members

assert lend_mem == 1 if lend_mem_times != .  // frequency DNE if lending did not take place
assert lend_mem_times != . if lend_mem == 1  // iff

assert lend_mem_still != . if lend_mem == 1  // debt outstanding DNE if lending did not take place
assert lend_mem == 1 if lend_mem_still != .  // iff

capture assert lend_mem_still == . if lend_mem_times == 0
// if a HH claims to have lended without mentioning an amount, assume it wasn't in last 3 months
if (_rc > 0) replace lend_mem_times = . if lend_mem_still != . & lend_mem_times == 0


****------------|
** D.6.1 Times lent money to others in household in last 3 months
// It appears that people misinterpreted the time question and entered an actual amount
assert lend_mem_still <= lend_mem_times if lend_mem_times >= 200 & !missing(lend_mem_times)
// amount outstanding is lower than "times" given for "times given" over 200
// will trim out time variables over 200 since they are very likely reporting values
// assume 1 time loan
replace lend_mem_times = 1 if lend_mem_times >= 200 & !missing(lend_mem_times)
replace lend_mem_times = 0 if missing(lend_mem_times) // unconditional
label var lend_mem_times "D.6.1 Times lent money to others in household in last 3 months"



**** ------------ |
** D.6.2 Outstanding debt from others in the household
*fix_continuous lend_mem_still

gen lend_still_xof = lend_mem_still
// scale for currency if currency var exists (NER, FU2)
capture confirm var lend_mem_still_curr
if _rc == 0 { // if currency var exists
scale_cur lend_still_xof lend_mem_still_curr
}

// winsorize
replace lend_still_xof = 0 if missing(lend_still_xof) // all vars unconditional
_pctile lend_still_xof, p(98)
replace lend_still_xof  = `r(r1)' if !missing(lend_still_xof ) & lend_still_xof  > `r(r1)'

// scale to K FCFA
replace lend_still_xof = lend_still_xof / 1000
label var lend_still_xof  "D.6.2 How much money do household members still owe you today? (1000 FCFA)"



keep $id_vars loan_out_xof lend_mem_times lend_still_xof
order $id_vars loan_out_xof lend_mem_times lend_still_xof
isid $id_var
sort $id_var

compress
save "${baseline_intermediate}/loans.dta", replace


