
********************************************************************************
* D3 Beneficiary Labor Participation   *
********************************************************************************


***----------| D.3.1 Beneficiary days spent in household business

use "${baseline_intermediate}/business_long", clear

merge m:1 hhid using "${baseline_intermediate}/demographics.dta", keepusing(chef_pos)
keep if _merge==3
drop _merge

global id_var  hhid
global id_vars hhid
gen all_workers = bus2_own + " " + bus2_manage + " " + bus2_workers, after(bus2_workers)

// count number of owners/managers for each business
gen uniq_workers = all_workers, after(all_workers)
gen chef_worker = "", after(uniq_workers)

forval i = 1/`=_N' {
 local all
local all  `"`=all_workers[`i']'"' // collect all workers
local uniq_all : list uniq all     // collect unique ones only
// dis "`i': `all' --> `uniq_all'"
qui replace uniq_workers = "`uniq_all'" in `i' // replace uniq ones in each obs

local chef_i `"`=chef_pos[`i']'"'  // list benef in HH
// dis "`i': `benef_pos'"
local working_chef : list chef_i & uniq_all // collect overlap between workers and benef in HH
// dis "`i': `working_benef'"
qui replace chef_worker = "`working_chef'" in `i'
}
replace chef_worker = " " + chef_worker + " " // need spaces to properly identify i in strpos


*drop bus2_own bus2_manage bus2_workers all_workers


ds actdays_mem*
local act_vars `r(varlist)'
local mems_n : word count `act_vars'

//clean actdays_mem*
ds actdays_mem*
egen num_days_bus30 = rowtotal(`r(varlist)') , missing
label var num_days_bus30 "D.3.1 Days spent by entire hh in given business activity in last 30 days" //still needs to be agregateted to household level for inclusion. It is currently at business activity level and final dataset is household. Could reshape to include?


// calculate for everyone
forval i = 1/`mems_n' {
qui byso hhid : egen tot_mm`i'_bus_days = total(actdays_mem`i')
qui replace tot_mm`i'_bus_days = 30 if tot_mm`i'_bus_days > 30 // cap at 30 to avoid overcounting businesses
label var tot_mm`i'_bus_days "Days spent by hh mem `i' in any business in last 30 days"
}



// calcalate for benef and chef
foreach mem in chef {
gen `mem'_days = ., after(`mem'_worker)

forval i = 1/`mems_n' {
qui replace `mem'_days  = actdays_mem`i' if strpos(`mem'_worker,  " `i' ") > 0
}
label var `mem'_days  "Days spent by `mem' in given business in last 30 days"
// capped at 30 because individual entries capped at 30

qui byso hhid : egen tot_`mem'_bus_days = total(`mem'_days)
qui replace tot_`mem'_bus_days = 30 if tot_`mem'_bus_days > 30 // cap at 30 to avoid overcounting businesses
label var tot_`mem'_bus_days "D.3.1 Days spent by `mem' in any business in last 30 days"
// note chef and benef can be the same person
}

ds tot_mm*
egen tot_hh_bus_days = rowtotal(`r(varlist)')
label var tot_hh_bus_days "D.3.1 Days spent by entire hh in any business in last 30 days"
// individual contributions capped at 30

gen tot_hhlb_bus_days = tot_hh_bus_days - tot_chef_bus_days
assert tot_hhlb_bus_days >= 0
label var tot_hhlb_bus_days "D.3.1 Days spent by non-chef hh members in any business in last 30 days"

gen tot_bohh_bus_days = tot_chef_bus_days / tot_hh_bus_days
assert inrange(tot_bohh_bus_days , 0, 1) | tot_bohh_bus_days == .
label var tot_bohh_bus_days "D.3.1 Share of days spent by chef in any household business in last 30 days"
keep hhid tot_hh_bus_days tot_hhlb_bus_days tot_bohh_bus_days tot_chef_bus_days
duplicates drop

tempfile d_3_1
save `d_3_1'


*** ----------| D.3.4 Beneficiary days spent in agriculture


// days spent in agriculture not available in BFA at FU


use "${baseline_intermediate}/main_plotlist_long", clear
merge m:1 hhid using "${baseline_intermediate}/demographics.dta", keepusing(chef_pos)
order hhid

keep  hhid chef_pos plot_man plot_owner plot_worked days_mem*
order hhid chef_pos plot_man plot_owner plot_worked days_mem*

gen all_workers = plot_owner + " " + plot_man + " " + plot_worked, after(plot_worked)

// count number of owners/managers for each business
gen uniq_workers = all_workers, after(all_workers)
gen chef_worker = "", after(uniq_workers) // will create list of working children

forval i = 1/`=_N' {
 local all
local all  `"`=all_workers[`i']'"' // collect all workers
local uniq_all : list uniq all     // collect unique ones only
// dis "`i': `all' --> `uniq_all'"
qui replace uniq_workers = "`uniq_all'" in `i' // replace uniq ones in each obs

local chef_i `"`=chef_pos[`i']'"'  // collect chef in HH
// dis "`i': `chef_pos'"
local working_chef : list chef_i & uniq_all // collect overlap between workers and chef in HH
// dis "`i': `working_chef'"
qui replace chef_worker = "`working_chef'" in `i'
}
replace chef_worker = " " + chef_worker + " " // need spaces to properly identify i in strpos

drop plot_man plot_owner plot_worked all_workers

gen chef_days = ., after(chef_worker)
label var chef_days "Days spent by chef on plot in last 30 days"

ds days_mem*
local mems_n : word count `r(varlist)'
forval i = 1/`mems_n' {
// chef
qui replace chef_days = days_mem`i' if strpos(chef_worker, " `i' ") > 0

// everyone
qui byso hhid : egen tot_mm`i'_bus_days = total(days_mem`i')
qui replace tot_mm`i'_bus_days = 120 if tot_mm`i'_bus_days > 120 // cap at 120 to avoid overcounting plots
label var tot_mm`i'_bus_days "D.3.4 Days spent by  hh mem `i'  on agriculture in last season"
}
// capped at 30 because individual entries capped at 30

// chef total
byso hhid : egen tot_chef_ag_days = total(chef_days)
replace tot_chef_ag_days = 120 if tot_chef_ag_days > 120
label var tot_chef_ag_days "D.3.4 Days spent by chef on agriculture in last season"

// hh total
ds tot_mm*
egen tot_hh_ag_days = rowtotal(`r(varlist)')
label var tot_hh_ag_days "D.3.4 Days spent by entire hh on agriculture in last season"
// individual contributions capped at 120

// hhlb
gen tot_hhlb_ag_days = tot_hh_ag_days - tot_chef_ag_days
assert tot_hhlb_ag_days >= 0
label var tot_hhlb_ag_days "D.3.1 Days spent by non-chef hh members on agriculture in last season"

// bohh
gen tot_bohh_ag_days = tot_chef_ag_days / tot_hh_ag_days
assert inrange(tot_bohh_ag_days, 0, 1) | tot_bohh_ag_days == .
label var tot_bohh_ag_days "D.3.1 Share of days spent by chef in any on agricultural plot in last season"

keep hhid tot_*_ag_days
duplicates drop
isid hhid

tempfile d_3_2
save `d_3_2'



*** ----------| D.3.3 Days in last month of paid employment (Beneficiary and chef)



use "${baseline_intermediate}/salary_long.dta", clear

merge m:1 hhid using "${baseline_intermediate}/demographics.dta", keepusing(chef_pos)
order hhid

drop if empl_type == .

// generate indicator for if household member held at least one job of a certian type

gen wg_agri_job = 0 if !missing(empl_type)
replace wg_agri_job = 1 if empl_type==1
bysort hhid mem_pos: egen wg_agri_num = total(wg_agri_job) , missing
gen wg_agri=0 if !missing(wg_agri_num)
replace wg_agri=1 if wg_agri_num>0 & !missing(wg_agri_num)
label var wg_agri "recieved wage for agricultural work"

gen wg_nonagri_job = 0 if !missing(empl_type)
replace wg_nonagri_job = 1 if empl_type==2
bysort hhid mem_pos: egen wg_nonagri_num = total(wg_nonagri_job) , missing
gen wg_nonagri=0 if !missing(wg_nonagri_num)
replace wg_nonagri=1 if wg_nonagri_num>0 & !missing(wg_nonagri_num)
label var wg_nonagri "recieved wage for non-agricultural work"

gen apprn_job = 0 if !missing(empl_type)
replace apprn_job = 1 if empl_type==3
bysort hhid mem_pos: egen apprn_num = total(apprn_job) , missing
gen apprn=0 if !missing(apprn_num)
replace apprn=1 if apprn_num>0 & !missing(apprn_num)
label var apprn "worked as an apprentice"

// gernerate total of time periods, months, weeks and days hh mmeber worked in agriculture

replace empl_wks = 4 if empl_wks==5

foreach period in mos wks days {

gen ag_empl_`period' = 0 if !missing(empl_`period')
replace ag_empl_`period'= empl_`period' if wg_agri_job==1

bysort hhid mem_pos: egen mem_ag_empl_`period' = total(ag_empl_`period') , missing
label var mem_ag_empl_`period' "number of `period' memeber worked in agricualture wage employment"
}

// gernerate total of time periods, months, weeks and days hh mmeber worked in non agriculture wage employment


foreach period in mos wks days {

gen nonag_empl_`period' = 0 if !missing(empl_`period')
replace nonag_empl_`period'= empl_`period' if wg_nonagri_job==1

bysort hhid mem_pos: egen mem_nonag_empl_`period' = total(nonag_empl_`period') , missing
label var mem_nonag_empl_`period' "number of `period' memeber worked in agricualture wage employment"
}


*generating number of days worked in non agricultural wage employment in the last 12 months

//recoding for multiplication used below

replace mem_nonag_empl_mos = 1 if mem_nonag_empl_mos==0
replace mem_nonag_empl_wks =1 if mem_nonag_empl_wks ==0

gen mem_nonag_time = mem_nonag_empl_days * mem_nonag_empl_wks * mem_nonag_empl_mos
label var mem_nonag_time "number of days memeber spent in non agirculture wage employment"
    bysort hhid: egen hh_nonag_time = total (mem_nonag_time) , missing
label var hh_nonag_time " days spent working in non agriculture wage employment"


// temp file to merge empl_type with employment data (not needed)
preserve

keep hhid mem_pos wg_agri wg_agri_num wg_nonagri wg_nonagri_num apprn apprn_num mem_ag_empl_mos mem_ag_empl_wks mem_ag_empl_days
duplicates drop
tempfile m_1
save `m_1'

restore


// compute monthly average using yearly info for benef
gen days_per_year = empl_days * empl_wks * empl_mos  // max at 336 days
gen days_per_mon = days_per_year / 12 // max 28 days
assert days_per_mon <= 30

// for chef only
gen days_per_year_chef =  days_per_year if chef_pos == mem_pos
gen days_per_mon_chef =  days_per_mon if chef_pos == mem_pos


// hh totals
bysort hhid: egen tot_empl_days_per_year = total(days_per_year)
replace tot_empl_days_per_year = 365 if tot_empl_days_per_year > 365
assert tot_empl_days_per_year <= 365
bysort hhid: egen tot_empl_days_per_mon = total(days_per_mon)
replace tot_empl_days_per_mon = 30 if tot_empl_days_per_mon > 30
assert tot_empl_days_per_mon <= 30

// chef totals
bysort hhid: egen tot_empl_days_per_year_chef = total(days_per_year_chef)
assert tot_empl_days_per_year_chef <= 365
bysort hhid: egen tot_empl_days_per_mon_chef = total(days_per_mon_chef)
assert tot_empl_days_per_mon_chef <= 30


keep $id_vars  tot_empl_days_per_year  tot_empl_days_per_mon tot_empl_days_per_year_chef tot_empl_days_per_mon_chef
duplicates drop
isid $id_var


tempfile d_3_3
save `d_3_3'


*** ----------| D.3.2 Beneficiary days spent on livestock (only exsists at FU)

use "${baseline_intermediate}/livestock_mem_wrk_long", clear

order liv_mm_pos, after(hhid)
sort hhid liv_mm_pos


merge m:1 hhid using "${baseline_intermediate}/demographics.dta", keepusing(chef_pos)
// identify beneficiaries
gen is_chef = 1 if chef_pos == liv_mm_pos
drop chef_pos liv_mm_pos


rename betail_heures liv_mins // averages number of mins per day
rename betail_jours  liv_days // average number of days per month
rename betail_mois   liv_months // number of months in the last year

gen liv_hours   = liv_mins / 60
replace liv_days = (liv_days*liv_months)/12 // average number of days per year
gen liv_hours_chef = liv_mins / 60 if is_chef == 1
gen liv_days_chef  = liv_days if is_chef == 1



foreach time in hours days {
// everyone
byso hhid : egen tot_hh_liv_`time' = total(liv_`time')
label var tot_hh_liv_`time' "D.3.2 Daily average no. of `time' spent working with livestock in last year"

// beneficiary only
byso hhid : egen tot_chef_liv_`time' = total(liv_`time'_chef)
label var tot_chef_liv_`time' "D.3.2 Daily average no. of `time' CHEF spent working with livestock in last year"
}

// hhlb
gen tot_hhlb_liv_days = tot_hh_liv_days - tot_chef_liv_days
assert tot_hhlb_liv_days >= 0
label var tot_hhlb_liv_days "D.3.1 Days spent by non-chef hh members on agriculture in last season"

// bohh
gen tot_bohh_liv_days = tot_chef_liv_days / tot_hh_liv_days
assert inrange(tot_bohh_liv_days, 0, 1) | tot_bohh_liv_days == .
label var tot_bohh_liv_days "D.3.1 Share of days spent by chef in any on agricultural plot in last season"

keep hhid tot_*_liv_days
duplicates drop // zero obs dropped. 3,200 HHs FU1, 2,771 HHs FU2

tempfile d_3_4
save `d_3_4'

/** ---------- | Beneficiary Employment

 use "${baseline_intermediate}/empl.dta" , clear

 order empl_key_pos, after(hhid)
sort hhid empl_key_pos

 merge m:1 hhid using "${baseline_intermediate}/demographics.dta", keepusing(chef_pos)

   tempfile d_3_5
save `d_3_5'
*/
** ---------- | Beneficiary Work

 use "${baseline_intermediate}/work.dta" , clear

 *can we add member postitions into this???

 sort hhid


 merge m:1 hhid using "${baseline_intermediate}/demographics.dta", keepusing(chef_pos)
 drop _merge

 *merge in employment dataset which is needed for some variable generation (no longer needed)

 rename wrk_key_pos mem_pos
 *merge in empl_type
 merge 1:1 hhid mem_pos using `m_1' //merge work and employment data sets together at a member level, latter full merge is at the household level


 // hh totals

*indicator for engaged in farming
replace wrk_ag12=1 if wrk_ag30==1
bysort hhid: egen hh_wrk_ag_num12 = total(wrk_ag12) , missing
bysort hhid: egen hh_wrk_ag_num30 = total(wrk_ag30) , missing
label var hh_wrk_ag_num12 "number of household members who worked in agriculture, in last year"
label var hh_wrk_ag_num30 "number of household members who worked in agriculture, in last 30 days"
gen hh_wrk_ag12 = 0 if !missing(hh_wrk_ag_num12)
replace hh_wrk_ag12 = 1 if !missing(hh_wrk_ag_num12) & hh_wrk_ag_num12>1
    label var hh_wrk_ag12 "household enaged in agricultural, in the last year"
gen hh_wrk_ag30 = 0 if !missing(hh_wrk_ag_num30)
replace hh_wrk_ag30 = 1 if !missing(hh_wrk_ag_num30) & hh_wrk_ag_num30>1
    label var hh_wrk_ag30 "household enaged in agricultural, in the last 30 days"

*indicator for engaged in any slaraied employment (0,1)
    replace wrk_sal12=1 if wrk_sal30==1
bysort hhid: egen hh_wrk_sal_num12 = total(wrk_sal12) , missing
bysort hhid: egen hh_wrk_sal_num30 = total(wrk_sal30) , missing
label var hh_wrk_sal_num12 "number of household members who enaged in paid employment, in last year"
label var hh_wrk_sal_num30 "number of household members mwho enaged in paid employment, in last 30 days"
gen hh_wrk_sal12 = 0 if !missing(hh_wrk_sal_num12)
replace hh_wrk_sal12 = 1 if !missing(hh_wrk_sal_num12) & hh_wrk_sal_num12>1
    label var hh_wrk_sal12 "household enaged in paid employment, in the last year"
gen hh_wrk_sal30 = 0 if !missing(hh_wrk_sal_num30)
replace hh_wrk_sal30 = 1 if !missing(hh_wrk_sal_num30) & hh_wrk_sal_num30>1
    label var hh_wrk_sal30 "household enaged in paid employment, in the last 30 days"

    *indicatory for enaged in agricultural wage employment
foreach i of numlist 12 30 {
gen mem_ag_wage`i'=0 if !missing(wrk_sal`i')
replace  mem_ag_wage`i'=1 if wrk_sal`i'==1 & wg_agri==1
bysort hhid: egen hh_ag_wage`i' = total(mem_ag_wage`i') , missing
}
label var mem_ag_wage30 "memeber enaged in agricultural wage employment, in the last 30 days"
label var mem_ag_wage12 "memeber enaged in agricultural wage employment, in the last year"
label var hh_ag_wage30 "enaged in agricultural wage employment, in the last 30 days"
label var hh_ag_wage12 "enaged in agricultural wage employment, in the last year"

   *indicatory for enaged in non-agricultural wage employment
foreach i of numlist 12 30 {
gen mem_nonag_wage`i'=0 if !missing(wrk_sal`i')
replace  mem_nonag_wage`i'=1 if wrk_sal`i'==1 & wg_nonagri==1
bysort hhid: egen hh_nonag_wage`i' = total(mem_nonag_wage`i') , missing
}
label var mem_nonag_wage30 "memeber enaged in non agricultural wage employment, in the last 30 days"
label var mem_nonag_wage12 "memeber enaged in non agricultural wage employment, in the last year"
label var hh_nonag_wage30 "enaged in non agricultural wage employment, in the last 30 days"
label var hh_nonag_wage12 "enaged in non agricultural wage employment, in the last year"




*generating number of days worked in agricultural in the last 12 months

//recoding for multiplication used below
replace mem_ag_empl_mos = 1 if mem_ag_empl_mos==0
replace mem_ag_empl_wks =1 if mem_ag_empl_wks ==0

gen mem_ag_time = mem_ag_empl_days * mem_ag_empl_wks * mem_ag_empl_mos
label var mem_ag_time "number of days memeber spent in agirculture wage employment"
    bysort hhid: egen hh_ag_time = total (mem_ag_time) , missing
label var hh_ag_time " days spent working in agriculture wage employment"


*engaged in livestock
bysort hhid: egen hh_wrk_liv_num30 = total(wrk_liv30) , missing
bysort hhid: egen hh_wrk_liv_num12 = total(wrk_liv12) , missing
label var hh_wrk_liv_num30 "number of household members enaged in livestock raising, in the last 30 days"
label var hh_wrk_liv_num12 "number of household members enaged in livestock raising, in the last year"

foreach i of numlist 12 30 {
gen hh_wrk_liv`i'=0 if !missing(hh_wrk_liv_num`i')
replace hh_wrk_liv`i'=1 if hh_wrk_liv_num`i'>0 & !missing(hh_wrk_liv_num`i')
}
label var hh_wrk_liv30 "enaged in livestock raising (0,1), in the last 30 days"
label var hh_wrk_liv12 "enaged in livestock raising (0,1), in the last year"

*Business outcomes


bysort hhid: egen num_mm_bus = total(wrk_na30) , missing
label var num_mm_bus "number of household memebers who have managed a non agricultural business"
gen business_any=0 if !missing(num_mm_bus)
replace business_any = 1 if num_mm_bus>0 &  !missing(num_mm_bus)
label var business_any "household has a business (0,1)"


keep hhid hh_wrk_ag* business_any business_any
duplicates drop



    tempfile d_3_6
save `d_3_6'

*** ----------| conclude
use hhid using "${baseline_intermediate}/demographics.dta", clear
merge 1:1 hhid using `d_3_1', gen(_mben_lab1)
merge 1:1 hhid using `d_3_2', gen(_mben_lab2)
merge 1:1 hhid using `d_3_3', gen(_mben_lab3)
merge 1:1 hhid using `d_3_4', gen(_mben_lab4)
* merge 1:1 hhid using `d_3_5', gen(_mben_lab5)
merge 1:1 hhid using `d_3_6', gen(_mben_lab6)

**Double Check this
// because every HH has a beneficiary and a chef
foreach var of varlist tot_empl* {
capture confirm var `var'
if _rc == 0 { // if var exists
replace `var' = 0 if missing(`var') // make unconditional like totbus and totag
}
}

compress
save "${baseline_intermediate}/labor_prtcp.dta", replace








