


/*******************************************************************************
Niger Baseline Data ( Shock-Response Project)

This do file 
- merges all constructed datasets to create the final outcomes dataset
- replaces missing values with zeros where they are true zeros
- Constructs final variables 
Input: all datasets in ${constructed}

Output: baseline_niger_outcomes.dta

*******************************************************************************/

clear
use "${baseline_intermediate}/niger_main_2021.dta"
keep if consent == 1
drop resp_*
drop eat_out_*
drop rcrops_show*
drop dcrops_show*
drop who_fourleg_*
drop who_twoleg_*
drop fish_who_*
drop language*

label variable stair_satis_today "Life Satisfaction"
rename stair_satis_today cantril

gen _IDENTIFICATION_ = "IDENTIFICATION", after(hhid)

gen _demog_ = "DEMOGRAPHICS"
merge m:1 hhid using "${baseline_intermediate}/demographics.dta", gen(_mdemog) 

gen _BUSINESS_ = "BUSINESS"
merge m:1 hhid using "${baseline_intermediate}/business.dta", gen(_mNONAG2)

gen _EMPLOYMENT_ = "EMPLOYMENT"
merge m:1 hhid using "${baseline_intermediate}/employment.dta", gen(_mACTIV) 

gen _CONSUMPTION_ = "CONSUMPTION"
merge m:1 hhid using "${baseline_intermediate}/consumption.dta", gen(_mCONSUM)

gen _ASSETS_ = "ASSETS"
merge m:1 hhid using "${baseline_intermediate}/assets.dta", gen(_mASSETS)

gen _LIVESTOCK_ = "LIVESTOCK"
merge m:1 hhid using "${baseline_intermediate}/livestock.dta", gen(_mLIV)

gen _AGRICULTURE_ = "AGRICULTURE"
merge m:1 hhid using "${baseline_intermediate}/agriculture.dta", gen(_mAGRIC)

gen _FINANCE_ = "FINANCE"
merge m:1 hhid using "${baseline_intermediate}/finance.dta", gen(_mFIN)

gen _PSYCHOLOGY_ = "PSYCHOLOGY"
merge m:1 hhid using "${baseline_intermediate}/psychology.dta", gen(_mPSYC)

gen _FOODSEC_ = "FOODSECURITY"
merge m:1 hhid using "${baseline_intermediate}/foodsecurity.dta", gen(_mFSEC)

gen _TRANSFERS_ = "TRANSFERS"
merge m:1 hhid using "${baseline_intermediate}/transfers.dta", gen(_mTRF)

gen _social_ = "SOCIAL"
merge m:1 hhid using "${baseline_intermediate}/social_wellbeing.dta", gen(_msocial_c2)

gen _loans_ = "LOANS"
merge m:1 hhid using "${baseline_intermediate}/loans.dta", gen(_mloans_c2)

gen _lab_prtcp_ = "LAB_PRTCP"
merge m:1 hhid using "${baseline_intermediate}/labor_prtcp.dta", gen(_mLab)

* -----------------------------------------------------------------------------*
* Constructing final variables*
* -----------------------------------------------------------------------------*

* adding harvest of dry and rain crops together 
egen tot_harvest_xof_98 = rowtotal(ag_d_harvest_xof_imp_98 ag_r_harvest_xof_imp_98)
egen tot_harvest_chef_xof_98 = rowtotal(ag_r_harvest_chef_xof_98 ag_d_harvest_chef_xof_98)

* 1000 FCFA unit 
replace tot_harvest_xof_98 = tot_harvest_xof_98/1000
replace tot_harvest_chef_xof_98 = tot_harvest_chef_xof_98/1000

* total number of income sources
egen div_income_sources = rowtotal(div_empl12_hh_n div_n_na_12_hh div_crop_types div_ani)
* total household productive revenues 
egen total_revenues_12 = rowtotal(tot_empl_rev12_xof tot_hh_rev12 tot_ani_hh_contr tot_harvest_xof_98)

replace empl_d30_chef = 0 if missing(empl_d30_chef)
replace empl_d12_chef = 0 if missing(empl_d12_chef)

* -----------------------------------------------------------------------------*
*SAVING CONSTRUCTED DATASET*
* -----------------------------------------------------------------------------*

rename *, lower
rename village_ village

isid hhid 
save "$baseline_final/baseline_niger_outcomes", replace
