clear
use "$baseline_final/baseline_niger_outcomes.dta"
tab na_bus2_op_wn_12 bus2_dum
tab div_empl12_hh_n

sum fcs, d
gen median_fcs = fcs > r(p50)
label variable median_fcs "Above median FCS"
label define median_fcs 0 "" 1 "Above median FCS"
label values median_fcs median_fcs

sum food_1_year_xof, d
gen median_fcons = food_1_year_xof > r(p50)
label variable median_fcons "Above median food cons."
label define median_fcons 0 "" 1 "Above median food cons."
label values median_fcons median_fcons

sum cantril, d
gen median_cantril = cantril > r(p50)
label variable median_cantril "Above median Cantril"
label define median_cantril 0 "" 1 "Above median Cantril"
label values median_cantril median_cantril

gen fcslow = fcs > 21
label variable fcslow "Low FCS"
gen fcsmid = fcs > 35
label variable fcsmid "Mid FCS"


foreach var in fcs {
    _pctile `var', p(10 25 50 75 90 99)
//     replace `var' = r(r1) if `var' > r(r1) & !missing(`var')
    gen fcs10 = fcs > r(r1)
    gen fcs25 = fcs > r(r2)
    gen fcs50 = fcs > r(r3)
    gen fcs75 = fcs > r(r4)
    gen fcs90 = fcs > r(r5)
    gen fcs99 = fcs > r(r6)
}

label variable fcs10 "10th perc"
label variable fcs25 "25th perc"
label variable fcs50 "50th perc"
label variable fcs75 "75th perc"
label variable fcs90 "90th perc"
label variable fcs99 "99th perc"

drop fcs

foreach var in food_1_year_xof {
    _pctile `var', p(10 25 50 75 90 99)
//     replace `var' = r(r1) if `var' > r(r1) & !missing(`var')
    gen fcons10 = food_1_year_xof > r(r1)
    gen fcons25 = food_1_year_xof > r(r2)
    gen fcons50 = food_1_year_xof > r(r3)
    gen fcons75 = food_1_year_xof > r(r4)
    gen fcons90 = food_1_year_xof > r(r5)
    gen fcons99 = food_1_year_xof > r(r6)
}


label variable fcons10 "10th perc"
label variable fcons25 "25th perc"
label variable fcons50 "50th perc"
label variable fcons75 "75th perc"
label variable fcons90 "90th perc"
label variable fcons99 "99th perc"


foreach var in cantril {
    _pctile `var', p(10 25 50 75 90 99)
//     replace `var' = r(r1) if `var' > r(r1) & !missing(`var')
    gen cantril10 = cantril > r(r1)
    gen cantril25 = cantril > r(r2)
    gen cantril50 = cantril > r(r3)
    gen cantril75 = cantril > r(r4)
    gen cantril90 = cantril > r(r5)
    gen cantril99 = cantril > r(r6)
}


label variable cantril10 "10th perc"
label variable cantril25 "25th perc"
label variable cantril50 "50th perc"
label variable cantril75 "75th perc"
label variable cantril90 "90th perc"
label variable cantril99 "99th perc"

count if (bus2_dum == 1) | div_empl12_hh_n > 0 & !missing(div_empl12_hh_n)
count

gen diverse = (bus2_dum == 1) | div_empl12_hh_n > 0 & !missing(div_empl12_hh_n)

// saving_xof // total savings
// tot_ani_count_tlu // livestock

sum saving_xof if treatment == 0
replace saving_xof = saving_xof - r(mean)
replace saving_xof = saving_xof/r(sd)

sum tot_ani_count_tlu if treatment == 0
replace tot_ani_count_tlu = tot_ani_count_tlu - r(mean)
replace tot_ani_count_tlu = tot_ani_count_tlu/r(sd)

sum saving_xof tot_ani_count_tlu

egen liquid = rowtotal(saving_xof tot_ani_count_tlu), missing
sum liquid if treatment == 0
replace liquid = liquid - r(mean)
replace liquid= liquid/r(sd)
sum liquid

// Phyllisa April 29th 2025 we standardise other rounds using baseline values.

//mental health
sum 	mentalhealth 								// Phyllisa April 29th 2025

local 	mentalhealth_mean_bline 	= r(mean)		// Phyllisa April 29th 2025
local 	mentalhealth_sd_bline 		= r(sd)			// Phyllisa April 29th 2025

keep hhid diverse liquid median* fcs* fcons* cantril10 cantril25 cantril50 cantril75 cantril90 cantril99 mem_n hhh_fem poly hhh_age hhh_edu hhh_prim hhh_noeduc hhh_lit depend child_school

sum liquid, d
replace liquid = 1 if liquid > r(p50) & !missing(liquid)
replace liquid = 0 if liquid <= r(p50) & !missing(liquid)

recode liquid (0 = 1) (1 = 0)

label variable liquid "liquidity index (binary at median)"

label variable diverse "Diversified LMA"
label variable liquid "Liquidity"

label define diverse 0 "" 1 "Off-farm work"
label values diverse diverse

label define liquid 0 "High liquidity" 1 "Low liquidity"
label values liquid liquid

tempfile baseline
save "`baseline'"

clear
use "$high_frequency_final/high_frequency_final_round1.dta"

ds proxy_*_win_mt
local fexp = r(varlist)

keep ///
strat_pmt ///
strat_vill_size ///
cohort ///
hhid ///
village village_name ///
consent ///
treatment ///
fcs stair_satis_today proxycon_mt ///
business_num_uc business_pft business_assval nonag_wage nonag_wage_inc ///
livestock_tlu ag_wage ag_wage_inc ///
mentalhealth vperception socialcohesion ///
savetotal loantotal_win remittance_amt remittance_amt_send risk_sharing ///
hasplots num_days_ag has_chicken lvs_wrk_days ///
business_any business_rev nbusworkers n_days_business ///
ag_emp_days nonag_emp_days ///
savings loan trans_fam trans_fam_send ///
prodsold ///
prodsold_rev ///
usepaidlbr ///
paidlbr_amt ///
usemutlbr ///
crop_seed ///
crop_fert ///
crop_seed_purch ///
crop_fert_purch ///
hasplots ///
div_cereal div_pulse div_veg div_fruit div_meat div_milk div_oil div_sugar ///
`fexp' ///
fcs_above_* ///
choc_* ///
nb_shocks ///
shock*occur ///
shock*en ///
absent_school aford_school absent_school_amt ///
ctrans_d prog_a prog_b prog_c ///
submissiondate commune commune_name ///
vid enumerator surveyed_twice

rename ( ///
prodsold ///
prodsold_rev ///
usepaidlbr ///
paidlbr_amt ///
usemutlbr ///
crop_seed ///
crop_fert ///
crop_seed_purch ///
crop_fert_purch ///
) ///
///
( ///
crop_didsell30 ///
crop_didsell_amt30 ///
paid_labor30 ///
paid_labor_total30 ///
mutual_labor ///
crop_seed30 ///
crop_fert30 ///
crop_seed_purch30 ///
crop_fert_purch30 ///
)

tempfile temp
save "`temp'"

foreach var in shock1en shock2en shock3en shock4en shock5en shock6en shock7en shock8en shock9en shock10en shock11en shock12en shock13en shock14en shock15en shock16en shock17en shock18en shock19en {
    distinct `var'
}

keep hhid shock*en shock*occur

tostring shock*en, replace
destring shock*occur, replace

rename shock*en shock_*
rename shock*occur shockoccur*

reshape long shockoccur shock_, i(hhid) j(j)
replace shock_ = "" if shock_ == "."
drop if missing(shock_)
drop j

sort hhid, stable
by hhid: egen nshocks = total(shockoccur)

sort hhid shock_, stable
encode shock_, gen(shock)

label drop shock

order hhid shock

reshape wide shock_ shockoccur, i(hhid) j(shock)

tempfile mshock
save "`mshock'"

use "`temp'"
merge 1:1 hhid using "`mshock'"
drop shock*en shock*occur
drop nb_shocks
drop _merge
rename nshocks nb_shocks

cap rename remittance_amt_send remittance_sent_amt
cap rename riskshare risk_sharing
cap rename hasplots hasplots30

replace ag_emp_days = 0 if missing(ag_emp_days)
replace nonag_emp_days = 0 if missing(nonag_emp_days)

gen svyround = 1

tempfile hfs1
save "`hfs1'"

clear
use "$midline_final/midline_final"

destring commune, replace
destring village, replace
destring departement, replace

ds proxy_*_win_mt
local fexp = r(varlist)

keep ///
strat_pmt ///
strat_vill_size ///
cohort ///
hhid ///
village village_name ///
consent ///
treatment ///
fcs stair_satis_today ///
business_num_uc business_pft business_assval nonag_wage nonag_wage_inc ///
livestock_tlu ag_wage ag_wage_inc ///
mentalhealth vperception socialcohesion ///
savetotal loantotal_win remittance_amt remittance_sent_amt risk_sharing ///
proxycon_mt ///
proxycon_mt_compare ///
hasplots num_days_ag has_chicken lvs_wrk_days ///
business_any business_rev nbusworkers n_days_business ///
savings loan trans_fam trans_fam_send ///
mdd_w_score mdd_i_score mdd_i_binary ///
amnt_excexp ///
food8_rev food8b_rev ///
off_farm ///
ag_emp_days nonag_emp_days ///
saved_amt_1 saved_amt_2 saved_amt_3 saved_amt_4 ///
prodsold ///
prodsold_rev ///
usepaidlbr ///
paidlbr_amt ///
usemutlbr ///
crop_seed ///
crop_fert ///
crop_seed_purch ///
crop_fert_purch ///
hasplots ///
div_cereal div_pulse div_veg div_fruit div_meat div_milk div_oil div_sugar ///
`fexp' ///
fcs_above_* ///
fcs_mother fcs_infant ///
choc_* ///
nb_shocks ///
shock*occur ///
shock*en ///
absent_school aford_school absent_school_amt ///
ctrans_d prog_a prog_b prog_c ///
sowing sowing_start_date ///
avgplotsize nrainyplots totalplotsize ///
submissiondate commune commune_name ///
vid enumerator surveyed_twice

rename ( ///
prodsold ///
prodsold_rev ///
usepaidlbr ///
paidlbr_amt ///
usemutlbr ///
crop_seed ///
crop_fert ///
crop_seed_purch ///
crop_fert_purch ///
) ///
///
( ///
crop_didsell30 ///
crop_didsell_amt30 ///
paid_labor30 ///
paid_labor_total30 ///
mutual_labor ///
crop_seed30 ///
crop_fert30 ///
crop_seed_purch30 ///
crop_fert_purch30 ///
)

drop shock13occur shock14occur shock15occur shock16occur shock17occur shock18occur shock19occur
drop shock13en shock14en shock15en shock16en shock17en shock18en shock19en

rename shock*occur shockoccur*
rename shock*en shock*

drop shock1 shock2 shock3 shock4 shock5 shock6 shock7 shock8 shock9 shock10 shock11 shock12

rename ///
(shockoccur1 shockoccur2 shockoccur3 shockoccur4 shockoccur5 shockoccur6 shockoccur7 shockoccur8 shockoccur9 shockoccur10 shockoccur11 shockoccur12) ///
(shockoccur2 shockoccur4 shockoccur8 shockoccur7 shockoccur10 shockoccur5 shockoccur3 shockoccur12 shockoccur1 shockoccur13 shockoccur9 shockoccur11)

replace ag_emp_days = 0 if missing(ag_emp_days)
replace nonag_emp_days = 0 if missing(nonag_emp_days)

cap rename amnt_excexp ex_expenses
cap rename hasplots hasplots30

gen svyround = 2
destring shockoccur*, replace
destring nb_shocks, replace

tempfile midline
save "`midline'"

clear
use "$high_frequency_final/high_frequency_final_round2.dta"

ds proxy_*win_mt
local fexp = r(varlist)

keep ///
strat_pmt ///
strat_vill_size ///
cohort ///
hhid ///
village village_name ///
consent ///
treatment ///
fcs stair_satis_today proxycon_mt ///
business_num_uc business_pft business_assval nonag_wage nonag_wage_inc ///
livestock_tlu ag_wage ag_wage_inc ///
mentalhealth vperception socialcohesion ///
savetotal loantotal_win remittance_amt remittance_amt_send risk_sharing ///
hasplots num_days_ag has_chicken lvs_wrk_days ///
ag_emp_days nonag_emp_days ///
business_any business_rev nbusworkers n_days_business ///
savings loan trans_fam trans_fam_send ///
prodsold ///
prodsold_rev ///
usepaidlbr ///
paidlbr_amt ///
usemutlbr ///
crop_seed ///
crop_fert ///
crop_seed_purch ///
crop_fert_purch ///
hasplots ///
div_cereal div_pulse div_veg div_fruit div_meat div_milk div_oil div_sugar ///
`fexp' ///
fcs_above_* ///
choc_* ///
nb_shocks ///
shock*occur ///
shock*en ///
absent_school aford_school absent_school_amt ///
ctrans_d prog_a prog_b prog_c ///
submissiondate commune commune_name ///
vid enumerator surveyed_twice

rename ( ///
prodsold ///
prodsold_rev ///
usepaidlbr ///
paidlbr_amt ///
usemutlbr ///
crop_seed ///
crop_fert ///
crop_seed_purch ///
crop_fert_purch ///
) ///
///
( ///
crop_didsell30 ///
crop_didsell_amt30 ///
paid_labor30 ///
paid_labor_total30 ///
mutual_labor ///
crop_seed30 ///
crop_fert30 ///
crop_seed_purch30 ///
crop_fert_purch30 ///
)

drop shock14occur shock15occur shock16occur shock17occur shock18occur shock19occur
drop shock14en shock15en shock16en shock17en shock18en shock19en

rename shock*occur shockoccur*
rename shock*en shock*

drop shock1 shock2 shock3 shock4 shock5 shock6 shock7 shock8 shock9 shock10 shock11 shock12 shock13


rename ///
(shockoccur1 shockoccur2 shockoccur3 shockoccur4 shockoccur5 shockoccur6 shockoccur7 shockoccur8 shockoccur9 shockoccur10 shockoccur11 shockoccur12 shockoccur13) ///
(shockoccur2 shockoccur4 shockoccur8 shockoccur7 shockoccur10 shockoccur5 shockoccur6 shockoccur3 shockoccur12 shockoccur1 shockoccur13 shockoccur9 shockoccur11)

cap rename remittance_amt_send remittance_sent_amt
cap rename riskshare risk_sharing
cap rename hasplots hasplots30

replace ag_emp_days = 0 if missing(ag_emp_days)
replace nonag_emp_days = 0 if missing(nonag_emp_days)

gen svyround = 3
destring shockoccur*, replace
destring nb_shocks, replace

tempfile hfs2
save "`hfs2'"

clear
use "`hfs1'"
append using "`midline'"
append using "`hfs2'"

sort hhid, stable

quietly ds *, not(type string)
local nostrings = r(varlist)

{
mvdecode `nostrings', mv(-999 = .r) // refused
mvdecode `nostrings', mv(-888 = .d) // don't know
mvdecode `nostrings', mv(-777 = .o) // other
mvdecode `nostrings', mv(-666 = .n) // na 
mvdecode `nostrings', mv(-555 = .g) // god or unknown relation
mvdecode `nostrings', mv(-333 = .m) 
mvdecode `nostrings', mv(-222 = .r)
mvdecode `nostrings', mv(-111 = .i)
mvdecode `nostrings', mv(-99 = .i)
mvdecode `nostrings', mv(-88 = .i)
mvdecode `nostrings', mv(-77 = .i)
mvdecode `nostrings', mv(-66 = .i)
}

rename business_num_uc nbusiness
rename business_pft bus_profit
rename business_assval bus_asset_value
rename nonag_wage non_agri_emp_binary
rename nonag_wage_inc non_agri_wages

rename ag_wage agri_emp_binary
rename ag_wage_inc agri_wages

rename ag_emp_days agri_emp
rename nonag_emp_days non_agri_emp
rename savetotal saved_total
rename loantotal_win loans_amt

rename num_days_ag n_days_cultivate
rename has_chicken livestock
rename lvs_wrk_days n_days_livestock

rename business_any business
rename business_rev bus_revenue

rename savings saved_binary_
rename loan loans_twelve_mo

drop shock_*
rename shockoccur* shock*

save "$panel/pooled_final.dta", replace

clear
use "$endline_final/final.dta"

foreach var in shock1 shock2 shock3 shock4 shock5 shock6 shock7 shock8 shock9 shock10 shock11 shock12 {
    label var `var' ""
}

rename ///
(shock1 shock2 shock3 shock4 shock5 shock6 shock7 shock8 shock9 shock10 shock11 shock12) ///
(shock2 shock4 shock8 shock7 shock5 shock10 shock6 shock12 shock11 temp10 shock14 shock15)

replace shock11 = 1 if temp10 == 1
drop temp10
rename shock_n nb_shocks

egen prog_a = rowmax(prog_2 prog_5 prog_10)
egen prog_b = rowmax(prog_1 prog_3)
egen prog_c = rowmax(prog_6 prog_7 prog_8 prog_9 prog_11)

/*

hfs 1


1 Bankruptcy of a non-agricultural household business
2 Drought / Irregular rain
3 End of regular transfers from other households
4 Floods
5 High prices of agricultural inputs
6 High prices of food
7 High rate of animal diseases
8 High rate of crop diseases
9 Loss of a paid employment by a member of the household
10 Major drop in prices of agricultural products
11 Serious illness or accident of a member of the household
12 Significant loss of household non agricultural income (other than due to accident or illness)
13 Significant loss of salary income (other than because of an accident or illness)


endline

shock1          byte    %8.0g      shock1     Drought
shock2          byte    %8.0g      shock2     Flood
shock3          byte    %8.0g      shock3     Crop disease
shock4          byte    %8.0g      shock4     Animal disease
shock5          byte    %8.0g      shock5     Increase in agri input prices
shock6          byte    %8.0g      shock6     Decrease in agri output prices
shock7          byte    %8.0g      shock7     Increase in food prices
shock8          byte    %8.0g      shock8     Loss of non-agri income
shock9          byte    %8.0g      shock9     Serious illness in HH
shock10         byte    %8.0g      shock10    Death of HH member
shock11         byte    %8.0g      shock11    Divorce
shock12         byte    %8.0g      shock12    Theft of money, goods


midline

j shock
1 Drought / Irregular rain
2 Floods
3 High rate of crop diseases
4 High rate of animal diseases
5 Major drop in prices of agricultural products
6 High prices of agricultural inputs
7 End of regular transfers from other households
8 Significant loss of household non agricultural income (other than due to accident or illness)
9 Bankruptcy of a non-agricultural household business
10 Significant loss of salary income (other than because of an accident or illness)
11 Loss of a paid employment by a member of the household
12 Serious illness or accident of a member of the household

hfs 2

j shock
1 Drought / Irregular rain
2 Floods
3 High rate of crop diseases
4 High rate of animal diseases
5 Major drop in prices of agricultural products
6 High prices of agricultural inputs
7 High prices of food
8 End of regular transfers from other households
9 Significant loss of household non agricultural income (other than due to accident or illness)
10 Bankruptcy of a non-agricultural household business
11 Significant loss of salary income (other than because of an accident or illness)
12 Loss of a paid employment by a member of the household
13 Serious illness or accident of a member of the household


*/


gen cohort = 1 // HFS 1, midline, and HFS 2 were collected in cohorts, endline has just one cohort
gen svyround = 4

label variable proxycon_mt_compare "\makecell{Food \\ consumption}"

drop surveyor
encode surveyor_nom, gen(surveyor)
rename surveyor enumerator

append using "$panel/pooled_final.dta"

tab svyround cohort, m

sum shock1 shock2 shock3 shock4 shock5 shock6 shock7 shock8 shock9 shock10 shock11 shock12 shock13 shock14 shock15

egen shk1 = rowmax(shock1 shock3 shock9 shock12 shock13 shock14 shock15)
label variable shk1 "\makecell{Income \\ loss}"
egen shk2 = rowmax(shock2)
label variable shk2 "Drought"
egen shk3 = rowmax(shock4)
label variable shk3 "Floods"
egen shk4 = rowmax(shock5 shock6 shock10)
label variable shk4 "\makecell{Price \\ shocks}"
egen shk5 = rowmax(shock7 shock8)
label variable shk5 "\makecell{Crop/animal \\ disease}"
egen shk6 = rowmax(shock11)
label variable shk6 "\makecell{Family \\ health}"

gen shock_binary = 1 if nb_shocks > 0 & !missing(nb_shocks)
replace shock_binary = 0 if nb_shocks == 0

sort svyround cohort, stable
egen roundcohort = group(svyround cohort)

merge m:1 hhid using "`baseline'"
drop _merge

label define svyround 1 "hfs 1" 2 "midline" 3 "hfs 2" 4 "endline"
label values svyround svyround

replace consent = 0 if missing(consent)

replace n_days_cultivate = 0 if missing(n_days_cultivate)

winsor2 n_days_cultivate if svyround == 1, replace cuts(0 98)
winsor2 n_days_cultivate if svyround == 2, replace cuts(0 98)
winsor2 n_days_cultivate if svyround == 3, replace cuts(0 98)
winsor2 n_days_cultivate if svyround == 4, replace cuts(0 98)

tempfile full
save "`full'"

keep consent svyround treatment village

replace consent = consent*100

forval i = 1/4 {
    gen c`i' = consent if svyround == `i'
}

label variable c1 "Pre-lean" 
label variable c2 "Lean"
label variable c3 "Post-lean"
label variable c4 "Endline"
label variable consent "Total"

local atvars c1 c2 c3 c4 consent

estpost sum `atvars' if treatment == 0
eststo t0

estpost sum `atvars' if treatment == 1
eststo t1

estpost sum `atvars' if treatment == 2
eststo t2

foreach var in `atvars' {

reghdfe `var' i.treatment, absorb() vce(cluster village)
eststo `var'
test (0.treatment = 1.treatment) (1.treatment = 2.treatment)
local fpval : di  %8.2f `r(p)'
quietly estadd scalar fpval = `fpval'
}

* report each model by row, not column
esttab `atvars', se nostar keep(1.treatment) stats(fpval)

matrix C = r(coefs)
matrix fpval = r(stats)

mat list C
mat list fpval

local rnames : rownames C
local equations : coleq C

local equations : list uniq equations

local i 0
foreach name of local rnames {
    local ++i
    local j 0
    capture matrix drop b
    capture matrix drop se
        foreach model of local equations {
            local ++j
            matrix tmp = C[`i', 2*`j'-1]
                if tmp[1, 1] < . {
                    matrix colnames tmp = `model'
                    matrix b = nullmat(b), tmp
                    matrix tmp[1, 1] = C[`i', 2*`j']
                    matrix se = nullmat(se), tmp
    }
}
* save results
ereturn post b
estadd matrix se
estadd matrix fpval
eststo model
}

estpost sum `atvars'							// phyllisa April 30th 2025 adding overall response rate
eststo tpool									// phyllisa April 30th 2025 adding overall response rate

esttab tpool t0 t1 t2 model ///					// tpool phyllisa April 30th 2025 adding overall response rate
using "$csae/attrition-rates.tex", ///
cells( ///
"mean(pattern(1 1 1 1 0) fmt(2)) fpval(pattern(0 0 0 0 1) fmt(2))" ///			// phyllisa April 30th 2025 adding overall response rate
) ///
mtitle( ///
"Pooled"	///																	// phyllisa April 30th 2025 adding overall response rate
"Trad. response" ///
"Early short" ///
"Early long" ///
"p-val" ///
) ///
collabels(none) ///
label ///
keep(c1 c2 c3 c4 consent) ///
order(c1 c2 c3 c4 consent) ///
booktabs ///
noobs numbers ///
starlevels(* 0.10 ** 0.05 *** 0.01) ///
replace

/*
keep svyround consent

replace consent = consent*100

forval i = 1/4 {
    gen c`i' = consent if svyround == `i'
}

label variable c1 "Pre-lean" 
label variable c2 "Lean"
label variable c3 "Post-lean"
label variable c4 "Endline"
label variable consent "Total"

estpost sum c1 c2 c3 c4
eststo response

esttab response ///
    , ///
    cells( ///
    "mean(fmt(1)) count(fmt(0))" ///
    ) ///
    label ///
    booktabs ///
    nomtitle noobs nonumbers ///
    collabels("Consent (\%)" "N") ///
    replace
*/
    
clear
use "`full'"
keep if consent == 1

foreach var in proxycon_mt {
    _pctile `var' if svyround == 1, p(10 25 50 75 90 99)
    gen efcons10 = proxycon_mt > r(r1) if svyround == 1
    gen efcons25 = proxycon_mt > r(r2) if svyround == 1
    gen efcons50 = proxycon_mt > r(r3) if svyround == 1
    gen efcons75 = proxycon_mt > r(r4) if svyround == 1
    gen efcons90 = proxycon_mt > r(r5) if svyround == 1
    gen efcons99 = proxycon_mt > r(r6) if svyround == 1
}

foreach var in proxycon_mt_compare {
    _pctile `var' if svyround == 2, p(10 25 50 75 90 99)
    replace efcons10 = proxycon_mt_compare > r(r1) if svyround == 2
    replace efcons25 = proxycon_mt_compare > r(r2) if svyround == 2
    replace efcons50 = proxycon_mt_compare > r(r3) if svyround == 2
    replace efcons75 = proxycon_mt_compare > r(r4) if svyround == 2
    replace efcons90 = proxycon_mt_compare > r(r5) if svyround == 2
    replace efcons99 = proxycon_mt_compare > r(r6) if svyround == 2
}

foreach var in proxycon_mt {
    _pctile `var' if svyround == 2, p(10 25 50 75 90 99)
    replace efcons10 = proxycon_mt > r(r1) if svyround == 3
    replace efcons25 = proxycon_mt > r(r2) if svyround == 3
    replace efcons50 = proxycon_mt > r(r3) if svyround == 3
    replace efcons75 = proxycon_mt > r(r4) if svyround == 3
    replace efcons90 = proxycon_mt > r(r5) if svyround == 3
    replace efcons99 = proxycon_mt > r(r6) if svyround == 3
}

foreach var in proxycon_mt_compare {
    _pctile `var' if svyround == 4, p(10 25 50 75 90 99)
    replace efcons10 = proxycon_mt_compare > r(r1) if svyround == 4
    replace efcons25 = proxycon_mt_compare > r(r2) if svyround == 4
    replace efcons50 = proxycon_mt_compare > r(r3) if svyround == 4
    replace efcons75 = proxycon_mt_compare > r(r4) if svyround == 4
    replace efcons90 = proxycon_mt_compare > r(r5) if svyround == 4
    replace efcons99 = proxycon_mt_compare > r(r6) if svyround == 4
}

label variable choc_strategy6 "Reduce exp."
label variable choc_strategy10 "More work"
label variable choc_strategy12 "Friends / family"
label variable choc_strategy13 "Gov. support"
label variable choc_strategy14 "NGO"


replace absent_school = -absent_school
label variable absent_school "\makecell{Missed school \\ (reversed)}"

replace aford_school = -aford_school
label variable aford_school "\makecell{Could not \\ afford school \\ (reversed)}"

replace absent_school_amt = -absent_school_amt
label variable absent_school_amt "\makecell{\# days missed \\ (reversed)}"

label variable ctrans_d "\makecell{Cash \\ transfers (0/1)?}" // regular cash transfers
label variable prog_a "\makecell{Cash \\ for work, etc. (0/1)?}" // other cash
label variable prog_b "\makecell{Food \\ transfer (0/1)}?" // food
label variable prog_c "Other transfers (0/1)"

label variable shock_binary "Shock (0/1)?"
label variable nb_shocks "\# of shocks"

capture drop random*
capture drop *pull*
capture drop sleep_who*
capture drop who_twoleg*

replace n_days_business = 0 if missing(n_days_business)
replace bus_asset_value = 0 if missing(bus_asset_value)
replace bus_revenue = 0 if missing(bus_revenue)

replace ani_value = 0 if missing(ani_value) & svyround == 4
replace ani_prod_value30 = 0 if missing(ani_prod_value30) & svyround == 4
replace ag_asset_value = 0 if missing(ag_asset_value) & svyround == 4

replace plot_n30 = 0 if missing(plot_n30) & svyround == 4
replace totalplotsize30 = 0 if missing(totalplotsize30) & svyround == 4

label define svyround 1 "Pre-lean" 2 "Lean" 3 "Post-lean" 4 "Endline", replace

label variable stair_satis_today "Life Satisfaction"
rename stair_satis_today cantril

//Phyllisa April 29th 2025 standardising mental health and life-satisifaction 

replace mentalhealth = mentalhealth - `mentalhealth_mean_bline'		//Phyllisa April 29th 2025 
replace mentalhealth = mentalhealth/`mentalhealth_sd_bline' 		//Phyllisa April 29th 2025 
replace mentalhealth = -mentalhealth  								// higher values mean better health //Phyllisa April 29th 2025 

drop age_*
drop sex_*
drop fish_who_*
drop resp_finance_*
drop resp_livestock_*
drop resp_agriculture_*
drop ag_hh_mem_work_*
drop list_*

quietly compress
save "$panel/ready.dta", replace
