/*

use "/Volumes/NO NAME/Niger Shock Response_Endline-Control.dta", clear
drop if consent == 0

drop consent status_noconsent

sort hhid submissiondate, stable

duplicates tag hhid, gen(dups)
order hhid submissiondate dups

by hhid: gen counter = _n
tab dups counter
drop if dups == 1 & counter == 1
drop if dups == 2 & counter == 1
drop if dups == 2 & counter == 2
drop dups counter

tempfile end_control
save "`end_control'"

drop start_*
drop starttime

drop end_*
drop endtime

drop deviceid subscriberid simid devicephonenum
drop allows_comments records_time instancename
drop isvalidated
drop note_*

drop formdef_version

des, short

local idvars ///
resp_name resp_confirm resp_name_pull *fullname* *firstname* *lastname* ///
gps* ///
address* *address* *key_name* ///
fname lname current_name ///
setof*

foreach var in `idvars' {
    capture ds `var'
    capture drop `r(varlist)'
}

drop fu_first*
drop fu_last*
drop fu_mem*
drop fu_gps
drop fu_tel*
drop date_birth*
drop country
des, short

label variable hhid "Household ID"

quietly destring *, replace

quietly ds *, not(type string)
local nostrings = r(varlist)

quietly {
    mvdecode `nostrings', mv(-999 = .r) // refused
    mvdecode `nostrings', mv(-888 = .d) // don't know
    mvdecode `nostrings', mv(-777 = .o) // other
    mvdecode `nostrings', mv(-666 = .n) // na 
    mvdecode `nostrings', mv(-555 = .g) // god or unknown relation
    mvdecode `nostrings', mv(-333 = .m) 
    mvdecode `nostrings', mv(-222 = .r)
    mvdecode `nostrings', mv(-111 = .i)
    mvdecode `nostrings', mv(-99 = .i)
    mvdecode `nostrings', mv(-88 = .i)
    mvdecode `nostrings', mv(-77 = .i)
    mvdecode `nostrings', mv(-66 = .i)
}

compress

save "~/dropbox/sahel-shocks/6. DataWork/niger/endline/datasets/intermediate/control.dta", replace

*/

clear
use "~/dropbox/sahel-shocks/6. DataWork/niger/endline/datasets/intermediate/control.dta"

rename fu_village_code village
rename fu_department_code departement
rename fu_commune_code commune

merge 1:1 hhid using "~/dropbox/sahel-shocks/6. DataWork/niger/main_data/datasets/sampling/rdd_sample.dta"
keep if _merge == 3
drop _merge

* primary outcomes *

* food insecurity scale (past twelve months)
label variable food1 "Worried about food?"
label variable food2 "Unable to eat healthy due to lack of money?"
label variable food3 "Ate less varied food due to lack of money?"
label variable food4 "Skipped meal due to lack of money?"
label variable food5 "Ate less than you wanted due to lack of money?"
label variable food6 "Ran out of food due to lack of money?"
label variable food7 "Hungry but could not eat due to lack of money?"
label variable food7b "How often were you hungry?"
label variable food8 "\makecell{Whole day \\ without food?}"
label variable food8b "How often did you go a whole day with no food?"
label variable food8c "\makecell{\# days \\ without food}"
label variable food10 "When you lack food, in what order does HH eat?"
* to do: food_men food_women food_boys food_girls
label variable food11 "Probability of going whole day without food next year?"

replace food8c = 0 if food8 == 0

foreach var in food8c {
    _pctile `var', p(98)
    replace `var' = r(r1) if `var' > r(r1) & !missing(`var')
}

local fies food1 food2 food3 food4 food5 food6 food7 food8
egen fies = rowtotal(`fies')
replace fies = -fies
label variable fies "\makecell{Food \\ security}"

gen food8c_rev = -food8c
label variable food8c_rev "\makecell{Days with \\ food}"

gen food8_rev = 1 if food8 == 0
replace food8_rev = 0 if food8 == 1
label variable food8_rev "\makecell{Not hungry \\ all day?}"

* food consumption score (past week)
* in the past seven days, how many days did the HH eat:
label variable div_cereal "Cereals"
label variable div_pulse "Legumes, nuts"
label variable div_milk "Milk, dairy"
label variable div_meat "Meat, fish, eggs"
label variable div_meat2 "Meat flesh"
label variable div_meat_org "Meat organ"
label variable div_fish "Fish and molluscs"
label variable div_egg "Eggs"
label variable div_veg "Vegetables"
label variable div_veg_vita "Orange vegetables"
label variable div_vega "Green vegetables"
label variable div_fruit "Fruits"
label variable div_fruit_vita "Fruits orange"
label variable div_oil "Oil, fats, butter"
label variable div_sugar "Sugar, sweets"
label variable div_spice "Condiments and spices"

* Infant Minimum Dietary Diversity (MDD) (past 24 hours)

label variable div_milk_mat_child "Breast milk"
label variable div_cereal_child "Cereals"
label variable div_pulse_child "Legumes"
label variable div_milk_child "Milk, dairy"
label variable div_meat_child "Meat and fish"
label variable div_egg_child "Eggs"
label variable div_fruit_vita_child "Fruits and vegetables greens"
label variable div_fruit_child "Other fruits and vegetables"

* Mother Minimum Dietary Diversity (MDD) (past 24 hours)

label variable div_cereal_mom "Cereals"
label variable div_pulse_mom "Peas, beans"
label variable div_pulse2_mom "Peanuts, sesame, seeds"
label variable div_milk_mom "Milk, dairy"
label variable div_meat_mom "Meat"
label variable div_egg_mom "Eggs"
label variable div_veg_mom "Vegetables greens"
label variable div_fruit1_mom "Mango and papaya"
label variable div_veg_vita_mom "Other vegetables"
label variable div_fruit_mom "Banana, apple, lemon"

* Children Minimum Dietary Diversity (MDD) (past 24 hours)

label variable div_cereal_child2 "Cereals"
label variable div_pulse_child2 "Peas, beans"
label variable div_pulse2_child2 "Peanuts, sesame, seeds"
label variable div_milk_child2 "Milk, dairy"
label variable div_meat_child2 "Meat"
label variable div_egg_child2 "Eggs"
label variable div_veg_child2 "Vegetables greens"
label variable div_fruit1_child2 "Mango and papaya"
label variable div_veg_vita_child2 "Other vegetables"
label variable div_fruit_child2 "Banana, apple, lemon"

egen mdd_i_score = rowtotal(div_milk_mat_child div_cereal_child div_pulse_child div_milk_child div_meat_child div_egg_child div_fruit_vita_child div_fruit_child), missing 
label var mdd_i_score "\makecell{MDD \\ Infant}"

egen mdd_w_score = rowtotal(div_cereal_mom div_pulse_mom div_pulse2_mom div_milk_mom div_meat_mom div_egg_mom div_veg_mom div_fruit1_mom div_veg_vita_mom div_fruit_mom), missing 
label var mdd_w_score "\makecell{MDD \\ Mother}"

egen mdd_c_score = rowtotal(div_cereal_child2 div_pulse_child2 div_pulse2_child2 div_milk_child2 div_meat_child2 div_egg_child2 div_veg_vita_child2 div_fruit1_child2 div_veg_vita_child2 div_fruit_child2), missing 
label var mdd_c_score "\makecell{MDD \\ Child}"

gen mdd_c_binary = 0 if !missing(mdd_c_score)
replace mdd_c_binary = 1 if mdd_c_score >= 4
label var mdd_c_binary "MDD Child (0/1)"

* note cereals includes tubers so the modified definition is below, taken from midline
* fcs = 2*cereals + 3*pulses + 1*vegetables + 1*fruit + 4*meat/fish/eggs + 4*milk + 0.5*oil + 0.5*sugar
gen fcs = 2*div_cereal + 3*div_pulse + 1*div_veg + 1*div_fruit + 4*div_meat + 4*div_milk + 0.5*div_oil + 0.5*div_sugar
label variable fcs "FCS"

gen fcs_above_poor = (fcs > 21)
replace fcs_above_poor = . if missing(fcs)
label variable fcs_above_poor "FCS above poor"

gen fcs_above_reason = (fcs > 42)
replace fcs_above_reason = . if missing(fcs)
label variable fcs_above_reason "FCS above reasonable"

label variable stair_satis_today "Cantril"

drop rpt_*

tempfile base
save "`base'"

* food consumption

keep ///
hhid ///
consum_qty_* consum_u_* consum_u_o_* consum_bot_* consum_bot_u_* consum_bot_u_o_* consum_bot_val_* consum_in_bot_* ///
consum2_pos_* ///
consum2_ate_* ///
consum2_name_* ///
consum_prod_* consum_gift_*

tostring consum_u_o_*, replace
tostring consum_bot_u_o_*, replace

tempfile foodconsumption
save "`foodconsumption'"

clear
use "`base'"

drop ///
consum_qty_* consum_u_* consum_u_o_* consum_bot_* consum_bot_u_* consum_bot_u_o_* consum_bot_val_* consum_in_bot_* ///
consum2_pos_* ///
consum2_ate_* ///
consum2_name_* ///
consum_prod_* consum_gift_*

save "`base'", replace

clear
use "`foodconsumption'"

reshape long ///
consum_qty_ consum_u_ consum_u_o_ consum_bot_ consum_bot_u_ consum_bot_u_o_ consum_bot_val_ consum_in_bot_ ///
consum_u_name_ consum_bot_freq_ consum_u_bot_name_ ///
consum2_name_ ///
consum2_pos_ ///
consum2_ate_ ///
consum_prod_ consum_gift_ ///
, i(hhid) j(djay)

rename *_ *
drop djay



save "`base'", replace

* mental health (in the past week)

label variable cd1 "More disturbed than usual"
label variable cd2 "Trouble focusing"
label variable cd3_new "Felt sad"
label variable cd4 "Taking more energy than usual"
label variable cd5 "Felt confident about future"
label variable cd6_new "Felt nervous or tense"
label variable cd7 "Had trouble sleeping"
label variable cd8 "Felt happy"
label variable cd9 "Felt alone"
label variable cd10_new "Too tired to do anything"
label variable useless "Felt unproductive"

replace cd5 = 7 - cd5
replace cd8 = 7 - cd8
egen mentalhealth = rowtotal(cd1 cd2 cd3_new cd4 cd5 cd6_new cd7 cd8 cd9 cd10_new useless), missing

replace mentalhealth = -mentalhealth // higher values mean better health
label variable mentalhealth "\makecell{Mental \\ health}"

* social cohesion
label variable tens "Tension between HH and community?"

gen socialcohesion = 0 if tens == 1
replace socialcohesion = 1 if tens == 0
label variable socialcohesion "\makecell{Social \\ cohesion}" // higher value is better

* violence perceptions
label variable ten_tension "How many women in ten experience tension in HH?"
label variable vill_burn "Common for husbands to beat wives?"

label define villburn 1 "no" 2 "could happen" 3 "usual" 4 "very usual"
label values vill_burn villburn

* perception of violence index

replace ten_tension = . if ten_tension > 10 & !missing(ten_tension)

foreach var in ten_tension vill_burn {
sum `var' if treatment == 0
gen `var'_std = (`var' - r(mean))/r(sd)
}

egen vperception = rowtotal(ten_tension_std vill_burn_std), missing
replace vperception = vperception/2
replace vperception = -vperception // higher values are better
label variable vperception "\makecell{Violence \\ perceptions}"
drop ten_tension_std vill_burn_std


* agricultural assets

order hhid ag_ass_name* ass_ag_*
drop ass_ag_n_* ass_ag_val_*
drop ag_ass_pos*

pca ass_ag_*, components(1)
predict xx

egen ag_ass_index = std(xx), mean(0) sd(1)
label variable ag_ass_index "Ag assets"
drop ass_ag_*
drop xx

* household assets

order hhid ass_hh_name_* ass_hh_pos* ass_hh_*

drop ass_hh_pos_* ass_hh_n_*

rename ass_hh_name_* asset_hh_name_*

pca ass_hh_*, components(1)
predict xx

egen hh_ass_index = std(xx), mean(0) sd(1)
label variable hh_ass_index "HH assets"
drop xx

* agri wage income and non agri wage income

order hhid d_hh_index* d7_emp_days* d8_salary* d8_salary* d11_salary*
destring d_hh_index* d7_emp_days* d8_salary* d8_salary* d11_salary*, replace

foreach var of varlist d8_salary* d11_salary* {
    _pctile `var', p(98)
    replace `var' = r(r1) if `var' > r(r1) & !missing(`var')
    replace `var' = 0 if missing(`var')
}

// label variable d7_emp_days "\# days of paid work in past thirty days, agri"
// label variable d8_salary "Wages past thirty days, agri"
// label variable d9_emp_days "\# od days of paid work in past thirty days, non-agri"
// label variable d11_salary "Wages past thirty days, non-agri"

egen agri_emp = rowtotal(d7_emp_days*)
egen non_agri_emp = rowtotal(d9_emp_days*)
egen agri_wages = rowtotal(d8_salary*)
egen non_agri_wages = rowtotal(d11_salary*)

label variable agri_emp "\makecell{\# days in \\ agriculture wage}"
label variable non_agri_emp "\makecell{\# days in \\ other wage}"

label variable agri_wages "\makecell{Agri wage \\ income}"
label variable non_agri_wages "\makecell{Non-agri wage \\ income}"

replace agri_wages = 0 if missing(agri_wages)
replace non_agri_wages = 0 if missing(non_agri_wages)

replace agri_emp = 0 if missing(agri_emp)
replace non_agri_emp = 0 if missing(non_agri_emp)

gen agri_emp_binary = (agri_emp > 0)
label variable agri_emp_binary "\makecell{Agricultural \\ employment?}"

gen non_agri_emp_binary = (non_agri_emp > 0)
label variable non_agri_emp_binary "\makecell{Non-agricultural \\ employment?}"


* main activity

gen off_farm = 1 if important_activity == 3 | important_activity == 4
replace off_farm = 0 if important_activity == 1 | important_activity == 2 | important_activity == 0
label variable off_farm "\makecell{Main activity \\ off-farm?}"

* farming

label variable hasplots "Farming, past twelve months?"
label variable plot_n "How many plots?"

* # of days own farm

order hhid f_hh_index* num_days_ag*
egen n_days_cultivate = rowtotal(num_days_ag*)
label variable n_days_cultivate "\makecell{\# days \\ own farm}"


* HH consumption and non-food consumption

* to do *

* livestock business

egen nagdays = rowtotal(num_days_ag_*)
gen agriculture = 1 if nagdays > 0
replace agriculture = 0 if nagdays == 0
label variable agriculture "\makecell{Agriculture \\ past month?}"
drop nagdays

egen nlivdays = rowtotal(num_days_livestock_*)
gen livestock = 1 if nlivdays > 0
replace livestock = 0 if nlivdays == 0
label variable livestock "\makecell{Livestock \\ past month?}"


egen avg_days_livestock = rowmean(num_days_livestock_*)
label variable avg_days_livestock "\makecell{\# days \\ livestock}"

gen business = business_any
label variable business "\makecell{Business \\ past month?}"


* business revenue
egen bus_revenue = rowtotal(enterprise_revenue_1 enterprise_revenue_2)
label variable bus_revenue "\makecell{Business \\ revenue}"
egen bus_asset_value = rowtotal(bus2_assval_1 bus2_assval_2)
label variable bus_asset_value "\makecell{Business \\ assets}"
egen bus_profit = rowtotal(enterprise_profit_1 enterprise_profit_2)
label variable bus_profit "\makecell{Business \\ profits}"

gen saved_binary_=.
label variable saved_binary_ "\makecell{Saved in past \\ three months}"
replace saved_binary_=0 if !missing(save_loc1) | !missing(save_loc2) | !missing(save_loc3) | !missing(save_loc4) | !missing(save_loc5) 
replace saved_binary_=1 if save_loc1==1 | save_loc2==1 | save_loc3==1 | save_loc4==1 | save_loc5==1

gen saved_amt_1 = dep_xof_1
label variable saved_amt_1 "\makecell{Savings, \\ bank}"

gen saved_amt_2 = dep_xof_2
label variable saved_amt_2 "\makecell{Savings, \\ savings groups}"

gen saved_amt_3 = dep_xof_3
label variable saved_amt_3 "\makecell{Savings, \\ family}"

egen saved_amt_4 = rowtotal(dep_xof_4 dep_xof_5)
label variable saved_amt_4 "\makecell{Savings, \\ others}"

label variable saved_amt_1 "\makecell{Savings, \\ bank}"
label variable saved_amt_2 "\makecell{Savings, \\ savings groups}"
label variable saved_amt_3 "\makecell{Savings, \\ family}"
label variable saved_amt_4 "\makecell{Savings, \\ others}"

foreach var in saved_amt_1 saved_amt_2 saved_amt_3 saved_amt_4 {
    _pctile `var', p(98)
    di r(r1)
    replace `var' = r(r1) if `var' > r(r1) & !missing(`var')
    replace `var' = 0 if missing(`var')
}

egen saved_total = rowtotal(saved_amt_1 saved_amt_2 saved_amt_3 saved_amt_4), missing
label variable saved_total "\makecell{Savings}"

local sources cred_1 cred_2 cred_3 cred_4
egen loans_twelve_mo = rowtotal(`sources')
replace loans_twelve_mo = 1 if loans_twelve_mo > 0
label variable loans_twelve_mo "\makecell{Borrowed (0, 1)}"

egen loans_amt = rowtotal(cred_amt_1 cred_amt_2 cred_amt_3 cred_amt_4)
label variable loans_amt "\makecell{Amount \\ borrowed}"

label variable trans_fam "\makecell{Received \\ remittances?}"

gen remittance_amt = trans_amt
replace remittance_amt = 0 if trans_fam == 0
label variable remittance_amt "\makecell{Remittance \\ amount}"

label variable trans_fam_send "\makecell{Sent \\ remittances?}"

gen remittance_sent_amt = trans_amt_send
replace remittance_sent_amt = 0 if trans_fam_send == 0
label variable remittance_sent_amt "\makecell{Remittance \\ amount}"

label variable accesstofunds "Probability of putting together CFA 30,000 in the next month?"
label values accesstofunds .
recode accesstofunds (1 = 1) (2 = 1) (3 = 0) (4 = 0)
label define accesstofunds 0 "Very unlikely" 1 "Very likely", replace
label values accesstofunds accesstofunds
gen risk_sharing = accesstofunds
label variable risk_sharing "\makecell{Risk-sharing \\ ability}"

drop rdd
gen rdd_treatment = 0
drop fu_score_pmt
order hhid pmt_threshold pmt_norm pmt_norm_round score_pmt
sort hhid, stable

save "${endline_final}/final-control.dta", replace


e
