* rainy season crops by crop rpt_rcrops2
* hhid by crop

clear
use "${endline_intermediate}/agriculture-cropsrain2-rpt_rcrops2.dta"

duplicates drop
drop if missing(rcrop2name)
sort hhid raincodeorother rcrop2name, stable
destring raincodeorother, replace force
drop if missing(raincodeorother)
drop raincodeorother
drop rcrop_left_pest_u_txt
drop calc_rcrop_harv_u

label variable rcrop_seed "What type of seeds did you mainly use for this crop?"
label variable rcrop_seedbot "Have you purchased any of the seeds?"
label variable rcrop_seedexpens "Total spend on seeds" // During the 2022 rainy season how much did you spend in total on seeds on this crop?
label variable rcrop_harv "Quantity harvested"
label variable rcrop_harv_u "Unit"

label variable rcrop_sold "Quantity sold"
label variable rcrop_rev "Total sales made from selling this crop?"

label variable rcrop_bought "Quantity bought"
label variable rcrop_lost_pest "Quantity lost to pest"
label variable rcrop_left "Quantity remaining?"

label values rcrop_seed .
recode rcrop_seed (1 = 0) (2 = 1)
label define rcrop_seed 0 "Locales" 1 "Améliorées", replace
label values rcrop_seed rcrop_seed

encode rcrop2name, gen(cropid)
label values cropid .
isid hhid cropid
order hhid cropid
sort hhid cropid, stable

order hhid cropid rcrop2name rcrop_harv rcrop_harv_u rcrop_sold rcrop_sold_u rcrop_rev rcrop_bought rcrop_bought_u rcrop_lost_pest rcrop_lost_pest_u rcrop_left rcrop_left_pest_u rcrop_left_pest_val

levelsof cropid, local(cropid)

foreach i of local cropid {
foreach var in rcrop_rev rcrop_seedexpens rcrop_left_pest_val {
    winsor2 `var' if cropid == `i', replace cuts(0 98)
}    
}

compress

order rcrop_sold rcrop_sold_u rcrop_rev rcrop_sold_u_o

gen flag = 1 if rcrop_sold == 0
replace rcrop_sold = . if flag == 1
replace rcrop_sold_u = . if flag == 1
replace rcrop_rev = . if flag == 1
drop flag

replace rcrop_harv = rcrop_harv*50 if rcrop_harv_u == 7
replace rcrop_harv = rcrop_harv*100 if rcrop_harv_u == 8

recode rcrop_harv_u (7 8 = 1)

replace rcrop_bought = rcrop_bought*50 if rcrop_bought_u == 7
replace rcrop_bought = rcrop_bought*100 if rcrop_bought_u == 8

recode rcrop_bought_u (7 8 = 1)

replace rcrop_lost_pest = rcrop_lost_pest*50 if rcrop_lost_pest_u == 7
replace rcrop_lost_pest = rcrop_lost_pest*100 if rcrop_lost_pest_u == 8
recode rcrop_lost_pest_u (7 8 = 1)

replace rcrop_left = rcrop_left*50 if rcrop_left_pest_u == 7
replace rcrop_left = rcrop_left*100 if rcrop_left_pest_u == 8

recode rcrop_left_pest_u (7 8 = 1)

replace rcrop_sold = rcrop_sold * 50 if rcrop_sold_u == 7
replace rcrop_sold = rcrop_sold * 100 if rcrop_sold_u == 8
recode rcrop_sold_u (7 8 = 1)

replace rcrop_rev = . if rcrop_rev > .
replace rcrop_sold = . if rcrop_sold > .

gen unitprice = rcrop_rev / rcrop_sold

levelsof cropid, local(cropid)

foreach i of local cropid {
foreach var in rcrop_harv rcrop_bought rcrop_lost_pest rcrop_left {
    winsor2 `var' if cropid == `i', replace cuts(0 98)
}    
}

tempfile unitprice
save "`unitprice'"

drop if missing(unitprice)

keep unitprice hhid cropid rcrop2name rcrop_sold_u
collapse (median) medunitprice = unitprice, by(cropid rcrop2name rcrop_sold_u)
drop if missing(rcrop_sold_u)
compress

rename rcrop_sold_u rcrop_harv_u
compress
sort cropid rcrop2name rcrop_harv_u
order cropid rcrop2name rcrop_harv_u

tempfile medunitprice
save "`medunitprice'"

clear
use "`unitprice'"
merge m:1 cropid rcrop2name rcrop_harv_u using "`medunitprice'"
drop if _merge == 2
drop _merge
drop unitprice

gen tempa = rcrop_harv * medunitprice
gen tempb = rcrop_bought * medunitprice
gen tempc = rcrop_lost_pest * medunitprice

sort hhid, stable

by hhid: egen rcropvalharvest = total(tempa)
by hhid: egen rcropvalbought = total(tempb)
by hhid: egen rcropvallost = total(tempc)

label variable rcropvalharvest "\makecell{Value of \\ crop harvest}"
label variable rcropvalbought "\makecell{Value of \\ crop bought}"
label variable rcropvallost "\makecell{Value of \\ crop lost}"

drop tempa tempb tempc

by hhid: egen improvedseed = max(rcrop_seed)
by hhid: egen boughtseed = max(rcrop_seedbot)
by hhid: egen expenseseed = total(rcrop_seedexpens)
by hhid: egen revenueharvest = total(rcrop_rev)
by hhid: egen rcropleftvalue = total(rcrop_left_pest_val)

label variable improvedseed "\makecell{Bought improved \\ seed?}"
label variable boughtseed "\makecell{Bought \\ seed?}"
label variable expenseseed "\makecell{Spend on \\ seed}"
label variable revenueharvest "\makecell{Harvest \\ revenue}"
label variable rcropleftvalue "\makecell{Value of \\ qty remaining}"

drop rcrop_harv_state rcrop_harv_u_o rcrop_harv_state_o rcrop_sold_state rcrop_sold_u_o rcrop_sold_state_o
drop rcrop_harv_u rcrop_sold_u rcrop_lost_pest_u rcrop_left_pest_u rcrop_bought_u
rename rcrop2name rcropname
keep hhid rcropvalharvest rcropvalbought rcropvallost improvedseed boughtseed expenseseed revenueharvest rcropleftvalue

duplicates drop
isid hhid

save "${endline_final}/rcrops2.dta", replace

* dry season crops by crop rpt_dcrops2
* hhid by crop

clear
use "${endline_intermediate}/agriculture-cropsdry2-rpt_dcrops2.dta"

duplicates drop
drop if missing(dcrop2name)
sort hhid drycodeorother dcrop2name, stable

destring drycodeorother, replace force
drop if missing(drycodeorother)
drop drycodeorother
drop calc_dcrop_harv_u
encode dcrop2name, gen(cropid)
label values cropid .
isid hhid cropid
order hhid cropid
sort hhid cropid, stable

// label variable dcrop_seed "What type of seeds did you mainly use for this crop?"
// label variable dcrop_seedbot "Have you purchased any of the seeds?"
// label variable dcrop_seedexpens "During the 2022 rainy season how much did you spend in total on seeds?"
label variable dcrop_harv "Quantity harvested"
label variable dcrop_harv_u "Unit"

label variable dcrop_rev "Total sales made from the sale of this product?"
// label variable dcrop_bought "Quantity bought"
// label variable dcrop_lost_pest "Quantity lost to pest"
// label variable dcrop_left "Quantity remaining?"

levelsof cropid, local(cropid)

foreach i of local cropid {
foreach var in dcrop_rev {
    winsor2 `var' if cropid == `i', replace cuts(0 98)
}    
}

replace dcrop_harv = dcrop_harv*50 if dcrop_harv_u == 7
replace dcrop_harv = dcrop_harv*100 if dcrop_harv_u == 8
recode dcrop_harv_u (7 8 = 1)

gen unitprice = dcrop_rev / dcrop_sold

levelsof cropid, local(cropid)

foreach i of local cropid {
foreach var in dcrop_harv {
    winsor2 `var' if cropid == `i', replace cuts(0 98)
}    
}

gen dcrop_sold_u = dcrop_harv_u
drop dcrop_harv_state dcrop_harv_u_o dcrop_harv_state_o dcrop_sold dcrop_sold_state dcrop_sold_state_o

tempfile unitprice
save "`unitprice'"

drop if missing(unitprice)

keep unitprice hhid cropid dcrop2name dcrop_sold_u
collapse (median) medunitprice = unitprice, by(cropid dcrop2name dcrop_sold_u)
drop if missing(dcrop_sold_u)
compress
rename dcrop_sold_u dcrop_harv_u
compress
sort cropid dcrop2name dcrop_harv_u
order cropid dcrop2name dcrop_harv_u

tempfile medunitprice
save "`medunitprice'"

clear
use "`unitprice'"
merge m:1 cropid dcrop2name dcrop_harv_u using "`medunitprice'"
drop if _merge == 2
drop _merge
drop unitprice

gen tempa = dcrop_harv * medunitprice
sort hhid, stable
by hhid: egen rcropvalharvest = total(tempa)
drop tempa
label variable rcropvalharvest "\makecell{Value of \\ crop harvest}"
by hhid: egen revenueharvest_dry = total(dcrop_rev)
label variable revenueharvest_dry "\makecell{Harvest \\ revenue}"
rename dcrop2name dcropname

keep hhid rcropvalharvest revenueharvest_dry

duplicates drop
isid hhid

save "${endline_final}/dcrops2.dta", replace

* agriculture in the past 30 days

clear
use "${endline_intermediate}/agriculture-f_ag_livestock-agriculture30-plots30-rpt_plots30.dta"
sort hhid plot_pos30 plot_name30d, stable

* convert hectares to meter squared
replace plot_size30 = plot_size30*10000 if plot_size_u30 == 1
replace plot_size_u30 = 2 if plot_size_u30 == 1
label variable plot_size30 "Plot size in metre squared"

replace plot_size30 = . if plot_size30 == 0
winsor2 plot_size30, cuts(0 98) replace

drop plot_size_u30
drop plot_ha30
drop plot_name30d
drop if missing(plot_size30)

sort hhid, stable
by hhid: egen totalplotsize30 = total(plot_size30)
by hhid: gen plot_n30 = _N

drop plot_size30
drop plot_pos30
duplicates drop

save "${endline_final}/plots30.dta", replace

* to do
clear
use "${endline_intermediate}/agriculture-f_ag_livestock-agriculture30-crops_rpt30.dta"
sort hhid crop_id30 crops_name30, stable

clear
use "${endline_intermediate}/agriculture-f_ag_livestock-agriculture30-f_hh_ag_labor.dta"
sort hhid f_hh_index, stable
label variable num_days_ag "In the last 30 days, how many days did X work cultivating land?"
by hhid: egen n_days_cultivate = total(num_days_ag)

keep hhid n_days_cultivate
label variable n_days_cultivate "\makecell{\# of days \\ own farm}" // across all workers in HH
duplicates drop

save "${endline_final}/cultivate.dta", replace


* dry season crops gp_drykeycond
* hh by plot

clear
use "${endline_intermediate}/gp_drykeycond-rpt_dcrops.dta"
duplicates drop
drop if missing(dcrop_name)
destring dcrop_codeor_o, replace force
drop if missing(dcrop_codeor_o)
drop dcrop_codeor_o
sort hhid dcrop_name, stable

by hhid: gen plotid = _n
sort hhid plotid, stable
order hhid plotid
isid hhid plotid

label variable dcrop_name "Crop"

label variable dcrop_status "Finished harvesting this crop?"
label variable dcrop_didsell "Sold (part of) harvest?"
label variable dcrop_controlrev "Who controls the income from this sale?"
label variable drydcrop_harvn "\# of times crop planted" // on this plot during the rainy season

sort hhid dcrop_name plotid, stable
label define dcrop_status 1 "finished harvest" 2 "ongoing harvest" 3 "have not started" 0 "harvest lost", replace
label define drydcrop_harvn 1 "Once" 2 "Twice", replace

drop harvesteddcrop solddcrop

drop dcrop_controlrev*

sort hhid plotid, stable
order hhid plotid

by hhid: egen soldharvest_dry = max(dcrop_didsell) // sold harvest across all plots

gen tempvar = 0 if inlist(dcrop_status, 0, 3)
replace tempvar = 1 if inlist(dcrop_status, 1, 2) // ongoing or finished harvest across all plots

by hhid: egen harvested_dry = max(tempvar)
drop tempvar

label variable harvested_dry "Harvested?"
label variable soldharvest_dry "\makecell{Sold \\ harvest?}"

local identifiers hhid plotid soldharvest_dry harvested_dry
ds `identifiers', not

foreach var in `r(varlist)' {
    ren `var' `var'_
    local l_`var'_ : variable label `var'_
}

levelsof plotid, local(plotid)

ds `identifiers', not
local stubnames "`r(varlist)'"
reshape wide `stubnames', i(hhid) j(plotid)

foreach variable of local stubnames {
foreach value of local plotid {
label variable `variable'`value' "`l_`variable'': plot # `value' "
}
}

save "${endline_final}/drykeycond.dta", replace
