* module 8 food consumption wide and long format

* part one
clear
use "${endline_intermediate}/foodconsumption-rpt_consum1.dta"
drop if missing(hhid)
sort hhid consum1_pos, stable
duplicates drop

label variable consum "Did your HH consume X in past week?"
label variable consum1_name "Food item"

* part two
* pulls in data from part one, indicating which foods were consumed
clear
use "${endline_intermediate}/foodconsumption-rpt_consum2.dta"

merge m:1 hhid using "${endline_final}/main_build_temp.dta", keepusing(commune_name village_name vid submissiondate year month deflator)
drop if _merge == 2
drop _merge
drop if missing(commune_name)

drop if missing(hhid)
sort hhid consum2_pos, stable
order hhid consum2_pos consum2_ate
duplicates drop
destring consum2_ate, replace
destring consum2_pos, replace
keep if consum2_ate == 1
drop consum2_ate

label var consum_qty "quantity consumed"
label var consum_u "unit"
label var consum_u_o "non standard unit"
label var consum_bot "quantity of the good last purchased"
label var consum_bot_u "unit of reported quantity of the good last purchased"
label var consum_bot_u_o "non standard unit of reported quantity of the good last purchased"
label var consum_bot_val "total value of the quantity of the good purchased last time"
label var consum_in_bot "consumption unit by purchase unit"
note consum_in_bot: "how many of units of the unit reported for consumption are in the unit reported for purchasing"

label variable consum_prod "From qty consumed, how much is from HH production?"
label variable consum_gift "From qty consumed, how much is from gifts, payment in kind, etc.?"

replace consum2_name = strlower(consum2_name)
replace consum2_name = subinstr(consum2_name, " ", "", .)
replace consum_u_name = strlower(consum_u_name)
replace consum_u_bot_name = strlower(consum_u_bot_name)

drop consum_u consum_bot_u

compress
order consum2_name consum_qty consum_u_name consum_bot consum_u_bot_name consum_in_bot consum_bot_val
order consum_bot_freq consum2_pos hhid, last

replace consum2_name = "manioc_farine" if consum2_name == "farinedemanioc(attieke,gari,tapioca,etc.)"
replace consum2_name = "onion" if consum2_name == "oignonfrais"
replace consum2_name = "haricots" if consum2_name == "haricotssecs"
replace consum2_name = "cube" if consum2_name == "cube(maggi,jumbo….etc)"
replace consum2_name = "soumbala" if consum2_name == "soumbala(based'oseilleoudenéré)"
replace consum2_name = "baobab" if consum2_name == "feuillesdebaobab"
replace consum2_name = "yodo" if consum2_name == "yodo(foyeyouto)"
replace consum2_name = "yam" if consum2_name == "patatedouce"
replace consum2_name = "noix" if consum2_name == "noixdecola"
replace consum2_name = "mouton" if consum2_name == "viandedemouton"
replace consum2_name = "huile_palme" if consum2_name == "huiledepalme"
replace consum2_name = "huile_arachide" if consum2_name == "huiled'arachide"
replace consum2_name = "caillee" if consum2_name == "laitcaillee"
replace consum2_name = "tea" if consum2_name == "theenpaquetouensachet"
replace consum2_name = "pates" if consum2_name == "patesalimentaires"
replace consum2_name = "manioc_tube" if consum2_name == "tuberculedemanioc"
replace consum2_name = "ronier" if consum2_name == "ronier/doumier(fruit)"
replace consum2_name = "boeuf" if consum2_name == "viandedechevre" // NOTE
replace consum2_name = "tomate" if consum2_name == "tomatesechee"
replace consum2_name = "haricots_vert" if consum2_name == "haricotvert"
replace consum2_name = "haricots_beign" if consum2_name == "beignetsdeharicot"

drop if consum2_name == "boeuf" // NOTE

replace consum_u_name = "unité" if consum_u_o == "noix" & consum2_name == "noix"
replace consum_u_bot_name = "unité" if consum_bot_u_o == "noix" & consum2_name == "noix"
replace consum_u_o = "" if consum_u_o == "noix" & consum2_name == "noix"
replace consum_bot_u_o = "" if consum_bot_u_o == "noix"

compress

* manual cleaning - these are specific cases, cannot be generalized

* incorrect unit
count if consum_u_name == "gramme" & inlist(consum2_name, "mil", "mais", "riz", "sorgho")
gen flag = 1 if consum_u_name == "gramme" & consum_u_bot_name == "gramme" & inlist(consum2_name, "mil", "mais", "riz", "sorgho") & inlist(consum_bot_val, 11000, 11500)
replace consum_u_name = "kg" if flag == 1
replace consum_u_bot_name = "kg" if flag == 1
drop flag
replace consum_u_name = "kg" if consum_u_name == "unité" & inlist(consum2_name, "mil", "mais", "riz", "sorgho") & consum_u_name != consum_u_bot_name & inlist(consum_u_bot_name, "sac de 50 kg", "sac de 100 kg")

drop if consum_u_name == "unité" & inlist(consum2_name, "mil", "mais", "riz", "sorgho")
drop if consum_u_name == "centilitre" & consum2_name == "baobab"

replace consum_bot = . if consum_u_bot_name == "litre" & inlist(consum2_name, "mil", "mais", "riz", "sorgho")
replace consum_bot_val = . if consum_u_bot_name == "litre" & inlist(consum2_name, "mil", "mais", "riz", "sorgho")
replace consum_in_bot = . if consum_u_bot_name == "litre" & inlist(consum2_name, "mil", "mais", "riz", "sorgho")
replace consum_u_bot_name = "" if consum_u_bot_name == "litre" & inlist(consum2_name, "mil", "mais", "riz", "sorgho")

* consum_in_bot asked if unit of consumption is not equal to unit of purchase AND last purchase not more than a year ago

replace consum_in_bot = 1 if consum_u_name == consum_u_bot_name

gen flag = 1 if consum_bot == 0
replace consum_bot = . if flag == 1
replace consum_in_bot = . if flag == 1
replace consum_u_bot_name = "" if flag == 1
drop flag

sort consum_qty
sum consum_qty if consum_u_name == "kg", d
sum consum_qty if consum_u_name == "sac de 50 kg", d
sum consum_qty if consum_u_name == "sac de 100 kg", d

replace consum_u_name = "kg" if consum_qty == 50 & consum_u_name == "sac de 50 kg"
replace consum_u_name = "kg" if consum_qty == 100 & consum_u_name == "sac de 100 kg"
replace consum_qty = . if consum_qty == 12250 & consum_u_name == "sac de 50 kg"
replace consum_qty = . if consum_qty == 2000 & consum_u_name == "kg"
replace consum_u_name = "kg" if inlist(consum_qty, 3, 7, 10) & consum_u_name == "sac de 50 kg"
replace consum_qty = . if consum_qty == 21000 & consum_u_name == "sac de 100 kg"

gen flag = 1 if consum_u_name == "sac de 100 kg" & consum_u_name == consum_u_bot_name & consum_qty > consum_bot
replace consum_u_name = "kg" if flag == 1
drop flag

drop if consum_u_name == "sac de 100 kg" & consum_qty > 2

replace consum_in_bot = 1 if consum_u_name == consum_u_bot_name

sort consum_bot
sum consum_bot if consum_u_bot_name == "kg", d
sum consum_bot if consum_u_bot_name == "sac de 50 kg", d
sum consum_bot if consum_u_bot_name == "sac de 100 kg", d

replace consum_u_bot_name = "kg" if consum_bot == 50 & consum_u_bot_name == "sac de 50 kg"
replace consum_u_bot_name = "kg" if consum_bot == 51 & consum_u_bot_name == "sac de 50 kg"
replace consum_u_bot_name = "kg" if consum_bot == 100 & consum_u_bot_name == "sac de 100 kg"

gen flag = 1 if consum_u_bot_name == "sac de 100 kg" & consum_bot > 2
replace consum_bot = . if flag == 1
replace consum_in_bot = . if flag == 1
replace consum_u_bot_name = "" if flag == 1
drop flag

gen flag = 1 if consum_u_bot_name == "sac de 50 kg" & consum_bot > 4
replace consum_bot = . if flag == 1
replace consum_in_bot = . if flag == 1
replace consum_u_bot_name = "" if flag == 1
drop flag

replace consum_in_bot = 1 if consum_u_name == consum_u_bot_name

gen flag = 1 if inlist(consum_bot, 25000, 1325, 500, 5000, 25000) & consum_u_bot_name == "kg"
replace consum_in_bot = . if flag == 1
replace consum_bot_val = . if flag == 1
replace consum_u_bot_name = "" if flag == 1
replace consum_bot = . if flag == 1
drop flag

replace consum_in_bot = 1 if consum_u_name == consum_u_bot_name
replace consum_in_bot = . if missing(consum_u_name) | missing(consum_u_bot_name)

sort consum_bot
sum consum_bot if consum_u_bot_name == "kg", d
sum consum_bot if consum_u_bot_name == "sac de 50 kg", d
sum consum_bot if consum_u_bot_name == "sac de 100 kg", d

count if consum_in_bot == 1 & consum_u_name != consum_u_bot_name
replace consum_in_bot = 1000 if consum_u_name == "gramme" & consum_u_bot_name == "kg"
replace consum_in_bot = 100 if consum_u_name == "centilitre" & consum_u_bot_name == "litre"
replace consum_in_bot = 2 if consum_u_name == "sac de 50 kg" & consum_u_bot_name == "sac de 100 kg"

replace consum_in_bot = 1 if consum_u_name == consum_u_bot_name
replace consum_in_bot = . if consum_in_bot == 0

order consum_qty consum_u_name consum_bot consum_u_bot_name consum_in_bot consum_bot_val consum2_name

sum consum_in_bot if consum_u_name == "tia" & consum_u_bot_name == "kg", d
sum consum_in_bot if consum_u_name == "tia" & consum_u_bot_name == "sac de 50 kg", d
sum consum_in_bot if consum_u_name == "tia" & consum_u_bot_name == "sac de 100 kg", d

* replace with modal value
replace consum_in_bot = 20 if consum_u_name == "tia" & consum_u_bot_name == "sac de 50 kg"
replace consum_in_bot = 40 if consum_u_name == "tia" & consum_u_bot_name == "sac de 100 kg"

gen conversion = 1 if consum_in_bot == 1
label variable conversion ""
order consum_qty consum_u_name consum_bot consum_u_bot_name consum_in_bot conversion consum_bot_val consum2_name

replace conversion = 100 / consum_in_bot if consum_u_name == "tia" & consum_u_bot_name == "sac de 100 kg"
replace conversion = 50 / consum_in_bot if consum_u_name == "tia" & consum_u_bot_name == "sac de 50 kg"

* these values seem to be misunderstood
* replace with the modal tia to kg conversion
sum consum_in_bot if consum_u_name == "tia" & consum_u_bot_name == "kg", d

replace conversion = 2.5 if consum_u_name == "tia" & consum_u_bot_name == "kg"
replace consum_in_bot = 1 / conversion if consum_u_name == "tia" & consum_u_bot_name == "kg"

replace consum_bot = consum_bot * 100 if consum_u_bot_name == "sac de 100 kg"
replace consum_bot = consum_bot * 50 if consum_u_bot_name == "sac de 50 kg"
replace consum_u_bot_name = "kg" if inlist(consum_u_bot_name, "sac de 50 kg", "sac de 100 kg")

replace consum_qty = consum_qty * 100 if consum_u_name == "sac de 100 kg"
replace consum_qty = consum_qty * 50 if consum_u_name == "sac de 50 kg"
replace consum_u_name = "kg" if inlist(consum_u_name, "sac de 50 kg", "sac de 100 kg")

replace consum_in_bot = 1 if consum_u_name == consum_u_bot_name
replace conversion = 1 if consum_u_name == consum_u_bot_name

gen flag = 1 if inlist(consum2_name, "mouton", "boeuf") & consum_u_name == consum_u_bot_name & consum_u_name == "gramme"
replace consum_u_name = "kg" if flag == 1 & consum_qty < 20
replace consum_u_bot_name = "kg" if flag == 1 & consum_bot < 20
drop flag

gen flag = 1 if consum_u_name == consum_u_bot_name & consum_u_name == "gramme"

replace consum_u_name = "kg" if flag == 1
replace consum_u_bot_name = "kg" if flag == 1
replace consum_qty = consum_qty / 1000 if flag == 1
replace consum_bot = consum_bot / 1000 if flag == 1
drop if consum_qty < 0.01 & consum_u_name == "kg"

drop flag

gen flag = 1 if consum_bot < 0.01 & consum_u_bot_name == "kg"
replace consum_bot_val = . if flag == 1
replace consum_bot = . if flag == 1
replace consum_u_bot_name = "" if flag == 1
replace conversion = . if flag == 1
drop flag

// * convert price per gram to price per kg
// replace consum_bot = consum_bot / consum_qty if flag == 1

replace consum_bot_val = . if consum_u_bot_name == "tia" & consum_u_name == "tia" & consum2_name == "riz" & consum_bot_val == 11000 

sum consum_qty if consum_u_name == "kg", d
sum consum_bot if consum_u_bot_name == "kg", d

*** convert consumed quantities and units to bought quantities and units ***
* convert quantities
replace consum_qty = consum_qty * conversion if !missing(conversion)
replace consum_prod = consum_prod * conversion if !missing(conversion)
replace consum_gift = consum_gift * conversion if !missing(conversion)

* convert units
replace consum_u_name = consum_u_bot_name if !missing(conversion)

replace conversion = 1 if consum_u_name == consum_u_bot_name

* winsorize quantities of foods consumed

egen gg = group(consum_u_name consum2_name)
levelsof gg, local(dunits)

sum consum_qty consum_prod consum_gift

foreach var in consum_qty { // consum_prod consum_gift 
   foreach du in `dunits' {
    _pctile `var' if gg == `du', p(98)
    quietly replace `var' = r(r1) if `var' > r(r1) & !missing(`var') & gg == `du'
} 
}

sum consum_qty consum_prod consum_gift
drop gg

compress


* calculate unit prices
gen bot_unit_price = consum_bot_val / consum_bot if !missing(conversion)
order consum_qty consum_u_name consum_bot consum_u_bot_name consum_in_bot conversion consum_bot_val bot_unit_price consum2_name
sort bot_unit_price
sum bot_unit_price, d

quietly {
egen gg = group(consum_u_name consum2_name)
levelsof gg, local(dunits)
}
/*
quietly {
foreach du in `dunits' {
// sum bot_unit_price if gg == `du', d
_pctile bot_unit_price if gg == `du', percentiles(2 98)
ret list
gen flag = 1 if (bot_unit_price <= r(r1) | bot_unit_price >= r(r2)) & gg == `du'

replace bot_unit_price = . if flag == 1
replace consum_bot_val = . if flag == 1
replace consum_bot = . if flag == 1
replace consum_u_bot_name = "" if flag == 1

drop flag
// sum bot_unit_price if gg == `du', d
}  
}
*/
drop gg
sort bot_unit_price
sum bot_unit_price, d

replace conversion = . if missing(consum_bot)
drop consum_in_bot

* calculate median prices

sort commune_name village_name vid consum2_pos consum2_name consum_u_bot_name, stable

tempfile brk
save "`brk'"

collapse (median) bot_mp_village = bot_unit_price (count) mp_village_count = bot_unit_price, by(commune_name village_name vid consum2_pos consum2_name consum_u_bot_name)
drop if missing(consum_u_bot_name)
drop if consum_u_bot_name == "autre"
drop if mp_village_count == 0
drop if mp_village_count < 5
tempfile village
save "`village'"
count

clear 
use "`brk'"

collapse (median) bot_mp_commune = bot_unit_price (count) mp_commune_count = bot_unit_price, by(commune_name consum2_pos consum2_name consum_u_bot_name)
drop if missing(consum_u_bot_name)
drop if consum_u_bot_name == "autre"
drop if mp_commune_count == 0
drop if mp_commune_count < 5
tempfile commune
save "`commune'"
count

clear 
use "`brk'"

collapse (median) bot_mp_region = bot_unit_price (count) mp_region_count = bot_unit_price, by(consum2_pos consum2_name consum_u_bot_name)
drop if missing(consum_u_bot_name)
drop if consum_u_bot_name == "autre"
drop if mp_region_count == 0
drop if mp_region_count < 5
tempfile region
save "`region'"
count

* compare median prices at different levels
clear
use "`village'"
merge m:1 consum_u_bot_name consum2_name commune_name consum2_pos using "`commune'"
label define novillage 3 "" 2 "commune median only", replace
rename _merge novillage
label values novillage novillage

merge m:1 consum_u_bot_name consum2_name using "`region'"
label define nocommune 3 "" 2 "region median only", replace
rename _merge nocommune
label values nocommune nocommune

clear
use "`brk'"

count if missing(consum_u_bot_name)
* do this for those food items which were never bought
replace consum_u_bot_name = consum_u_name if consum_bot_freq == 5 | consum_bot_freq == 6
* also do this for those who bought but their bought values, unit prices, units were incorrect, etc.
replace consum_u_bot_name = consum_u_name if missing(consum_u_bot_name)

merge m:1 commune_name village_name vid consum2_pos consum2_name consum_u_bot_name using "`village'"
drop _merge
merge m:1 commune_name consum2_pos consum2_name consum_u_bot_name using "`commune'"
drop _merge
merge m:1 consum2_pos consum2_name consum_u_bot_name using "`region'"
drop _merge

quietly gen proxy = .
order consum2_pos consum2_name proxy consum_qty bot_unit_price 
order consum_u_name consum_u_bot_name bot_mp_region mp_region_count bot_mp_commune mp_commune_count bot_mp_village mp_village_count, after(bot_unit_price)

replace proxy = consum_qty * bot_unit_price
compress
sum proxy, d
count if missing(proxy) & !missing(bot_mp_commune)

if "${impute_rule}" == "village" {
    replace proxy = consum_qty * bot_mp_village if missing(proxy)
    replace proxy = consum_qty * bot_mp_commune if missing(proxy)
    replace proxy = consum_qty * bot_mp_region if missing(proxy)
}

if "${impute_rule}" == "commune" {
    replace proxy = consum_qty * bot_mp_commune if missing(proxy)
    replace proxy = consum_qty * bot_mp_region if missing(proxy)
}

if "${impute_rule}" == "region" {
    replace proxy = consum_qty * bot_mp_region if missing(proxy)
}

sum proxy, d

drop consum_bot_freq

drop bot_mp*
drop village_name commune_name
drop consum2_pos
drop bot_unit_price
drop consum_bot
drop consum_prod
drop consum_gift
drop consum_bot_val

drop consum_qty consum_u_name consum_u_bot_name consum_u_o consum_bot_u_o

drop if missing(proxy)

drop conversion
drop mp_*

local identifiers hhid vid submissiondate year month deflator consum2_name
ds `identifiers', not

foreach var in `r(varlist)' {
    ren `var' `var'_
    local l_`var'_ : variable label `var'_
}

order hhid consum2_name, first
sort hhid consum2_name, stable

ds `identifiers', not
local stubnames "`r(varlist)'"
reshape wide `stubnames', i(hhid) j(consum2_name) string

ds proxy_*
local count = wordcount("`r(varlist)'")
di "`count'"

tabstat proxy_*, stat(n mean sd min max) col(stat) varwidth(40)

replace proxy_mais = proxy_mais/deflator
replace proxy_mil = proxy_mil/deflator
replace proxy_riz = proxy_riz/deflator

* winsorize weekly consumption, each food group

tabstat proxy_*, stat(n mean sd min max) col(stat) varwidth(40)

ds proxy_*
foreach var in `r(varlist)' {
winsor2 `var', replace cuts(0 98)
rename `var' `var'_win
}

tabstat proxy_*, stat(n mean sd min max) col(stat) varwidth(40)

* multiply each item by four 

ds proxy_*_win

foreach var in `r(varlist)' {
   qui gen `var'_mt = 4 * `var'
   drop `var'
}

* sum across items

ds proxy_*_mt
egen proxycon_mt = rowtotal(`r(varlist)'), missing

label var proxycon_mt "\makecell{Food \\ consumption}"

label variable proxy_mais_win_mt "Maize"
label variable proxy_mil_win_mt "Mil"
label variable proxy_sel_win_mt "Sel"
label variable proxy_sucre_win_mt "Sucre"
label variable proxy_riz_win_mt "Riz"
label variable proxy_huile_palme_win_mt "Palm oil"
label variable proxy_mouton_win_mt "Mutton"
label variable proxy_noix_win_mt "Noix de cola"
label variable proxy_sorgho_win_mt "Sorghum"
label variable proxy_huile_arachide_win_mt "Peanut oil"
label variable proxy_haricots_win_mt "Haricots secs"
label variable proxy_pates_win_mt "Pates"

* winsorize total monthly consumption - 12 food groups

local restrict ///
proxy_mais_win_mt ///
proxy_mil_win_mt ///
proxy_sel_win_mt ///
proxy_sucre_win_mt ///
proxy_riz_win_mt ///
proxy_huile_palme_win_mt ///
proxy_mouton_win_mt ///
proxy_noix_win_mt ///
proxy_sorgho_win_mt ///
proxy_huile_arachide_win_mt ///
proxy_haricots_win_mt ///
proxy_pates_win_mt

egen proxycon_mt_compare = rowtotal(`restrict'), missing

label variable proxycon_mt_compare "\makecell{Food \\ consumption}"

drop submissiondate year month deflator vid
tabstat `restrict', stat(n mean sd min max) col(stat) varwidth(40)

save "${endline_final}/hh_food_consumption.dta", replace
