* import_niger_2023_Endline_Terrain-gp_empl_cond-rpt_sal.do
*
*     Imports and aggregates "Niger 2023- Shock Response- ENDLINE-gp_empl_cond-rpt_sal" (ID: niger_2023_Endline_Terrain) data.
*
*    Inputs:  "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-gp_empl_cond-rpt_sal.csv"
*    Outputs: "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-gp_empl_cond-rpt_sal.dta"
*
*    Output by SurveyCTO August 24, 2023 9:33 AM.

* initialize Stata
clear all
set more off
set mem 100m

* initialize workflow-specific parameters
*    Set overwrite_old_data to 1 if you use the review and correction
*    workflow and allow un-approving of submissions. If you do this,
*    incoming data will overwrite old data, so you won't want to make
*    changes to data in your local .dta file (such changes can be
*    overwritten with each new import).
local overwrite_old_data 0

* initialize form-specific parameters
local csvfile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-gp_empl_cond-rpt_sal.csv"
local dtafile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-gp_empl_cond-rpt_sal.dta"
local corrfile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-gp_empl_cond-rpt_sal_corrections.csv"
local note_fields1 ""
local text_fields1 "empl_pos empl_name empl_type_o"
local date_fields1 ""
local datetime_fields1 ""

disp
disp "Starting import of: `csvfile'"
disp

* import data from primary .csv file
insheet using "`csvfile'", names clear

* drop extra table-list columns
cap drop reserved_name_for_field_*
cap drop generated_table_list_lab*

* continue only if there's at least one row of data to import
if _N>0 {
    * drop note fields (since they don't contain any real data)
    forvalues i = 1/100 {
        if "`note_fields`i''" ~= "" {
            drop `note_fields`i''
        }
    }
    
    * format date and date/time fields
    forvalues i = 1/100 {
        if "`datetime_fields`i''" ~= "" {
            foreach dtvarlist in `datetime_fields`i'' {
                cap unab dtvarlist : `dtvarlist'
                if _rc==0 {
                    foreach dtvar in `dtvarlist' {
                        tempvar tempdtvar
                        rename `dtvar' `tempdtvar'
                        gen double `dtvar'=.
                        cap replace `dtvar'=clock(`tempdtvar',"DMYhms",2025)
                        * automatically try without seconds, just in case
                        cap replace `dtvar'=clock(`tempdtvar',"DMYhm",2025) if `dtvar'==. & `tempdtvar'~=""
                        format %tc `dtvar'
                        drop `tempdtvar'
                    }
                }
            }
        }
        if "`date_fields`i''" ~= "" {
            foreach dtvarlist in `date_fields`i'' {
                cap unab dtvarlist : `dtvarlist'
                if _rc==0 {
                    foreach dtvar in `dtvarlist' {
                        tempvar tempdtvar
                        rename `dtvar' `tempdtvar'
                        gen double `dtvar'=.
                        cap replace `dtvar'=date(`tempdtvar',"DMY",2025)
                        format %td `dtvar'
                        drop `tempdtvar'
                    }
                }
            }
        }
    }

    * ensure that text fields are always imported as strings (with "" for missing values)
    * (note that we treat "calculate" fields as text; you can destring later if you wish)
    tempvar ismissingvar
    quietly: gen `ismissingvar'=.
    forvalues i = 1/100 {
        if "`text_fields`i''" ~= "" {
            foreach svarlist in `text_fields`i'' {
                cap unab svarlist : `svarlist'
                if _rc==0 {
                    foreach stringvar in `svarlist' {
                        quietly: replace `ismissingvar'=.
                        quietly: cap replace `ismissingvar'=1 if `stringvar'==.
                        cap tostring `stringvar', format(%100.0g) replace
                        cap replace `stringvar'="" if `ismissingvar'==1
                    }
                }
            }
        }
    }
    quietly: drop `ismissingvar'



    * label variables
    label variable key "Unique submission ID"
    cap label variable submissiondate "Date/time submitted"
    cap label variable formdef_version "Form version used on device"
    cap label variable review_status "Review status"
    cap label variable review_comments "Comments made during review"
    cap label variable review_corrections "Corrections made during review"


    label variable empl_type "2,11: [ \${empl_name} ] : De quel type d'emploi s'agit-il :"
    note empl_type: "2,11: [ \${empl_name} ] : De quel type d'emploi s'agit-il :"
    label define empl_type 1 "Salarié / rémunéré agricole" 2 "Salarié / rémunéré non-agricole" 3 "Apprenti" -777 "Autre (à préciser)"
    label values empl_type empl_type

    label variable empl_type_o "2.11b[ \${empl_name} ] : Spécifier cet autre type d'emploi"
    note empl_type_o: "2.11b[ \${empl_name} ] : Spécifier cet autre type d'emploi"

    label variable empl_mos "2.12: Combien de mois \${empl_key_name} a-t-il/elle exercé cet emploi [ \${empl_"
    note empl_mos: "2.12: Combien de mois \${empl_key_name} a-t-il/elle exercé cet emploi [ \${empl_name} ] au cours des 12 derniers mois ?"

    label variable empl_wks "2.13: Combien de semaines par mois \${empl_key_name} consacre-t-il/elle habituel"
    note empl_wks: "2.13: Combien de semaines par mois \${empl_key_name} consacre-t-il/elle habituellement à cet emploi [ \${empl_name} ] ?"

    label variable empl_days "2.14: Combien de jours par semaine \${empl_key_name} consacre-t-il/elle habituel"
    note empl_days: "2.14: Combien de jours par semaine \${empl_key_name} consacre-t-il/elle habituellement à cet emploi [ \${empl_name} ] ?"

    label variable empl_rev30 "2.15: Quel a été son revenu pour cet emploi [ \${empl_name} ] au cours des 30 de"
    note empl_rev30: "2.15: Quel a été son revenu pour cet emploi [ \${empl_name} ] au cours des 30 derniers jours ?"

    label variable empl_rev12 "2.16: Quel a été le revenu de \${empl_key_name} pour cet emploi [ \${empl_name} "
    note empl_rev12: "2.16: Quel a été le revenu de \${empl_key_name} pour cet emploi [ \${empl_name} ] au cours des 12 derniers mois ?"






    * append old, previously-imported data (if any)
    cap confirm file "`dtafile'"
    if _rc == 0 {
        * mark all new data before merging with old data
        gen new_data_row=1
        
        * pull in old data
        append using "`dtafile'"
        
        * drop duplicates in favor of old, previously-imported data if overwrite_old_data is 0
        * (alternatively drop in favor of new data if overwrite_old_data is 1)
        sort key
        by key: gen num_for_key = _N
        drop if num_for_key > 1 & ((`overwrite_old_data' == 0 & new_data_row == 1) | (`overwrite_old_data' == 1 & new_data_row ~= 1))
        drop num_for_key

        * drop new-data flag
        drop new_data_row
    }
    
    * save data to Stata format
    save "`dtafile'", replace


}

disp
disp "Finished import of: `csvfile'"
disp

* OPTIONAL: LOCALLY-APPLIED STATA CORRECTIONS
*
* Rather than using SurveyCTO's review and correction workflow, the code below can apply a list of corrections
* listed in a local .csv file. Feel free to use, ignore, or delete this code.
*
*   Corrections file path and filename:  /users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-gp_empl_cond-rpt_sal_corrections.csv
*
*   Corrections file columns (in order): key, fieldname, value, notes

capture confirm file "`corrfile'"
if _rc==0 {
    disp
    disp "Starting application of corrections in: `corrfile'"
    disp

    * save primary data in memory
    preserve

    * load corrections
    insheet using "`corrfile'", names clear
    
    if _N>0 {
        * number all rows (with +1 offset so that it matches row numbers in Excel)
        gen rownum=_n+1
        
        * drop notes field (for information only)
        drop notes
        
        * make sure that all values are in string format to start
        gen origvalue=value
        tostring value, format(%100.0g) replace
        cap replace value="" if origvalue==.
        drop origvalue
        replace value=trim(value)
        
        * correct field names to match Stata field names (lowercase, drop -'s and .'s)
        replace fieldname=lower(subinstr(subinstr(fieldname,"-","",.),".","",.))
        
        * format date and date/time fields (taking account of possible wildcards for repeat groups)
        forvalues i = 1/100 {
            if "`datetime_fields`i''" ~= "" {
                foreach dtvar in `datetime_fields`i'' {
                    * skip fields that aren't yet in the data
                    cap unab dtvarignore : `dtvar'
                    if _rc==0 {
                        gen origvalue=value
                        replace value=string(clock(value,"DMYhms",2025),"%25.0g") if strmatch(fieldname,"`dtvar'")
                        * allow for cases where seconds haven't been specified
                        replace value=string(clock(origvalue,"DMYhm",2025),"%25.0g") if strmatch(fieldname,"`dtvar'") & value=="." & origvalue~="."
                        drop origvalue
                    }
            	}
			}
			if "`date_fields`i''" ~= "" {
				foreach dtvar in `date_fields`i'' {
					* skip fields that aren't yet in the data
					cap unab dtvarignore : `dtvar'
					if _rc==0 {
						replace value=string(clock(value,"DMY",2025),"%25.0g") if strmatch(fieldname,"`dtvar'")
					}
				}
			}
		}

		* write out a temp file with the commands necessary to apply each correction
		tempfile tempdo
		file open dofile using "`tempdo'", write replace
		local N = _N
		forvalues i = 1/`N' {
			local fieldnameval=fieldname[`i']
			local valueval=value[`i']
			local keyval=key[`i']
			local rownumval=rownum[`i']
			file write dofile `"cap replace `fieldnameval'="`valueval'" if key=="`keyval'""' _n
			file write dofile `"if _rc ~= 0 {"' _n
			if "`valueval'" == "" {
				file write dofile _tab `"cap replace `fieldnameval'=. if key=="`keyval'""' _n
			}
			else {
				file write dofile _tab `"cap replace `fieldnameval'=`valueval' if key=="`keyval'""' _n
			}
			file write dofile _tab `"if _rc ~= 0 {"' _n
			file write dofile _tab _tab `"disp"' _n
			file write dofile _tab _tab `"disp "CAN'T APPLY CORRECTION IN ROW #`rownumval'""' _n
			file write dofile _tab _tab `"disp"' _n
			file write dofile _tab `"}"' _n
			file write dofile `"}"' _n
		}
		file close dofile
	
		* restore primary data
		restore
		
		* execute the .do file to actually apply all corrections
		do "`tempdo'"

		* re-save data
		save "`dtafile'", replace
	}
	else {
		* restore primary data		
		restore
	}

	disp
	disp "Finished applying corrections in: `corrfile'"
	disp
}
