* import_niger_2023_Endline_Terrain-informed_consent-SECTION_AGR_NA-SECTION_na-rpt_agr_enum.do
*
*     Imports and aggregates "Niger 2023- Shock Response- ENDLINE-informed_consent-SECTION_AGR_NA-SECTION_na-rpt_agr_enum" (ID: niger_2023_Endline_Terrain) data.
*
*    Inputs:  "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-SECTION_AGR_NA-SECTION_na-rpt_agr_enum.csv"
*    Outputs: "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-SECTION_AGR_NA-SECTION_na-rpt_agr_enum.dta"
*
*    Output by SurveyCTO August 24, 2023 9:33 AM.

* initialize Stata
clear all
set more off
set mem 100m

* initialize workflow-specific parameters
*    Set overwrite_old_data to 1 if you use the review and correction
*    workflow and allow un-approving of submissions. If you do this,
*    incoming data will overwrite old data, so you won't want to make
*    changes to data in your local .dta file (such changes can be
*    overwritten with each new import).
local overwrite_old_data 0

* initialize form-specific parameters
local csvfile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-SECTION_AGR_NA-SECTION_na-rpt_agr_enum.csv"
local dtafile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-SECTION_AGR_NA-SECTION_na-rpt_agr_enum.dta"
local corrfile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-SECTION_AGR_NA-SECTION_na-rpt_agr_enum_corrections.csv"
local note_fields1 ""
local text_fields1 "agr_key_pos agr_key_name agr_key_rpos bus1_food_pos bus1_tail_pos bus1_constr_pos bus1_comm_pos bus1_prof_pos bus1_serv_pos bus1_trans_pos bus1_art_pos bus1_extra_pos bus_def_type_list act_n activity1"
local text_fields2 "activity2 activity3 activity4 activity5 activity6_type activity7 activity8 activity9 activity10 activity11 activity12 activity13 activity14 activity15 show_allactivity rpt_activitylist_count"
local date_fields1 ""
local datetime_fields1 ""

disp
disp "Starting import of: `csvfile'"
disp

* import data from primary .csv file
insheet using "`csvfile'", names clear

* drop extra table-list columns
cap drop reserved_name_for_field_*
cap drop generated_table_list_lab*

* continue only if there's at least one row of data to import
if _N>0 {
    * drop note fields (since they don't contain any real data)
    forvalues i = 1/100 {
        if "`note_fields`i''" ~= "" {
            drop `note_fields`i''
        }
    }
    
    * format date and date/time fields
    forvalues i = 1/100 {
        if "`datetime_fields`i''" ~= "" {
            foreach dtvarlist in `datetime_fields`i'' {
                cap unab dtvarlist : `dtvarlist'
                if _rc==0 {
                    foreach dtvar in `dtvarlist' {
                        tempvar tempdtvar
                        rename `dtvar' `tempdtvar'
                        gen double `dtvar'=.
                        cap replace `dtvar'=clock(`tempdtvar',"DMYhms",2025)
                        * automatically try without seconds, just in case
                        cap replace `dtvar'=clock(`tempdtvar',"DMYhm",2025) if `dtvar'==. & `tempdtvar'~=""
                        format %tc `dtvar'
                        drop `tempdtvar'
                    }
                }
            }
        }
        if "`date_fields`i''" ~= "" {
            foreach dtvarlist in `date_fields`i'' {
                cap unab dtvarlist : `dtvarlist'
                if _rc==0 {
                    foreach dtvar in `dtvarlist' {
                        tempvar tempdtvar
                        rename `dtvar' `tempdtvar'
                        gen double `dtvar'=.
                        cap replace `dtvar'=date(`tempdtvar',"DMY",2025)
                        format %td `dtvar'
                        drop `tempdtvar'
                    }
                }
            }
        }
    }

    * ensure that text fields are always imported as strings (with "" for missing values)
    * (note that we treat "calculate" fields as text; you can destring later if you wish)
    tempvar ismissingvar
    quietly: gen `ismissingvar'=.
    forvalues i = 1/100 {
        if "`text_fields`i''" ~= "" {
            foreach svarlist in `text_fields`i'' {
                cap unab svarlist : `svarlist'
                if _rc==0 {
                    foreach stringvar in `svarlist' {
                        quietly: replace `ismissingvar'=.
                        quietly: cap replace `ismissingvar'=1 if `stringvar'==.
                        cap tostring `stringvar', format(%100.0g) replace
                        cap replace `stringvar'="" if `ismissingvar'==1
                    }
                }
            }
        }
    }
    quietly: drop `ismissingvar'



    * label variables
    label variable key "Unique submission ID"
    cap label variable submissiondate "Date/time submitted"
    cap label variable formdef_version "Form version used on device"
    cap label variable review_status "Review status"
    cap label variable review_comments "Comments made during review"
    cap label variable review_corrections "Corrections made during review"


    label variable bus1_food "3.01: Au cours des 12 derniers mois, [\${agr_key_name}] a transformé des produit"
    note bus1_food: "3.01: Au cours des 12 derniers mois, [\${agr_key_name}] a transformé des produits agricoles ou de la viande pour les revendre (comme transformer de la farine pour faire des beignets; griller de la viande de boeuf, de mouton, ou du poulet; gérer un restaurant; fabriquer des jus de fruits -gingembre, bissap- pour vendre; vendre de l'eau glacée/de la glace, fabriquer de la bière de maïs ou de mil, boulangerie etc.) ? Combien de ces activités ?"

    label variable bus1_tail "3.02: Au cours des 12 derniers mois, [\${agr_key_name}] a possédé/exercé, à domi"
    note bus1_tail: "3.02: Au cours des 12 derniers mois, [\${agr_key_name}] a possédé/exercé, à domicile ou ailleurs, une petite activite de confection de vêtements (tailleur), de fabrication de sandales ou autres chaussures ? Combien de ces activités ?"

    label variable bus1_constr "3.03: Au cours des 12 derniers mois, [\${agr_key_name}] a possédé/exercé, à domi"
    note bus1_constr: "3.03: Au cours des 12 derniers mois, [\${agr_key_name}] a possédé/exercé, à domicile ou ailleurs, une activité travaillant dans le domaine de la construction de maisons (maçonnerie, électricité, plomberie, électricité) ou dans la menuiserie (fabrication de meubles, lits, portes, fenêtres) en bois ou en en métal tel que le fer ou l'aluminium? Combien de ces activités ?"

    label variable bus1_comm "3.04: Au cours des 12 derniers mois, [\${agr_key_name}] a possédé/exercé, à domi"
    note bus1_comm: "3.04: Au cours des 12 derniers mois, [\${agr_key_name}] a possédé/exercé, à domicile ou ailleurs, une activité de commerce (boutique, tablier, vente de matériaux de construction, achat-vente de céréales, de cartes téléphonique, de cigarettes ou de mélange au bord de la route, etc.)? Combien de ces activités ?"

    label variable bus1_prof "3.05: Au cours des 12 derniers mois, [\${agr_key_name}] a possédé ou exercé une "
    note bus1_prof: "3.05: Au cours des 12 derniers mois, [\${agr_key_name}] a possédé ou exercé une profession libérale pour son propre compte (pharmacien ayant son officine, traducteur ou interprète travaillant comme son propre patron, etc.) ou pratiquant de la médecine traditionnelle (marabout, féticheur, guérisseur traditionnel, tradi-praticien)? Combien de ces activités ?"

    label variable bus1_serv "3.06: Au cours des 12 derniers mois, [\${agr_key_name}] a possédé/exercé une act"
    note bus1_serv: "3.06: Au cours des 12 derniers mois, [\${agr_key_name}] a possédé/exercé une activité rendant tout autre service ; les services de réparation et d'entretien (voitures, motos, radios, ordinateurs, TV, frigo, climatiseurs, etc.); lavage de voitures; cireur de chaussures; cabine téléphonique, traitement de texte, photocopies de documents/secrétariat, etc.? Combien de ces activités ?"

    label variable bus1_trans "3.07: Au cours des 12 derniers mois, [\${agr_key_name}] a possédé un moyen de tr"
    note bus1_trans: "3.07: Au cours des 12 derniers mois, [\${agr_key_name}] a possédé un moyen de transport comme une activité ou pour une activité commerciale (charrette, taxi-brousse/moto-taxi/tricycle,…)? Combien de ces activités ?"

    label variable bus1_art "3.08: Au cours des 12 derniers mois, [\${agr_key_name}] a possédé/exercé une que"
    note bus1_art: "3.08: Au cours des 12 derniers mois, [\${agr_key_name}] a possédé/exercé une quelconque activité non agricole , même s'il s'agit d'une petite activité s'exerçant à domicile ou dans la rue (exemple : fabrication et la vente d'objets d'artisanat, de tapis, de bijoux, tressage de nattes, etc.), tressage de cheveux, salon de coiffure, etc. ? Combien de ces activités ?"

    label variable bus1_extra "3.09: Y a t-il d'autres activités que vous n'avez pas encore mentionné que [\${a"
    note bus1_extra: "3.09: Y a t-il d'autres activités que vous n'avez pas encore mentionné que [\${agr_key_name}] a possédé/exercé ? Combien de ces activités ?"

    label variable activity1 "Activité 1 : Nom descriptif"
    note activity1: "Activité 1 : Nom descriptif"

    label variable activity1_type "Activité 1 : Type"
    note activity1_type: "Activité 1 : Type"
    label define activity1_type -2 "agriculture" -1 "élevage" 1 "transformation de produits agricoles" 2 "confection de vêtements, chaussures" 3 "construction, menuiserie" 4 "commerce" 5 "Professional libérale" 6 "tout autre service" 7 "moyen de transport" 8 "quelconque activité non-agricole" 9 "autres activités"
    label values activity1_type activity1_type

    label variable activity2 "Activité 2 : Nom descriptif"
    note activity2: "Activité 2 : Nom descriptif"

    label variable activity2_type "Activité 2 : Type"
    note activity2_type: "Activité 2 : Type"
    label define activity2_type -2 "agriculture" -1 "élevage" 1 "transformation de produits agricoles" 2 "confection de vêtements, chaussures" 3 "construction, menuiserie" 4 "commerce" 5 "Professional libérale" 6 "tout autre service" 7 "moyen de transport" 8 "quelconque activité non-agricole" 9 "autres activités"
    label values activity2_type activity2_type

    label variable activity3 "Activité 3: Nom descriptif"
    note activity3: "Activité 3: Nom descriptif"

    label variable activity3_type "Activité 3 : Type"
    note activity3_type: "Activité 3 : Type"
    label define activity3_type -2 "agriculture" -1 "élevage" 1 "transformation de produits agricoles" 2 "confection de vêtements, chaussures" 3 "construction, menuiserie" 4 "commerce" 5 "Professional libérale" 6 "tout autre service" 7 "moyen de transport" 8 "quelconque activité non-agricole" 9 "autres activités"
    label values activity3_type activity3_type

    label variable activity4 "Activité 4 : Nom descriptif"
    note activity4: "Activité 4 : Nom descriptif"

    label variable activity4_type "Activité 4 : Type"
    note activity4_type: "Activité 4 : Type"
    label define activity4_type -2 "agriculture" -1 "élevage" 1 "transformation de produits agricoles" 2 "confection de vêtements, chaussures" 3 "construction, menuiserie" 4 "commerce" 5 "Professional libérale" 6 "tout autre service" 7 "moyen de transport" 8 "quelconque activité non-agricole" 9 "autres activités"
    label values activity4_type activity4_type

    label variable activity5 "Activité 5 : Nom descriptif"
    note activity5: "Activité 5 : Nom descriptif"

    label variable activity5_type "Activité 5 : Type"
    note activity5_type: "Activité 5 : Type"
    label define activity5_type -2 "agriculture" -1 "élevage" 1 "transformation de produits agricoles" 2 "confection de vêtements, chaussures" 3 "construction, menuiserie" 4 "commerce" 5 "Professional libérale" 6 "tout autre service" 7 "moyen de transport" 8 "quelconque activité non-agricole" 9 "autres activités"
    label values activity5_type activity5_type

    label variable activity6_type "Activité 6 : Nom descriptif"
    note activity6_type: "Activité 6 : Nom descriptif"

    label variable activity6 "Activité 6 : Type"
    note activity6: "Activité 6 : Type"
    label define activity6 -2 "agriculture" -1 "élevage" 1 "transformation de produits agricoles" 2 "confection de vêtements, chaussures" 3 "construction, menuiserie" 4 "commerce" 5 "Professional libérale" 6 "tout autre service" 7 "moyen de transport" 8 "quelconque activité non-agricole" 9 "autres activités"
    label values activity6 activity6

    label variable activity7 "Activité 7 : Nom descriptif"
    note activity7: "Activité 7 : Nom descriptif"

    label variable activity7_type "Activité 7 : Type"
    note activity7_type: "Activité 7 : Type"
    label define activity7_type -2 "agriculture" -1 "élevage" 1 "transformation de produits agricoles" 2 "confection de vêtements, chaussures" 3 "construction, menuiserie" 4 "commerce" 5 "Professional libérale" 6 "tout autre service" 7 "moyen de transport" 8 "quelconque activité non-agricole" 9 "autres activités"
    label values activity7_type activity7_type

    label variable activity8 "Activité 8 : Nom descriptif"
    note activity8: "Activité 8 : Nom descriptif"

    label variable activity8_type "Activité 8 : Type"
    note activity8_type: "Activité 8 : Type"
    label define activity8_type -2 "agriculture" -1 "élevage" 1 "transformation de produits agricoles" 2 "confection de vêtements, chaussures" 3 "construction, menuiserie" 4 "commerce" 5 "Professional libérale" 6 "tout autre service" 7 "moyen de transport" 8 "quelconque activité non-agricole" 9 "autres activités"
    label values activity8_type activity8_type

    label variable activity9 "Activité 9 : Nom descriptif"
    note activity9: "Activité 9 : Nom descriptif"

    label variable activity9_type "Activité 9 : Type"
    note activity9_type: "Activité 9 : Type"
    label define activity9_type -2 "agriculture" -1 "élevage" 1 "transformation de produits agricoles" 2 "confection de vêtements, chaussures" 3 "construction, menuiserie" 4 "commerce" 5 "Professional libérale" 6 "tout autre service" 7 "moyen de transport" 8 "quelconque activité non-agricole" 9 "autres activités"
    label values activity9_type activity9_type

    label variable activity10 "Activité 10 : Nom descriptif"
    note activity10: "Activité 10 : Nom descriptif"

    label variable activity10_type "Activité 10 : Type"
    note activity10_type: "Activité 10 : Type"
    label define activity10_type -2 "agriculture" -1 "élevage" 1 "transformation de produits agricoles" 2 "confection de vêtements, chaussures" 3 "construction, menuiserie" 4 "commerce" 5 "Professional libérale" 6 "tout autre service" 7 "moyen de transport" 8 "quelconque activité non-agricole" 9 "autres activités"
    label values activity10_type activity10_type

    label variable activity11 "Activité 11 : Nom descriptif"
    note activity11: "Activité 11 : Nom descriptif"

    label variable activity11_type "Activité 11 : Type"
    note activity11_type: "Activité 11 : Type"
    label define activity11_type -2 "agriculture" -1 "élevage" 1 "transformation de produits agricoles" 2 "confection de vêtements, chaussures" 3 "construction, menuiserie" 4 "commerce" 5 "Professional libérale" 6 "tout autre service" 7 "moyen de transport" 8 "quelconque activité non-agricole" 9 "autres activités"
    label values activity11_type activity11_type

    label variable activity12 "Activité 12 : Nom descriptif"
    note activity12: "Activité 12 : Nom descriptif"

    label variable activity12_type "Activité 12 : Type"
    note activity12_type: "Activité 12 : Type"
    label define activity12_type -2 "agriculture" -1 "élevage" 1 "transformation de produits agricoles" 2 "confection de vêtements, chaussures" 3 "construction, menuiserie" 4 "commerce" 5 "Professional libérale" 6 "tout autre service" 7 "moyen de transport" 8 "quelconque activité non-agricole" 9 "autres activités"
    label values activity12_type activity12_type

    label variable activity13 "Activité 13 : Nom descriptif"
    note activity13: "Activité 13 : Nom descriptif"

    label variable activity13_type "Activité 13 : Type"
    note activity13_type: "Activité 13 : Type"
    label define activity13_type -2 "agriculture" -1 "élevage" 1 "transformation de produits agricoles" 2 "confection de vêtements, chaussures" 3 "construction, menuiserie" 4 "commerce" 5 "Professional libérale" 6 "tout autre service" 7 "moyen de transport" 8 "quelconque activité non-agricole" 9 "autres activités"
    label values activity13_type activity13_type

    label variable activity14 "Activité 14 : Nom descriptif"
    note activity14: "Activité 14 : Nom descriptif"

    label variable activity14_type "Activité 14 : Type"
    note activity14_type: "Activité 14 : Type"
    label define activity14_type -2 "agriculture" -1 "élevage" 1 "transformation de produits agricoles" 2 "confection de vêtements, chaussures" 3 "construction, menuiserie" 4 "commerce" 5 "Professional libérale" 6 "tout autre service" 7 "moyen de transport" 8 "quelconque activité non-agricole" 9 "autres activités"
    label values activity14_type activity14_type

    label variable activity15 "Activité 15 : Nom descriptif"
    note activity15: "Activité 15 : Nom descriptif"

    label variable activity15_type "Activité 15 : Type"
    note activity15_type: "Activité 15 : Type"
    label define activity15_type -2 "agriculture" -1 "élevage" 1 "transformation de produits agricoles" 2 "confection de vêtements, chaussures" 3 "construction, menuiserie" 4 "commerce" 5 "Professional libérale" 6 "tout autre service" 7 "moyen de transport" 8 "quelconque activité non-agricole" 9 "autres activités"
    label values activity15_type activity15_type

    label variable show_allactivity "Voici la liste des AGR de \${agr_key_name}"
    note show_allactivity: "Voici la liste des AGR de \${agr_key_name}"






    * append old, previously-imported data (if any)
    cap confirm file "`dtafile'"
    if _rc == 0 {
        * mark all new data before merging with old data
        gen new_data_row=1
        
        * pull in old data
        append using "`dtafile'"
        
        * drop duplicates in favor of old, previously-imported data if overwrite_old_data is 0
        * (alternatively drop in favor of new data if overwrite_old_data is 1)
        sort key
        by key: gen num_for_key = _N
        drop if num_for_key > 1 & ((`overwrite_old_data' == 0 & new_data_row == 1) | (`overwrite_old_data' == 1 & new_data_row ~= 1))
        drop num_for_key

        * drop new-data flag
        drop new_data_row
    }
    
    * save data to Stata format
    save "`dtafile'", replace


}

disp
disp "Finished import of: `csvfile'"
disp

* OPTIONAL: LOCALLY-APPLIED STATA CORRECTIONS
*
* Rather than using SurveyCTO's review and correction workflow, the code below can apply a list of corrections
* listed in a local .csv file. Feel free to use, ignore, or delete this code.
*
*   Corrections file path and filename:  /users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-SECTION_AGR_NA-SECTION_na-rpt_agr_enum_corrections.csv
*
*   Corrections file columns (in order): key, fieldname, value, notes

capture confirm file "`corrfile'"
if _rc==0 {
    disp
    disp "Starting application of corrections in: `corrfile'"
    disp

    * save primary data in memory
    preserve

    * load corrections
    insheet using "`corrfile'", names clear
    
    if _N>0 {
        * number all rows (with +1 offset so that it matches row numbers in Excel)
        gen rownum=_n+1
        
        * drop notes field (for information only)
        drop notes
        
        * make sure that all values are in string format to start
        gen origvalue=value
        tostring value, format(%100.0g) replace
        cap replace value="" if origvalue==.
        drop origvalue
        replace value=trim(value)
        
        * correct field names to match Stata field names (lowercase, drop -'s and .'s)
        replace fieldname=lower(subinstr(subinstr(fieldname,"-","",.),".","",.))
        
        * format date and date/time fields (taking account of possible wildcards for repeat groups)
        forvalues i = 1/100 {
            if "`datetime_fields`i''" ~= "" {
                foreach dtvar in `datetime_fields`i'' {
                    * skip fields that aren't yet in the data
                    cap unab dtvarignore : `dtvar'
                    if _rc==0 {
                        gen origvalue=value
                        replace value=string(clock(value,"DMYhms",2025),"%25.0g") if strmatch(fieldname,"`dtvar'")
                        * allow for cases where seconds haven't been specified
                        replace value=string(clock(origvalue,"DMYhm",2025),"%25.0g") if strmatch(fieldname,"`dtvar'") & value=="." & origvalue~="."
                        drop origvalue
                    }
                }
            }
            if "`date_fields`i''" ~= "" {
                foreach dtvar in `date_fields`i'' {
                    * skip fields that aren't yet in the data
                    cap unab dtvarignore : `dtvar'
                    if _rc==0 {
                        replace value=string(clock(value,"DMY",2025),"%25.0g") if strmatch(fieldname,"`dtvar'")
                    }
                }
            }
        }

        * write out a temp file with the commands necessary to apply each correction
        tempfile tempdo
        file open dofile using "`tempdo'", write replace
        local N = _N
        forvalues i = 1/`N' {
            local fieldnameval=fieldname[`i']
            local valueval=value[`i']
            local keyval=key[`i']
            local rownumval=rownum[`i']
            file write dofile `"cap replace `fieldnameval'="`valueval'" if key=="`keyval'""' _n
            file write dofile `"if _rc ~= 0 {"' _n
            if "`valueval'" == "" {
                file write dofile _tab `"cap replace `fieldnameval'=. if key=="`keyval'""' _n
            }
            else {
                file write dofile _tab `"cap replace `fieldnameval'=`valueval' if key=="`keyval'""' _n
            }
            file write dofile _tab `"if _rc ~= 0 {"' _n
            file write dofile _tab _tab `"disp"' _n
            file write dofile _tab _tab `"disp "CAN'T APPLY CORRECTION IN ROW #`rownumval'""' _n
            file write dofile _tab _tab `"disp"' _n
            file write dofile _tab `"}"' _n
            file write dofile `"}"' _n
        }
        file close dofile
    
        * restore primary data
        restore
        
        * execute the .do file to actually apply all corrections
        do "`tempdo'"

        * re-save data
        save "`dtafile'", replace
    }
    else {
        * restore primary data        
        restore
    }

    disp
    disp "Finished applying corrections in: `corrfile'"
    disp
}
