* import_niger_2023_Endline_Terrain-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_cropsrain1-rpt_plotrain.do
*
*     Imports and aggregates "Niger 2023- Shock Response- ENDLINE-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_cropsrain1-rpt_plotrain" (ID: niger_2023_Endline_Terrain) data.
*
*    Inputs:  "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_cropsrain1-rpt_plotrain.csv"
*    Outputs: "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_cropsrain1-rpt_plotrain.dta"
*
*    Output by SurveyCTO August 24, 2023 9:33 AM.

* initialize Stata
clear all
set more off
set mem 100m

* initialize workflow-specific parameters
*    Set overwrite_old_data to 1 if you use the review and correction
*    workflow and allow un-approving of submissions. If you do this,
*    incoming data will overwrite old data, so you won't want to make
*    changes to data in your local .dta file (such changes can be
*    overwritten with each new import).
local overwrite_old_data 0

* initialize form-specific parameters
local csvfile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_cropsrain1-rpt_plotrain.csv"
local dtafile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_cropsrain1-rpt_plotrain.dta"
local corrfile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_cropsrain1-rpt_plotrain_corrections.csv"
local note_fields1 ""
local text_fields1 "rain_plot_name rcrop1_o rcrop2_o rcrop3_o rcrop4_o rcrop5_o rcrop6_o rcrop7_o rcrop8_o rcrop9_o rcrop10_o raincodeorother1 raincodeorother2 raincodeorother3 raincodeorother4 raincodeorother5"
local text_fields2 "raincodeorother6 raincodeorother7 raincodeorother8 raincodeorother9 raincodeorother10 rcropname1 rcropname2 rcropname3 rcropname4 rcropname5 rcropname6 rcropname7 rcropname8 rcropname9 rcropname10"
local text_fields3 "rpt_rcrops_count plot_rain_grew plot_rain_harv plot_rain_sold"
local date_fields1 ""
local datetime_fields1 ""

disp
disp "Starting import of: `csvfile'"
disp

* import data from primary .csv file
insheet using "`csvfile'", names clear

* drop extra table-list columns
cap drop reserved_name_for_field_*
cap drop generated_table_list_lab*

* continue only if there's at least one row of data to import
if _N>0 {
    * drop note fields (since they don't contain any real data)
    forvalues i = 1/100 {
        if "`note_fields`i''" ~= "" {
            drop `note_fields`i''
        }
    }
    
    * format date and date/time fields
    forvalues i = 1/100 {
        if "`datetime_fields`i''" ~= "" {
            foreach dtvarlist in `datetime_fields`i'' {
                cap unab dtvarlist : `dtvarlist'
                if _rc==0 {
                    foreach dtvar in `dtvarlist' {
                        tempvar tempdtvar
                        rename `dtvar' `tempdtvar'
                        gen double `dtvar'=.
                        cap replace `dtvar'=clock(`tempdtvar',"DMYhms",2025)
                        * automatically try without seconds, just in case
                        cap replace `dtvar'=clock(`tempdtvar',"DMYhm",2025) if `dtvar'==. & `tempdtvar'~=""
                        format %tc `dtvar'
                        drop `tempdtvar'
                    }
                }
            }
        }
        if "`date_fields`i''" ~= "" {
            foreach dtvarlist in `date_fields`i'' {
                cap unab dtvarlist : `dtvarlist'
                if _rc==0 {
                    foreach dtvar in `dtvarlist' {
                        tempvar tempdtvar
                        rename `dtvar' `tempdtvar'
                        gen double `dtvar'=.
                        cap replace `dtvar'=date(`tempdtvar',"DMY",2025)
                        format %td `dtvar'
                        drop `tempdtvar'
                    }
                }
            }
        }
    }

    * ensure that text fields are always imported as strings (with "" for missing values)
    * (note that we treat "calculate" fields as text; you can destring later if you wish)
    tempvar ismissingvar
    quietly: gen `ismissingvar'=.
    forvalues i = 1/100 {
        if "`text_fields`i''" ~= "" {
            foreach svarlist in `text_fields`i'' {
                cap unab svarlist : `svarlist'
                if _rc==0 {
                    foreach stringvar in `svarlist' {
                        quietly: replace `ismissingvar'=.
                        quietly: cap replace `ismissingvar'=1 if `stringvar'==.
                        cap tostring `stringvar', format(%100.0g) replace
                        cap replace `stringvar'="" if `ismissingvar'==1
                    }
                }
            }
        }
    }
    quietly: drop `ismissingvar'



    * label variables
    label variable key "Unique submission ID"
    cap label variable submissiondate "Date/time submitted"
    cap label variable formdef_version "Form version used on device"
    cap label variable review_status "Review status"
    cap label variable review_comments "Comments made during review"
    cap label variable review_corrections "Corrections made during review"


    label variable rcrop_n "12,12 Parcelle [\${rain_plot_name}] : ENQUETEUR : Combien de cultures (annuelles"
    note rcrop_n: "12,12 Parcelle [\${rain_plot_name}] : ENQUETEUR : Combien de cultures (annuelles) ont été cultivées sur cette parcelle pendant la saison des pluies ?"

    label variable rcrop1 "Culture 1 :"
    note rcrop1: "Culture 1 :"
    label define rcrop1 36 "Ail" 42 "Amarante-(Tchapata)" 10 "Arachide" 32 "Aubergine" 44 "Betterave" 6 "Blé" 38 "Calebassier" 30 "Carotte" 22 "Céleri" 28 "Chou" 34 "Concombre" 43 "Coton" 35 "Courge" 21 "Epinard" 7 "Fonio" 18 "Gingembre" 19 "Girofle" 11 "Gombo" 37 "Haricot-vert" 47 "Igname" 31 "Jaxatu" 27 "Laitue/salade" 4 "Maïs" 14 "Manioc" 25 "Melon" 20 "Menthe" 1 "Mil" 40 "Navet" 8 "Niébé" 33 "Oignon" 12 "Oseille" 26 "Pastèque" 15 "Patate-douce" 23 "Persil" 45 "Petits-pois" 24 "Piment" 41 "Poireaux" 17 "Poivron" 16 "Pomme-de-terre" 39 "Radis" 3 "Riz-Paddy" 13 "Sésame" 2 "Sorgho" 5 "Souchet" 46 "Taro" 29 "Tomate" 9 "Voandzou" 50 "Morenga (kopto)" -777 "Autre (à préciser)"
    label values rcrop1 rcrop1

    label variable rcrop2 "Culture 2 :"
    note rcrop2: "Culture 2 :"
    label define rcrop2 36 "Ail" 42 "Amarante-(Tchapata)" 10 "Arachide" 32 "Aubergine" 44 "Betterave" 6 "Blé" 38 "Calebassier" 30 "Carotte" 22 "Céleri" 28 "Chou" 34 "Concombre" 43 "Coton" 35 "Courge" 21 "Epinard" 7 "Fonio" 18 "Gingembre" 19 "Girofle" 11 "Gombo" 37 "Haricot-vert" 47 "Igname" 31 "Jaxatu" 27 "Laitue/salade" 4 "Maïs" 14 "Manioc" 25 "Melon" 20 "Menthe" 1 "Mil" 40 "Navet" 8 "Niébé" 33 "Oignon" 12 "Oseille" 26 "Pastèque" 15 "Patate-douce" 23 "Persil" 45 "Petits-pois" 24 "Piment" 41 "Poireaux" 17 "Poivron" 16 "Pomme-de-terre" 39 "Radis" 3 "Riz-Paddy" 13 "Sésame" 2 "Sorgho" 5 "Souchet" 46 "Taro" 29 "Tomate" 9 "Voandzou" 50 "Morenga (kopto)" -777 "Autre (à préciser)"
    label values rcrop2 rcrop2

    label variable rcrop3 "Culture 3 :"
    note rcrop3: "Culture 3 :"
    label define rcrop3 36 "Ail" 42 "Amarante-(Tchapata)" 10 "Arachide" 32 "Aubergine" 44 "Betterave" 6 "Blé" 38 "Calebassier" 30 "Carotte" 22 "Céleri" 28 "Chou" 34 "Concombre" 43 "Coton" 35 "Courge" 21 "Epinard" 7 "Fonio" 18 "Gingembre" 19 "Girofle" 11 "Gombo" 37 "Haricot-vert" 47 "Igname" 31 "Jaxatu" 27 "Laitue/salade" 4 "Maïs" 14 "Manioc" 25 "Melon" 20 "Menthe" 1 "Mil" 40 "Navet" 8 "Niébé" 33 "Oignon" 12 "Oseille" 26 "Pastèque" 15 "Patate-douce" 23 "Persil" 45 "Petits-pois" 24 "Piment" 41 "Poireaux" 17 "Poivron" 16 "Pomme-de-terre" 39 "Radis" 3 "Riz-Paddy" 13 "Sésame" 2 "Sorgho" 5 "Souchet" 46 "Taro" 29 "Tomate" 9 "Voandzou" 50 "Morenga (kopto)" -777 "Autre (à préciser)"
    label values rcrop3 rcrop3

    label variable rcrop4 "Culture 4 :"
    note rcrop4: "Culture 4 :"
    label define rcrop4 36 "Ail" 42 "Amarante-(Tchapata)" 10 "Arachide" 32 "Aubergine" 44 "Betterave" 6 "Blé" 38 "Calebassier" 30 "Carotte" 22 "Céleri" 28 "Chou" 34 "Concombre" 43 "Coton" 35 "Courge" 21 "Epinard" 7 "Fonio" 18 "Gingembre" 19 "Girofle" 11 "Gombo" 37 "Haricot-vert" 47 "Igname" 31 "Jaxatu" 27 "Laitue/salade" 4 "Maïs" 14 "Manioc" 25 "Melon" 20 "Menthe" 1 "Mil" 40 "Navet" 8 "Niébé" 33 "Oignon" 12 "Oseille" 26 "Pastèque" 15 "Patate-douce" 23 "Persil" 45 "Petits-pois" 24 "Piment" 41 "Poireaux" 17 "Poivron" 16 "Pomme-de-terre" 39 "Radis" 3 "Riz-Paddy" 13 "Sésame" 2 "Sorgho" 5 "Souchet" 46 "Taro" 29 "Tomate" 9 "Voandzou" 50 "Morenga (kopto)" -777 "Autre (à préciser)"
    label values rcrop4 rcrop4

    label variable rcrop5 "Culture 5 :"
    note rcrop5: "Culture 5 :"
    label define rcrop5 36 "Ail" 42 "Amarante-(Tchapata)" 10 "Arachide" 32 "Aubergine" 44 "Betterave" 6 "Blé" 38 "Calebassier" 30 "Carotte" 22 "Céleri" 28 "Chou" 34 "Concombre" 43 "Coton" 35 "Courge" 21 "Epinard" 7 "Fonio" 18 "Gingembre" 19 "Girofle" 11 "Gombo" 37 "Haricot-vert" 47 "Igname" 31 "Jaxatu" 27 "Laitue/salade" 4 "Maïs" 14 "Manioc" 25 "Melon" 20 "Menthe" 1 "Mil" 40 "Navet" 8 "Niébé" 33 "Oignon" 12 "Oseille" 26 "Pastèque" 15 "Patate-douce" 23 "Persil" 45 "Petits-pois" 24 "Piment" 41 "Poireaux" 17 "Poivron" 16 "Pomme-de-terre" 39 "Radis" 3 "Riz-Paddy" 13 "Sésame" 2 "Sorgho" 5 "Souchet" 46 "Taro" 29 "Tomate" 9 "Voandzou" 50 "Morenga (kopto)" -777 "Autre (à préciser)"
    label values rcrop5 rcrop5

    label variable rcrop6 "Culture 6 :"
    note rcrop6: "Culture 6 :"
    label define rcrop6 36 "Ail" 42 "Amarante-(Tchapata)" 10 "Arachide" 32 "Aubergine" 44 "Betterave" 6 "Blé" 38 "Calebassier" 30 "Carotte" 22 "Céleri" 28 "Chou" 34 "Concombre" 43 "Coton" 35 "Courge" 21 "Epinard" 7 "Fonio" 18 "Gingembre" 19 "Girofle" 11 "Gombo" 37 "Haricot-vert" 47 "Igname" 31 "Jaxatu" 27 "Laitue/salade" 4 "Maïs" 14 "Manioc" 25 "Melon" 20 "Menthe" 1 "Mil" 40 "Navet" 8 "Niébé" 33 "Oignon" 12 "Oseille" 26 "Pastèque" 15 "Patate-douce" 23 "Persil" 45 "Petits-pois" 24 "Piment" 41 "Poireaux" 17 "Poivron" 16 "Pomme-de-terre" 39 "Radis" 3 "Riz-Paddy" 13 "Sésame" 2 "Sorgho" 5 "Souchet" 46 "Taro" 29 "Tomate" 9 "Voandzou" 50 "Morenga (kopto)" -777 "Autre (à préciser)"
    label values rcrop6 rcrop6

    label variable rcrop7 "Culture 7 :"
    note rcrop7: "Culture 7 :"
    label define rcrop7 36 "Ail" 42 "Amarante-(Tchapata)" 10 "Arachide" 32 "Aubergine" 44 "Betterave" 6 "Blé" 38 "Calebassier" 30 "Carotte" 22 "Céleri" 28 "Chou" 34 "Concombre" 43 "Coton" 35 "Courge" 21 "Epinard" 7 "Fonio" 18 "Gingembre" 19 "Girofle" 11 "Gombo" 37 "Haricot-vert" 47 "Igname" 31 "Jaxatu" 27 "Laitue/salade" 4 "Maïs" 14 "Manioc" 25 "Melon" 20 "Menthe" 1 "Mil" 40 "Navet" 8 "Niébé" 33 "Oignon" 12 "Oseille" 26 "Pastèque" 15 "Patate-douce" 23 "Persil" 45 "Petits-pois" 24 "Piment" 41 "Poireaux" 17 "Poivron" 16 "Pomme-de-terre" 39 "Radis" 3 "Riz-Paddy" 13 "Sésame" 2 "Sorgho" 5 "Souchet" 46 "Taro" 29 "Tomate" 9 "Voandzou" 50 "Morenga (kopto)" -777 "Autre (à préciser)"
    label values rcrop7 rcrop7

    label variable rcrop8 "Culture 8 :"
    note rcrop8: "Culture 8 :"
    label define rcrop8 36 "Ail" 42 "Amarante-(Tchapata)" 10 "Arachide" 32 "Aubergine" 44 "Betterave" 6 "Blé" 38 "Calebassier" 30 "Carotte" 22 "Céleri" 28 "Chou" 34 "Concombre" 43 "Coton" 35 "Courge" 21 "Epinard" 7 "Fonio" 18 "Gingembre" 19 "Girofle" 11 "Gombo" 37 "Haricot-vert" 47 "Igname" 31 "Jaxatu" 27 "Laitue/salade" 4 "Maïs" 14 "Manioc" 25 "Melon" 20 "Menthe" 1 "Mil" 40 "Navet" 8 "Niébé" 33 "Oignon" 12 "Oseille" 26 "Pastèque" 15 "Patate-douce" 23 "Persil" 45 "Petits-pois" 24 "Piment" 41 "Poireaux" 17 "Poivron" 16 "Pomme-de-terre" 39 "Radis" 3 "Riz-Paddy" 13 "Sésame" 2 "Sorgho" 5 "Souchet" 46 "Taro" 29 "Tomate" 9 "Voandzou" 50 "Morenga (kopto)" -777 "Autre (à préciser)"
    label values rcrop8 rcrop8

    label variable rcrop9 "Culture 9 :"
    note rcrop9: "Culture 9 :"
    label define rcrop9 36 "Ail" 42 "Amarante-(Tchapata)" 10 "Arachide" 32 "Aubergine" 44 "Betterave" 6 "Blé" 38 "Calebassier" 30 "Carotte" 22 "Céleri" 28 "Chou" 34 "Concombre" 43 "Coton" 35 "Courge" 21 "Epinard" 7 "Fonio" 18 "Gingembre" 19 "Girofle" 11 "Gombo" 37 "Haricot-vert" 47 "Igname" 31 "Jaxatu" 27 "Laitue/salade" 4 "Maïs" 14 "Manioc" 25 "Melon" 20 "Menthe" 1 "Mil" 40 "Navet" 8 "Niébé" 33 "Oignon" 12 "Oseille" 26 "Pastèque" 15 "Patate-douce" 23 "Persil" 45 "Petits-pois" 24 "Piment" 41 "Poireaux" 17 "Poivron" 16 "Pomme-de-terre" 39 "Radis" 3 "Riz-Paddy" 13 "Sésame" 2 "Sorgho" 5 "Souchet" 46 "Taro" 29 "Tomate" 9 "Voandzou" 50 "Morenga (kopto)" -777 "Autre (à préciser)"
    label values rcrop9 rcrop9

    label variable rcrop10 "Culture 10 :"
    note rcrop10: "Culture 10 :"
    label define rcrop10 36 "Ail" 42 "Amarante-(Tchapata)" 10 "Arachide" 32 "Aubergine" 44 "Betterave" 6 "Blé" 38 "Calebassier" 30 "Carotte" 22 "Céleri" 28 "Chou" 34 "Concombre" 43 "Coton" 35 "Courge" 21 "Epinard" 7 "Fonio" 18 "Gingembre" 19 "Girofle" 11 "Gombo" 37 "Haricot-vert" 47 "Igname" 31 "Jaxatu" 27 "Laitue/salade" 4 "Maïs" 14 "Manioc" 25 "Melon" 20 "Menthe" 1 "Mil" 40 "Navet" 8 "Niébé" 33 "Oignon" 12 "Oseille" 26 "Pastèque" 15 "Patate-douce" 23 "Persil" 45 "Petits-pois" 24 "Piment" 41 "Poireaux" 17 "Poivron" 16 "Pomme-de-terre" 39 "Radis" 3 "Riz-Paddy" 13 "Sésame" 2 "Sorgho" 5 "Souchet" 46 "Taro" 29 "Tomate" 9 "Voandzou" 50 "Morenga (kopto)" -777 "Autre (à préciser)"
    label values rcrop10 rcrop10

    label variable rcrop1_o "Autre Culture 1 :"
    note rcrop1_o: "Autre Culture 1 :"

    label variable rcrop2_o "Autre Culture 2 :"
    note rcrop2_o: "Autre Culture 2 :"

    label variable rcrop3_o "Autre Culture 3 :"
    note rcrop3_o: "Autre Culture 3 :"

    label variable rcrop4_o "Autre Culture 4 :"
    note rcrop4_o: "Autre Culture 4 :"

    label variable rcrop5_o "Autre Culture 5 :"
    note rcrop5_o: "Autre Culture 5 :"

    label variable rcrop6_o "Autre Culture 6 :"
    note rcrop6_o: "Autre Culture 6 :"

    label variable rcrop7_o "Autre Culture 7 :"
    note rcrop7_o: "Autre Culture 7 :"

    label variable rcrop8_o "Autre Culture 8 :"
    note rcrop8_o: "Autre Culture 8 :"

    label variable rcrop9_o "Autre Culture 9 :"
    note rcrop9_o: "Autre Culture 9 :"

    label variable rcrop10_o "Autre Culture 10 :"
    note rcrop10_o: "Autre Culture 10 :"






    * append old, previously-imported data (if any)
    cap confirm file "`dtafile'"
    if _rc == 0 {
        * mark all new data before merging with old data
        gen new_data_row=1
        
        * pull in old data
        append using "`dtafile'"
        
        * drop duplicates in favor of old, previously-imported data if overwrite_old_data is 0
        * (alternatively drop in favor of new data if overwrite_old_data is 1)
        sort key
        by key: gen num_for_key = _N
        drop if num_for_key > 1 & ((`overwrite_old_data' == 0 & new_data_row == 1) | (`overwrite_old_data' == 1 & new_data_row ~= 1))
        drop num_for_key

        * drop new-data flag
        drop new_data_row
    }
    
    * save data to Stata format
    save "`dtafile'", replace


}

disp
disp "Finished import of: `csvfile'"
disp

* OPTIONAL: LOCALLY-APPLIED STATA CORRECTIONS
*
* Rather than using SurveyCTO's review and correction workflow, the code below can apply a list of corrections
* listed in a local .csv file. Feel free to use, ignore, or delete this code.
*
*   Corrections file path and filename:  /users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_cropsrain1-rpt_plotrain_corrections.csv
*
*   Corrections file columns (in order): key, fieldname, value, notes

capture confirm file "`corrfile'"
if _rc==0 {
    disp
    disp "Starting application of corrections in: `corrfile'"
    disp

    * save primary data in memory
    preserve

    * load corrections
    insheet using "`corrfile'", names clear
    
    if _N>0 {
        * number all rows (with +1 offset so that it matches row numbers in Excel)
        gen rownum=_n+1
        
        * drop notes field (for information only)
        drop notes
        
        * make sure that all values are in string format to start
        gen origvalue=value
        tostring value, format(%100.0g) replace
        cap replace value="" if origvalue==.
        drop origvalue
        replace value=trim(value)
        
        * correct field names to match Stata field names (lowercase, drop -'s and .'s)
        replace fieldname=lower(subinstr(subinstr(fieldname,"-","",.),".","",.))
        
        * format date and date/time fields (taking account of possible wildcards for repeat groups)
        forvalues i = 1/100 {
            if "`datetime_fields`i''" ~= "" {
                foreach dtvar in `datetime_fields`i'' {
                    * skip fields that aren't yet in the data
                    cap unab dtvarignore : `dtvar'
                    if _rc==0 {
                        gen origvalue=value
                        replace value=string(clock(value,"DMYhms",2025),"%25.0g") if strmatch(fieldname,"`dtvar'")
                        * allow for cases where seconds haven't been specified
                        replace value=string(clock(origvalue,"DMYhm",2025),"%25.0g") if strmatch(fieldname,"`dtvar'") & value=="." & origvalue~="."
                        drop origvalue
                    }
                }
            }
            if "`date_fields`i''" ~= "" {
                foreach dtvar in `date_fields`i'' {
                    * skip fields that aren't yet in the data
                    cap unab dtvarignore : `dtvar'
                    if _rc==0 {
                        replace value=string(clock(value,"DMY",2025),"%25.0g") if strmatch(fieldname,"`dtvar'")
                    }
                }
            }
        }

        * write out a temp file with the commands necessary to apply each correction
        tempfile tempdo
        file open dofile using "`tempdo'", write replace
        local N = _N
        forvalues i = 1/`N' {
            local fieldnameval=fieldname[`i']
            local valueval=value[`i']
            local keyval=key[`i']
            local rownumval=rownum[`i']
            file write dofile `"cap replace `fieldnameval'="`valueval'" if key=="`keyval'""' _n
            file write dofile `"if _rc ~= 0 {"' _n
            if "`valueval'" == "" {
                file write dofile _tab `"cap replace `fieldnameval'=. if key=="`keyval'""' _n
            }
            else {
                file write dofile _tab `"cap replace `fieldnameval'=`valueval' if key=="`keyval'""' _n
            }
            file write dofile _tab `"if _rc ~= 0 {"' _n
            file write dofile _tab _tab `"disp"' _n
            file write dofile _tab _tab `"disp "CAN'T APPLY CORRECTION IN ROW #`rownumval'""' _n
            file write dofile _tab _tab `"disp"' _n
            file write dofile _tab `"}"' _n
            file write dofile `"}"' _n
        }
        file close dofile
    
        * restore primary data
        restore
        
        * execute the .do file to actually apply all corrections
        do "`tempdo'"

        * re-save data
        save "`dtafile'", replace
    }
    else {
        * restore primary data        
        restore
    }

    disp
    disp "Finished applying corrections in: `corrfile'"
    disp
}
