* import_niger_2023_Endline_Terrain-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_plot-rpt_plots.do
*
*     Imports and aggregates "Niger 2023- Shock Response- ENDLINE-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_plot-rpt_plots" (ID: niger_2023_Endline_Terrain) data.
*
*    Inputs:  "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_plot-rpt_plots.csv"
*    Outputs: "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_plot-rpt_plots.dta"
*
*    Output by SurveyCTO August 24, 2023 9:33 AM.

* initialize Stata
clear all
set more off
set mem 100m

* initialize workflow-specific parameters
*    Set overwrite_old_data to 1 if you use the review and correction
*    workflow and allow un-approving of submissions. If you do this,
*    incoming data will overwrite old data, so you won't want to make
*    changes to data in your local .dta file (such changes can be
*    overwritten with each new import).
local overwrite_old_data 0

* initialize form-specific parameters
local csvfile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_plot-rpt_plots.csv"
local dtafile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_plot-rpt_plots.dta"
local corrfile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_plot-rpt_plots_corrections.csv"
local note_fields1 ""
local text_fields1 "plot_pos plot_name plot_ha plot_man plot_owner plot_key plot_israin plotpos_israinandkey plot_isdry plotpos_isdryandkey plot_worked"
local date_fields1 ""
local datetime_fields1 ""

disp
disp "Starting import of: `csvfile'"
disp

* import data from primary .csv file
insheet using "`csvfile'", names clear

* drop extra table-list columns
cap drop reserved_name_for_field_*
cap drop generated_table_list_lab*

* continue only if there's at least one row of data to import
if _N>0 {
    * drop note fields (since they don't contain any real data)
    forvalues i = 1/100 {
        if "`note_fields`i''" ~= "" {
            drop `note_fields`i''
        }
    }
    
    * format date and date/time fields
    forvalues i = 1/100 {
        if "`datetime_fields`i''" ~= "" {
            foreach dtvarlist in `datetime_fields`i'' {
                cap unab dtvarlist : `dtvarlist'
                if _rc==0 {
                    foreach dtvar in `dtvarlist' {
                        tempvar tempdtvar
                        rename `dtvar' `tempdtvar'
                        gen double `dtvar'=.
                        cap replace `dtvar'=clock(`tempdtvar',"DMYhms",2025)
                        * automatically try without seconds, just in case
                        cap replace `dtvar'=clock(`tempdtvar',"DMYhm",2025) if `dtvar'==. & `tempdtvar'~=""
                        format %tc `dtvar'
                        drop `tempdtvar'
                    }
                }
            }
        }
        if "`date_fields`i''" ~= "" {
            foreach dtvarlist in `date_fields`i'' {
                cap unab dtvarlist : `dtvarlist'
                if _rc==0 {
                    foreach dtvar in `dtvarlist' {
                        tempvar tempdtvar
                        rename `dtvar' `tempdtvar'
                        gen double `dtvar'=.
                        cap replace `dtvar'=date(`tempdtvar',"DMY",2025)
                        format %td `dtvar'
                        drop `tempdtvar'
                    }
                }
            }
        }
    }

    * ensure that text fields are always imported as strings (with "" for missing values)
    * (note that we treat "calculate" fields as text; you can destring later if you wish)
    tempvar ismissingvar
    quietly: gen `ismissingvar'=.
    forvalues i = 1/100 {
        if "`text_fields`i''" ~= "" {
            foreach svarlist in `text_fields`i'' {
                cap unab svarlist : `svarlist'
                if _rc==0 {
                    foreach stringvar in `svarlist' {
                        quietly: replace `ismissingvar'=.
                        quietly: cap replace `ismissingvar'=1 if `stringvar'==.
                        cap tostring `stringvar', format(%100.0g) replace
                        cap replace `stringvar'="" if `ismissingvar'==1
                    }
                }
            }
        }
    }
    quietly: drop `ismissingvar'



    * label variables
    label variable key "Unique submission ID"
    cap label variable submissiondate "Date/time submitted"
    cap label variable formdef_version "Form version used on device"
    cap label variable review_status "Review status"
    cap label variable review_comments "Comments made during review"
    cap label variable review_corrections "Corrections made during review"


    label variable plot_size "Nombre"
    note plot_size: "Nombre"

    label variable plot_size_u "Unité"
    note plot_size_u: "Unité"
    label define plot_size_u 1 "Hectare" 2 "Mètres carrés"
    label values plot_size_u plot_size_u

    label variable plot_man "12.04 Parcelle [\${plot_name}] : Qui gére la parcelle (qui décide quoi cultiver,"
    note plot_man: "12.04 Parcelle [\${plot_name}] : Qui gére la parcelle (qui décide quoi cultiver, quand le cultiver, les intrants etc.) ?"

    label variable plot_owner "12.05 Parcelle [\${plot_name}] : Qui est le propriétaire de la parcelle?"
    note plot_owner: "12.05 Parcelle [\${plot_name}] : Qui est le propriétaire de la parcelle?"

    label variable plot_season "12.06 Parcelle [\${plot_name}] : Est-ce que cette parcelle a été cultivée pendan"
    note plot_season: "12.06 Parcelle [\${plot_name}] : Est-ce que cette parcelle a été cultivée pendant la saison des pluies 2022, la saison sèche 2022-2023, ou les deux saisons ?"
    label define plot_season 1 "la saison des pluies 2022 (seulement)" 2 "la saison sèche 2022-2023 (seulement)" 3 "les deux saisons"
    label values plot_season plot_season

    label variable plot_worked "12.08: Parcelle [\${plot_name}] : Qui dans le ménage a travaillé sur cette parce"
    note plot_worked: "12.08: Parcelle [\${plot_name}] : Qui dans le ménage a travaillé sur cette parcelle au cours de la saison des pluies ?"

    label variable days_mem1 "\${firstname_mem1}, Age : \${age_mem1}"
    note days_mem1: "\${firstname_mem1}, Age : \${age_mem1}"

    label variable days_mem2 "\${firstname_mem2}, Age : \${age_mem2}"
    note days_mem2: "\${firstname_mem2}, Age : \${age_mem2}"

    label variable days_mem3 "\${firstname_mem3}, Age : \${age_mem3}"
    note days_mem3: "\${firstname_mem3}, Age : \${age_mem3}"

    label variable days_mem4 "\${firstname_mem4}, Age : \${age_mem4}"
    note days_mem4: "\${firstname_mem4}, Age : \${age_mem4}"

    label variable days_mem5 "\${firstname_mem5}, Age : \${age_mem5}"
    note days_mem5: "\${firstname_mem5}, Age : \${age_mem5}"

    label variable days_mem6 "\${firstname_mem6}, Age : \${age_mem6}"
    note days_mem6: "\${firstname_mem6}, Age : \${age_mem6}"

    label variable days_mem7 "\${firstname_mem7}, Age : \${age_mem7}"
    note days_mem7: "\${firstname_mem7}, Age : \${age_mem7}"

    label variable days_mem8 "\${firstname_mem8}, Age : \${age_mem8}"
    note days_mem8: "\${firstname_mem8}, Age : \${age_mem8}"

    label variable days_mem9 "\${firstname_mem9}, Age : \${age_mem9}"
    note days_mem9: "\${firstname_mem9}, Age : \${age_mem9}"

    label variable days_mem10 "\${firstname_mem10}, Age : \${age_mem10}"
    note days_mem10: "\${firstname_mem10}, Age : \${age_mem10}"

    label variable days_mem11 "\${firstname_mem11}, Age : \${age_mem11}"
    note days_mem11: "\${firstname_mem11}, Age : \${age_mem11}"

    label variable days_mem12 "\${firstname_mem12}, Age : \${age_mem12}"
    note days_mem12: "\${firstname_mem12}, Age : \${age_mem12}"

    label variable days_mem13 "\${firstname_mem13}, Age : \${age_mem13}"
    note days_mem13: "\${firstname_mem13}, Age : \${age_mem13}"

    label variable days_mem14 "\${firstname_mem14}, Age : \${age_mem14}"
    note days_mem14: "\${firstname_mem14}, Age : \${age_mem14}"

    label variable days_mem15 "\${firstname_mem15}, Age : \${age_mem15}"
    note days_mem15: "\${firstname_mem15}, Age : \${age_mem15}"

    label variable days_mem16 "\${firstname_mem16}, Age : \${age_mem16}"
    note days_mem16: "\${firstname_mem16}, Age : \${age_mem16}"

    label variable days_mem17 "\${firstname_mem17}, Age : \${age_mem17}"
    note days_mem17: "\${firstname_mem17}, Age : \${age_mem17}"

    label variable days_mem18 "\${firstname_mem18}, Age : \${age_mem18}"
    note days_mem18: "\${firstname_mem18}, Age : \${age_mem18}"

    label variable days_mem19 "\${firstname_mem19}, Age : \${age_mem19}"
    note days_mem19: "\${firstname_mem19}, Age : \${age_mem19}"

    label variable days_mem20 "\${firstname_mem20}, Age : \${age_mem20}"
    note days_mem20: "\${firstname_mem20}, Age : \${age_mem20}"

    label variable days_mem21 "\${firstname_mem21}, Age : \${age_mem21}"
    note days_mem21: "\${firstname_mem21}, Age : \${age_mem21}"

    label variable days_mem22 "\${firstname_mem22}, Age : \${age_mem22}"
    note days_mem22: "\${firstname_mem22}, Age : \${age_mem22}"

    label variable days_mem23 "\${firstname_mem23}, Age : \${age_mem23}"
    note days_mem23: "\${firstname_mem23}, Age : \${age_mem23}"

    label variable days_mem24 "\${firstname_mem24}, Age : \${age_mem24}"
    note days_mem24: "\${firstname_mem24}, Age : \${age_mem24}"

    label variable days_mem25 "\${firstname_mem25}, Age : \${age_mem25}"
    note days_mem25: "\${firstname_mem25}, Age : \${age_mem25}"

    label variable days_mem26 "\${firstname_mem26}, Age : \${age_mem26}"
    note days_mem26: "\${firstname_mem26}, Age : \${age_mem26}"

    label variable days_mem27 "\${firstname_mem27}, Age : \${age_mem27}"
    note days_mem27: "\${firstname_mem27}, Age : \${age_mem27}"

    label variable days_mem28 "\${firstname_mem28}, Age : \${age_mem28}"
    note days_mem28: "\${firstname_mem28}, Age : \${age_mem28}"

    label variable days_mem29 "\${firstname_mem29}, Age : \${age_mem29}"
    note days_mem29: "\${firstname_mem29}, Age : \${age_mem29}"

    label variable days_mem30 "\${firstname_mem30}, Age : \${age_mem30}"
    note days_mem30: "\${firstname_mem30}, Age : \${age_mem30}"

    label variable days_mem31 "\${firstname_mem31}, Age : \${age_mem31}"
    note days_mem31: "\${firstname_mem31}, Age : \${age_mem31}"

    label variable days_mem32 "\${firstname_mem32}, Age : \${age_mem32}"
    note days_mem32: "\${firstname_mem32}, Age : \${age_mem32}"

    label variable days_mem33 "\${firstname_mem33}, Age : \${age_mem33}"
    note days_mem33: "\${firstname_mem33}, Age : \${age_mem33}"

    label variable days_mem34 "\${firstname_mem34}, Age : \${age_mem34}"
    note days_mem34: "\${firstname_mem34}, Age : \${age_mem34}"

    label variable days_mem35 "\${firstname_mem35}, Age : \${age_mem35}"
    note days_mem35: "\${firstname_mem35}, Age : \${age_mem35}"

    label variable days_mem36 "\${firstname_mem36}, Age : \${age_mem36}"
    note days_mem36: "\${firstname_mem36}, Age : \${age_mem36}"

    label variable days_mem37 "\${firstname_mem37}, Age : \${age_mem37}"
    note days_mem37: "\${firstname_mem37}, Age : \${age_mem37}"

    label variable days_mem38 "\${firstname_mem38}, Age : \${age_mem38}"
    note days_mem38: "\${firstname_mem38}, Age : \${age_mem38}"

    label variable days_mem39 "\${firstname_mem39}, Age : \${age_mem39}"
    note days_mem39: "\${firstname_mem39}, Age : \${age_mem39}"

    label variable days_mem40 "\${firstname_mem40}, Age : \${age_mem40}"
    note days_mem40: "\${firstname_mem40}, Age : \${age_mem40}"

    label variable days_mem41 "\${firstname_mem41}, Age : \${age_mem41}"
    note days_mem41: "\${firstname_mem41}, Age : \${age_mem41}"

    label variable days_mem42 "\${firstname_mem42}, Age : \${age_mem42}"
    note days_mem42: "\${firstname_mem42}, Age : \${age_mem42}"

    label variable days_mem43 "\${firstname_mem43}, Age : \${age_mem43}"
    note days_mem43: "\${firstname_mem43}, Age : \${age_mem43}"

    label variable days_mem44 "\${firstname_mem44}, Age : \${age_mem44}"
    note days_mem44: "\${firstname_mem44}, Age : \${age_mem44}"

    label variable days_mem45 "\${firstname_mem45}, Age : \${age_mem45}"
    note days_mem45: "\${firstname_mem45}, Age : \${age_mem45}"

    label variable days_mem46 "\${firstname_mem46}, Age : \${age_mem46}"
    note days_mem46: "\${firstname_mem46}, Age : \${age_mem46}"

    label variable days_mem47 "\${firstname_mem47}, Age : \${age_mem47}"
    note days_mem47: "\${firstname_mem47}, Age : \${age_mem47}"

    label variable days_mem48 "\${firstname_mem48}, Age : \${age_mem48}"
    note days_mem48: "\${firstname_mem48}, Age : \${age_mem48}"

    label variable days_mem49 "\${firstname_mem49}, Age : \${age_mem49}"
    note days_mem49: "\${firstname_mem49}, Age : \${age_mem49}"

    label variable days_mem50 "\${firstname_mem50}, Age : \${age_mem50}"
    note days_mem50: "\${firstname_mem50}, Age : \${age_mem50}"






    * append old, previously-imported data (if any)
    cap confirm file "`dtafile'"
    if _rc == 0 {
        * mark all new data before merging with old data
        gen new_data_row=1
        
        * pull in old data
        append using "`dtafile'"
        
        * drop duplicates in favor of old, previously-imported data if overwrite_old_data is 0
        * (alternatively drop in favor of new data if overwrite_old_data is 1)
        sort key
        by key: gen num_for_key = _N
        drop if num_for_key > 1 & ((`overwrite_old_data' == 0 & new_data_row == 1) | (`overwrite_old_data' == 1 & new_data_row ~= 1))
        drop num_for_key

        * drop new-data flag
        drop new_data_row
    }
    
    * save data to Stata format
    save "`dtafile'", replace


}

disp
disp "Finished import of: `csvfile'"
disp

* OPTIONAL: LOCALLY-APPLIED STATA CORRECTIONS
*
* Rather than using SurveyCTO's review and correction workflow, the code below can apply a list of corrections
* listed in a local .csv file. Feel free to use, ignore, or delete this code.
*
*   Corrections file path and filename:  /users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_plot-rpt_plots_corrections.csv
*
*   Corrections file columns (in order): key, fieldname, value, notes

capture confirm file "`corrfile'"
if _rc==0 {
    disp
    disp "Starting application of corrections in: `corrfile'"
    disp

    * save primary data in memory
    preserve

    * load corrections
    insheet using "`corrfile'", names clear
    
    if _N>0 {
        * number all rows (with +1 offset so that it matches row numbers in Excel)
        gen rownum=_n+1
        
        * drop notes field (for information only)
        drop notes
        
        * make sure that all values are in string format to start
        gen origvalue=value
        tostring value, format(%100.0g) replace
        cap replace value="" if origvalue==.
        drop origvalue
        replace value=trim(value)
        
        * correct field names to match Stata field names (lowercase, drop -'s and .'s)
        replace fieldname=lower(subinstr(subinstr(fieldname,"-","",.),".","",.))
        
        * format date and date/time fields (taking account of possible wildcards for repeat groups)
        forvalues i = 1/100 {
            if "`datetime_fields`i''" ~= "" {
                foreach dtvar in `datetime_fields`i'' {
                    * skip fields that aren't yet in the data
                    cap unab dtvarignore : `dtvar'
                    if _rc==0 {
                        gen origvalue=value
                        replace value=string(clock(value,"DMYhms",2025),"%25.0g") if strmatch(fieldname,"`dtvar'")
                        * allow for cases where seconds haven't been specified
                        replace value=string(clock(origvalue,"DMYhm",2025),"%25.0g") if strmatch(fieldname,"`dtvar'") & value=="." & origvalue~="."
                        drop origvalue
                    }
                }
            }
            if "`date_fields`i''" ~= "" {
                foreach dtvar in `date_fields`i'' {
                    * skip fields that aren't yet in the data
                    cap unab dtvarignore : `dtvar'
                    if _rc==0 {
                        replace value=string(clock(value,"DMY",2025),"%25.0g") if strmatch(fieldname,"`dtvar'")
                    }
                }
            }
        }

        * write out a temp file with the commands necessary to apply each correction
        tempfile tempdo
        file open dofile using "`tempdo'", write replace
        local N = _N
        forvalues i = 1/`N' {
            local fieldnameval=fieldname[`i']
            local valueval=value[`i']
            local keyval=key[`i']
            local rownumval=rownum[`i']
            file write dofile `"cap replace `fieldnameval'="`valueval'" if key=="`keyval'""' _n
            file write dofile `"if _rc ~= 0 {"' _n
            if "`valueval'" == "" {
                file write dofile _tab `"cap replace `fieldnameval'=. if key=="`keyval'""' _n
            }
            else {
                file write dofile _tab `"cap replace `fieldnameval'=`valueval' if key=="`keyval'""' _n
            }
            file write dofile _tab `"if _rc ~= 0 {"' _n
            file write dofile _tab _tab `"disp"' _n
            file write dofile _tab _tab `"disp "CAN'T APPLY CORRECTION IN ROW #`rownumval'""' _n
            file write dofile _tab _tab `"disp"' _n
            file write dofile _tab `"}"' _n
            file write dofile `"}"' _n
        }
        file close dofile
    
        * restore primary data
        restore
        
        * execute the .do file to actually apply all corrections
        do "`tempdo'"

        * re-save data
        save "`dtafile'", replace
    }
    else {
        * restore primary data        
        restore
    }

    disp
    disp "Finished applying corrections in: `corrfile'"
    disp
}
