* import_niger_2023_Endline_Terrain-informed_consent-mod_c_hh_roster-hh_roster_new.do
*
*     Imports and aggregates "Niger 2023- Shock Response- ENDLINE-informed_consent-mod_c_hh_roster-hh_roster_new" (ID: niger_2023_Endline_Terrain) data.
*
*    Inputs:  "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_c_hh_roster-hh_roster_new.csv"
*    Outputs: "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_c_hh_roster-hh_roster_new.dta"
*
*    Output by SurveyCTO August 24, 2023 9:33 AM.

* initialize Stata
clear all
set more off
set mem 100m

* initialize workflow-specific parameters
*    Set overwrite_old_data to 1 if you use the review and correction
*    workflow and allow un-approving of submissions. If you do this,
*    incoming data will overwrite old data, so you won't want to make
*    changes to data in your local .dta file (such changes can be
*    overwritten with each new import).
local overwrite_old_data 0

* initialize form-specific parameters
local csvfile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_c_hh_roster-hh_roster_new.csv"
local dtafile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_c_hh_roster-hh_roster_new.dta"
local corrfile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_c_hh_roster-hh_roster_new_corrections.csv"
local note_fields1 ""
local text_fields1 "mem_id pull_fullname pull_firstname pull_lastname pull_sex pull_rel_to_hhh pull_age pull_mem_id_old hh_old_confirmed hh_new fname lname current_name sex_repeat_o months birthdate age1 age m_age"
local text_fields2 "age_repeat rel_to_hhh_other rel_to_hhh_txt age_calc posif_here posif_chef posif_spouse is_chef fullname_ifadult is_woman is_adult is_adultresp is_child baby_pos child2_pos children_pos"
local text_fields3 "fullname_ifchild"
local date_fields1 ""
local datetime_fields1 ""

disp
disp "Starting import of: `csvfile'"
disp

* import data from primary .csv file
insheet using "`csvfile'", names clear

* drop extra table-list columns
cap drop reserved_name_for_field_*
cap drop generated_table_list_lab*

* continue only if there's at least one row of data to import
if _N>0 {
    * drop note fields (since they don't contain any real data)
    forvalues i = 1/100 {
        if "`note_fields`i''" ~= "" {
            drop `note_fields`i''
        }
    }
    
    * format date and date/time fields
    forvalues i = 1/100 {
        if "`datetime_fields`i''" ~= "" {
            foreach dtvarlist in `datetime_fields`i'' {
                cap unab dtvarlist : `dtvarlist'
                if _rc==0 {
                    foreach dtvar in `dtvarlist' {
                        tempvar tempdtvar
                        rename `dtvar' `tempdtvar'
                        gen double `dtvar'=.
                        cap replace `dtvar'=clock(`tempdtvar',"DMYhms",2025)
                        * automatically try without seconds, just in case
                        cap replace `dtvar'=clock(`tempdtvar',"DMYhm",2025) if `dtvar'==. & `tempdtvar'~=""
                        format %tc `dtvar'
                        drop `tempdtvar'
                    }
                }
            }
        }
        if "`date_fields`i''" ~= "" {
            foreach dtvarlist in `date_fields`i'' {
                cap unab dtvarlist : `dtvarlist'
                if _rc==0 {
                    foreach dtvar in `dtvarlist' {
                        tempvar tempdtvar
                        rename `dtvar' `tempdtvar'
                        gen double `dtvar'=.
                        cap replace `dtvar'=date(`tempdtvar',"DMY",2025)
                        format %td `dtvar'
                        drop `tempdtvar'
                    }
                }
            }
        }
    }

    * ensure that text fields are always imported as strings (with "" for missing values)
    * (note that we treat "calculate" fields as text; you can destring later if you wish)
    tempvar ismissingvar
    quietly: gen `ismissingvar'=.
    forvalues i = 1/100 {
        if "`text_fields`i''" ~= "" {
            foreach svarlist in `text_fields`i'' {
                cap unab svarlist : `svarlist'
                if _rc==0 {
                    foreach stringvar in `svarlist' {
                        quietly: replace `ismissingvar'=.
                        quietly: cap replace `ismissingvar'=1 if `stringvar'==.
                        cap tostring `stringvar', format(%100.0g) replace
                        cap replace `stringvar'="" if `ismissingvar'==1
                    }
                }
            }
        }
    }
    quietly: drop `ismissingvar'



    * label variables
    label variable key "Unique submission ID"
    cap label variable submissiondate "Date/time submitted"
    cap label variable formdef_version "Form version used on device"
    cap label variable review_status "Review status"
    cap label variable review_comments "Comments made during review"
    cap label variable review_corrections "Corrections made during review"


    label variable fname "C3_1: Prénom:"
    note fname: "C3_1: Prénom:"

    label variable lname "Nom de famille:"
    note lname: "Nom de famille:"

    label variable sex_repeat "C4_1: Sexe de \${current_name}"
    note sex_repeat: "C4_1: Sexe de \${current_name}"
    label define sex_repeat 0 "Masculin" 1 "Féminin" -66 "Préfère ne pas le dire" -88 "Autre, veuillez préciser"
    label values sex_repeat sex_repeat

    label variable sex_repeat_o "C4_1b: Préciser"
    note sex_repeat_o: "C4_1b: Préciser"

    label variable birthyear "C5_1: Année de naissance de \${current_name} :"
    note birthyear: "C5_1: Année de naissance de \${current_name} :"

    label variable birthmonth "C6_1: Mois de naissance de \${current_name} :"
    note birthmonth: "C6_1: Mois de naissance de \${current_name} :"
    label define birthmonth 1 "Janvier" 2 "Février" 3 "Mars" 4 "Avril" 5 "Mai" 6 "Juin" 7 "Juillet" 8 "Août" 9 "Septembre" 10 "Octobre" 11 "Novembre" 12 "Décembre" -66 "-66 (Refus de répondre)" -99 "-99 (Ne sait pas)"
    label values birthmonth birthmonth

    label variable age_approx "C7_1: Quel âge a \${current_name} approximativement (en années révolues)?"
    note age_approx: "C7_1: Quel âge a \${current_name} approximativement (en années révolues)?"

    label variable rel_to_hhh "C8_1: Quel est le lien de parenté de \${current_name} avec le chef de ménage?"
    note rel_to_hhh: "C8_1: Quel est le lien de parenté de \${current_name} avec le chef de ménage?"
    label define rel_to_hhh 1 "Chef de ménage" 2 "1ère épouse du chef de ménage" 3 "2ème épouse du chef de ménage" 4 "3ème épouse du chef de ménage" 5 "4ème épouse du chef de ménage" 19 "Coépouse" 6 "Fils/Fille du chef de ménage" 7 "Père/Mère" 8 "Petit fils/fille" 9 "Grand père/mère" 10 "Frère/Sœur du chef de ménage" 20 "Conjoint du fils / fille (gendre/belle-fille)" 21 "Conjoint de frère/sœur (beau-frère/belle-soeur)" 22 "Père/Mère de conjoint(e) (Beau Père/Belle Mère)" 11 "Beau fils/fille" 12 "Neveu/Nièce" 13 "Cousin/Cousine" 14 "Beau frère/Belle sœur" 15 "Beau père/Belle mère" 16 "Autres parents du chef de ménage ou de son épouse" 17 "Personne sans lien de parenté avec le chef de ménage" 18 "Domestique ou parent du domestique" -777 "Autre à spécifier"
    label values rel_to_hhh rel_to_hhh

    label variable rel_to_hhh_other "C8_2: Préciser son lien de parenté avec le chef de ménage:"
    note rel_to_hhh_other: "C8_2: Préciser son lien de parenté avec le chef de ménage:"

    label variable newmem_why "C8_3 Pourquoi \${current_name} n’était pas enregistré(e) comme membre de votre m"
    note newmem_why: "C8_3 Pourquoi \${current_name} n’était pas enregistré(e) comme membre de votre ménage lors de la dernière collecte ?"
    label define newmem_why 1 "est né(e) après la dernière collecte" 2 "n’habitait pas ici au moment de la dernière collecte" 3 "était en voyage ou en exode lors de la dernière collecte" 4 "habitait ici, mais la liste est incomplète"
    label values newmem_why newmem_why

    label variable age_warning "Vous avez indiqué que \${current_name} est âgé de moins de 18 ans alors que le m"
    note age_warning: "Vous avez indiqué que \${current_name} est âgé de moins de 18 ans alors que le membre est \${rel_to_hhh_txt} du chef de menage. Etes-vous sûr que c'est correct ?"
    label define age_warning 1 "oui" 0 "non"
    label values age_warning age_warning






    * append old, previously-imported data (if any)
    cap confirm file "`dtafile'"
    if _rc == 0 {
        * mark all new data before merging with old data
        gen new_data_row=1
        
        * pull in old data
        append using "`dtafile'"
        
        * drop duplicates in favor of old, previously-imported data if overwrite_old_data is 0
        * (alternatively drop in favor of new data if overwrite_old_data is 1)
        sort key
        by key: gen num_for_key = _N
        drop if num_for_key > 1 & ((`overwrite_old_data' == 0 & new_data_row == 1) | (`overwrite_old_data' == 1 & new_data_row ~= 1))
        drop num_for_key

        * drop new-data flag
        drop new_data_row
    }
    
    * save data to Stata format
    save "`dtafile'", replace


}

disp
disp "Finished import of: `csvfile'"
disp

* OPTIONAL: LOCALLY-APPLIED STATA CORRECTIONS
*
* Rather than using SurveyCTO's review and correction workflow, the code below can apply a list of corrections
* listed in a local .csv file. Feel free to use, ignore, or delete this code.
*
*   Corrections file path and filename:  /users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_c_hh_roster-hh_roster_new_corrections.csv
*
*   Corrections file columns (in order): key, fieldname, value, notes

capture confirm file "`corrfile'"
if _rc==0 {
    disp
    disp "Starting application of corrections in: `corrfile'"
    disp

    * save primary data in memory
    preserve

    * load corrections
    insheet using "`corrfile'", names clear
    
    if _N>0 {
        * number all rows (with +1 offset so that it matches row numbers in Excel)
        gen rownum=_n+1
        
        * drop notes field (for information only)
        drop notes
        
        * make sure that all values are in string format to start
        gen origvalue=value
        tostring value, format(%100.0g) replace
        cap replace value="" if origvalue==.
        drop origvalue
        replace value=trim(value)
        
        * correct field names to match Stata field names (lowercase, drop -'s and .'s)
        replace fieldname=lower(subinstr(subinstr(fieldname,"-","",.),".","",.))
        
        * format date and date/time fields (taking account of possible wildcards for repeat groups)
        forvalues i = 1/100 {
            if "`datetime_fields`i''" ~= "" {
                foreach dtvar in `datetime_fields`i'' {
                    * skip fields that aren't yet in the data
                    cap unab dtvarignore : `dtvar'
                    if _rc==0 {
                        gen origvalue=value
                        replace value=string(clock(value,"DMYhms",2025),"%25.0g") if strmatch(fieldname,"`dtvar'")
                        * allow for cases where seconds haven't been specified
                        replace value=string(clock(origvalue,"DMYhm",2025),"%25.0g") if strmatch(fieldname,"`dtvar'") & value=="." & origvalue~="."
                        drop origvalue
                    }
                }
            }
            if "`date_fields`i''" ~= "" {
                foreach dtvar in `date_fields`i'' {
                    * skip fields that aren't yet in the data
                    cap unab dtvarignore : `dtvar'
                    if _rc==0 {
                        replace value=string(clock(value,"DMY",2025),"%25.0g") if strmatch(fieldname,"`dtvar'")
                    }
                }
            }
        }

        * write out a temp file with the commands necessary to apply each correction
        tempfile tempdo
        file open dofile using "`tempdo'", write replace
        local N = _N
        forvalues i = 1/`N' {
            local fieldnameval=fieldname[`i']
            local valueval=value[`i']
            local keyval=key[`i']
            local rownumval=rownum[`i']
            file write dofile `"cap replace `fieldnameval'="`valueval'" if key=="`keyval'""' _n
            file write dofile `"if _rc ~= 0 {"' _n
            if "`valueval'" == "" {
                file write dofile _tab `"cap replace `fieldnameval'=. if key=="`keyval'""' _n
            }
            else {
                file write dofile _tab `"cap replace `fieldnameval'=`valueval' if key=="`keyval'""' _n
            }
            file write dofile _tab `"if _rc ~= 0 {"' _n
            file write dofile _tab _tab `"disp"' _n
            file write dofile _tab _tab `"disp "CAN'T APPLY CORRECTION IN ROW #`rownumval'""' _n
            file write dofile _tab _tab `"disp"' _n
            file write dofile _tab `"}"' _n
            file write dofile `"}"' _n
        }
        file close dofile
    
        * restore primary data
        restore
        
        * execute the .do file to actually apply all corrections
        do "`tempdo'"

        * re-save data
        save "`dtafile'", replace
    }
    else {
        * restore primary data        
        restore
    }

    disp
    disp "Finished applying corrections in: `corrfile'"
    disp
}
