* import_niger_2023_Endline_Terrain-informed_consent-mod_c_hh_roster-rpt_caregiver.do
*
*     Imports and aggregates "Niger 2023- Shock Response- ENDLINE-informed_consent-mod_c_hh_roster-rpt_caregiver" (ID: niger_2023_Endline_Terrain) data.
*
*    Inputs:  "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_c_hh_roster-rpt_caregiver.csv"
*    Outputs: "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_c_hh_roster-rpt_caregiver.dta"
*
*    Output by SurveyCTO August 24, 2023 9:33 AM.

* initialize Stata
clear all
set more off
set mem 100m

* initialize workflow-specific parameters
*    Set overwrite_old_data to 1 if you use the review and correction
*    workflow and allow un-approving of submissions. If you do this,
*    incoming data will overwrite old data, so you won't want to make
*    changes to data in your local .dta file (such changes can be
*    overwritten with each new import).
local overwrite_old_data 0

* initialize form-specific parameters
local csvfile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_c_hh_roster-rpt_caregiver.csv"
local dtafile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_c_hh_roster-rpt_caregiver.dta"
local corrfile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_c_hh_roster-rpt_caregiver_corrections.csv"
local note_fields1 ""
local text_fields1 "children_age children_pos2 children_name"
local date_fields1 ""
local datetime_fields1 ""

disp
disp "Starting import of: `csvfile'"
disp

* import data from primary .csv file
insheet using "`csvfile'", names clear

* drop extra table-list columns
cap drop reserved_name_for_field_*
cap drop generated_table_list_lab*

* continue only if there's at least one row of data to import
if _N>0 {
    * drop note fields (since they don't contain any real data)
    forvalues i = 1/100 {
        if "`note_fields`i''" ~= "" {
            drop `note_fields`i''
        }
    }
    
    * format date and date/time fields
    forvalues i = 1/100 {
        if "`datetime_fields`i''" ~= "" {
            foreach dtvarlist in `datetime_fields`i'' {
                cap unab dtvarlist : `dtvarlist'
                if _rc==0 {
                    foreach dtvar in `dtvarlist' {
                        tempvar tempdtvar
                        rename `dtvar' `tempdtvar'
                        gen double `dtvar'=.
                        cap replace `dtvar'=clock(`tempdtvar',"DMYhms",2025)
                        * automatically try without seconds, just in case
                        cap replace `dtvar'=clock(`tempdtvar',"DMYhm",2025) if `dtvar'==. & `tempdtvar'~=""
                        format %tc `dtvar'
                        drop `tempdtvar'
                    }
                }
            }
        }
        if "`date_fields`i''" ~= "" {
            foreach dtvarlist in `date_fields`i'' {
                cap unab dtvarlist : `dtvarlist'
                if _rc==0 {
                    foreach dtvar in `dtvarlist' {
                        tempvar tempdtvar
                        rename `dtvar' `tempdtvar'
                        gen double `dtvar'=.
                        cap replace `dtvar'=date(`tempdtvar',"DMY",2025)
                        format %td `dtvar'
                        drop `tempdtvar'
                    }
                }
            }
        }
    }

    * ensure that text fields are always imported as strings (with "" for missing values)
    * (note that we treat "calculate" fields as text; you can destring later if you wish)
    tempvar ismissingvar
    quietly: gen `ismissingvar'=.
    forvalues i = 1/100 {
        if "`text_fields`i''" ~= "" {
            foreach svarlist in `text_fields`i'' {
                cap unab svarlist : `svarlist'
                if _rc==0 {
                    foreach stringvar in `svarlist' {
                        quietly: replace `ismissingvar'=.
                        quietly: cap replace `ismissingvar'=1 if `stringvar'==.
                        cap tostring `stringvar', format(%100.0g) replace
                        cap replace `stringvar'="" if `ismissingvar'==1
                    }
                }
            }
        }
    }
    quietly: drop `ismissingvar'



    * label variables
    label variable key "Unique submission ID"
    cap label variable submissiondate "Date/time submitted"
    cap label variable formdef_version "Form version used on device"
    cap label variable review_status "Review status"
    cap label variable review_comments "Comments made during review"
    cap label variable review_corrections "Corrections made during review"


    label variable mom_alive "1.10a : La mère de [\${children_name}(Age \${children_age})] est-elle en vie?"
    note mom_alive: "1.10a : La mère de [\${children_name}(Age \${children_age})] est-elle en vie?"
    label define mom_alive 1 "oui" 0 "non"
    label values mom_alive mom_alive

    label variable mom_house "1.10b : La mère de [\${children_name}(Age \${children_age})] habite-t-elle dans "
    note mom_house: "1.10b : La mère de [\${children_name}(Age \${children_age})] habite-t-elle dans le ménage?"
    label define mom_house 1 "oui" 0 "non"
    label values mom_house mom_house

    label variable mom_who "1.10c : Qui est la mère de[\${children_name}(Age \${children_age})] ?"
    note mom_who: "1.10c : Qui est la mère de[\${children_name}(Age \${children_age})] ?"
    label define mom_who -5 "[décédé.e]" -4 "[ne fait pas partie du ménage]" -2 "Personne" -1 "Tous les membres du ménage" 0 "Personnes hors du ménage" 1 "\${fullname1} (Age: \${age_1} , pos 1)" 2 "\${fullname2} (Age: \${age_2} , pos 2)" 3 "\${fullname3} (Age: \${age_3} , pos 3)" 4 "\${fullname4} (Age: \${age_4} , pos 4)" 5 "\${fullname5} (Age: \${age_5} , pos 5)" 6 "\${fullname6} (Age: \${age_6} , pos 6)" 7 "\${fullname7} (Age: \${age_7} , pos 7)" 8 "\${fullname8} (Age: \${age_8} , pos 8)" 9 "\${fullname9} (Age: \${age_9} , pos 9)" 10 "\${fullname10} (Age: \${age_10} , pos 10)" 11 "\${fullname11} (Age: \${age_11} , pos 11)" 12 "\${fullname12} (Age: \${age_12} , pos 12)" 13 "\${fullname13} (Age: \${age_13} , pos 13)" 14 "\${fullname14} (Age: \${age_14} , pos 14)" 15 "\${fullname15} (Age: \${age_15} , pos 15)" 16 "\${fullname16} (Age: \${age_16} , pos 16)" 17 "\${fullname17} (Age: \${age_17} , pos 17)" 18 "\${fullname18} (Age: \${age_18} , pos 18)" 19 "\${fullname19} (Age: \${age_19} , pos 19)" 20 "\${fullname20} (Age: \${age_20} , pos 20)" 21 "\${fullname21} (Age: \${age_21} , pos 21)" 22 "\${fullname22} (Age: \${age_22} , pos 22)" 23 "\${fullname23} (Age: \${age_23} , pos 23)" 24 "\${fullname24} (Age: \${age_24} , pos 24)" 25 "\${fullname25} (Age: \${age_25} , pos 25)" 26 "\${fullname26} (Age: \${age_26} , pos 26)" 27 "\${fullname27} (Age: \${age_27} , pos 27)" 28 "\${fullname28} (Age: \${age_28} , pos 28)" 29 "\${fullname29} (Age: \${age_29} , pos 29)" 30 "\${fullname30} (Age: \${age_30} , pos 30)" 31 "\${fullname31} (Age: \${age_31} , pos 31)" 32 "\${fullname32} (Age: \${age_32} , pos 32)" 33 "\${fullname33} (Age: \${age_33} , pos 33)" 34 "\${fullname34} (Age: \${age_34} , pos 34)" 35 "\${fullname35} (Age: \${age_35} , pos 35)" 36 "\${fullname36} (Age: \${age_36} , pos 36)" 37 "\${fullname37} (Age: \${age_37} , pos 37)" 38 "\${fullname38} (Age: \${age_38} , pos 38)" 39 "\${fullname39} (Age: \${age_39} , pos 39)" 40 "\${fullname40} (Age: \${age_40} , pos 40)" 41 "\${fullname41} (Age: \${age_41} , pos 41)" 42 "\${fullname42} (Age: \${age_42} , pos 42)" 43 "\${fullname43} (Age: \${age_43} , pos 43)" 44 "\${fullname44} (Age: \${age_44} , pos 44)" 45 "\${fullname45} (Age: \${age_45} , pos 45)" 46 "\${fullname46} (Age: \${age_46} , pos 46)" 47 "\${fullname47} (Age: \${age_47} , pos 47)" 48 "\${fullname48} (Age: \${age_48} , pos 48)" 49 "\${fullname49} (Age: \${age_49} , pos 49)" 50 "\${fullname50} (Age: \${age_50} , pos 50)" 51 "\${fullname51} (Age: \${age_51} , pos 51)" 52 "\${fullname52} (Age: \${age_52} , pos 52)" 53 "\${fullname53} (Age: \${age_53} , pos 53)" 54 "\${fullname54} (Age: \${age_54} , pos 54)" 55 "\${fullname55} (Age: \${age_55} , pos 55)" 56 "\${fullname56} (Age: \${age_56} , pos 56)" 57 "\${fullname57} (Age: \${age_57} , pos 57)" 58 "\${fullname58} (Age: \${age_58} , pos 58)" 59 "\${fullname59} (Age: \${age_59} , pos 59)" 60 "\${fullname60} (Age: \${age_60} , pos 60)"
    label values mom_who mom_who

    label variable carer "1.11 : Qui est la personne du ménage qui joue le rôle de mère pour [\${children_"
    note carer: "1.11 : Qui est la personne du ménage qui joue le rôle de mère pour [\${children_name}(Age \${children_age})] ?"
    label define carer -5 "[décédé.e]" -4 "[ne fait pas partie du ménage]" -2 "Personne" -1 "Tous les membres du ménage" 0 "Personnes hors du ménage" 1 "\${fullname1} (Age: \${age_1} , pos 1)" 2 "\${fullname2} (Age: \${age_2} , pos 2)" 3 "\${fullname3} (Age: \${age_3} , pos 3)" 4 "\${fullname4} (Age: \${age_4} , pos 4)" 5 "\${fullname5} (Age: \${age_5} , pos 5)" 6 "\${fullname6} (Age: \${age_6} , pos 6)" 7 "\${fullname7} (Age: \${age_7} , pos 7)" 8 "\${fullname8} (Age: \${age_8} , pos 8)" 9 "\${fullname9} (Age: \${age_9} , pos 9)" 10 "\${fullname10} (Age: \${age_10} , pos 10)" 11 "\${fullname11} (Age: \${age_11} , pos 11)" 12 "\${fullname12} (Age: \${age_12} , pos 12)" 13 "\${fullname13} (Age: \${age_13} , pos 13)" 14 "\${fullname14} (Age: \${age_14} , pos 14)" 15 "\${fullname15} (Age: \${age_15} , pos 15)" 16 "\${fullname16} (Age: \${age_16} , pos 16)" 17 "\${fullname17} (Age: \${age_17} , pos 17)" 18 "\${fullname18} (Age: \${age_18} , pos 18)" 19 "\${fullname19} (Age: \${age_19} , pos 19)" 20 "\${fullname20} (Age: \${age_20} , pos 20)" 21 "\${fullname21} (Age: \${age_21} , pos 21)" 22 "\${fullname22} (Age: \${age_22} , pos 22)" 23 "\${fullname23} (Age: \${age_23} , pos 23)" 24 "\${fullname24} (Age: \${age_24} , pos 24)" 25 "\${fullname25} (Age: \${age_25} , pos 25)" 26 "\${fullname26} (Age: \${age_26} , pos 26)" 27 "\${fullname27} (Age: \${age_27} , pos 27)" 28 "\${fullname28} (Age: \${age_28} , pos 28)" 29 "\${fullname29} (Age: \${age_29} , pos 29)" 30 "\${fullname30} (Age: \${age_30} , pos 30)" 31 "\${fullname31} (Age: \${age_31} , pos 31)" 32 "\${fullname32} (Age: \${age_32} , pos 32)" 33 "\${fullname33} (Age: \${age_33} , pos 33)" 34 "\${fullname34} (Age: \${age_34} , pos 34)" 35 "\${fullname35} (Age: \${age_35} , pos 35)" 36 "\${fullname36} (Age: \${age_36} , pos 36)" 37 "\${fullname37} (Age: \${age_37} , pos 37)" 38 "\${fullname38} (Age: \${age_38} , pos 38)" 39 "\${fullname39} (Age: \${age_39} , pos 39)" 40 "\${fullname40} (Age: \${age_40} , pos 40)" 41 "\${fullname41} (Age: \${age_41} , pos 41)" 42 "\${fullname42} (Age: \${age_42} , pos 42)" 43 "\${fullname43} (Age: \${age_43} , pos 43)" 44 "\${fullname44} (Age: \${age_44} , pos 44)" 45 "\${fullname45} (Age: \${age_45} , pos 45)" 46 "\${fullname46} (Age: \${age_46} , pos 46)" 47 "\${fullname47} (Age: \${age_47} , pos 47)" 48 "\${fullname48} (Age: \${age_48} , pos 48)" 49 "\${fullname49} (Age: \${age_49} , pos 49)" 50 "\${fullname50} (Age: \${age_50} , pos 50)" 51 "\${fullname51} (Age: \${age_51} , pos 51)" 52 "\${fullname52} (Age: \${age_52} , pos 52)" 53 "\${fullname53} (Age: \${age_53} , pos 53)" 54 "\${fullname54} (Age: \${age_54} , pos 54)" 55 "\${fullname55} (Age: \${age_55} , pos 55)" 56 "\${fullname56} (Age: \${age_56} , pos 56)" 57 "\${fullname57} (Age: \${age_57} , pos 57)" 58 "\${fullname58} (Age: \${age_58} , pos 58)" 59 "\${fullname59} (Age: \${age_59} , pos 59)" 60 "\${fullname60} (Age: \${age_60} , pos 60)"
    label values carer carer






    * append old, previously-imported data (if any)
    cap confirm file "`dtafile'"
    if _rc == 0 {
        * mark all new data before merging with old data
        gen new_data_row=1
        
        * pull in old data
        append using "`dtafile'"
        
        * drop duplicates in favor of old, previously-imported data if overwrite_old_data is 0
        * (alternatively drop in favor of new data if overwrite_old_data is 1)
        sort key
        by key: gen num_for_key = _N
        drop if num_for_key > 1 & ((`overwrite_old_data' == 0 & new_data_row == 1) | (`overwrite_old_data' == 1 & new_data_row ~= 1))
        drop num_for_key

        * drop new-data flag
        drop new_data_row
    }
    
    * save data to Stata format
    save "`dtafile'", replace


}

disp
disp "Finished import of: `csvfile'"
disp

* OPTIONAL: LOCALLY-APPLIED STATA CORRECTIONS
*
* Rather than using SurveyCTO's review and correction workflow, the code below can apply a list of corrections
* listed in a local .csv file. Feel free to use, ignore, or delete this code.
*
*   Corrections file path and filename:  /users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-informed_consent-mod_c_hh_roster-rpt_caregiver_corrections.csv
*
*   Corrections file columns (in order): key, fieldname, value, notes

capture confirm file "`corrfile'"
if _rc==0 {
    disp
    disp "Starting application of corrections in: `corrfile'"
    disp

    * save primary data in memory
    preserve

    * load corrections
    insheet using "`corrfile'", names clear
    
    if _N>0 {
        * number all rows (with +1 offset so that it matches row numbers in Excel)
        gen rownum=_n+1
        
        * drop notes field (for information only)
        drop notes
        
        * make sure that all values are in string format to start
        gen origvalue=value
        tostring value, format(%100.0g) replace
        cap replace value="" if origvalue==.
        drop origvalue
        replace value=trim(value)
        
        * correct field names to match Stata field names (lowercase, drop -'s and .'s)
        replace fieldname=lower(subinstr(subinstr(fieldname,"-","",.),".","",.))
        
        * format date and date/time fields (taking account of possible wildcards for repeat groups)
        forvalues i = 1/100 {
            if "`datetime_fields`i''" ~= "" {
                foreach dtvar in `datetime_fields`i'' {
                    * skip fields that aren't yet in the data
                    cap unab dtvarignore : `dtvar'
                    if _rc==0 {
                        gen origvalue=value
                        replace value=string(clock(value,"DMYhms",2025),"%25.0g") if strmatch(fieldname,"`dtvar'")
                        * allow for cases where seconds haven't been specified
                        replace value=string(clock(origvalue,"DMYhm",2025),"%25.0g") if strmatch(fieldname,"`dtvar'") & value=="." & origvalue~="."
                        drop origvalue
                    }
                }
            }
            if "`date_fields`i''" ~= "" {
                foreach dtvar in `date_fields`i'' {
                    * skip fields that aren't yet in the data
                    cap unab dtvarignore : `dtvar'
                    if _rc==0 {
                        replace value=string(clock(value,"DMY",2025),"%25.0g") if strmatch(fieldname,"`dtvar'")
                    }
                }
            }
        }

        * write out a temp file with the commands necessary to apply each correction
        tempfile tempdo
        file open dofile using "`tempdo'", write replace
        local N = _N
        forvalues i = 1/`N' {
            local fieldnameval=fieldname[`i']
            local valueval=value[`i']
            local keyval=key[`i']
            local rownumval=rownum[`i']
            file write dofile `"cap replace `fieldnameval'="`valueval'" if key=="`keyval'""' _n
            file write dofile `"if _rc ~= 0 {"' _n
            if "`valueval'" == "" {
                file write dofile _tab `"cap replace `fieldnameval'=. if key=="`keyval'""' _n
            }
            else {
                file write dofile _tab `"cap replace `fieldnameval'=`valueval' if key=="`keyval'""' _n
            }
            file write dofile _tab `"if _rc ~= 0 {"' _n
            file write dofile _tab _tab `"disp"' _n
            file write dofile _tab _tab `"disp "CAN'T APPLY CORRECTION IN ROW #`rownumval'""' _n
            file write dofile _tab _tab `"disp"' _n
            file write dofile _tab `"}"' _n
            file write dofile `"}"' _n
        }
        file close dofile
    
        * restore primary data
        restore
        
        * execute the .do file to actually apply all corrections
        do "`tempdo'"

        * re-save data
        save "`dtafile'", replace
    }
    else {
        * restore primary data        
        restore
    }

    disp
    disp "Finished applying corrections in: `corrfile'"
    disp
}
