* import_niger_2023_Endline_Terrain-rpt_activitylist.do
*
*     Imports and aggregates "Niger 2023- Shock Response- ENDLINE-rpt_activitylist" (ID: niger_2023_Endline_Terrain) data.
*
*    Inputs:  "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-rpt_activitylist.csv"
*    Outputs: "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-rpt_activitylist.dta"
*
*    Output by SurveyCTO August 24, 2023 9:33 AM.

* initialize Stata
clear all
set more off
set mem 100m

* initialize workflow-specific parameters
*    Set overwrite_old_data to 1 if you use the review and correction
*    workflow and allow un-approving of submissions. If you do this,
*    incoming data will overwrite old data, so you won't want to make
*    changes to data in your local .dta file (such changes can be
*    overwritten with each new import).
local overwrite_old_data 0

* initialize form-specific parameters
local csvfile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-rpt_activitylist.csv"
local dtafile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-rpt_activitylist.dta"
local corrfile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-rpt_activitylist_corrections.csv"
local note_fields1 ""
local text_fields1 "act_pos activity1det activity2det activity3det activity4det activity5det activity6det activity7det activity8det activity9det activity10det activity11det activity12det activity13det activity14det"
local text_fields2 "activity15det bus2_name agrd_key_name agrd_key_rpos act_details_n bus2_own bus2_manage bus2_workers bus2_mos12 pos_abandon bus2_abandon_why_o bus_active_rev resp_bus2"
local date_fields1 "bus2_date"
local datetime_fields1 ""

disp
disp "Starting import of: `csvfile'"
disp

* import data from primary .csv file
insheet using "`csvfile'", names clear

* drop extra table-list columns
cap drop reserved_name_for_field_*
cap drop generated_table_list_lab*

* continue only if there's at least one row of data to import
if _N>0 {
    * drop note fields (since they don't contain any real data)
    forvalues i = 1/100 {
        if "`note_fields`i''" ~= "" {
            drop `note_fields`i''
        }
    }
    
    * format date and date/time fields
    forvalues i = 1/100 {
        if "`datetime_fields`i''" ~= "" {
            foreach dtvarlist in `datetime_fields`i'' {
                cap unab dtvarlist : `dtvarlist'
                if _rc==0 {
                    foreach dtvar in `dtvarlist' {
                        tempvar tempdtvar
                        rename `dtvar' `tempdtvar'
                        gen double `dtvar'=.
                        cap replace `dtvar'=clock(`tempdtvar',"DMYhms",2025)
                        * automatically try without seconds, just in case
                        cap replace `dtvar'=clock(`tempdtvar',"DMYhm",2025) if `dtvar'==. & `tempdtvar'~=""
                        format %tc `dtvar'
                        drop `tempdtvar'
                    }
                }
            }
        }
        if "`date_fields`i''" ~= "" {
            foreach dtvarlist in `date_fields`i'' {
                cap unab dtvarlist : `dtvarlist'
                if _rc==0 {
                    foreach dtvar in `dtvarlist' {
                        tempvar tempdtvar
                        rename `dtvar' `tempdtvar'
                        gen double `dtvar'=.
                        cap replace `dtvar'=date(`tempdtvar',"DMY",2025)
                        format %td `dtvar'
                        drop `tempdtvar'
                    }
                }
            }
        }
    }

    * ensure that text fields are always imported as strings (with "" for missing values)
    * (note that we treat "calculate" fields as text; you can destring later if you wish)
    tempvar ismissingvar
    quietly: gen `ismissingvar'=.
    forvalues i = 1/100 {
        if "`text_fields`i''" ~= "" {
            foreach svarlist in `text_fields`i'' {
                cap unab svarlist : `svarlist'
                if _rc==0 {
                    foreach stringvar in `svarlist' {
                        quietly: replace `ismissingvar'=.
                        quietly: cap replace `ismissingvar'=1 if `stringvar'==.
                        cap tostring `stringvar', format(%100.0g) replace
                        cap replace `stringvar'="" if `ismissingvar'==1
                    }
                }
            }
        }
    }
    quietly: drop `ismissingvar'



    * label variables
    label variable key "Unique submission ID"
    cap label variable submissiondate "Date/time submitted"
    cap label variable formdef_version "Form version used on device"
    cap label variable review_status "Review status"
    cap label variable review_comments "Comments made during review"
    cap label variable review_corrections "Corrections made during review"


    label variable bus2_own "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.11 Qui est/sont le(s) propri"
    note bus2_own: "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.11 Qui est/sont le(s) propriétaire (s) de cette activité?"

    label variable bus2_manage "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.11b: Qui gère cette activité"
    note bus2_manage: "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.11b: Qui gère cette activité ?"

    label variable bus2_workers "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.12 Quel (autre) membre du mé"
    note bus2_workers: "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.12 Quel (autre) membre du ménage a travaillé dans l'activité les 12 derniers mois (y compris les propriétaires/gérants)?"

    label variable bus2_outworkers "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.12b Sans vous compter vous-m"
    note bus2_outworkers: "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.12b Sans vous compter vous-même et les membres votre ménage, combien d' autres personnes ont travaillé au sein de votre activité au cours des 12 derniers mois (incluez les travailleurs rénumérés et les co-propriétaires)"

    label variable bus2_mos12 "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.13 Au cours des 12 derniers "
    note bus2_mos12: "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.13 Au cours des 12 derniers mois pendant quels mois l’activité était active ?"

    label variable bus2_active "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.14 Au cours des 30 derniers "
    note bus2_active: "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.14 Au cours des 30 derniers jours, l’activité était-elle active/fonctionnelle ?"
    label define bus2_active 1 "oui" 0 "non"
    label values bus2_active bus2_active

    label variable actdays_mem1 "\${firstname_mem1}, Age : \${age_mem1}"
    note actdays_mem1: "\${firstname_mem1}, Age : \${age_mem1}"

    label variable actdays_mem2 "\${firstname_mem2}, Age : \${age_mem2}"
    note actdays_mem2: "\${firstname_mem2}, Age : \${age_mem2}"

    label variable actdays_mem3 "\${firstname_mem3}, Age : \${age_mem3}"
    note actdays_mem3: "\${firstname_mem3}, Age : \${age_mem3}"

    label variable actdays_mem4 "\${firstname_mem4}, Age : \${age_mem4}"
    note actdays_mem4: "\${firstname_mem4}, Age : \${age_mem4}"

    label variable actdays_mem5 "\${firstname_mem5}, Age : \${age_mem5}"
    note actdays_mem5: "\${firstname_mem5}, Age : \${age_mem5}"

    label variable actdays_mem6 "\${firstname_mem6}, Age : \${age_mem6}"
    note actdays_mem6: "\${firstname_mem6}, Age : \${age_mem6}"

    label variable actdays_mem7 "\${firstname_mem7}, Age : \${age_mem7}"
    note actdays_mem7: "\${firstname_mem7}, Age : \${age_mem7}"

    label variable actdays_mem8 "\${firstname_mem8}, Age : \${age_mem8}"
    note actdays_mem8: "\${firstname_mem8}, Age : \${age_mem8}"

    label variable actdays_mem9 "\${firstname_mem9}, Age : \${age_mem9}"
    note actdays_mem9: "\${firstname_mem9}, Age : \${age_mem9}"

    label variable actdays_mem10 "\${firstname_mem10}, Age : \${age_mem10}"
    note actdays_mem10: "\${firstname_mem10}, Age : \${age_mem10}"

    label variable actdays_mem11 "\${firstname_mem11}, Age : \${age_mem11}"
    note actdays_mem11: "\${firstname_mem11}, Age : \${age_mem11}"

    label variable actdays_mem12 "\${firstname_mem12}, Age : \${age_mem12}"
    note actdays_mem12: "\${firstname_mem12}, Age : \${age_mem12}"

    label variable actdays_mem13 "\${firstname_mem13}, Age : \${age_mem13}"
    note actdays_mem13: "\${firstname_mem13}, Age : \${age_mem13}"

    label variable actdays_mem14 "\${firstname_mem14}, Age : \${age_mem14}"
    note actdays_mem14: "\${firstname_mem14}, Age : \${age_mem14}"

    label variable actdays_mem15 "\${firstname_mem15}, Age : \${age_mem15}"
    note actdays_mem15: "\${firstname_mem15}, Age : \${age_mem15}"

    label variable actdays_mem16 "\${firstname_mem16}, Age : \${age_mem16}"
    note actdays_mem16: "\${firstname_mem16}, Age : \${age_mem16}"

    label variable actdays_mem17 "\${firstname_mem17}, Age : \${age_mem17}"
    note actdays_mem17: "\${firstname_mem17}, Age : \${age_mem17}"

    label variable actdays_mem18 "\${firstname_mem18}, Age : \${age_mem18}"
    note actdays_mem18: "\${firstname_mem18}, Age : \${age_mem18}"

    label variable actdays_mem19 "\${firstname_mem19}, Age : \${age_mem19}"
    note actdays_mem19: "\${firstname_mem19}, Age : \${age_mem19}"

    label variable actdays_mem20 "\${firstname_mem20}, Age : \${age_mem20}"
    note actdays_mem20: "\${firstname_mem20}, Age : \${age_mem20}"

    label variable actdays_mem21 "\${firstname_mem21}, Age : \${age_mem21}"
    note actdays_mem21: "\${firstname_mem21}, Age : \${age_mem21}"

    label variable actdays_mem22 "\${firstname_mem22}, Age : \${age_mem22}"
    note actdays_mem22: "\${firstname_mem22}, Age : \${age_mem22}"

    label variable actdays_mem23 "\${firstname_mem23}, Age : \${age_mem23}"
    note actdays_mem23: "\${firstname_mem23}, Age : \${age_mem23}"

    label variable actdays_mem24 "\${firstname_mem24}, Age : \${age_mem24}"
    note actdays_mem24: "\${firstname_mem24}, Age : \${age_mem24}"

    label variable actdays_mem25 "\${firstname_mem25}, Age : \${age_mem25}"
    note actdays_mem25: "\${firstname_mem25}, Age : \${age_mem25}"

    label variable actdays_mem26 "\${firstname_mem26}, Age : \${age_mem26}"
    note actdays_mem26: "\${firstname_mem26}, Age : \${age_mem26}"

    label variable actdays_mem27 "\${firstname_mem27}, Age : \${age_mem27}"
    note actdays_mem27: "\${firstname_mem27}, Age : \${age_mem27}"

    label variable actdays_mem28 "\${firstname_mem28}, Age : \${age_mem28}"
    note actdays_mem28: "\${firstname_mem28}, Age : \${age_mem28}"

    label variable actdays_mem29 "\${firstname_mem29}, Age : \${age_mem29}"
    note actdays_mem29: "\${firstname_mem29}, Age : \${age_mem29}"

    label variable actdays_mem30 "\${firstname_mem30}, Age : \${age_mem30}"
    note actdays_mem30: "\${firstname_mem30}, Age : \${age_mem30}"

    label variable actdays_mem31 "\${firstname_mem31}, Age : \${age_mem31}"
    note actdays_mem31: "\${firstname_mem31}, Age : \${age_mem31}"

    label variable actdays_mem32 "\${firstname_mem32}, Age : \${age_mem32}"
    note actdays_mem32: "\${firstname_mem32}, Age : \${age_mem32}"

    label variable actdays_mem33 "\${firstname_mem33}, Age : \${age_mem33}"
    note actdays_mem33: "\${firstname_mem33}, Age : \${age_mem33}"

    label variable actdays_mem34 "\${firstname_mem34}, Age : \${age_mem34}"
    note actdays_mem34: "\${firstname_mem34}, Age : \${age_mem34}"

    label variable actdays_mem35 "\${firstname_mem35}, Age : \${age_mem35}"
    note actdays_mem35: "\${firstname_mem35}, Age : \${age_mem35}"

    label variable actdays_mem36 "\${firstname_mem36}, Age : \${age_mem36}"
    note actdays_mem36: "\${firstname_mem36}, Age : \${age_mem36}"

    label variable actdays_mem37 "\${firstname_mem37}, Age : \${age_mem37}"
    note actdays_mem37: "\${firstname_mem37}, Age : \${age_mem37}"

    label variable actdays_mem38 "\${firstname_mem38}, Age : \${age_mem38}"
    note actdays_mem38: "\${firstname_mem38}, Age : \${age_mem38}"

    label variable actdays_mem39 "\${firstname_mem39}, Age : \${age_mem39}"
    note actdays_mem39: "\${firstname_mem39}, Age : \${age_mem39}"

    label variable actdays_mem40 "\${firstname_mem40}, Age : \${age_mem40}"
    note actdays_mem40: "\${firstname_mem40}, Age : \${age_mem40}"

    label variable actdays_mem41 "\${firstname_mem41}, Age : \${age_mem41}"
    note actdays_mem41: "\${firstname_mem41}, Age : \${age_mem41}"

    label variable actdays_mem42 "\${firstname_mem42}, Age : \${age_mem42}"
    note actdays_mem42: "\${firstname_mem42}, Age : \${age_mem42}"

    label variable actdays_mem43 "\${firstname_mem43}, Age : \${age_mem43}"
    note actdays_mem43: "\${firstname_mem43}, Age : \${age_mem43}"

    label variable actdays_mem44 "\${firstname_mem44}, Age : \${age_mem44}"
    note actdays_mem44: "\${firstname_mem44}, Age : \${age_mem44}"

    label variable actdays_mem45 "\${firstname_mem45}, Age : \${age_mem45}"
    note actdays_mem45: "\${firstname_mem45}, Age : \${age_mem45}"

    label variable actdays_mem46 "\${firstname_mem46}, Age : \${age_mem46}"
    note actdays_mem46: "\${firstname_mem46}, Age : \${age_mem46}"

    label variable actdays_mem47 "\${firstname_mem47}, Age : \${age_mem47}"
    note actdays_mem47: "\${firstname_mem47}, Age : \${age_mem47}"

    label variable actdays_mem48 "\${firstname_mem48}, Age : \${age_mem48}"
    note actdays_mem48: "\${firstname_mem48}, Age : \${age_mem48}"

    label variable actdays_mem49 "\${firstname_mem49}, Age : \${age_mem49}"
    note actdays_mem49: "\${firstname_mem49}, Age : \${age_mem49}"

    label variable actdays_mem50 "\${firstname_mem50}, Age : \${age_mem50}"
    note actdays_mem50: "\${firstname_mem50}, Age : \${age_mem50}"

    label variable bus2_abandon "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.15: \${agrd_key_name} a aban"
    note bus2_abandon: "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.15: \${agrd_key_name} a abandonné cette activité ?"
    label define bus2_abandon 1 "oui" 0 "non"
    label values bus2_abandon bus2_abandon

    label variable bus2_abandon_why "3.16 : Quelle est la principale raison pour laquelle \${agrd_key_name} a abandon"
    note bus2_abandon_why: "3.16 : Quelle est la principale raison pour laquelle \${agrd_key_name} a abandonné cette activité?"
    label define bus2_abandon_why 1 "Non rentable" 2 "Choc : vol, incendie ou autre catastrophe" 3 "Manque de financement" 4 "Manque de clients" 5 "Difficile de trouver des intrants / équipement" 6 "Trop de concurrence" 7 "Distance par rapport au marché" 8 "Manque de temps" 9 "Manque de connaissances" 10 "Mari" 11 "Pression sociale" -777 "Autre (préciser)"
    label values bus2_abandon_why bus2_abandon_why

    label variable bus2_abandon_why_o "Pré ciser autre raison principale d'abandon"
    note bus2_abandon_why_o: "Pré ciser autre raison principale d'abandon"

    label variable bus2_assval "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.17 [\${bus2_name}] : Quelle "
    note bus2_assval: "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.17 [\${bus2_name}] : Quelle est la valeur actuelle des équipements et matériels ? [Si vous deviez le(s) vendre(s) ce mois-ci, combien recevriez-vous ?]"

    label variable bus2_rev30 "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.18 Au cours des 30 derniers "
    note bus2_rev30: "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.18 Au cours des 30 derniers jours ou durant le dernier mois où l'activité a opéré/fonctionné, quel a été le chiffre d’affaires ou revenus totaux (valeur totale des ventes) de l’activité, , avant de payer des dépenses ?"

    label variable bus2_pro30 "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.19 Au cours des 30 derniers "
    note bus2_pro30: "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.19 Au cours des 30 derniers jours ou durant le dernier mois où l'activité a opéré/fonctionné, quel a été le bénéfice de l’activité après avoir pris en compte les différentes charges (achat de marchandises, matières premiers...) y compris le salaire de la main-d’œuvre salariée, mais sans compter les revenus que vous avez payés vous-même?"

    label variable bus2_profitable "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3,20 Quel était le mois le plu"
    note bus2_profitable: "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3,20 Quel était le mois le plus rentable ?"
    label define bus2_profitable 0 "Jamais" 2205 "2022 Mai" 2206 "2022 Juin" 2207 "2022 Juillet" 2208 "2022 Août" 2209 "2022 Septembre" 2210 "2022 Octobre" 2211 "2022 Novembre" 2212 "2022 Décembre" 2301 "2023 Janvier" 2302 "2023 Février" 2303 "2023 Mars" 2304 "2023 Avril" 2305 "2023 Mai"
    label values bus2_profitable bus2_profitable

    label variable bus_most_xof "3,21: Bénéfice dans le mois le plus rentable :"
    note bus_most_xof: "3,21: Bénéfice dans le mois le plus rentable :"

    label variable bus2_least "3.22: Quel était le mois le moins rentable [quand l’activité était active]?"
    note bus2_least: "3.22: Quel était le mois le moins rentable [quand l’activité était active]?"
    label define bus2_least 0 "Jamais" 2205 "2022 Mai" 2206 "2022 Juin" 2207 "2022 Juillet" 2208 "2022 Août" 2209 "2022 Septembre" 2210 "2022 Octobre" 2211 "2022 Novembre" 2212 "2022 Décembre" 2301 "2023 Janvier" 2302 "2023 Février" 2303 "2023 Mars" 2304 "2023 Avril" 2305 "2023 Mai"
    label values bus2_least bus2_least

    label variable bus_least_xof "3.23: Bénéfice dans le mois où l´activité était active et le bénéfice le moins r"
    note bus_least_xof: "3.23: Bénéfice dans le mois où l´activité était active et le bénéfice le moins rentable :"

    label variable bus2_years "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.24 Depuis combien de temps c"
    note bus2_years: "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.24 Depuis combien de temps cette activité fonctionne-t-elle? (en années révolues, si moins d'1 an, écrire 0)"

    label variable bus2_date "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.24b Quel été la date (mois e"
    note bus2_date: "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.24b Quel été la date (mois et année) du démarrage ?"

    label variable bus_future "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.25 Au cours des 12 prochains"
    note bus_future: "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: 3.25 Au cours des 12 prochains mois, pensez-vous que vous allez.. :"
    label define bus_future 2 "investir plus d'argent et développer cette activité" 1 "ne pas investir d'argent, mais continuer à faire cette activité" 0 "arrêter/ne plus faire cette activité"
    label values bus_future bus_future

    label variable resp_bus2 "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: Agent Enqueteur : Qui à répond"
    note resp_bus2: "[ Nom: \${agrd_key_name} ] [ AGR \${bus2_name} ]: Agent Enqueteur : Qui à répondu pour cette activité ?"






    * append old, previously-imported data (if any)
    cap confirm file "`dtafile'"
    if _rc == 0 {
        * mark all new data before merging with old data
        gen new_data_row=1
        
        * pull in old data
        append using "`dtafile'"
        
        * drop duplicates in favor of old, previously-imported data if overwrite_old_data is 0
        * (alternatively drop in favor of new data if overwrite_old_data is 1)
        sort key
        by key: gen num_for_key = _N
        drop if num_for_key > 1 & ((`overwrite_old_data' == 0 & new_data_row == 1) | (`overwrite_old_data' == 1 & new_data_row ~= 1))
        drop num_for_key

        * drop new-data flag
        drop new_data_row
    }
    
    * save data to Stata format
    save "`dtafile'", replace


}

disp
disp "Finished import of: `csvfile'"
disp

* OPTIONAL: LOCALLY-APPLIED STATA CORRECTIONS
*
* Rather than using SurveyCTO's review and correction workflow, the code below can apply a list of corrections
* listed in a local .csv file. Feel free to use, ignore, or delete this code.
*
*   Corrections file path and filename:  /users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE-rpt_activitylist_corrections.csv
*
*   Corrections file columns (in order): key, fieldname, value, notes

capture confirm file "`corrfile'"
if _rc==0 {
    disp
    disp "Starting application of corrections in: `corrfile'"
    disp

    * save primary data in memory
    preserve

    * load corrections
    insheet using "`corrfile'", names clear
    
    if _N>0 {
        * number all rows (with +1 offset so that it matches row numbers in Excel)
        gen rownum=_n+1
        
        * drop notes field (for information only)
        drop notes
        
        * make sure that all values are in string format to start
        gen origvalue=value
        tostring value, format(%100.0g) replace
        cap replace value="" if origvalue==.
        drop origvalue
        replace value=trim(value)
        
        * correct field names to match Stata field names (lowercase, drop -'s and .'s)
        replace fieldname=lower(subinstr(subinstr(fieldname,"-","",.),".","",.))
        
        * format date and date/time fields (taking account of possible wildcards for repeat groups)
        forvalues i = 1/100 {
            if "`datetime_fields`i''" ~= "" {
                foreach dtvar in `datetime_fields`i'' {
                    * skip fields that aren't yet in the data
                    cap unab dtvarignore : `dtvar'
                    if _rc==0 {
                        gen origvalue=value
                        replace value=string(clock(value,"DMYhms",2025),"%25.0g") if strmatch(fieldname,"`dtvar'")
                        * allow for cases where seconds haven't been specified
                        replace value=string(clock(origvalue,"DMYhm",2025),"%25.0g") if strmatch(fieldname,"`dtvar'") & value=="." & origvalue~="."
                        drop origvalue
                    }
                }
            }
            if "`date_fields`i''" ~= "" {
                foreach dtvar in `date_fields`i'' {
                    * skip fields that aren't yet in the data
                    cap unab dtvarignore : `dtvar'
                    if _rc==0 {
                        replace value=string(clock(value,"DMY",2025),"%25.0g") if strmatch(fieldname,"`dtvar'")
                    }
                }
            }
        }

        * write out a temp file with the commands necessary to apply each correction
        tempfile tempdo
        file open dofile using "`tempdo'", write replace
        local N = _N
        forvalues i = 1/`N' {
            local fieldnameval=fieldname[`i']
            local valueval=value[`i']
            local keyval=key[`i']
            local rownumval=rownum[`i']
            file write dofile `"cap replace `fieldnameval'="`valueval'" if key=="`keyval'""' _n
            file write dofile `"if _rc ~= 0 {"' _n
            if "`valueval'" == "" {
                file write dofile _tab `"cap replace `fieldnameval'=. if key=="`keyval'""' _n
            }
            else {
                file write dofile _tab `"cap replace `fieldnameval'=`valueval' if key=="`keyval'""' _n
            }
            file write dofile _tab `"if _rc ~= 0 {"' _n
            file write dofile _tab _tab `"disp"' _n
            file write dofile _tab _tab `"disp "CAN'T APPLY CORRECTION IN ROW #`rownumval'""' _n
            file write dofile _tab _tab `"disp"' _n
            file write dofile _tab `"}"' _n
            file write dofile `"}"' _n
        }
        file close dofile
    
        * restore primary data
        restore
        
        * execute the .do file to actually apply all corrections
        do "`tempdo'"

        * re-save data
        save "`dtafile'", replace
    }
    else {
        * restore primary data        
        restore
    }

    disp
    disp "Finished applying corrections in: `corrfile'"
    disp
}
