**************************************************************************
*  *
*PREPARATION CLEANING NIGER SHOCK RESPONSE IE     *
*  *
***************************************************************************

****************************************************************************
* -------------- Intial cleaning for all files ---------------- *
****************************************************************************

clear

// use only if running without master
// global hfs = 2
// global cohort = 4

if ${hfs} == 1 {
use "$high_frequency_raw_admin/cohorte_reassignement_high_frequency1.dta", clear
gen surveyed_twice = cohorte != cohorte_new
replace surveyed_twice = 0 if missing(surveyed_twice)
keep hhid surveyed_twice cohorte_new
rename cohorte_new cohort_new
tempfile reassigns
save "`reassigns'"
save "$high_frequency_final/reassigns1.dta", replace
}

if ${hfs} == 2 {
use "$high_frequency_raw_admin/cohorte_reassignement_high_frequency2.dta", clear
gen surveyed_twice = cohorte != cohorte_new
replace surveyed_twice = 0 if missing(surveyed_twice)
keep hhid surveyed_twice cohorte_new
rename cohorte_new cohort_new
tempfile reassigns
save "`reassigns'"
save "$high_frequency_final/reassigns2.dta", replace
}

** a. remove duplicates from each file 
* ------------------------------------

*import duplicates infomation from excel and create drop list 

if ${cohort} == 1 & ${hfs} == 1 {

import excel "${high_frequency_raw_admin}/hfc_duplicates_hfs1_cohort1.xlsx", clear firstrow

* drop list not given, dropping all duplicates
keep key
rename key instance
tempfile hfs_drop
save `hfs_drop' 

}

if ${cohort} == 2 & ${hfs} == 1 {

import excel "${high_frequency_raw_admin}/hfc_duplicates_hfs1_cohort2.xlsx", clear firstrow

keep if drop == "drop"
keep key
rename key instance
tempfile hfs_drop
save `hfs_drop'

}

if ${cohort} == 3 & ${hfs} == 1 {

import excel "${high_frequency_raw_admin}/hfc_duplicates_hfs1_cohort3.xlsx", clear firstrow

* drop list not given, dropping all duplicates
keep key
rename key instance
tempfile hfs_drop
save `hfs_drop' 


}

if ${cohort} == 4 & ${hfs} == 1 {

import excel "${high_frequency_raw_admin}/hfc_duplicates_hfs1_cohort4.xlsx", clear firstrow

* drop list not given, dropping all duplicates
keep key
rename key instance
tempfile hfs_drop
save `hfs_drop' 

}

if ${cohort} == 1 & ${hfs} == 2 {

import excel "${high_frequency_raw_admin}/hfc_duplicates_hfs2_cohort1.xlsx", clear firstrow

keep if drop == "drop"
keep key
rename key instance
tempfile hfs_drop
save `hfs_drop'

}

if ${cohort} == 2 & ${hfs} == 2 {

import excel "${high_frequency_raw_admin}/hfc_duplicates_hfs2_cohort2.xlsx", clear firstrow

keep if drop == "drop"
keep key
rename key instance
tempfile hfs_drop
save `hfs_drop'

}

if ${cohort} == 3 & ${hfs} == 2 {

import excel "${high_frequency_raw_admin}/hfc_duplicates_hfs2_cohort3.xlsx", clear firstrow

keep if drop == "drop"
keep key
rename key instance
tempfile hfs_drop
save `hfs_drop' 

}

if ${cohort} == 4 & ${hfs} == 2 {

import excel "${high_frequency_raw_admin}/hfc_duplicates_hfs2_cohort4.xlsx", clear firstrow

keep if drop == "drop"
keep key
rename key instance
tempfile hfs_drop
save `hfs_drop'  

}

* add hhid into each long file

if ${cohort} == 1 & ${hfs} == 1 {
    use "${high_frequency_raw}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - 1er passage.dta", clear
}

else {
    use "${high_frequency_raw}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}.dta", clear
}

destring hhid, replace
drop if missing(hhid)

rename key instance
keep hhid instance
tempfile hhid_key_v19
save "`hhid_key_v19'", replace

* loop over each long data set and drop duplicates 

local dta_files : dir "${high_frequency_raw}/HFS${hfs}/cohort${cohort}" files "*.dta"

foreach dta_file in `dta_files' {

display as error "`dta_file'"

use "${high_frequency_raw}/HFS${hfs}/cohort${cohort}/`dta_file'", clear

    cap sum parent_key
    
    if _rc == 0 {
        di "this is a long form dataset, with parent key and key"
       
        * first 41 characters are the instance/survey id
        gen instance = substr(parent_key, 1, 41)
        drop parent_key
        drop key
        * drop duplicates
        quietly merge m:1 instance using "`hfs_drop'", gen(_merge)
        keep if _merge == 1
        drop _merge
        * merge hhid
        quietly merge m:1 instance using "`hhid_key_v19'"
        keep if _merge == 3
        drop _merge
        drop instance
        destring hhid, replace
        order hhid, first
       
        gen hfs = $hfs
        gen cohort = $cohort
       
        quietly merge m:1 hhid using "`reassigns'"
        keep if _merge == 3
        drop _merge
        drop if cohort != cohort_new
        drop cohort_new
        drop cohort
        drop hfs
        drop surveyed_twice

        * repeat observations e.g. two observations per food item consumed for a household
        if ${cohort} == 3 & ${hfs} == 2 {
        drop if hhid == 2103681 | hhid == 2103769 | hhid == 2103783 | hhid == 2105982 | hhid == 2120056 | hhid == 2120147 | hhid == 2121662 | hhid == 2133294 | hhid == 2135875 | hhid ==  2135900 | hhid == 2150762
        }

        if ${cohort} == 4 & ${hfs} == 2 {
        drop if hhid == 2133163
        }
       
    }
    
    else {
        di "this is a wide form dataset"
        
        * drop duplicates
        rename key instance
        quietly merge m:1 instance using "`hfs_drop'", gen(_merge)
        keep if _merge == 1
        drop _merge
        
        destring hhid, replace
        order hhid, first
        
        gen hfs = $hfs
        gen cohort = $cohort
        
        * repeat observations e.g. two observations per food item consumed for a household
        if ${cohort} == 3 & ${hfs} == 2 {
        drop if hhid == 2103681 | hhid == 2103769 | hhid == 2103783 | hhid == 2105982 | hhid == 2120056 | hhid == 2120147 | hhid == 2121662 | hhid == 2133294 | hhid == 2135875 | hhid ==  2135900 | hhid == 2150762
        }

        if ${cohort} == 4 & ${hfs} == 2 {
        drop if hhid == 2133163
        }
        
        quietly merge 1:1 hhid using "`reassigns'"
        keep if _merge == 3
        drop _merge
        drop if cohort != cohort_new
        drop cohort_new
        
    }
    
    capture drop setofrpt*
    capture drop setofbr*
    capture drop end_*
    capture drop start_*
    capture drop pull_rel_*

    quietly save "${high_frequency_prepared}/HFS${hfs}/cohort${cohort}/`dta_file'", replace
}

** c. destring variables, recode "don't know", add hhid
* -----------------------------------------------------

local dta_files : dir "${high_frequency_prepared}/HFS${hfs}/cohort${cohort}" files "*.dta"

*note: recoding may be different for the Maternal health section / may need to be
foreach dta_file in `dta_files' {
di as error "`dta_file'"
use "${high_frequency_prepared}/HFS${hfs}/cohort${cohort}/`dta_file'", clear

*destring all variables except "specify other"
quietly destring *, replace
capture tostring *_o, replace
        
quietly {
*numeric variables: recode missing
mvdecode _all, mv(-999 = .r) // refused
mvdecode _all, mv(-888 = .d) // don't know
mvdecode _all, mv(-777 = .o) // other
mvdecode _all, mv(-666 = .n) // na 
mvdecode _all, mv(-555 = .g) // god or unknown relation
mvdecode _all, mv(-333 = .m) 
mvdecode _all, mv(-222 = .r)
mvdecode _all, mv(-111 = .i)
}


*string variables: recode missing
ds , has(type string)
local string_var `r(varlist)'
display "here"

quietly {
foreach var in `string_var' {
replace `var' = ".r" if `var' == "-999" // refused
replace `var' = ".d" if `var' == "-888" // don't know
replace `var' = ".o" if `var' == "-777" // other
replace `var' = ".n" if `var' == "-666" // na 
replace `var' = ".g" if `var' == "-555" // god or unknown relation
}    
}

order hhid, first

*shorten variable labels for Stata 13
foreach i of varlist _all {
local longlabel: var label `i'
local shortlabel = substr(`"`longlabel'"',1,79)
label var `i' `"`shortlabel'"'
}

save "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/`dta_file'", replace
}

* use village names from endline data
clear
use "${endline_intermediate}/main_temp.dta"

keep commune commune_name village village_name treatment strat_vill_size strat_pmt vid
duplicates drop
sort commune_name village_name, stable
distinct commune_name village_name vid
* note there are 171 villages, village kodey appears twice
* use vid in regressions

tab commune
tab commune_name

/*
. tab commune

    Commune |      Freq.     Percent        Cum.
------------+-----------------------------------
         49 |         98       57.31       57.31
       8980 |         39       22.81       80.12
       9223 |         34       19.88      100.00
------------+-----------------------------------
      Total |        171      100.00

. tab commune_name

commune_nam |
          e |      Freq.     Percent        Cum.
------------+-----------------------------------
DANTCHANDOU |         39       22.81       22.81
     IMANAN |         34       19.88       42.69
    TAGAZAR |         98       57.31      100.00
------------+-----------------------------------
      Total |        171      100.00

*/


* 171 villages
* 3 communes

tempfile reference
save "`reference'"

* price deflator data
clear
use "${community_final}/median_prices_all_commodities.dta"
keep commune_name year month deflator
replace commune_name = strupper(commune_name)

tempfile deflator
save "`deflator'"

* drop incorrect village names for this cohort
if ${hfs} == 1 & ${cohort} == 1 {
clear
use "${high_frequency_intermediate}/HFS1/cohort1/Enquête à Haute Fréquence - 1er passage.dta"

drop village_name

* merge in village code and commune name - do not merge in village names here because it contains special characters
merge 1:1 hhid using "${high_frequency_raw_admin}/hfs_householdvillagesandcomunes.dta", keepusing(village commune_name)
keep if _merge == 3
drop _merge
replace commune_name = "DANTCHANDOU" if commune_name == "DANTCHANDOU."

* merge in village name from endline instead
merge m:1 village commune commune_name using "`reference'", keepusing(village_name)
order hhid village village_name commune commune_name 
drop if _merge == 2
drop _merge

save "${high_frequency_intermediate}/HFS1/cohort1/Enquête à Haute Fréquence - Menage - passage1 - cohorte1.dta", replace
rm "${high_frequency_intermediate}/HFS1/cohort1/Enquête à Haute Fréquence - 1er passage.dta"
}

* add treatment and strata variables from endline also

clear
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}.dta"
replace village_name = "GAOALJANA" if village_name == "GAO-ALJANA"
merge m:1 village_name commune_name using "`reference'", keepusing(treatment strat_vill_size strat_pmt vid village)
drop if _merge == 2
drop _merge
capture drop treated_pull
capture drop treat_pull
capture drop treatment_pull
capture drop treatment_definition

* add in price deflator

capture drop current_month

gen dd = dofc(submissiondate)
format dd %td
gen month = month(dd)
gen year = year(dd)
order hhid commune_name submissiondate year month
drop dd

merge m:1 commune_name year month using "`deflator'"

drop if _merge == 2
drop _merge

save "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/main - passage${hfs} - cohorte${cohort}.dta", replace
rm "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}.dta"

****************************************************************************

* -------------- Clean Each Long file Separately ---------------- *

******

**--------------------- Prepare Main Data set  "Enquête à Haute Fréquence - Menage - midline - cohorte1.dta" -------------------------**

******


*a. prep main file
*----------------- 

clear
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/main - passage${hfs} - cohorte${cohort}.dta"

merge 1:1 hhid instance using "${high_frequency_raw_admin}/enumerators-hfs${hfs}-cohort${cohort}.dta"
keep if _merge == 3
drop _merge
duplicates report hhid

// if ${cohort} == 1 & ${hfs} == 1 {
// gen departement_name = "BALLEYARA" if departement == 27
// replace departement_name = "KOLLO" if departement == 9220
// replace departement_name = "FILINGUE" if departement == 9222
// }

drop if missing(hhid)

tempfile mainfile
save "`mainfile'"

clear
use "`mainfile'"

foreach var in `r(varlist)' {
tostring `var', replace
}

*reconde to fix specific variables 

tostring miss_school_hh_mems, replace 


if ${cohort}==3 & ${hfs}==2 {

}

else {
replace  livestock_use="3" if  livestock_use=="1 2"
destring livestock_use, replace
}

label define livestock_use_val 0 "none" 1 "yes, sold" 2 "yes, consumed" 3 "yes, sold and consumed"
label values livestock_use livestock_use_val

gen lvsused =. 
label var lvsused "any livestock consumed or sold (0,1)"
replace lvsused = 0 if livestock_use == 0
replace lvsused = 1 if livestock_use == 1 | livestock_use == 2 | livestock_use == 3


*** Primary Variable Cantril Cleaning ****
// codebook stair_satis_today
label var stair_satis_today "cantril ladder current"
*138 missing 

*** Secondary Vairable Cleaning ***


*food security 

gen day_noeat = 1 
label var day_noeat "during last 30 days household member went a whole day without eating, not asked for HFS"
gen numberday_noeat = 1
label var day_noeat "how often did household members go a whole day without eating, not asked for HFS"

*labour market participation 
// codebook important_activity
label var important_activity "most important activity for the household in the last 30 days"
label define varlab_activity 0 "none" 1 "agriculture" 2 "breeding" 3 "salaried employment" 4 "other income generating activities"
label values important_activity varlab_activity

gen off_farm =. 
replace off_farm = 0 if important_activity==0 | important_activity==1 | important_activity==2 
replace off_farm = 1 if important_activity==3 | important_activity==4
label var off_farm "most important activity for household is not agriculutre"
label values off_farm noyes

// codebook any_employment
replace any_employment=.r if any_employment==-66
replace any_employment=.d if any_employment==-99

// codebook own_livestock
replace own_livestock=.r if own_livestock==-66
replace own_livestock=.d if own_livestock==-99

*engaged in agriculture
// codebook hasplots 
label var hasplots "household has engaed in agricultural activity"

*Agriculture and livestock activities 

label var hasplots "household has engaed in agricultural activity"

gen prodsold = crop_didsell 
label var prodsold "hould sold any produce"
replace prodsold = 0 if hasplots==0

gen prodsold_rev = crop_didsell_amt
label var prodsold_rev "revenue generated from selling produce"
replace prodsold_rev = 0 if hasplots==0

gen usepaidlbr = paid_labor
replace usepaidlbr = 0 if hasplots==0
label var usepaidlbr "household used paid labour for cultivating"

gen paidlbr_amt = paid_labor_total 
replace paidlbr_amt = 0 if usepaidlbr==0
label var paidlbr_amt "total household paid for labour for cultivating"

gen usemutlbr = mutual_labor
replace usemutlbr = 0 if hasplots==0
label var usemutlbr "household used mutual labour for cultivating"

gen crop_seed_kind=1 
label var crop_seed_kind "what type of seed did household use, missing for high frequency surveys"


*Revenue and Income 

label var lstock_turnover "livestock revenue"

gen harvalue = crop_didsell_amt 
label var harvalue "value of crop sales in last 30 days"
replace harvalue = 0 if crop_didsell==0

*Agriculture  and livestock activities

foreach var in crop_seed_purch crop_fert_purch {
    winsor2 `var', cuts(0 98) replace
}

label var crop_seed "purchsed seeds"
label var crop_fert "bought chemical or inorganic fertiliser"
label var crop_seed_purch "amount spent purchasing seeds"
replace crop_seed_purch=0 if crop_seed == 0
label var crop_fert_purch "amount spent purchasing fertiliser"
replace crop_fert_purch=0 if crop_fert == 0

gen sowing = 1
label var sowing "family has already sown lands for this agricultural season, not recorded for high frequency surveys"

gen hhplotarea= 1 
label var hhplotarea  "areas of cultivated crops (hectors), not recorded for high frequency surveys"


*Finantial engagement 

gen savings = .
label variable savings "households saved in the last 30 days (0,1)"
replace savings = 1 if save_loc1 == 1 | save_loc2 == 1 | save_loc3 == 1 | save_loc4 == 1 | save_loc5 == 1
replace savings = 0 if missing(savings)

gen loan = .
label variable loan "households took out a loan in the last 30 days"
replace loan = 1 if cred_1 == 1 | cred_2 == 1 | cred_3 == 1 | cred_4 == 1
replace loan = 0 if missing(loan)

gen withdrw=.
label var withdrw "households withdrew from savings in the last 30 days"
replace withdrw=0 if !missing(with_loc1) | !missing(with_loc2) | !missing(with_loc3) | !missing(with_loc4) | !missing(with_loc5) 
replace withdrw=1 if with_loc1==1 | with_loc2==1 | with_loc3==1 | with_loc4==1 | with_loc5==1

gen remittance = trans_fam
label var remittance "remittances recieved (0,1)"

gen remittance_amt = trans_amt
replace remittance_amt = 0 if remittance==0

gen remittance_send = trans_fam_send
label var remittance_send "household has sent remittances (0,1)"

gen remittance_amt_send = trans_amt_send
replace remittance_amt_send = 0 if remittance_send==0

label variable accesstofunds "Probability of putting together CFA 30,000 in the next month?"
label values accesstofunds .
recode accesstofunds (1 = 1) (2 = 1) (3 = 0) (4 = 0)
label define accesstofunds 0 "Very unlikely" 1 "Very likely", replace
label values accesstofunds accesstofunds
gen risk_sharing = accesstofunds
label variable risk_sharing "\makecell{Risk-sharing \\ ability}"

***Livestock 

label var hh_chicken "number of chickens household owns or rents"
label var hh_goat "number of chickens household owns or rents"
label var hh_cow "number of chickens household owns or rents"
label var hh_sheep "number of chickens household owns or rents"
label var hh_loth "number of other livestock household owns or rents"

gen has_chicken=.
label var has_chicken "household owns or rents chickens (0,1)"
replace has_chicken=0 if own_livestock==0
replace has_chicken=1 if hh_chicken>1 & !missing(hh_chicken)

gen has_goat=.
label var has_chicken "household owns or rents goats (0,1)"
replace has_goat=0 if own_livestock==0
replace has_goat=1 if hh_goat>1 & !missing(hh_goat)

gen has_cow=.
label var has_chicken "household owns or rents cows (0,1)"
replace has_cow=0 if own_livestock==0
replace has_cow=1 if hh_cow>1 & !missing(hh_cow)

gen has_sheep=.
label var has_chicken "household owns or rents sheep (0,1)"
replace has_sheep=0 if own_livestock==0
replace has_sheep=1 if hh_sheep>1 & !missing(hh_sheep)

gen has_loth=.
label var has_chicken "household owns or rents other livestock (0,1)"
replace has_loth=0 if own_livestock==0
replace has_loth=1 if hh_loth>1 & !missing(hh_loth)

*clean up other livestock options
replace hh_livestockx = "Ane" if hh_livestockx == "ANE" | hh_livestockx == "Anne" | hh_livestockx == "ane" | hh_livestockx == "Âne" |  hh_livestockx == "Ané" | hh_livestockx == "Aîné" | hh_livestockx == "Àne" | hh_livestockx == "âne" | hh_livestockx == "L anne" | hh_livestockx == "Anes" | hh_livestockx == "Ans" | hh_livestockx == "L anne" | hh_livestockx == "L'âne" | hh_livestockx == "Z Anne" | hh_livestockx == "anes" | hh_livestockx == "Un âne" | hh_livestockx == "Anê"
replace hh_livestockx = "Chameau" if hh_livestockx == "Chameaux" | hh_livestockx == "Chamaux" | hh_livestockx == "Chamau" | hh_livestockx == "Chamels"
replace hh_livestockx = "Pintade" if hh_livestockx == "PINTADE" | hh_livestockx == "Paintade" | hh_livestockx == "Pintades" | hh_livestockx == "Pintard" | hh_livestockx == "pintades" | hh_livestockx == "PANTADE" | hh_livestockx == "Pantade" | hh_livestockx == "Pintade," | hh_livestockx == "Pontade"
replace hh_livestockx = "Pigeon" if hh_livestockx == "Pigeons" | hh_livestockx == "Pijon" | hh_livestockx == "Pignon" | hh_livestockx == "Pigions" | hh_livestockx == "Pigon" 
replace hh_livestockx = "Cheval" if hh_livestockx == "Chevale" | hh_livestockx == "Chevaux"

tab hh_livestockx

*intermediate variable for tlu score 
gen hh_loth_tlu =.
replace hh_loth_tlu = 1.1*hh_loth if hh_livestockx== "Chameau"
replace hh_loth_tlu = 0.8*hh_loth if hh_livestockx== "Ane"
replace hh_loth_tlu = 0.8*hh_loth if hh_livestockx== "Cheval"
replace hh_loth_tlu = 0.03*hh_loth if hh_livestockx== "Pintade"
replace hh_loth_tlu = 0.1*hh_loth if hh_livestockx== "Chèvres"
replace hh_loth_tlu = 0.7*hh_loth if hh_livestockx== "Vache"
replace hh_loth_tlu = 0.1*hh_loth if hh_livestockx== "Mouton"

foreach var of varlist hh_chicken hh_goat hh_cow hh_sheep hh_loth {
gen temp_`var'= `var'
winsor2 temp_`var', cuts(0 98) replace
replace temp_`var' = 0 if missing(`var')
}

gen livestock_tlu=.
label var livestock_tlu "livestock count TLU"
replace livestock_tlu=0 if own_livestock==0 
replace livestock_tlu = 0.01*temp_hh_chicken + 0.1*temp_hh_goat + 0.7*temp_hh_cow + 0.1*temp_hh_sheep + temp_hh_loth
replace livestock_tlu=. if missing(hh_chicken) & missing(hh_goat) & missing(hh_cow) & missing(hh_sheep) & missing(hh_loth) 
replace livestock_tlu = 0 if missing(livestock_tlu)

gen lvsconsm = 1 
label var lvsconsm "number of live stock livestock consumed, using tropical livestock conversion units, not recorded for high frequency surveys"

gen lvs_rev = lstock_turnover
label var lvs_rev "livestock revenue"
replace lvs_rev = 0 if own_livestock==0 

drop temp_*

***Psychosocial 

gen mh_both = cd1
label var mh_both "Number of days the details of life bothered repondent more then usual"
gen mh_trbl = cd2
label var mh_trbl "Number of days repondent had trouble concentrating"
gen mh_sad = cd3_new
label var mh_sad " Number of days repondent felt sad"
gen mh_engy = cd4
label var mh_engy "Number of days respondent felt everthing took all their energy"
gen mh_cnf = cd5
label var mh_cnf "Number of days respondent felt confident about the future"
gen mh_nerv = cd6_new
label var mh_nerv "Number of days respondent felt nervous tense or worried"
gen mh_sleep = cd7
label var mh_sleep "Number of days respondent had trouble sleeping peacfully"
gen mh_hppy = cd8
label var mh_hppy "Number of days respondent felt happy"
gen mh_lnly = cd9
label var mh_lnly "Number of days respondent felt lonely"
gen mh_trd = cd10_new
label var mh_trd "Number of days respondent felt so tired that they couldn't do anything"
gen mh_uls = useless
label var mh_uls "Number of days respondent felt useless"

replace cd5 = 7-cd5
replace cd8 = 7-cd8

egen mentalhealth = rowtotal(cd1 cd2 cd3_new cd4 cd5 cd6_new cd7 cd8 cd9 cd10_new useless), missing
/* Phyllisa march 19th 2025 we standardise other rounds using baseline values.
sum mentalhealth if treatment == 0
replace mentalhealth = mentalhealth - r(mean)
replace mentalhealth = mentalhealth/r(sd)

replace mentalhealth = -mentalhealth */ // higher values mean better health
label variable mentalhealth "\makecell{Mental \\ health}"



gen socialcohesion =.  
replace socialcohesion = 0 if tens==1
replace socialcohesion = 1 if tens==0
label var socialcohesion "The household has not tensions with any other members of the comunity in the last 30 days (0,1)"

label var ten_tension "How many women out of ten experaince tention in their household?"
label var vill_burn "In this village is it common for husbands to beat their wives if they burn food?"
label define villburn 1 "no" 2 "could happen" 3 "usual" 4 "very usual"
label values vill_burn villburn

label var att_next_crop "How good did the household think the next harvest would be, 1- 10 where 1 is the worst and 10 is the best"


***Business Outcomes

gen business_num_uc = business_num 
label var business_num_uc "number of household businesses"
replace business_num_uc=0 if business_any==0

forval i = 1/2 {
foreach var in enterprise_revenue_`i' enterprise_profit_`i' {
    winsor2 `var', replace cuts(0 98)
}
}

foreach var in bus2_assval {
    winsor2 `var', replace cuts(0 98)
}

egen business_rev = rowtotal(enterprise_revenue_1 enterprise_revenue_2)
label variable business_rev "revenue from households two main businesses"

egen business_pft = rowtotal(enterprise_profit_1 enterprise_profit_2)
label variable business_pft "profit from households two main businesses"

egen business_assval = rowtotal(bus2_assval)
label variable business_assval "asset value from households two main businesses"

drop enterprise_member_work_*
split enterprise_member_work, parse(" ")
drop enterprise_member_work
destring enterprise_member_work1 enterprise_member_work2, replace
egen nbusworkers = rownonmiss(enterprise_member_work1 enterprise_member_work2)
label variable nbusworkers "\makecell{\# of people \\ who worked in business}"
drop enterprise_member_work1 enterprise_member_work2

gen business_invest = 0 
label var business_invest "household is planning to invest in one of its main businesses in the next 12 months"
/*
replace business_invest = 0 if business_any==0
replace business_invest = 0 if !missing(bus_future_1) | !missing(bus_future_2)
replace business_invest = 1 if bus_future_1==2 | bus_future_2==2
*/

gen business_numwrks = 0

label var business_numwrks "number of non household memeber workers employed by family busineses"
*replace business_numwrks=. if bus2_outworkers>100 //a few large values reported i.e. 7000


*** Education 

gen absent_school =. 
label var absent_school "missed school (0,1)"
replace absent_school = 0 if miss_school==0
replace absent_school = 1 if miss_school==1

gen aford_school = school_fees 
label var aford_school "could not afford to pay education expense in the last 30 days"


***Consumption and Food Security

gen mdd_w_score = 1 
label var mdd_w_score "women dietry diversity score (0-10), not recorded for high frequency surveys"

gen mdd_c_score = 1 
label var mdd_c_score "child dietry diversity score (0-7), not recorded for high frequency surveys"
gen mdd_c = 1 
label var mdd_c "child MDD equal to 1 if score above 4, not recorded for high frequency surveys"

**Coping Strategies

label var other_coping_strg_yesno "used another coping strategy"

gen other_copstr_rdcom = other_coping_strg_used_1
replace other_copstr_rdcom = 0 if other_coping_strg_yesno==0
label var other_copstr_rdcom "coping strategy reduction in non food expenditure"

gen other_copstr_cred = other_coping_strg_used_2
replace other_copstr_cred = 0 if other_coping_strg_yesno==0
label var other_copstr_cred "coping strategy used credit "

gen other_copstr_adac = other_coping_strg_used_3
replace other_copstr_adac = 0 if other_coping_strg_yesno==0
label var other_copstr_adac "coping strategy took up additional activites"

gen other_copstr_mig = other_coping_strg_used_4
replace other_copstr_mig = 0 if other_coping_strg_yesno==0
label var other_copstr_mig "coping strategy migrated"

gen other_copstr_frnd = other_coping_strg_used_5
replace other_copstr_frnd = 0 if other_coping_strg_yesno==0
label var other_copstr_frnd "coping strategy help from relatives or friends"

gen other_copstr_gov = other_coping_strg_used_6
replace other_copstr_gov = 0 if other_coping_strg_yesno==0
label var other_copstr_gov "coping strategy help from gov or state aid"

gen other_copstr_ngo = other_coping_strg_used_7
replace other_copstr_ngo = 0 if other_coping_strg_yesno==0
label var other_copstr_ngo "coping strategy help from NGOs"

gen other_copstr_god = other_coping_strg_used_8
replace other_copstr_god = 0 if other_coping_strg_yesno==0
label var other_copstr_god "coping strategy help from god"

gen other_copstr_other = other_coping_strg_used__88
replace other_copstr_other = 0 if other_coping_strg_yesno==0
label var other_copstr_other "other (in other section) coping strategy"

rename other_copstr_rdcom choc_strategy6
rename other_copstr_cred choc_strategy9
rename other_copstr_adac choc_strategy10
rename other_copstr_mig choc_strategy11
rename other_copstr_frnd choc_strategy12
rename other_copstr_gov choc_strategy13
rename other_copstr_ngo choc_strategy14
rename other_copstr_god choc_strategy16


**Household size and movement variables 

split(oldlist), destring 
egen numoldmem = rowtotal(oldlist_*) , missing 
label var numoldmem "number of household members who were registered in previous surveys"

label var new_hh_members "number of new household members"

egen hhsize = rowtotal(numoldmem new_hh_members), missing
label var hhsize "number of current household members"


*Save dataset

compress
save "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/main - passage${hfs} - cohorte${cohort}_wide.dta", replace

*******

**------------Prepare Food Security Data Set "Enquête à Haute Fréquence - Menage - midline - cohorte1-informed_consent-mod_g_fcs-br_fcs.dta"-------------**

*******



if ${cohort} == 1 & ${hfs} == 1 {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - 1er passage-informed_consent-mod_g_fcs-br_fcs.dta", clear
}
else {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_g_fcs-br_fcs.dta", clear
}

drop if hhid==. // those observations are empty. 


*save long dataset
*compress
*save "${preparation}/HFS${hfs}/cohort${cohort}/niger_high_frequency_foodsec_long", replace

*reshape to wide format (houshold level)
drop fcs_ki fcs_qid fcs_id
duplicates drop

ds hhid fcs_index, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

ds hhid fcs_index, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(fcs_index)

ds fcs_consumed_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label var `varstub'`i' "`l_`varstub''"
}
}

*Gen food security Primary Vairable 

*double check this coding given that cerials and tubers are in the same category so PAP FCS = 2*cereals + 2*tubers + 3*pulses + 1*vegetables + 1*fruit + 4*meat/fish/eggs + 4*milk + 0.5*oil + 0.5*sugar becomes FCS = 2*cereals + 3*pulses + 1*vegetables + 1*fruit + 4*meat/fish/eggs + 4*milk + 0.5*oil + 0.5*sugar

codebook fcs_consumed_4 fcs_consumed_5 fcs_consumed_6 fcs_consumed_7 fcs_consumed_8 fcs_consumed_9 fcs_consumed_10 fcs_consumed_11 fcs_consumed_12 fcs_consumed_13     fcs_consumed_14 fcs_consumed_15 fcs_consumed_16


label var fcs_consumed_1 "no. days in past week hh consumed cerials and tubers"
label var fcs_consumed_2 "no. days in past week hh consumed pulses"
label var fcs_consumed_9 "no. days in past week hh consumed vegitables"
label var fcs_consumed_12 "no. days in past week hh consumed fruit"
label var fcs_consumed_4 "no. days in past week hh consumed meat fish eggs"
label var fcs_consumed_3 "no. days in past week hh consumed milk"
label var fcs_consumed_14 "no. days in past week hh consumed oil and butter"
label var fcs_consumed_15 "no. days in past week hh consumed sugar"

gen fcs=. 
replace fcs= 2*fcs_consumed_1 + 3*fcs_consumed_2 + 1*fcs_consumed_9 + 1*fcs_consumed_12 + 4*fcs_consumed_4 + 4*fcs_consumed_3 + 0.5*fcs_consumed_14 + 0.5*fcs_consumed_15

label var fcs "primary outcome: food security"

gen fcs_above_poor = (fcs > 21)
replace fcs_above_poor = . if missing(fcs)
label variable fcs_above_poor "FCS above poor"

gen fcs_above_reason = (fcs > 42)
replace fcs_above_reason = . if missing(fcs)
label variable fcs_above_reason "FCS above reasonable"

clonevar div_cereal = fcs_consumed_1
clonevar div_pulse = fcs_consumed_2
clonevar div_veg = fcs_consumed_9
clonevar div_fruit = fcs_consumed_12
clonevar div_meat = fcs_consumed_4
clonevar div_milk = fcs_consumed_3
clonevar div_oil = fcs_consumed_14
clonevar div_sugar = fcs_consumed_15

*Save wide dataset (this will be merged to main)
save "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_g_fcs-br_fcs_wide.dta", replace

*******

**------------Prepare Wage Labour Data Set "Enquête à Haute Fréquence - Menage - midline - cohorte1-informed_consent-mod_d_edu_labor-grp_emploi-d_hh_wage_labor"-------------**

*******

if ${hfs}==1 & ${cohort}==1 {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - 1er passage-informed_consent-mod_d_edu_labor-grp_emploi-d_hh_wage_labor.dta", clear
}
else {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_d_edu_labor-grp_emploi-d_hh_wage_labor.dta", clear 
}

drop if hhid==. // those observations are empty.

codebook d7_emp_days  

mvdecode d7_emp_days, mv(-66 = .r) // refused
mvdecode d7_emp_days, mv(-99 = .d) //don't know 

codebook d9_emp_days

*reshape to wide format (houshold level)
ds hhid d_hh_index, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

ds hhid d_hh_index, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(d_hh_index)

ds d7_emp_days_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label var `varstub'`i' "`l_`varstub''"
}
}

*agregate at the household level 

egen ag_emp_days = rowtotal(d7_emp_days_*), missing
label var ag_emp_days "sum of household members  number of days spent workin in agri wage employment"

egen ag_emp_days_mean = rowmean(d7_emp_days_*)
label var ag_emp_days_mean "mean of household members number of days spent workin in agri wage employment"

egen nonag_emp_days = rowtotal(d9_emp_days*), missing
label var nonag_emp_days "sum of household members  number of days spent workin in non agri wage employment"

egen nonag_emp_days_mean = rowmean(d9_emp_days*)
label var nonag_emp_days_mean "mean of household members number of days spent workin in non agri wage employment"

replace nonag_emp_days = . if nonag_emp_days < 0
replace ag_emp_days = . if ag_emp_days < 0 

replace nonag_emp_days_mean = . if nonag_emp_days_mean < 0
replace ag_emp_days_mean = . if ag_emp_days_mean < 0 


gen ag_wage=. 
replace ag_wage=0 if ag_emp_days==0
replace ag_wage=1 if ag_emp_days>0 & !missing(ag_emp_days)
label var ag_wage "household enaged in agri wage employment"
label values ag_wage noyes

gen nonag_wage=. 
replace nonag_wage=0 if nonag_emp_days==0
replace nonag_wage=1 if nonag_emp_days>0 & !missing(nonag_emp_days)
label var nonag_wage "household enaged in non agri wage employment"
label values nonag_wage noyes

*Revenue and Income 

egen ag_wage_inc= rowtotal(d8_salary_*), missing 
label var ag_wage_inc "agricultural wage income"

egen nonag_wage_inc= rowtotal(d11_salary_*), missing 
label var nonag_wage_inc "Non- agricultural wage income"

replace ag_wage_inc = . if ag_wage_inc < 0
replace nonag_wage_inc = . if nonag_wage_inc < 0

drop d8_salary_*
drop d11_salary_*

save "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs}- cohorte${cohort}-informed_consent-mod_d_edu_labor-grp_emploi-d_hh_wage_labor_wide.dta", replace

*******

**------Prepare  "Enquête à Haute Fréquence - Menage - midline -cohorte${cohort}-informed_consent-mod_f_ag_livestock-livestock-f_hh_livestock_labor"--------**

*******

if ${hfs}==1 & ${cohort}==1 {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - 1er passage-informed_consent-mod_f_ag_livestock-livestock-f_hh_livestock_labor.dta", clear
}
else {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_f_ag_livestock-livestock-f_hh_livestock_labor.dta" , clear 
}

drop if hhid==. // those observations are empty.


codebook num_days_livestock
label var num_days_livestock "number of days meber spent looking after livestock"

*reshape to wide format (houshold level)
ds hhid f_hh_index2, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

ds hhid f_hh_index2, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(f_hh_index2)

ds num_days_livestock_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label var `varstub'`i' "`l_`varstub''"
}
}


*agregate at the household level 

egen lvs_wrk_days = rowtotal(num_days_livestock_*)
label var  lvs_wrk_days "sum of household members number of days spent looking after livestock"

egen lvs_wrk_days_mean = rowmean(num_days_livestock_*)
label var lvs_wrk_days_mean "mean of household members number of days spent looking after livestock"

gen lvs_care =. 
replace lvs_care =0 if lvs_wrk_days==0
replace lvs_care =1 if lvs_wrk_days>0 & !missing(lvs_wrk_days)
label var lvs_care "household spent time looking after livestock"
label values lvs_care noyes

save "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_f_ag_livestock-livestock-f_hh_livestock_labor_wide.dta", replace


*******

**---------Prepare  "Enquête à Haute Fréquence - Menage - midline - cohorte1-informed_consent-mod_f_ag_livestock-agriculture-f_hh_ag_labor"----------**

*******


if ${hfs}==1 & ${cohort}==1 {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - 1er passage-informed_consent-mod_f_ag_livestock-agriculture-f_hh_ag_labor.dta", clear
}
else {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_f_ag_livestock-agriculture-f_hh_ag_labor.dta" , clear 
}
drop if hhid==. // those observations are empty.


*number of days cucltivating land
codebook num_days_ag
label var num_days_ag "number of days member cultivated land for farming"

*reshape to wide format (houshold level)
ds hhid f_hh_index, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

ds hhid f_hh_index, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(f_hh_index)

ds num_days_ag_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label var `varstub'`i' "`l_`varstub''"
}
}

*agregate at the household level 

egen num_days_ag = rowtotal(num_days_ag_*), missing
label var num_days_ag "sum of household members number of days spent cultivating land"

egen num_days_ag_mean = rowmean(num_days_ag_*)
label var num_days_ag_mean "household members mean number of days spent cultivating land"


save "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_f_ag_livestock-agriculture-f_hh_ag_labor_wide.dta", replace

*******

**---------Prepare  "Enquête à Haute Fréquence - Menage - midline - cohorte1-informed_consent-mod_e_business-e_hh_business_labor"----------**

*******

if ${hfs}==1 & ${cohort}==1 {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - 1er passage-informed_consent-mod_e_business-e_hh_business_labor.dta", clear
}
else {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_e_business-e_hh_business_labor.dta" , clear 
}

drop if hhid==. // those observations are empty.


*number of days cucltivating land
codebook hh_business_labor
label var hh_business_labor "number of days member worked in off farm business"

*reshape to wide format (houshold level)
ds hhid e_hh_index, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

ds hhid e_hh_index, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(e_hh_index)

ds hh_business_labor_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label var `varstub'`i' "`l_`varstub''"
}
}

*agregate at the household level 

egen n_days_business = rowtotal(hh_business_labor_*), missing
label var n_days_business "sum of household members number of days spent working in family business"

egen num_days_bus_mean = rowmean(hh_business_labor_*)
label var num_days_bus_mean "household members mean number of days spent working in family business"

save "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_e_business-e_hh_business_labor_wide.dta", replace


*******

**---------Prepare  "Enquête à Haute Fréquence - Menage - midline - cohorte1-informed_consent-mod_c_hh_roster-s_hh_sleep"----------**

*******

if ${hfs}==1 & ${cohort}==1 {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - 1er passage-informed_consent-mod_c_hh_roster-s_hh_sleep.dta", clear
}
else {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_c_hh_roster-s_hh_sleep.dta" , clear 
}

drop if hhid==. // those observations are empty.


*change any answers longer than 30 days to be the max of 30 nights 
replace sleep_n=. if missing(sleep_u)
replace sleep_n = 30 if sleep_n>30 & !missing(sleep_n) & sleep_u==1 //nights
replace sleep_n = 30/7 if sleep_n>4 & !missing(sleep_n) & sleep_u==2 //weeks
replace sleep_n = 1 if sleep_n>1 & !missing(sleep_n) & sleep_u==3 //months

*Recode number of nights slept away from household to be in nights 

gen sleep_n_std = sleep_n if sleep_u==1  
replace sleep_n_std=7*sleep_n if sleep_u==2
replace sleep_n_std=30*sleep_n if sleep_u==3
label var sleep_n_std "number of nights household member slept away from the household"

*recode sleep why so that other is its own cateogry 

replace sleep_why=11 if sleep_why==.o


*reshape to wide format (houshold level)
ds hhid s_hh_index, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

ds hhid s_hh_index, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(s_hh_index)

ds exode_money_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label var `varstub'`i' "`l_`varstub''"
}
}

*agregate at the household level 

gen remit=.
label var remit "household sent remitances"
forvalues i = 1 / `count' {
replace remit=0 if !missing(exode_money_`i')
replace remit=1 if exode_money_`i'==1
}

egen amt_remit=rowtotal(exode_amt_sendt_*) , missing
label var amt_remit "value of household remitances"


*gen variables for each reason for sleeping away from household

foreach i of numlist 1/`count' {
gen away_study_`i' = sleep_n_std_`i' if sleep_why_`i'==1
label var away_study_`i' "slept away from the household to study"

gen away_ill_`i' = sleep_n_std_`i' if sleep_why_`i'==2
label var away_ill_`i' "slept away from the household due to disease or hosiptal stay"

gen away_vfam_`i' = sleep_n_std_`i' if sleep_why_`i'==3
label var away_vfam_`i' "slept away from the household due to visiting family"

gen away_mrkt_`i' = sleep_n_std_`i' if sleep_why_`i'==4
label var away_mrkt_`i' "slept away from the household due to going to market"

gen away_busi_`i' = sleep_n_std_`i' if sleep_why_`i'==5
label var away_busi_`i' "slept away from the household due to small business"

gen away_agri_`i' = sleep_n_std_`i' if sleep_why_`i'==6
label var away_agri_`i' "slept away from the household due to agricultural work"

gen away_ahus_`i' = sleep_n_std_`i' if sleep_why_`i'==7
label var away_ahus_`i' "slept away from the household due to work in animal husbandry"

gen away_ming_`i' = sleep_n_std_`i' if sleep_why_`i'==8
label var away_ming_`i' "slept away from the household due to mining"

gen away_owrk_`i' = sleep_n_std_`i' if sleep_why_`i'==9
label var away_owrk_`i' "slept away from the household due to other work"

gen away_afam_`i' = sleep_n_std_`i' if sleep_why_`i'==10
label var away_afam_`i' "slept away from the household to accompany family"

gen away_other_`i' = sleep_n_std_`i' if sleep_why_`i'==11
label var away_other_`i' "slept away from the household due to non specified reason"

}

egen away_study = rowmean(away_study_*)
label var away_study "average days household members slept away to study"

egen away_ill = rowmean(away_ill_*)
label var away_ill "average days household members slept away due to disease or hosiptal stay"

egen away_vfam = rowmean(away_vfam_*) 
label var away_vfam "average days household members slept due to visiting family"

egen away_mrkt = rowmean(away_mrkt_*) 
label var away_mrkt "average days household members slept due to going to market"

egen away_busi = rowmean(away_busi_*)
label var away_busi "average days household members slept due to small business"

egen away_agri = rowmean(away_agri_*) 
label var away_agri "average days household members slept due to agricultural work"

egen away_ahus = rowmean(away_ahus_*)
label var away_ahus "average days household members slept due to work in animal husbandry"

egen away_ming = rowmean(away_ming_*) 
label var away_ming "average days household members slept due to mining"

egen away_owrk = rowmean(away_owrk_*)
label var away_owrk "average days household members slept due to other work"

egen away_afam = rowmean(away_afam_*)
label var away_afam "average days household members slept to accompany family"

egen away_other = rowmean(away_other_*)
label var away_other "average days household members slept away due to non specified reason"


egen away = rowmean(sleep_n_std_*)
label var away "average days household mebers slept away"


save "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_c_hh_roster-s_hh_sleep_wide.dta", replace


*******

**---------Prepare  "Enquête à Haute Fréquence - Menage - midline - cohorte1-informed_consent-mod_j_excep_exp-rpt_cel1"----------**

*******

if ${hfs}==1 & ${cohort}==1 {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - 1er passage-informed_consent-mod_j_excep_exp-rpt_cel1.dta", clear
}
else {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_j_excep_exp-rpt_cel1.dta" , clear 
}


drop if hhid==. // those observations are empty.

*reshape to wide format (houshold level)
ds hhid cel1_pos, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

ds hhid cel1_pos, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(cel1_pos)

ds cel_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label var `varstub'`i' "`l_`varstub''"
}
}

*agregate at the household level 

gen excexp=. 
label var excexp "any exceptionl expenditure (0,1)"
replace excexp=0 if !missing(cel_1) | !missing(cel_2) | !missing(cel_3) | !missing(cel_4) | !missing(cel_5) 
replace  excexp=1 if cel_1==1 | cel_2==1 | cel_3==1 | cel_4==1 | cel_5==1 

save "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_j_excep_exp-rpt_cel1_wide.dta", replace


*******

**---------Prepare  "Enquête à Haute Fréquence - Menage - midline - cohorte${cohort}-informed_consent-mod_j_excep_exp-rpt_cel2"----------**

*******

if ${hfs}==1 & ${cohort}==1 {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - 1er passage-informed_consent-mod_j_excep_exp-rpt_cel2.dta", clear
}
else {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_j_excep_exp-rpt_cel2.dta" , clear 
}


drop if hhid==. // those observations are empty.


*reshape to wide format (houshold level)
ds hhid cel2_pos, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

ds hhid cel2_pos, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(cel2_pos)

ds cel_food_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label var `varstub'`i' "`l_`varstub''"
}
}

*agregate at the household level 

egen amnt_excexp_food=rowtotal(cel_food_*) , missing 
label var amnt_excexp_food "amount of exceptionl expenditure on food"

egen amnt_excexp_drink=rowtotal(cel_drink_*) , missing 
label var amnt_excexp_drink"amount of exceptionl expenditure on drink"

egen amnt_excexp_cloth=rowtotal(cel_cloth_*) , missing 
label var amnt_excexp_cloth "amount of exceptionl expenditure on cloth"

egen amnt_excexp_nonfood=rowtotal(cel_nonfood_*) , missing 
label var amnt_excexp_nonfood "amount of exceptionl expenditure on nonfood"


egen amnt_excexp_rama=rowtotal(cel_food_1 cel_drink_1 cel_cloth_1 cel_nonfood_1) , missing 
label var amnt_excexp_rama "amount of exceptionl expenditure on Fin de Ramadan"

egen amnt_excexp_tab=rowtotal(cel_food_2 cel_drink_2 cel_cloth_2 cel_nonfood_2) , missing 
label var amnt_excexp_tab "amount of exceptionl expenditure on Tabaski"

egen amnt_excexp_bap=rowtotal(cel_food_3 cel_drink_3 cel_cloth_3 cel_nonfood_3) , missing 
label var amnt_excexp_bap "amount of exceptionl expenditure on Baptemes"

egen amnt_excexp_mar=rowtotal(cel_food_4 cel_drink_4 cel_cloth_4 cel_nonfood_4) , missing 
label var amnt_excexp_mar "amount of exceptionl expenditure on Mariage"

egen amnt_excexp_aut=rowtotal(cel_food_5 cel_drink_5 cel_cloth_5 cel_nonfood_5) , missing 
label var amnt_excexp_aut "amount of exceptionl expenditure on Autre événement"

save "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_j_excep_exp-rpt_cel2_wide.dta", replace


*******

**---------Prepare  "Enquête à Haute Fréquence - Menage - midline - cohorte${cohort}-informed_consent-mod_l_finance-PART_othersave-gp_savemoreinfo"----------**

*******

if ${hfs}==1 & ${cohort}==1 {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - 1er passage-informed_consent-mod_l_finance-PART_othersave-gp_savemoreinfo.dta", clear
}
else {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_l_finance-PART_othersave-gp_savemoreinfo.dta" , clear 
}

drop if hhid==. // those observations are empty.


*reshape to wide format (houshold level)
ds hhid saves_pos, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

ds hhid saves_pos, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(saves_pos)

ds dep_xof_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label var `varstub'`i' "`l_`varstub''"
}
}

*agregate at the household level 

gen save1= dep_xof_1
label var save1 "amount saved in bank or other formal insitution"

gen save2= dep_xof_2
label var save2 "amount saved in savings group"

gen save3= dep_xof_3
label var save3 "amount saved with family outside of household"

gen save4= dep_xof_4
label var save4 "amount saved with neighbours or friends"

gen save5= dep_xof_5
label var save5 "amount saved with other source"



save "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_l_finance-PART_othersave-gp_savemoreinfo_wide.dta", replace



*******

**---------Prepare  "Enquête à Haute Fréquence - Menage - midline - cohorte${cohort}-informed_consent-mod_l_finance-PART_othersave-gp_withmoreinfo"----------**

*******

if ${hfs}==1 & ${cohort}==1 {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - 1er passage-informed_consent-mod_l_finance-PART_othersave-gp_withmoreinfo.dta", clear
}
else {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_l_finance-PART_othersave-gp_withmoreinfo.dta" , clear 
}

drop if hhid==. // those observations are empty.


*reshape to wide format (houshold level)
ds hhid withdraw_pos, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

ds hhid withdraw_pos, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(withdraw_pos)

ds with_xof_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label var `varstub'`i' "`l_`varstub''"
}
}

*agregate at the household level 

gen withdrw1= with_xof_1
label var withdrw1 "amount saved in bank or other formal insitution"

gen withdrw2= with_xof_2
label var withdrw2 "amount saved in savings group"

gen withdrw3= with_xof_3
label var withdrw3 "amount saved with family outside of household"

gen withdrw4= with_xof_4
label var withdrw4 "amount saved with neighbours or friends"

gen withdrw5= with_xof_5
label var withdrw5 "amount saved with other source"



save "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_l_finance-PART_othersave-gp_withmoreinfo_wide.dta", replace


*******

**---------Prepare  "Enquête à Haute Fréquence - Menage - midline - cohorte${cohort}-informed_consent-mod_l_finance-PART_credit-rpt_cred"----------**

*******

if ${hfs}==1 & ${cohort}==1 {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - 1er passage-informed_consent-mod_l_finance-PART_credit-rpt_cred.dta", clear
}
else {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_l_finance-PART_credit-rpt_cred.dta" , clear 
}


drop if hhid==. // those observations are empty.

*reshape to wide format (houshold level)
ds hhid cred_pos, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

ds hhid cred_pos, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(cred_pos)

ds cred_amt_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label var `varstub'`i' "`l_`varstub''"
}
}

*agregate at the household level 

gen loan1= cred_amt_1
label var loan1 "amount of loan from family in the last 30 days"

gen loan2= cred_amt_2
label var loan2 "amount of loan from  freinds in the last 30 days"

gen loan3= cred_amt_3
label var loan3 "amount of loan from formal institution in the last 30 days"

gen loan4= cred_amt_4
label var loan4 "amount of loan from other person or group in the last 30 days"


save "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_l_finance-PART_credit-rpt_cred_wide.dta", replace



*******

**---------Prepare  "Enquête à Haute Fréquence - Menage - midline - cohorte1-informed_consent-mod_d_edu_labor-grp_edu-rpt_miss_school"----------**

*******


if ${hfs}==1 & ${cohort}==1 {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - 1er passage-informed_consent-mod_d_edu_labor-grp_edu-rpt_miss_school.dta", clear
}
else {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_d_edu_labor-grp_edu-rpt_miss_school.dta" , clear 
}

drop if hhid==. // those observations are empty.

*reshape to wide format (houshold level)
ds hhid missscool_hh_index, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

ds hhid missscool_hh_index, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(missscool_hh_index)

ds miss_school_nbdays_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label var `varstub'`i' "`l_`varstub''"
}
}

egen absent_school_amt = rowtotal(miss_school_nbdays_*), missing 
label var absent_school_amt "total number of school days missed for children in the household"

save "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_d_edu_labor-grp_edu-rpt_miss_school_wide.dta", replace



********

**-------- Prepare "Enquête à Haute Fréquence - Menage - midline - cohorte${cohort}-informed_consent-mod_y_coping_strategies-r_coping_strg" -------**

********


if ${hfs}==1 & ${cohort}==1 {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - 1er passage-informed_consent-mod_y_coping_strategies-r_coping_strg.dta", clear
}
else {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_y_coping_strategies-r_coping_strg.dta" , clear 
}

drop if hhid==. // those observations are empty.

*coping strategies
replace coping_strg_used=.r if coping_strg_used==-66
replace coping_strg_used=.d if coping_strg_used==-99

*reshape to wide format (houshold level)
ds hhid coping_strg_index, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

ds hhid coping_strg_index, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(coping_strg_index)

ds coping_strg_used_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label var `varstub'`i' "`l_`varstub''"
}
}

***Agregate at a household level*** 
label var coping_strg_used_1 "used coping strategy reduced food consumption"
label var coping_strg_used_2 "used coping strategy spend savings"
label var coping_strg_used_3 "used coping strategy sell livestock"
label var coping_strg_used_4 "used coping strategy sell foodstocks"
label var coping_strg_used_5 "used coping strategy withdraw children from school"


save "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_y_coping_strategies-r_coping_strg_wide.dta" ,    replace


********

**-------- Prepare "Enquête à Haute Fréquence - Menage - midline - cohorte${cohort}-informed_consent-mod_c_hh_roster-hh_unconf" -------**

********


if ${hfs}==1 & ${cohort}==1 {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - 1er passage-informed_consent-mod_c_hh_roster-hh_unconf.dta", clear
}
else {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_c_hh_roster-hh_unconf.dta" , clear 
}

drop if hhid==. // those observations are empty.

*Number of members of household that moved 

duplicates tag hhid, gen(duphhid)
gen nummemmove = duphhid + 1 if !missing(hhid)
label var nummemmove "number of members that have left the household"

*Store values to work out propostion of people who moved for a particular reason 

summ hhid 
global nmmv_hfs${hfs}_cohort${cohort} = `r(N)'

//number moved for work 
count if hh_unconf_why== 4 | hh_unconf_why== 5 | hh_unconf_why== 6 | hh_unconf_why== 7 | hh_unconf_why== 8 | hh_unconf_why== 9
global nmlvwk_hfs${hfs}_cohort${cohort} = `r(N)'

//number moved for reasons other than marrige/divorse/death  
count if hh_unconf_reason== 3
global nmlvlng_hfs${hfs}_cohort${cohort} = `r(N)'

//number moved outside commune but withing Niger

count if hh_unconf_where== 3 | hh_unconf_where== 4
global nmlvNiger_hfs${hfs}_cohort${cohort} = `r(N)'

//number moved outside Niger

count if hh_unconf_where== 5
global nmlvoutNiger_hfs${hfs}_cohort${cohort} = `r(N)'

*reshape to wide format (houshold level)
ds hhid hh_unconf_index, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

ds hhid hh_unconf_index, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(hh_unconf_index)

ds hh_unconf_why_o_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label var `varstub'`i' "`l_`varstub''"
}
}

rename nummemmove_1 nummemmove
foreach var of varlist nummemmove_* {
drop `var'
}


save "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_c_hh_roster-hh_unconf_wide.dta" ,    replace



********

**-------- Prepare "Enquête à Haute Fréquence - Menage - midline - cohorte${cohort}-informed_consent-mod_c_hh_roster-hh_unconf" -------**

********


if ${hfs}==1 & ${cohort}==1 {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - 1er passage-informed_consent-mod_X_shocks-r_shocks.dta", clear
}
else {
use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_X_shocks-r_shocks.dta" , clear 
}


drop if hhid==. // those observations are empty.

*weirdd results that shouldn't exist

drop if shock_index>13 & !missing(shock_index)


*reshape to wide format (houshold level)
ds hhid shock_index, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

ds hhid shock_index, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(shock_index)

ds shock_occur_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label var `varstub'`i' "`l_`varstub''"
}
}

*agregate at a household level 
label define socksev 1 "more severe" 2 "moderatly severe" 3 "less severe"

label var shock_occur_1 "shock drought occurred"
label var shock_sev_1 "severity of drought"
label values shock_sev_1 shocksev
label var shock_occur_2 "shock floods occurred"
label var shock_sev_2 "severity of flood"
label values shock_sev_2 shocksev
label var shock_occur_3 "shock crop disease occurred"
label var shock_sev_3 "severity of crop disease"
label values shock_sev_3 shocksev
label var shock_occur_4 "shock animal disease occurred"
label var shock_sev_4 "severity of animal disease"
label values shock_sev_4 shocksev
label var shock_occur_5 "shock price drop occurred"
label var shock_sev_5 "severity of price drop"
label values shock_sev_5 shocksev
label var shock_occur_6 "shock high agricularal input prices occurred"
label var shock_sev_6 "severity of high agri prices"
label values shock_sev_6 shocksev
label var shock_occur_7 "shock end of transfers from occurred"
label var shock_sev_7 "severity of end of transfers"
label values shock_sev_7 shocksev
label var shock_occur_8 "shock loss of non agri income occurred"
label var shock_sev_8 "severity of loss of non agri income"
label values shock_sev_8 shocksev
label var shock_occur_9 "shock bankrupcy of non agri business occurred"
label var shock_sev_9 "severity of bankrupcy"
label values shock_sev_9 shocksev
label var shock_occur_10 "shock loss of salary income occurred"
label var shock_sev_10 "severity of loss of salary income"
label values shock_sev_10 shocksev
label var shock_occur_11 "shock loss of paid employment occurred"
label var shock_sev_11 "severity of loss of paid employment"
label values shock_sev_11 shocksev
label var shock_occur_12 "shock serious accident or illness occurred"
label var shock_sev_12 "severity of accident or illness"
label values shock_sev_12 shocksev

save "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/Enquête à Haute Fréquence - Menage - passage${hfs} - cohorte${cohort}-informed_consent-mod_X_shocks-r_shocks_wide.dta" , replace




