**************************************************************************
*  *
*Generate variables from joint clened data set    *
*  *
***************************************************************************

/*
** PROJECT: Niger Shock-Reponsive Cash Transfers IE

** ROUND:

** USES:This do file generates primary and secondary variables that require a merged midline data set to generate. 


** PRODUCES:Intermediate datasets (by survey sections) in ${preparation}

** OUTLINE: 1. Remove duplicate surveys
2. Prepare household data
3. Prepare household member data
4. Prepare data by survey section and 
save each file in long and wide format


** Created BY:  Desmond Fairall

** MODIFIED ON: May 2023

*/

// use only if running without master
// global hfs = 2
// global cohort = 3

use "${high_frequency_intermediate}/HFS${hfs}/cohort${cohort}/cohort${cohort}_intermediate_data.dta", clear

****************************************************************************
* -------------- Gen Secondary Outcome Variables ---------------- *
****************************************************************************

 ** Consumption and food security 

replace amnt_excexp_rama=0 if cel_1==0
replace amnt_excexp_tab=0 if cel_2==0
replace amnt_excexp_bap=0 if cel_3==0
replace amnt_excexp_mar=0 if cel_4==0
replace amnt_excexp_aut=0 if cel_5==0

egen amnt_excexp=rowtotal(amnt_excexp_rama amnt_excexp_tab amnt_excexp_bap amnt_excexp_mar amnt_excexp_aut) , missing 
label variable amnt_excexp "amount of exceptionl expenditure"

** Labour markey participation 

foreach var of varlist ag_wage nonag_wage ag_emp_days_mean nonag_emp_days_mean  {
    replace `var'=0 if any_employment==0
}


foreach var of varlist lvs_wrk_days_mean lvs_care  {
    replace `var'=0 if own_livestock==0
}


foreach var of varlist num_days_ag_mean  {
    replace `var'=0 if hasplots==0
}

    foreach var of varlist num_days_bus_mean  {
    replace `var'=0 if business_any==0
}

        foreach var of varlist remit amt_remit {
    replace `var'=0 if sleep==0
}

  ** Revenue and Income 

foreach var of varlist ag_wage_inc nonag_wage_inc {
    replace `var'=0 if any_employment==0
}

** Finantial Engagement 

forval i = 1/5 {
    gen save`i'_win = save`i'
    winsor2 save`i'_win, replace cuts(0 98)
    replace save`i'_win = 0 if missing(save`i'_win)
    replace save`i' = 0 if missing(save`i')
}

label variable save1_win "amount saved in bank or other formal insitution in the last 30 days  (winsorised)"
label variable save2_win "amount saved in savings group in the last 30 days  (winsorised)"
label variable save3_win "amount saved with family outside of household in the last 30 days  (winsorised)"
label variable save4_win "amount saved with neighbours or friends in the last 30 days  (winsorised)"
label variable save5_win "amount saved with other source in the last 30 days  (winsorised)"

egen savetotal=rowtotal(save1 save2 save3 save4 save5), missing
label variable savetotal "total household saving"
egen savetotal_win=rowtotal(save1_win save2_win save3_win save4_win save5_win), missing
label variable savetotal_win "total household saving (winsorised)"

forval i = 1/4 {
    gen loan`i'_win = loan`i'
    winsor2 loan`i'_win, replace cuts(0 98)
    replace loan`i'_win = 0 if missing(loan`i'_win)
    replace loan`i' = 0 if missing(loan`i')
}

label variable loan1_win "amount of loan from family in the last 30 days (winsorised)"
label variable loan2_win "amount of loan from  freinds in the last 30 days (winsorised)"
label variable loan3_win "amount of loan from formal institution in the last 30 days (winsorised)"
label variable loan4_win "amount of loan from other person or group in the last 30 days (winsorised)"

egen loantotal=rowtotal(loan1 loan2 loan3 loan4), missing
label variable loantotal "total amount household loans in the last 30 days"
egen loantotal_win=rowtotal(loan1_win loan2_win loan3_win loan4_win), missing
label variable loantotal_win "total amount household loans in the last 30 days (winsorised)"


 foreach i of numlist 1/5 {
 replace withdrw`i'=0 if with_loc`i'==0
 gen withdrw`i'_win = withdrw`i'
 winsor2 withdrw`i'_win , replace cuts(2 98) 
}

label variable withdrw1_win "amount withdrawn from bank or other formal insitution in the last 30 days  (winsorised)"
label variable withdrw2_win "amount withdrawn from savings group in the last 30 days  (winsorised)"
label variable withdrw3_win "amount withdrawn from family outside of household in the last 30 days  (winsorised)"
label variable withdrw4_win "amount withdrawn from neighbours or friends in the last 30 days  (winsorised)"
label variable withdrw5_win "amount withdrawn from other source in the last 30 days  (winsorised)"

egen withdrwtotal=rowtotal(withdrw1 withdrw2 withdrw3 withdrw4 withdrw5), missing
label variable withdrwtotal "total household saving"
egen withdrwtotal_win=rowtotal(withdrw1_win withdrw2_win withdrw3_win withdrw4_win withdrw5_win), missing
label variable withdrwtotal_win "total household withdrew (winsorised)"

***Education 

replace absent_school_amt =0 if absent_school==0

* perception of violence index

replace ten_tension = . if ten_tension > 10 & !missing(ten_tension)

foreach var in ten_tension vill_burn {
sum `var' if treatment == 0
gen `var'_std = (`var' - r(mean))/r(sd)
}

egen vperception = rowtotal(ten_tension_std vill_burn_std), missing
replace vperception = vperception/2
replace vperception = -vperception // higher values are better
label variable vperception "\makecell{Violence \\ perceptions}"
drop ten_tension_std vill_burn_std

**household size and movement 

replace nummemmove = 0 if missing(nummemmove) & !missing(oldlist)

gen memleft = 0 if nummemmove == 0 
replace memleft = 1 if nummemmove > 1 & !missing(nummemmove) 
label variable memleft "at least one member left the household (0 1)"
/*
**Coping strategies 

egen totnumcopstrg = rowtotal(coping_strg_used_* other_copstr_rdcom other_copstr_cred other_copstr_adac other_copstr_mig other_copstr_frnd other_copstr_gov other_copstr_ngo other_copstr_god other_copstr_other), missing 
label variable totnumcopstrg "total number of coping strategies used"
*/

drop duphhid*
drop username
drop formdef_version

save "${high_frequency_final}/HFS${hfs}/cohort${cohort}/cohort${cohort}_final_data.dta", replace
