macro drop hfs
macro drop cohort

clear

use "${high_frequency_intermediate}/HFS1/cohort1/Enquête à Haute Fréquence - 1er passage-informed_consent-mod_i_consumption_exp-conexp_food_i-food_cons.dta"
save "${high_frequency_intermediate}/HFS1/cohort1/Enquête à Haute Fréquence - Menage - passage1 - cohorte1-informed_consent-mod_i_consumption_exp-conexp_food_i-food_cons.dta", replace

forval hfs = 1/2 {

clear
use "${high_frequency_intermediate}/HFS`hfs'/cohort1/main - passage`hfs' - cohorte1.dta"

keep village_name commune_name hhid cohort hfs treatment strat_vill_size strat_pmt vid
duplicates drop

tempfile first
save "`first'"

clear
use "${high_frequency_intermediate}/HFS`hfs'/cohort2/main - passage`hfs' - cohorte2.dta"

keep village_name commune_name hhid cohort hfs treatment strat_vill_size strat_pmt vid
duplicates drop

tempfile second
save "`second'"

clear
use "${high_frequency_intermediate}/HFS`hfs'/cohort3/main - passage`hfs' - cohorte3.dta"

keep village_name commune_name hhid cohort hfs treatment strat_vill_size strat_pmt vid
duplicates drop

tempfile third
save "`third'"

clear
use "${high_frequency_intermediate}/HFS`hfs'/cohort4/main - passage`hfs' - cohorte4.dta"

keep village_name commune_name hhid cohort hfs treatment strat_vill_size strat_pmt vid
duplicates drop

tempfile fourth
save "`fourth'"

clear
use "`first'"
append using "`second'"
append using "`third'"
append using "`fourth'"

tempfile geovars
save "`geovars'"

*******

* prepare food consumption modules for all cohorts

*******



clear
use "${high_frequency_intermediate}/HFS`hfs'/cohort1/Enquête à Haute Fréquence - Menage - passage`hfs' - cohorte1-informed_consent-mod_i_consumption_exp-conexp_food_i-food_cons.dta"
gen cohort = 1
append using "${high_frequency_intermediate}/HFS`hfs'/cohort2/Enquête à Haute Fréquence - Menage - passage`hfs' - cohorte2-informed_consent-mod_i_consumption_exp-conexp_food_i-food_cons.dta"
replace cohort = 2 if missing(cohort)
append using "${high_frequency_intermediate}/HFS`hfs'/cohort3/Enquête à Haute Fréquence - Menage - passage`hfs' - cohorte3-informed_consent-mod_i_consumption_exp-conexp_food_i-food_cons.dta"
replace cohort = 3 if missing(cohort)
append using "${high_frequency_intermediate}/HFS`hfs'/cohort4/Enquête à Haute Fréquence - Menage - passage`hfs' - cohorte4-informed_consent-mod_i_consumption_exp-conexp_food_i-food_cons.dta"
replace cohort = 4 if missing(cohort)

gen hfs = `hfs'

drop if missing(hhid)

merge m:1 hhid hfs cohort using "`geovars'"
keep if _merge == 3
drop _merge

sort hfs cohort hhid food_index, stable
destring food_index, replace
drop food_id
drop setoffood_cons
drop food_en // ignore english labels, they do not correspond to french labels
duplicates drop
drop if food_index == 14
drop if missing(food_fr)
rename food_fr consum2_name

label define food_source 1 "Bought" 2 "Own produce" 3 "Gift, barter, payment for work"
tab food_source, m // only a few HH chose multiple sources

label variable food_source_1 "bought"
label variable food_source_2 "own produce"
label variable food_source_3 "gift, barter, etc."

label variable hhid "Select respondent ID"
label variable food_consum "Did HH consume X in the last 7 days?"
label variable food_source "Source of the food consumed"
label variable food_quant_consum "Total quantity consumed in the last 7 days?"
label variable food_unit_consum "unit"

label variable food_quant_consum_st "How much does this correspond to in standard units?"
label variable food_unit_consum_st "Select standard unit [READ CHOICES]"

label variable food_quant_own "How many units are own production?"
label variable food_quant_other "How many units are gifts, barter, etc.?"

label variable food_purc "When was the last purchase?"
label variable food_quant_purc "Quantity of last purchase"
label variable food_unit_purc "Choose unit"
label variable food_val_purc "Value of last purchase"
label variable food_unit_diff "consumption unit by purchase unit"

drop food_unit_own food_unit_other

* change variable names to match names from midline and endline

rename food_index consum2_pos
rename food_consum consum2_ate
rename food_quant_consum consum_qty
rename food_unit_consum consum_u
rename food_unit_consum_oth consum_u_o

rename food_quant_own consum_prod
rename food_quant_other consum_gift

rename food_quant_purc consum_bot
rename food_unit_purc consum_bot_u
rename food_unit_purc_oth consum_bot_u_o
rename food_val_purc consum_bot_val
rename food_unit_diff consum_in_bot

destring consum2_pos consum2_ate, replace

label var consum_qty "quantity consumed"
label var consum_u "unit"
label var consum_u_o "non standard unit"
label var consum_bot "quantity of the good last purchased"
label var consum_bot_u "unit of reported quantity of the good last purchased"
label var consum_bot_u_o "non standard unit of reported quantity of the good last purchased"
label var consum_bot_val "total value of the quantity of the good purchased last time"
label var consum_in_bot "consumption unit by purchase unit"
note consum_in_bot: "how many of units of the unit reported for consumption are in the unit reported for purchasing"

label variable consum_prod "From qty consumed, how much is from HH production?"
label variable consum_gift "From qty consumed, how much is from gifts, payment in kind, etc.?"

drop nfood_unit_consum nfood_unit_purc
keep if consum2_ate == 1
drop consum2_ate

decode food_unit_consum_st, gen(temp)
drop food_unit_consum_st
rename temp food_unit_consum_st

replace food_unit_consum_st = strlower(food_unit_consum_st)

decode consum_u, gen(temp)
drop consum_u
rename temp consum_u

replace consum_u = strlower(consum_u)
replace consum_u = "kg" if consum_u == "kilogrammes"

decode consum_bot_u, gen(temp)
drop consum_bot_u
rename temp consum_bot_u

replace consum_bot_u = strlower(consum_bot_u)
replace consum_bot_u = "kg" if consum_bot_u == "kilogrammes"

order hhid consum2_name consum_qty consum_u food_quant_consum_st food_unit_consum_st consum_bot consum_bot_u
order consum2_pos, last

replace consum2_name = "haricots" if consum2_name == "Haricots Secs"
replace consum2_name = "huile_arachide" if consum2_name == "Huile d'arachide"
replace consum2_name = "huile_palme" if consum2_name == "Huile de palme"
replace consum2_name = "mais" if consum2_name == "Mais"
replace consum2_name = "mil" if consum2_name == "Mil"
replace consum2_name = "noix" if consum2_name == "Noix de cola"
replace consum2_name = "pates" if consum2_name == "Pates alimentaires"
replace consum2_name = "riz" if consum2_name == "Riz"
replace consum2_name = "sel" if consum2_name == "Sel"
replace consum2_name = "sorgho" if consum2_name == "Sorgho"
replace consum2_name = "sucre" if consum2_name == "Sucre"
replace consum2_name = "boeuf" if consum2_name == "Viande de boeuf"
replace consum2_name = "mouton" if consum2_name == "Viande de mouton"

drop if consum2_name == "boeuf" // NOTE

* clean consumption in two stages

* first take up the non-standard to standard conversions
tab consum2_name consum_u if missing(food_quant_consum_st)

* drop incompatible values
gen incompatible = 1 if consum2_name == "Huile de palme" & consum_u == "grammes"
replace incompatible = 1 if consum2_name == "Huile de palme" & consum_u == "kg"
replace incompatible = 1 if consum2_name == "Sel" & consum_u == "litres"
replace incompatible = 1 if consum2_name == "Sorgho" & consum_u == "litres"
replace incompatible = 1 if consum2_name == "Sucre" & consum_u == "litres"
replace incompatible = 1 if consum2_name == "Viande de mouton" & consum_u == "litres"

drop if incompatible == 1
drop incompatible

tab consum_u food_unit_consum_st

* incorrect values
replace food_quant_consum_st = . if food_unit_consum_st == "10kg" & consum_u == "botte"
replace food_quant_consum_st = . if food_unit_consum_st == "10kg" & consum_u == "sachet"
replace food_unit_consum_st = "" if missing(food_quant_consum_st)

* calculate the most common values for tia to kg
gen tvar = food_quant_consum_st / consum_qty if food_unit_consum_st == "1kg" & consum_u == "tia"
sum tvar, d
bysort consum2_name: sum tvar, d
// twoway (histogram tvar if tvar < 3 & tvar > 2)
* modal value is 2.5 kg per tia and middle 90 percent of values are between 2 and 3 for most food items

order hfs cohort hhid consum2_name consum_qty consum_u food_quant_consum_st food_unit_consum_st tvar

* set extreme values to missing
replace food_quant_consum_st = . if tvar > 5 & tvar < .
replace food_unit_consum_st = "" if tvar > 5 & tvar < .
drop tvar

* now apply the conversions

replace food_quant_consum_st = food_quant_consum_st * (1 / 1000) if food_unit_consum_st == "1g"
replace food_quant_consum_st = food_quant_consum_st * (10 / 1000) if food_unit_consum_st == "10g"
replace food_quant_consum_st = food_quant_consum_st * (100 / 1000) if food_unit_consum_st == "100g"
replace food_quant_consum_st = food_quant_consum_st * (500 / 1000) if food_unit_consum_st == "500g"
replace food_quant_consum_st = food_quant_consum_st * 1 if food_unit_consum_st == "1kg"
replace food_quant_consum_st = food_quant_consum_st * 10 if food_unit_consum_st == "10kg"

* use the same modal value to make correction for tia to 10kg

gen tvar = food_quant_consum_st / consum_qty if food_unit_consum_st == "10kg" & consum_u == "tia"

replace food_quant_consum_st = . if tvar > 5 & tvar < .
replace food_unit_consum_st = "" if tvar > 5 & tvar < .
drop tvar

replace food_unit_consum_st = "kg" if !missing(food_unit_consum_st)

* set extreme values missing 
gen cvar = food_quant_consum_st / consum_qty if consum2_name == "Sel" & food_unit_consum_st == "kg" & consum_u == "sachet"
sum cvar, d
replace food_quant_consum_st = . if cvar >= r(p99) & !missing(cvar)
drop cvar
replace food_unit_consum_st = "" if missing(food_quant_consum_st)

* store variables so that we can use non-standard units to convert bought quantities and units
gen conversion = food_quant_consum_st / consum_qty
order hhid consum2_name consum_qty consum_u food_quant_consum_st food_unit_consum_st conversion

label variable conversion "# of kg per tia or sachet or tas or ..."
gen over = food_unit_consum_st if !missing(conversion)
gen under = consum_u if !missing(conversion)
label variable under "original non-standard consumption unit"

sum conversion, d
* correct some values manually
replace food_quant_consum_st = . if conversion > 10 & conversion < .
replace food_unit_consum_st = "" if conversion > 10 & conversion < .
replace conversion = . if conversion > 10 & conversion < .

* now bring in the standardized units and values
replace consum_qty = food_quant_consum_st if !missing(food_quant_consum_st)
replace consum_u = food_unit_consum_st if !missing(food_unit_consum_st)

drop food_quant_consum_st food_unit_consum_st
order hhid consum2_name consum_qty consum_u under conversion

* now clean standard values and quantities

foreach var in consum_qty consum_prod consum_gift {
    replace `var' = `var' / 1000 if consum_u == "grammes"
    replace `var' = `var' * 50 if consum_u == "sac de 50 kg"
    replace `var' = `var' * 100 if consum_u == "sac de 100 kg"
}

replace consum_u = "kg" if inlist(consum_u, "grammes", "sac de 50 kg", "sac de 100 kg")

foreach var in consum_qty consum_prod consum_gift {
    replace `var' = `var' / 1000 if consum_u == "millilitre"
} 

replace consum_u = "litres" if inlist(consum_u, "millilitre")

label define food_purc 1 "yesterday" 2 "past 7 days (before yesterday)" 3 "past 30 days (before past 8 days)" 4 "past 12 months (before 30 days)" 5 "more than a year" 6 "never", replace
drop consum_in_bot

order consum2_name consum_bot_val consum_bot consum_bot_u
sort consum2_name
order hhid, last

sum consum_bot_val, d
sum consum_bot, d

* now clean bought values

replace consum_bot = consum_bot / 1000 if consum_bot_u == "grammes"
replace consum_bot = consum_bot * 50 if consum_bot_u == "sac de 50 kg"
replace consum_bot = consum_bot * 100 if consum_bot_u == "sac de 100 kg"

replace consum_bot_u = "kg" if inlist(consum_bot_u, "grammes", "sac de 50 kg", "sac de 100 kg")

replace consum_bot = consum_bot / 1000 if consum_bot_u == "millilitre"
replace consum_bot_u = "litres" if inlist(consum_bot_u, "millilitre")

order consum2_name conversion consum_bot_val consum_bot consum_bot_u under consum_u hfs cohort

tab over if !missing(conversion)
tab under if !missing(conversion)

tab consum_u if !missing(conversion)
tab consum_bot_u if !missing(conversion)

* use the earlier stored conversion to convert non-kg bought units
replace consum_bot = consum_bot * conversion if !missing(conversion) & under == consum_bot_u
replace consum_bot_u = over if !missing(conversion) & under == consum_bot_u
replace consum_bot_u = "" if missing(consum_bot)

// replace consum_bot = consum_bot * conversion if !missing(conversion) & consum_bot_u != "kg"
// replace consum_bot_u = over if !missing(conversion) & under == consum_bot_u

gen assign_prices = 1 if consum_u == consum_bot_u & missing(conversion) // consumed and bought in the same unit
replace assign_prices = 2 if consum_u == consum_bot_u & !missing(conversion) // consumed and bought in different units, used conversion
replace assign_prices = 3 if missing(assign_prices) & food_purc < 6 // conversion not available, impute prices
replace assign_prices = 4 if missing(assign_prices) & food_purc == 6 // never bought, impute prices
tab assign_prices, m

* do this for those food items which were never bought
replace consum_bot_u = consum_u if assign_prices == 4

* calculate unit prices
gen bot_unit_price = consum_bot_val / consum_bot if (assign_prices == 1 | assign_prices == 2)

sum bot_unit_price, d
_pctile bot_unit_price, p(98)
replace consum_bot = . if bot_unit_price > r(r1) & !missing(bot_unit_price)
replace consum_bot_val = . if bot_unit_price > r(r1) & !missing(bot_unit_price)
replace bot_unit_price = . if bot_unit_price > r(r1) & !missing(bot_unit_price)
sum bot_unit_price, d

* winsorize quantities of foods consumed

egen gg = group(consum_u)
levelsof gg, local(dunits)

foreach du in `dunits' {
    foreach var in consum_qty consum_prod consum_gift {
        _pctile `var' if gg == `du', p(98)
        replace `var' = r(r1) if `var' > r(r1) & !missing(`var') & gg == `du'
    }
}

drop gg

* winsorize quantities of foods purchased

order consum2_name consum_bot_val consum_bot consum_bot_u
sort consum2_name
order hhid, last

order hhid consum2_name consum_qty consum_u conversion consum_bot consum_bot_val bot_unit_price consum_bot_u under
label variable bot_unit_price "unit price"


capture drop key parent_key
duplicates drop

order commune_name village_name consum2_pos consum2_name consum_bot_u consum_bot_val consum_bot bot_unit_price
sort commune_name village_name consum2_pos consum2_name consum_bot_u

tempfile brk
save "`brk'"

collapse (median) bot_mp_commune = bot_unit_price (count) mp_commune_count = bot_unit_price, by(commune_name consum2_pos consum2_name consum_bot_u)
drop if missing(consum_bot_u)
drop if consum_bot_u == "autre"
drop if mp_commune_count < 5
tempfile commune
save "`commune'"

clear 
use "`brk'"

collapse (median) bot_mp_village = bot_unit_price (count) mp_village_count = bot_unit_price, by(village_name consum2_pos consum2_name consum_bot_u)
drop if missing(consum_bot_u)
drop if consum_bot_u == "autre"
drop if mp_village_count < 5
tempfile village
save "`village'"

clear 
use "`brk'"

collapse (median) bot_mp_region = bot_unit_price (count) mp_region_count = bot_unit_price, by(consum2_pos consum2_name consum_bot_u)
drop if missing(consum_bot_u)
drop if consum_bot_u == "autre"
drop if mp_region_count < 5
tempfile region
save "`region'"

clear
use "`brk'"
merge m:1 commune_name consum2_pos consum2_name consum_bot_u using "`commune'"
drop _merge
merge m:1 village_name consum2_pos consum2_name consum_bot_u using "`village'"
drop _merge
merge m:1 consum2_pos consum2_name consum_bot_u using "`region'"
drop _merge

quietly gen proxy = .
order consum2_pos consum2_name proxy consum_qty bot_unit_price consum_bot_u bot_mp_commune mp_commune_count bot_mp_village mp_village_count assign_prices
replace proxy = consum_qty * bot_unit_price
sum proxy, d

if "${impute_rule}" == "village" {
    replace proxy = consum_qty * bot_mp_village if missing(proxy)
    replace proxy = consum_qty * bot_mp_commune if missing(proxy)
    replace proxy = consum_qty * bot_mp_region if missing(proxy)
}

if "${impute_rule}" == "commune" {
    replace proxy = consum_qty * bot_mp_commune if missing(proxy)
    replace proxy = consum_qty * bot_mp_region if missing(proxy)
}

if "${impute_rule}" == "region" {
    replace proxy = consum_qty * bot_mp_region if missing(proxy)
}

sum proxy, d

drop bot_mp_*
drop mp_*
drop under over
drop food_purc
drop conversion
drop food_source
drop food_source_*
drop bot_unit_price
drop assign_prices
drop consum2_pos

local identifiers hfs cohort hhid consum2_name village_name commune_name treatment strat_vill_size strat_pmt vid
ds `identifiers', not

foreach var in `r(varlist)' {
    ren `var' `var'_
    local l_`var'_ : variable label `var'_
}

order hfs cohort hhid consum2_name, first
sort hfs cohort hhid consum2_name, stable
// destring consum2_pos, replace

ds `identifiers', not
local stubnames "`r(varlist)'"
reshape wide `stubnames', i(hfs cohort hhid) j(consum2_name) string

ds proxy_*
local count = wordcount("`r(varlist)'")
di "`count'"

merge m:1 hhid using "${high_frequency_intermediate}/HFS`hfs'/cohort1/main - passage`hfs' - cohorte1.dta", keepusing(submissiondate year month deflator) update replace
drop if _merge == 2
drop _merge

merge m:1 hhid using "${high_frequency_intermediate}/HFS`hfs'/cohort2/main - passage`hfs' - cohorte2.dta", keepusing(submissiondate year month deflator) update replace
drop if _merge == 2
drop _merge

merge m:1 hhid using "${high_frequency_intermediate}/HFS`hfs'/cohort3/main - passage`hfs' - cohorte3.dta", keepusing(submissiondate year month deflator) update replace
drop if _merge == 2
drop _merge

merge m:1 hhid using "${high_frequency_intermediate}/HFS`hfs'/cohort4/main - passage`hfs' - cohorte4.dta", keepusing(submissiondate year month deflator) update replace
drop if _merge == 2
drop _merge

replace proxy_mais = proxy_mais/deflator
replace proxy_mil = proxy_mil/deflator
replace proxy_riz = proxy_riz/deflator

* winsorize weekly consumption, each food group

ds proxy_*

foreach var in `r(varlist)' {
winsor2 `var', replace cuts(0 98)
rename `var' `var'_win

}

* multiply each item by four 

ds proxy_*_win

foreach var in `r(varlist)' {
   qui gen `var'_mt = 4 * `var'
   drop `var'
}

* sum across items

ds proxy_*_mt
egen proxycon_mt = rowtotal(`r(varlist)'), missing

* winsorize total monthly consumption

* winsor2 proxycon_mt, replace cuts(0 98)
* winsor2 hhfdcon_mt, replace cuts(0 98)

label var proxycon_mt "\makecell{Food \\ consumption}"

label variable proxy_mais_win_mt "Maize"
label variable proxy_mil_win_mt "Mil"
label variable proxy_sel_win_mt "Sel"
label variable proxy_sucre_win_mt "Sucre"
label variable proxy_riz_win_mt "Riz"
label variable proxy_huile_palme_win_mt "Palm oil"
label variable proxy_mouton_win_mt "Mutton"
label variable proxy_noix_win_mt "Noix de cola"
label variable proxy_sorgho_win_mt "Sorghum"
label variable proxy_huile_arachide_win_mt "Peanut oil"
label variable proxy_haricots_win_mt "Haricots secs"
label variable proxy_pates_win_mt "Pates"

sum proxycon_mt
order hhid proxycon_mt proxy*

drop consum_*
drop strat_vill_size strat_pmt vid deflator
drop commune_name submissiondate year month village_name
drop treatment

tabstat proxy_*, stat(n mean sd min max) col(stat) varwidth(40)

save "${high_frequency_final}/hfs_`hfs'_food_consumption_final.dta", replace
}
