**************************************************************************
*  *
*PREPARATION CLEANING NIGER SHOCK RESPONSE IE     *
*  *


****************************************************************************
* -------------- Intial cleaning for all files ---------------- *
****************************************************************************

// use only if running without master
// global cohort = 1

* ------------------------------------
* a. remove duplicates from each file 
* ------------------------------------

use "${midline_raw_admin}/cohorte_reassignement_midline.dta", clear
gen surveyed_twice = cohorte != cohorte_new
replace surveyed_twice = 0 if missing(surveyed_twice)
keep hhid surveyed_twice cohorte_new
rename cohorte_new cohort_new
save "${midline_final}/reassigns.dta", replace

clear
import excel "${midline_raw_admin}/hfc_duplicates_midline_cohorte${cohort}.xlsx", clear firstrow
keep if drop == "drop"
keep key
rename key instance
tempfile mid_drop
save "`mid_drop'"

clear
use "${midline_raw}/cohort${cohort}/midline - cohorte${cohort}.dta"
destring hhid, replace
drop if missing(hhid)
keep hhid key
rename key instance
tempfile hhid_key_v19
save "`hhid_key_v19'", replace

local dta_files : dir "${midline_raw}/cohort${cohort}" files "*.dta"

foreach dta_file in `dta_files' {
    display as error "`dta_file'"
    use "${midline_raw}/cohort${cohort}/`dta_file'", clear
}

foreach dta_file in `dta_files' {
    display as error "`dta_file'"
    use "${midline_raw}/cohort${cohort}/`dta_file'", clear
    
    * drop duplicates in each file 
    
    cap sum parent_key
    
    if _rc == 0 {
        di "this is a long form dataset, with parent key and key"
        
        * first 41 characters are the instance/survey id
        gen instance = substr(parent_key, 1, 41)
        drop parent_key
        drop key
        
        quietly merge m:1 instance using "`mid_drop'", gen(_merge)
        keep if _merge == 1
        drop _merge
        
        quietly merge m:1 instance using "`hhid_key_v19'"
        keep if _merge == 3
        drop _merge
        drop instance
        destring hhid, replace
        order hhid, first
        
        gen cohort = $cohort
        
        order hhid, first

        merge m:1 hhid using "${midline_final}/reassigns.dta", keepusing(cohort_new)
        keep if _merge == 3
        drop _merge
        drop if cohort != cohort_new
        drop cohort_new
        drop cohort

    }
    
    else {
        di "this is a wide form dataset"
        rename key instance
        merge 1:1 instance using "`mid_drop'", gen(_merge)
        keep if _merge == 1
        drop _merge

        destring hhid, replace
        order hhid, first
        
        gen cohort = $cohort
        merge 1:1 hhid using "${midline_final}/reassigns.dta", keepusing(cohort_new)
        keep if _merge == 3
        drop _merge
        drop if cohort != cohort_new
        drop cohort_new

        order hhid, first
        
    }
    
        capture drop setof*
        capture drop end_*
        capture drop start_*
        capture drop pull_rel_*

        capture drop pull_*
        capture drop age_mem*
        capture drop resp_santeeduc_*
        capture drop employment_hh_mems_*
        capture drop calc_strategy*u
    
    * shorten variable labels for Stata 13
    foreach i of varlist _all {
      local longlabel: variable label `i'
      local shortlabel = substr(`"`longlabel'"', 1, 79)
      label variable `i' `"`shortlabel'"'
    }

    quietly ds *, not(type string)
    local nostrings = r(varlist)
    quietly {
    * reocde numeric to missing
    mvdecode `nostrings', mv(-999 = .r) // refused
    mvdecode `nostrings', mv(-888 = .d) // don't know
    mvdecode `nostrings', mv(-777 = .o) // other
    mvdecode `nostrings', mv(-666 = .n) // na 
    mvdecode `nostrings', mv(-555 = .g) // god or unknown relation
    mvdecode `nostrings', mv(-333 = .m) 
    mvdecode `nostrings', mv(-222 = .r)
    mvdecode `nostrings', mv(-111 = .i)
    mvdecode `nostrings', mv(-99 = .i)
    mvdecode `nostrings', mv(-88 = .i)
    mvdecode `nostrings', mv(-77 = .i)
    }

duplicates drop   
save "${midline_intermediate}/cohort${cohort}/`dta_file'", replace

}

*/

* use village names from endline data
clear
use "${endline_intermediate}/main_temp.dta"

keep commune commune_name village village_name treatment strat_vill_size strat_pmt vid
duplicates drop
sort commune_name village_name, stable
distinct commune_name village_name vid
* note there are 171 villages, village kodey appears twice
* use vid in regressions

tab commune
tab commune_name

/*
. tab commune

    Commune |      Freq.     Percent        Cum.
------------+-----------------------------------
         49 |         98       57.31       57.31
       8980 |         39       22.81       80.12
       9223 |         34       19.88      100.00
------------+-----------------------------------
      Total |        171      100.00

. tab commune_name

commune_nam |
          e |      Freq.     Percent        Cum.
------------+-----------------------------------
DANTCHANDOU |         39       22.81       22.81
     IMANAN |         34       19.88       42.69
    TAGAZAR |         98       57.31      100.00
------------+-----------------------------------
      Total |        171      100.00

*/


* 171 villages
* 3 communes

tempfile reference
save "`reference'"

* price deflator data
clear
use "${community_final}/median_prices_all_commodities.dta"
keep commune_name year month deflator
replace commune_name = strupper(commune_name)

tempfile deflator
save "`deflator'"

* -------------- Clean Each Long file Separatly ---------------- *

******

**--------------------- Prepare Main Data set  "midline - cohorte${cohort}.dta" -------------------------**

******


*a. prep main file
*----------------- 

** Variable types changed during SurveyCTO import -- fix
clear
use "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}.dta"
drop if missing(hhid)
replace village_name = "GAOALJANA" if village_name == "GAO-ALJANA"
merge m:1 village_name commune_name using "`reference'", keepusing(treatment strat_vill_size strat_pmt vid)
drop if _merge == 2
drop _merge
capture drop treated_pull
capture drop treat_pull
capture drop treatment_pull
capture drop treatment_definition

* add in price deflator

capture drop current_month

gen dd = dofc(submissiondate)
format dd %td
gen month = month(dd)
gen year = year(dd)
order hhid commune_name submissiondate year month
drop dd

merge m:1 commune_name year month using "`deflator'"

drop if _merge == 2
drop _merge

merge 1:1 hhid instance using "${midline_raw}/enumerators-cohort${cohort}.dta"
keep if _merge == 3
drop _merge
duplicates report hhid

tempfile mainfile
save "`mainfile'"

save "${midline_intermediate}/cohort${cohort}/main - cohorte${cohort}.dta", replace

clear
use "`mainfile'"

*reconde to fix specific variables 

tostring miss_school_hh_mems, replace 

if $cohort == 1 {
replace  livestock_use="3" if  livestock_use=="1 2"
destring livestock_use, replace
}
destring livestock_use, replace
label define livestock_use_val 0 "none" 1 "yes, sold" 2 "yes, consumed" 3 "yes, sold and consumed"
label values livestock_use livestock_use_val

gen lvsused =. 
label variable lvsused "any livestock consumed or sold (0,1)"
replace lvsused = 0 if livestock_use == 0
replace lvsused = 1 if livestock_use == 1 | livestock_use == 2 | livestock_use == 3



*** Primary Variable Cantril Cleaning ****
codebook stair_satis_today
label variable stair_satis_today "cantril ladder current"
*138 missing 


*** Secondary Vairable Cleaning ***

*food security 
codebook food8

label variable food8b "How often did you go a whole day with no food?"
label define food8b 1 "only once or twice or never" 2 "a few months but not every month" 3 "almost every month", replace
label values food8b food8b

replace food8b = 1 if food8 == 0

gen food8b_rev = -food8b
label variable food8b_rev "\makecell{How often \\ days with food}"

gen food8_rev = 1 if food8 == 0
replace food8_rev = 0 if food8 == 1
label variable food8_rev "\makecell{Not hungry \\ all day?}"

*labour market participation 
codebook important_activity
label variable important_activity "most important activity for the household in the last 30 days"
label define varlab_activity 0 "none" 1 "agriculture" 2 "breeding" 3 "salaried employment" 4 "other income generating activities"
label values important_activity varlab_activity

gen off_farm =. 
replace off_farm = 0 if important_activity==0 | important_activity==1 | important_activity==2 
replace off_farm = 1 if important_activity==3 | important_activity==4
label variable off_farm "most important activity for household is not agriculutre"
label values off_farm noyes

codebook any_employment
replace any_employment=.r if any_employment==-66
replace any_employment=.d if any_employment==-99

codebook own_livestock
replace own_livestock=.r if own_livestock==-66
replace own_livestock=.d if own_livestock==-99


*Agriculture and livestock activities 

ds plot_name*, has(type numeric)

foreach var in `r(varlist)' {
tostring `var', replace
}

label variable hasplots "household has engaed in agricultural activity"

gen prodsold = crop_didsell 
label variable prodsold "hould sold any produce"
replace prodsold = 0 if hasplots==0

gen prodsold_rev = crop_didsell_amt
label variable prodsold_rev "revenue generated from selling produce"
replace prodsold_rev = 0 if hasplots==0

gen usepaidlbr = paid_labor
replace usepaidlbr = 0 if hasplots==0
label variable usepaidlbr "household used paid labour for cultivating"

gen paidlbr_amt = paid_labor_total 
replace paidlbr_amt = 0 if usepaidlbr==0
label variable paidlbr_amt "total household paid for labour for cultivating"

gen usemutlbr = mutual_labor
replace usemutlbr = 0 if hasplots==0
label variable usemutlbr "household used mutual labour for cultivating"

label variable crop_seed_kind "what type of seed did household use"
label define seedkind 1 "local" 2 "improved"
label values crop_seed_kind seedkind


*Revenue and Income 

label variable lstock_turnover "livestock revenue"

gen harvalue = crop_didsell_amt 
label variable harvalue "value of crop sales in last 30 days"
replace harvalue = 0 if crop_didsell==0

*Agriculture  and livestock activities 

foreach var in crop_seed_purch crop_fert_purch {
    winsor2 `var', cuts(0 98) replace
}

label variable crop_seed "purchased seeds"
label variable crop_fert "bought chemical or inorganic fertiliser"
label variable crop_seed_purch "amount spent purchasing seeds"
replace crop_seed_purch=0 if crop_seed==0
label variable crop_fert_purch "amount spent purchasing fertiliser"
replace crop_fert_purch=0 if crop_fert==0

label variable sowing "family has already sown lands for this agricultural season"

*Finantial engagement 

gen savings = .
label variable savings "households saved in the last 30 days (0,1)"
replace savings = 1 if save_loc1 == 1 | save_loc2 == 1 | save_loc3 == 1 | save_loc4 == 1 | save_loc5 == 1
replace savings = 0 if missing(savings)

gen loan = .
label variable loan "households took out a loan in the last 30 days"
replace loan = 1 if cred_1 == 1 | cred_2 == 1 | cred_3 == 1 | cred_4 == 1
replace loan = 0 if missing(loan)

gen withdrw=.
label variable withdrw "households withdrew from savings in the last 30 days"
replace withdrw=0 if !missing(with_loc1) | !missing(with_loc2) | !missing(with_loc3) | !missing(with_loc4) | !missing(with_loc5) 
replace withdrw=1 if with_loc1==1 | with_loc2==1 | with_loc3==1 | with_loc4==1 | with_loc5==1

gen remittance = trans_fam
label variable remittance "remittances recieved (0,1)"

gen remittance_amt = trans_amt
replace remittance_amt = 0 if remittance==0

gen remittance_send = trans_fam_send
label variable remittance_send "household has sent remittances (0,1)"

gen remittance_sent_amt = trans_amt_send
replace remittance_sent_amt = 0 if remittance_send==0

label variable accesstofunds "Probability of putting together CFA 30,000 in the next month?"
label values accesstofunds .
recode accesstofunds (1 = 1) (2 = 1) (3 = 0) (4 = 0)
label define accesstofunds 0 "Very unlikely" 1 "Very likely", replace
label values accesstofunds accesstofunds
gen risk_sharing = accesstofunds
label variable risk_sharing "\makecell{Risk-sharing \\ ability}"

***Livestock 

label variable hh_chicken "number of chickens household owns or rents"
label variable hh_goat "number of chickens household owns or rents"
label variable hh_cow "number of chickens household owns or rents"
label variable hh_sheep "number of chickens household owns or rents"
label variable hh_loth "number of other livestock household owns or rents"
    
gen has_chicken=.
label variable has_chicken "household owns or rents chickens (0,1)"
replace has_chicken=0 if own_livestock==0
replace has_chicken=1 if hh_chicken>1 & !missing(hh_chicken)

gen has_goat=.
label variable has_chicken "household owns or rents goats (0,1)"
replace has_goat=0 if own_livestock==0
replace has_goat=1 if hh_goat>1 & !missing(hh_goat)

gen has_cow=.
label variable has_chicken "household owns or rents cows (0,1)"
replace has_cow=0 if own_livestock==0
replace has_cow=1 if hh_cow>1 & !missing(hh_cow)

gen has_sheep=.
label variable has_chicken "household owns or rents sheep (0,1)"
replace has_sheep=0 if own_livestock==0
replace has_sheep=1 if hh_sheep>1 & !missing(hh_sheep)

gen has_loth=.
label variable has_chicken "household owns or rents other livestock (0,1)"
replace has_loth=0 if own_livestock==0
replace has_loth=1 if hh_loth>1 & !missing(hh_loth)

*clean up other livestock options
replace hh_livestockx = "Ane" if hh_livestockx == "ANE" | hh_livestockx == "Anne" | hh_livestockx == "ane" | hh_livestockx == "Âne" |  | hh_livestockx == "Ané" | hh_livestockx == "Aîné" | hh_livestockx == "Àne" | hh_livestockx == "âne" | hh_livestockx == "L anne"
replace hh_livestockx = "Chameau" if hh_livestockx == "Chameaux" | hh_livestockx == "Chamaux"
replace hh_livestockx = "Pintade" if hh_livestockx == "PINTADE" | hh_livestockx == "Paintade"
replace hh_livestockx = "Pigeon" if hh_livestockx == "Pigeons"

*intermediate variable for tlu score 
gen hh_loth_tlu =.
replace hh_loth_tlu = 1.1*hh_loth if hh_livestockx== "Chameau"
replace hh_loth_tlu = 0.8*hh_loth if hh_livestockx== "Ane"
replace hh_loth_tlu = 0.8*hh_loth if hh_livestockx== "Cheval"
replace hh_loth_tlu = 0.03*hh_loth if hh_livestockx== "Pintade"
replace hh_loth_tlu = 0.1*hh_loth if hh_livestockx== "Chèvres"

foreach var of varlist hh_chicken hh_goat hh_cow hh_sheep hh_loth hh_chicken_ate hh_goat_ate hh_cow_ate hh_sheep_ate hh_loth_ate {
gen temp_`var'= `var'
winsor2 temp_`var', cuts(0 98) replace
replace temp_`var' = 0 if missing(`var')
}

gen livestock_tlu=.
label variable livestock_tlu "livestock count TLU"
replace livestock_tlu=0 if own_livestock==0 
replace livestock_tlu = 0.01*temp_hh_chicken + 0.1*temp_hh_goat + 0.7*temp_hh_cow + 0.1*temp_hh_sheep + temp_hh_loth
replace livestock_tlu=. if missing(hh_chicken) & missing(hh_goat) & missing(hh_cow) & missing(hh_sheep) & missing(hh_loth) 
replace livestock_tlu = 0 if missing(livestock_tlu)

gen lvsconsm =. 
label variable lvsconsm "number of live stock livestock consumed, using tropical livestock conversion units"
replace lvsconsm = 0.01*temp_hh_chicken_ate + 0.1*temp_hh_goat_ate + 0.7*temp_hh_cow_ate + 0.1*temp_hh_sheep_ate + temp_hh_loth_ate
replace lvsconsm = 0 if missing(hh_chicken_ate) & missing(hh_goat_ate) & missing(hh_cow_ate) & missing(hh_sheep_ate) & missing(hh_loth_ate) 

gen lvs_rev = lstock_turnover
label variable lvs_rev "livestock revenue"
replace lvs_rev = 0 if own_livestock==0 

drop temp_*

***Psychosocial 

gen mh_both = cd1
label variable mh_both "Number of days the details of life bothered repondent more then usual"
gen mh_trbl = cd2
label variable mh_trbl "Number of days repondent had trouble concentrating"
gen mh_sad = cd3_new
label variable mh_sad " Number of days repondent felt sad"
gen mh_engy = cd4
label variable mh_engy "Number of days respondent felt everthing took all their energy"
gen mh_cnf = cd5
label variable mh_cnf "Number of days respondent felt confident about the future"
gen mh_nerv = cd6_new
label variable mh_nerv "Number of days respondent felt nervous tense or worried"
gen mh_sleep = cd7
label variable mh_sleep "Number of days respondent had trouble sleeping peacfully"
gen mh_hppy = cd8
label variable mh_hppy "Number of days respondent felt happy"
gen mh_lnly = cd9
label variable mh_lnly "Number of days respondent felt lonely"
gen mh_trd = cd10_new
label variable mh_trd "Number of days respondent felt so tired that they couldn't do anything"
gen mh_uls = useless
label variable mh_uls "Number of days respondent felt useless"

replace cd5 = 7-cd5
replace cd8 = 7-cd8

egen mentalhealth = rowtotal(cd1 cd2 cd3_new cd4 cd5 cd6_new cd7 cd8 cd9 cd10_new useless), missing
/* Phyllisa march 19th 2025 we standardise other rounds using baseline values.
sum mentalhealth if treatment == 0
replace mentalhealth = mentalhealth - r(mean)
replace mentalhealth = mentalhealth/r(sd)

replace mentalhealth = -mentalhealth */ // higher values mean better health
label variable mentalhealth "\makecell{Mental \\ health}"



gen socialcohesion =.  
replace socialcohesion = 0 if tens==1
replace socialcohesion = 1 if tens==0
label variable socialcohesion "The household has not tensions with any other members of the comunity in the last 30 days (0,1)"

label variable ten_tension "How many women out of ten experaince tention in their household?"
label variable vill_burn "In this village is it common for husbands to beat their wives if they burn food?"
label define villburn 1 "no" 2 "could happen" 3 "usual" 4 "very usual"
label values vill_burn villburn


label variable att_next_crop "How good did the household think the next harvest would be, 1- 10 where 1 is the worst and 10 is the best"


***Business Outcomes

gen business_num_uc = business_num 
label variable business_num_uc "number of household businesses"
replace business_num_uc=0 if business_any==0

forval i = 1/2 {
foreach var in enterprise_revenue_`i' enterprise_profit_`i' bus2_assval_`i' {
    winsor2 `var', replace cuts(0 98)
}
}

egen business_rev = rowtotal(enterprise_revenue_1 enterprise_revenue_2)
label variable business_rev "revenue from households two main businesses"

egen business_pft = rowtotal(enterprise_profit_1 enterprise_profit_2)
label variable business_pft "profit from households two main businesses"

egen business_assval = rowtotal(bus2_assval_1 bus2_assval_2)
label variable business_assval "asset value from households two main businesses"

drop enterprise_member_work_*
split enterprise_member_work, parse(" ")
drop enterprise_member_work
destring enterprise_member_work1 enterprise_member_work2, replace
egen nbusworkers = rownonmiss(enterprise_member_work1 enterprise_member_work2)
label variable nbusworkers "\makecell{\# of people \\ who worked in business}"
drop enterprise_member_work1 enterprise_member_work2

gen business_invest = . 
label variable business_invest "household is planning to invest in one of its main businesses in the next 12 months"
replace business_invest = 0 if business_any==0
replace business_invest = 0 if !missing(bus_future_1) | !missing(bus_future_2)
replace business_invest = 1 if bus_future_1==2 | bus_future_2==2

gen business_numwrks = bus2_outworkers
label variable business_numwrks "number of non household memeber workers employed by family busineses"
replace business_numwrks=. if bus2_outworkers>100 //a few large values reported i.e. 7000


*** Education 

gen absent_school =. 
label variable absent_school "missed school (0,1)"
replace absent_school = 0 if miss_school==0
replace absent_school = 1 if miss_school==1

gen aford_school = school_fees 
label variable aford_school "could not afford to pay education expense in the last 30 days"

***Consumption and Food Security

egen mdd_w_score = rowtotal(div_cereal_mom div_pulse_mom div_pulse2_mom div_milk_mom div_meat_mom div_egg_mom div_veg_mom div_fruit1_mom div_veg_vita_mom div_fruit_mom) , missing 
label variable mdd_w_score "women dietry diversity score (0-10)"

egen pulsex = rowmax(div_pulse_mom div_pulse2_mom)
egen meatx = rowmax(div_meat_mom div_egg_mom)
egen vegx = rowmax(div_veg_mom div_veg_vita_mom)
egen fruitx = rowmax(div_fruit1_mom div_fruit_mom)

gen fcs_mother = 2*div_cereal_mom + 3*pulsex + 1*vegx + 1*fruitx + 4*meatx + 4*div_milk_mom
replace fcs_mother = fcs_mother*7
label variable fcs_mother "FCS (mother)"

drop pulsex meatx vegx fruitx

egen mdd_i_score = rowtotal(div_cereal_child div_pulse_child div_milk_child div_meat_child div_egg_child div_fruit_vita_child div_fruit_child), missing 
label variable mdd_i_score "child dietry diversity score (0-7)"

egen pulsex = rowmax(div_pulse_child)
egen meatx = rowmax(div_meat_child div_egg_child)
egen vegx = rowmax(div_egg_child)
egen fruitx = rowmax(div_fruit_vita_child div_fruit_child)

gen fcs_infant = 2*div_cereal_child + 3*pulsex + 1*vegx + 1*fruitx + 4*meatx + 4*div_milk_child
replace fcs_infant = fcs_infant*7

label variable fcs_infant "FCS (infant)"

drop pulsex vegx fruitx meatx

gen mdd_i_binary = 1 if mdd_i_score >= 4 & !missing(mdd_i_score)
replace mdd_i_binary = 0 if mdd_i_score < 4
label var mdd_i_binary "MDD Child (0/1)"

**Coping Strategies

label variable other_coping_strg_yesno "used another coping strategy"

gen other_copstr_rdcom = other_coping_strg_used_1
replace other_copstr_rdcom = 0 if other_coping_strg_yesno==0
label variable other_copstr_rdcom "used coping strategy reduction in non food expenditure"

gen other_copstr_cred = other_coping_strg_used_2
replace other_copstr_cred = 0 if other_coping_strg_yesno==0
label variable other_copstr_cred "used coping strategy used credit"

gen other_copstr_adac = other_coping_strg_used_3
replace other_copstr_adac = 0 if other_coping_strg_yesno==0
label variable other_copstr_adac "used coping strategy took up additional activites"

gen other_copstr_mig = other_coping_strg_used_4
replace other_copstr_mig = 0 if other_coping_strg_yesno==0
label variable other_copstr_mig "used coping strategy migrated"

gen other_copstr_frnd = other_coping_strg_used_5
replace other_copstr_frnd = 0 if other_coping_strg_yesno==0
label variable other_copstr_frnd "used coping strategy help from relatives or friends"

gen other_copstr_gov = other_coping_strg_used_6
replace other_copstr_gov = 0 if other_coping_strg_yesno==0
label variable other_copstr_gov "used coping strategy help from gov or state aid"

gen other_copstr_ngo = other_coping_strg_used_7
replace other_copstr_ngo = 0 if other_coping_strg_yesno==0
label variable other_copstr_ngo "used coping strategy help from NGOs"

gen other_copstr_god = other_coping_strg_used_8
replace other_copstr_god = 0 if other_coping_strg_yesno==0
label variable other_copstr_god "used coping strategy help from god"

gen other_copstr_other = other_coping_strg_used__88
replace other_copstr_other = 0 if other_coping_strg_yesno==0
label variable other_copstr_other "used other (in other section) coping strategy"


rename other_copstr_rdcom choc_strategy6
rename other_copstr_cred choc_strategy9
rename other_copstr_adac choc_strategy10
rename other_copstr_mig choc_strategy11
rename other_copstr_frnd choc_strategy12
rename other_copstr_gov choc_strategy13
rename other_copstr_ngo choc_strategy14
rename other_copstr_god choc_strategy16

**Household size and movement variables 
/*
split(oldlist), destring 
egen numoldmem = rowtotal(oldlist_*) , missing 
label variable numoldmem "number of household members who were registered in previous surveys"

label variable new_hh_members "number of new household members"

egen hhsize = rowtotal(numoldmem new_hh_members), missing
label variable hhsize "number of current household members"
*/
*save dataset

compress
save "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}_wide.dta", replace

tempfile main_temp
save "`main_temp'"

*******

**------------Prepare Food Security Data Set "midline - cohorte1-g_fcs-br_fcs.dta"-------------**

*******

clear
use "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-g_fcs-br_fcs.dta"
drop if missing(hhid)


destring fcs_index, replace
sort hhid fcs_index, stable

order hhid fcs_index fcs_en
drop fcs_id
drop fcs_ki
drop fcs_qid
drop fcs_fr

codebook fcs_consumed
codebook fcs_index 

*save long dataset
*compress
*save "${preparation}/cohort${cohort}/niger_midline_foodsec_long", replace

*reshape to wide format (houshold level)
ds hhid fcs_index, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

ds hhid fcs_index, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(fcs_index)

ds fcs_consumed_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label variable `varstub'`i' "`l_`varstub''"
}
}

*Gen food security Primary Vairable 

*double check this coding given that cerials and tubers are in the same category so PAP FCS = 2*cereals + 2*tubers + 3*pulses + 1*vegetables + 1*fruit + 4*meat/fish/eggs + 4*milk + 0.5*oil + 0.5*sugar becomes FCS = 2*cereals + 3*pulses + 1*vegetables + 1*fruit + 4*meat/fish/eggs + 4*milk + 0.5*oil + 0.5*sugar

// codebook fcs_consumed_4 fcs_consumed_5 fcs_consumed_6 fcs_consumed_7 fcs_consumed_8 fcs_consumed_9 fcs_consumed_10 fcs_consumed_11 fcs_consumed_12 fcs_consumed_13 fcs_consumed_14 fcs_consumed_15 fcs_consumed_16

* how many days in past week did HH consume:

label variable fcs_consumed_1 "no. days in past week hh consumed cerials and tubers"
label variable fcs_consumed_2 "no. days in past week hh consumed pulses"
label variable fcs_consumed_9 "no. days in past week hh consumed vegitables"
label variable fcs_consumed_12 "no. days in past week hh consumed fruit"
label variable fcs_consumed_4 "no. days in past week hh consumed meat fish eggs"
label variable fcs_consumed_3 "no. days in past week hh consumed milk"
label variable fcs_consumed_14 "no. days in past week hh consumed oil and butter"
label variable fcs_consumed_15 "no. days in past week hh consumed sugar"

gen fcs = 2*fcs_consumed_1 + 3*fcs_consumed_2 + 1*fcs_consumed_9 + 1*fcs_consumed_12 + 4*fcs_consumed_4 + 4*fcs_consumed_3 + 0.5*fcs_consumed_14 + 0.5*fcs_consumed_15
label variable fcs "FCS"

gen fcs_above_poor = (fcs > 21)
replace fcs_above_poor = . if missing(fcs)
label variable fcs_above_poor "FCS above poor"

gen fcs_above_reason = (fcs > 42)
replace fcs_above_reason = . if missing(fcs)
label variable fcs_above_reason "FCS above reasonable"

clonevar div_cereal = fcs_consumed_1
clonevar div_pulse = fcs_consumed_2
clonevar div_veg = fcs_consumed_9
clonevar div_fruit = fcs_consumed_12
clonevar div_meat = fcs_consumed_4
clonevar div_milk = fcs_consumed_3
clonevar div_oil = fcs_consumed_14
clonevar div_sugar = fcs_consumed_15

drop fcs_consumed*
drop fcs_en*

*Save wide dataset (this will be merged to main)
save "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-g_fcs-br_fcs_wide.dta", replace

tempfile fcs_hh
save "`fcs_hh'"

*******

**------------Prepare Wage Labour Data Set "midline - cohorte1-d_edu_labor-grp_emploi-d_hh_wage_labor"-------------**

*******

use "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-d_edu_labor-grp_emploi-d_hh_wage_labor.dta", clear
drop if missing(hhid)

codebook d7_emp_days  

mvdecode d7_emp_days, mv(-66 = .r) // refused
mvdecode d7_emp_days, mv(-99 = .d) //don't know 

codebook d9_emp_days

*reshape to wide format (houshold level)
ds hhid d_hh_index, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

destring d_hh_index, replace
ds hhid d_hh_index, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(d_hh_index)

ds d7_emp_days_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label variable `varstub'`i' "`l_`varstub''"
}
}

  *agregate at the household level 
  
  
*Labour Market Participation  
egen ag_emp_days = rowtotal(d7_emp_days_*)
label variable ag_emp_days "sum of household members  number of days spent workin in agri wage employment"

egen ag_emp_days_mean = rowmean(d7_emp_days_*)
label variable ag_emp_days_mean "mean of household members number of days spent workin in agri wage employment"


egen nonag_emp_days = rowtotal(d9_emp_days*)
label variable nonag_emp_days "sum of household members  number of days spent workin in non agri wage employment"

egen nonag_emp_days_mean = rowmean(d9_emp_days*)
label variable nonag_emp_days_mean "mean of household members number of days spent workin in non agri wage employment"

gen ag_wage=. 
replace ag_wage=0 if ag_emp_days==0
replace ag_wage=1 if ag_emp_days>0 & !missing(ag_emp_days)
label variable ag_wage "household enaged in agri wage employment"
label values ag_wage noyes

gen nonag_wage=. 
replace nonag_wage=0 if nonag_emp_days==0
replace nonag_wage=1 if nonag_emp_days>0 & !missing(nonag_emp_days)
label variable nonag_wage "household enaged in non agri wage employment"
label values nonag_wage noyes

*Revenue and Income 

egen ag_wage_inc= rowtotal(d8_salary_*), missing 
label variable ag_wage_inc "agricultural wage income"

egen nonag_wage_inc= rowtotal(d11_salary_*), missing 
label variable nonag_wage_inc "Non- agricultural wage income"

 save "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-d_edu_labor-grp_emploi-d_hh_wage_labor_wide.dta", replace

*******

    **------Prepare  "midline -cohorte${cohort}-f_ag_livestock-livestock-f_hh_livestock_labor"--------**

    *******

use "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-f_ag_livestock-livestock-f_hh_livestock_labor.dta", clear
drop if missing(hhid)

codebook num_days_livestock
label variable num_days_livestock "number of days meber spent looking after livestock"

*reshape to wide format (houshold level)
ds hhid f_hh_index2, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

destring f_hh_index2, replace
ds hhid f_hh_index2, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(f_hh_index2)

ds num_days_livestock_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label variable `varstub'`i' "`l_`varstub''"
}
}


*agregate at the household level 
  
egen lvs_wrk_days = rowtotal(num_days_livestock_*)
label variable  lvs_wrk_days "sum of household members number of days spent looking after livestock"

egen lvs_wrk_days_mean = rowmean(num_days_livestock_*)
label variable lvs_wrk_days_mean "mean of household members number of days spent looking after livestock"

gen lvs_care =. 
replace lvs_care =0 if lvs_wrk_days==0
replace lvs_care =1 if lvs_wrk_days>0 & !missing(lvs_wrk_days)
label variable lvs_care "household enaged in agri wage employment"
label values lvs_care noyes

 save "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-f_ag_livestock-livestock-f_hh_livestock_labor_wide.dta", replace


*******

    **---------Prepare  "midline - cohorte1-f_ag_livestock-agriculture-f_hh_ag_labor"----------**

    *******



use "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-f_ag_livestock-agriculture-f_hh_ag_labor.dta", clear
    drop if missing(hhid)

*number of days cucltivating land
codebook num_days_ag
label variable num_days_ag "number of days member cultivated land for farming"

*reshape to wide format (houshold level)
ds hhid f_hh_index, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

destring f_hh_index, replace
ds hhid f_hh_index, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(f_hh_index)

ds num_days_ag_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label variable `varstub'`i' "`l_`varstub''"
}
}

    *agregate at the household level 

egen num_days_ag = rowtotal(num_days_ag_*), missing
label variable num_days_ag "sum of household members number of days spent cultivating land"

egen num_days_ag_mean = rowmean(num_days_ag_*)
label variable num_days_ag_mean "household members mean number of days spent cultivating land"


save "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-f_ag_livestock-agriculture-f_hh_ag_labor_wide.dta", replace

*******

    **---------Prepare  "midline - cohorte1-e_business-e_hh_business_labor"----------**

    *******



use "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-e_business-e_hh_business_labor.dta", clear
    drop if missing(hhid)

*number of days cucltivating land
codebook hh_business_labor
label variable hh_business_labor "number of days member worked in off farm business"

    *reshape to wide format (houshold level)
ds hhid e_hh_index, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

destring e_hh_index, replace
ds hhid e_hh_index, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(e_hh_index)

ds hh_business_labor_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label variable `varstub'`i' "`l_`varstub''"
}
}

    *agregate at the household level 

egen n_days_business = rowtotal(hh_business_labor_*), missing
label variable n_days_business "sum of household members number of days spent cultivating land"

egen num_days_bus_mean = rowmean(hh_business_labor_*)
label variable num_days_bus_mean "household members mean number of days spent cultivating land"

save "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-e_business-e_hh_business_labor_wide.dta", replace


*******

    **---------Prepare  "midline - cohorte1-c_hh_roster-s_hh_sleep"----------**

    *******

use "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-c_hh_roster-s_hh_sleep.dta", clear
drop if missing(hhid)
 
 

 *change any answers longer than 30 days to be the max of 30 nights 
 replace sleep_n=. if missing(sleep_u)
 replace sleep_n = 30 if sleep_n>30 & !missing(sleep_n) & sleep_u==1 //nights
 replace sleep_n = 30/7 if sleep_n>4 & !missing(sleep_n) & sleep_u==2 //weeks
 replace sleep_n = 1 if sleep_n>1 & !missing(sleep_n) & sleep_u==3 //months
 
  *Recode number of nights slept away from household to be in nights 
 gen sleep_n_std = sleep_n if sleep_u==1  
 replace sleep_n_std=7*sleep_n if sleep_u==2
 replace sleep_n_std=30*sleep_n if sleep_u==3
 label variable sleep_n_std "number of nights household member slept away from the household"
 
 *recode sleep why so that other is its own cateogry 
 
 replace sleep_why=11 if sleep_why==.o
 
 
    *reshape to wide format (houshold level)
ds hhid s_hh_index, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

destring s_hh_index, replace
ds hhid s_hh_index, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(s_hh_index)

ds exode_money_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label variable `varstub'`i' "`l_`varstub''"
}
}

 *agregate at the household level 

gen remit=.
label variable remit "household sent remitances"
forvalues i = 1 / `count' {
replace remit=0 if !missing(exode_money_`i')
replace remit=1 if exode_money_`i'==1
}
    
egen amt_remit=rowtotal(exode_amt_sendt_*) , missing
label variable amt_remit "value of household remitances"


*gen variables for each reason for sleeping away from household

foreach i of numlist 1/`count' {
gen away_study_`i' = sleep_n_std_`i' if sleep_why_`i'==1
label variable away_study_`i' "slept away from the household to study"

gen away_ill_`i' = sleep_n_std_`i' if sleep_why_`i'==2
label variable away_ill_`i' "slept away from the household due to disease or hosiptal stay"

gen away_vfam_`i' = sleep_n_std_`i' if sleep_why_`i'==3
label variable away_vfam_`i' "slept away from the household due to visiting family"

gen away_mrkt_`i' = sleep_n_std_`i' if sleep_why_`i'==4
label variable away_mrkt_`i' "slept away from the household due to going to market"

gen away_busi_`i' = sleep_n_std_`i' if sleep_why_`i'==5
label variable away_busi_`i' "slept away from the household due to small business"

gen away_agri_`i' = sleep_n_std_`i' if sleep_why_`i'==6
label variable away_agri_`i' "slept away from the household due to agricultural work"

gen away_ahus_`i' = sleep_n_std_`i' if sleep_why_`i'==7
label variable away_ahus_`i' "slept away from the household due to work in animal husbandry"

gen away_ming_`i' = sleep_n_std_`i' if sleep_why_`i'==8
label variable away_ming_`i' "slept away from the household due to mining"

gen away_owrk_`i' = sleep_n_std_`i' if sleep_why_`i'==9
label variable away_owrk_`i' "slept away from the household due to other work"

gen away_afam_`i' = sleep_n_std_`i' if sleep_why_`i'==10
label variable away_afam_`i' "slept away from the household to accompany family"

gen away_other_`i' = sleep_n_std_`i' if sleep_why_`i'==11
label variable away_other_`i' "slept away from the household due to non specified reason"

gen away_work_`i' = sleep_n_std_`i' if sleep_why_`i'==5 | sleep_why_`i'==6 | sleep_why_`i'==7 | sleep_why_`i'==8 | sleep_why_`i'==9
label variable away_work_`i' "slept away from the household due to work "

}

egen away_study = rowmean(away_study_*)
label variable away_study "average days household members slept away to study"

egen away_ill = rowmean(away_ill_*)
label variable away_ill "average days household members slept away due to disease or hosiptal stay"

egen away_vfam = rowmean(away_vfam_*) 
label variable away_vfam "average days household members slept due to visiting family"

egen away_mrkt = rowmean(away_mrkt_*) 
label variable away_mrkt "average days household members slept due to going to market"

egen away_busi = rowmean(away_busi_*)
label variable away_busi "average days household members slept due to small business"

egen away_agri = rowmean(away_agri_*) 
label variable away_agri "average days household members slept due to agricultural work"

egen away_ahus = rowmean(away_ahus_*)
label variable away_ahus "average days household members slept due to work in animal husbandry"

egen away_ming = rowmean(away_ming_*) 
label variable away_ming "average days household members slept due to mining"

egen away_owrk = rowmean(away_owrk_*)
label variable away_owrk "average days household members slept due to other work"

egen away_afam = rowmean(away_afam_*)
label variable away_afam "average days household members slept to accompany family"

egen away_other = rowmean(away_other_*)
label variable away_other "average days household members slept away due to non specified reason"

egen away_work = rowmean(away_work_*)
label variable away_other "average days household members slept away due to work"

egen away = rowmean(sleep_n_std_*)
label variable away "average days household mebers slept away"


    save "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-c_hh_roster-s_hh_sleep_wide.dta", replace


*******

    **---------Prepare  "midline - cohorte1-j_excep_exp-rpt_cel1"----------**

    *******

use "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-j_excep_exp-rpt_cel1.dta", clear
drop if missing(hhid)
 
 
    *reshape to wide format (houshold level)
ds hhid cel1_pos, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

destring cel1_pos, replace
ds hhid cel1_pos, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(cel1_pos)

ds cel_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label variable `varstub'`i' "`l_`varstub''"
}
}

 *agregate at the household level 

gen excexp=. 
label variable excexp "any exceptionl expenditure (0,1)"
replace excexp=0 if !missing(cel_1) | !missing(cel_2) | !missing(cel_3) | !missing(cel_4) | !missing(cel_5) 
replace  excexp=1 if cel_1==1 | cel_2==1 | cel_3==1 | cel_4==1 | cel_5==1 

    save "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-j_excep_exp-rpt_cel1_wide.dta", replace


*******

    **---------Prepare  "midline - cohorte${cohort}-j_excep_exp-rpt_cel2"----------**

    *******

use "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-j_excep_exp-rpt_cel2.dta", clear
drop if missing(hhid)
 
 
    *reshape to wide format (houshold level)
ds hhid cel2_pos, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

destring cel2_pos, replace
ds hhid cel2_pos, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(cel2_pos)

ds cel_food_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label variable `varstub'`i' "`l_`varstub''"
}
}

 *agregate at the household level 

egen amnt_excexp_food=rowtotal(cel_food_*) , missing 
label variable amnt_excexp_food "amount of exceptionl expenditure on food"

egen amnt_excexp_drink=rowtotal(cel_drink_*) , missing 
label variable amnt_excexp_drink"amount of exceptionl expenditure on drink"

egen amnt_excexp_cloth=rowtotal(cel_cloth_*) , missing 
label variable amnt_excexp_cloth "amount of exceptionl expenditure on cloth"

egen amnt_excexp_nonfood=rowtotal(cel_nonfood_*) , missing 
label variable amnt_excexp_nonfood "amount of exceptionl expenditure on nonfood"


egen amnt_excexp_rama=rowtotal(cel_food_1 cel_drink_1 cel_cloth_1 cel_nonfood_1) , missing 
label variable amnt_excexp_rama "amount of exceptionl expenditure on Fin de Ramadan"

egen amnt_excexp_tab=rowtotal(cel_food_2 cel_drink_2 cel_cloth_2 cel_nonfood_2) , missing 
label variable amnt_excexp_tab "amount of exceptionl expenditure on Tabaski"

egen amnt_excexp_bap=rowtotal(cel_food_3 cel_drink_3 cel_cloth_3 cel_nonfood_3) , missing 
label variable amnt_excexp_bap "amount of exceptionl expenditure on Baptemes"

egen amnt_excexp_mar=rowtotal(cel_food_4 cel_drink_4 cel_cloth_4 cel_nonfood_4) , missing 
label variable amnt_excexp_mar "amount of exceptionl expenditure on Mariage"

egen amnt_excexp_aut=rowtotal(cel_food_5 cel_drink_5 cel_cloth_5 cel_nonfood_5) , missing 
label variable amnt_excexp_aut "amount of exceptionl expenditure on Autre événement"

    save "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-j_excep_exp-rpt_cel2_wide.dta", replace


*******

    **---------Prepare  "midline - cohorte${cohort}-l_finance-PART_othersave-gp_savemoreinfo"----------**

    *******

use "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-l_finance-PART_othersave-gp_savemoreinfo.dta", clear
drop if missing(hhid)
 
 
    *reshape to wide format (houshold level)

ds hhid saves_pos, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

destring saves_pos, replace
ds hhid saves_pos, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(saves_pos)

ds dep_xof_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label variable `varstub'`i' "`l_`varstub''"
}
}

 *agregate at the household level 

gen save1= dep_xof_1
label variable save1 "amount saved in bank or other formal insitution"

gen save2= dep_xof_2
label variable save2 "amount saved in savings group"

gen save3= dep_xof_3
label variable save3 "amount saved with family outside of household"

gen save4= dep_xof_4
label variable save4 "amount saved with neighbours or friends"

gen save5= dep_xof_5
label variable save5 "amount saved with other source"

gen temp = dep_xof_4 + dep_xof_5
gen saved_amt_1 = dep_xof_1
gen saved_amt_2 = dep_xof_2
gen saved_amt_3 = dep_xof_3
gen saved_amt_4 = temp
drop temp

label variable saved_amt_1 "\makecell{Savings, \\ bank}"
label variable saved_amt_2 "\makecell{Savings, \\ savings groups}"
label variable saved_amt_3 "\makecell{Savings, \\ family}"
label variable saved_amt_4 "\makecell{Savings, \\ others}"

foreach var in saved_amt_1 saved_amt_2 saved_amt_3 saved_amt_4 {
    _pctile `var', p(98)
    ret list
    replace `var' = r(r1) if `var' > r(r1) & !missing(`var')
    replace `var' = 0 if missing(`var')
}

save "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-l_finance-PART_othersave-gp_savemoreinfo_wide.dta", replace


*******

    **---------Prepare  "midline - cohorte${cohort}-l_finance-PART_othersave-gp_withmoreinfo"----------**

    *******

use "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-l_finance-PART_othersave-gp_withmoreinfo.dta", clear
drop if missing(hhid)
 
 
    *reshape to wide format (houshold level)
ds hhid withdraw_pos, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

destring withdraw_pos, replace
ds hhid withdraw_pos, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(withdraw_pos)

ds with_xof_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label variable `varstub'`i' "`l_`varstub''"
}
}

 *agregate at the household level 

gen withdrw1= with_xof_1
label variable withdrw1 "amount saved in bank or other formal insitution"

gen withdrw2= with_xof_2
label variable withdrw2 "amount saved in savings group"

gen withdrw3= with_xof_3
label variable withdrw3 "amount saved with family outside of household"

gen withdrw4= with_xof_4
label variable withdrw4 "amount saved with neighbours or friends"

gen withdrw5= with_xof_5
label variable withdrw5 "amount saved with other source"



    save "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-l_finance-PART_othersave-gp_withmoreinfo_wide.dta", replace


    *******

    **---------Prepare  "midline - cohorte${cohort}-l_finance-PART_othersave-gp_savemoreinfo"----------**

    *******

use "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-l_finance-PART_credit-rpt_cred.dta", clear
drop if missing(hhid)
 
 
    *reshape to wide format (houshold level)
ds hhid cred_pos, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

destring cred_pos, replace
ds hhid cred_pos, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(cred_pos)

ds cred_amt_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label variable `varstub'`i' "`l_`varstub''"
}
}

 *agregate at the household level 

gen loan1= cred_amt_1
label variable loan1 "amount of loan from family in the last 30 days"

gen loan2= cred_amt_2
label variable loan2 "amount of loan from  freinds in the last 30 days"

gen loan3= cred_amt_3
label variable loan3 "amount of loan from formal institution in the last 30 days"

gen loan4= cred_amt_4
label variable loan4 "amount of loan from other person or group in the last 30 days"


    save "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-l_finance-PART_credit-rpt_cred_wide.dta", replace


*******

    **---------Prepare  "midline - cohorte1-d_edu_labor-grp_edu-rpt_miss_school"----------**

    *******

use "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-d_edu_labor-grp_edu-rpt_miss_school.dta", clear
drop if missing(hhid)
 
 
    *reshape to wide format (houshold level)
ds hhid missscool_hh_index, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

destring missscool_hh_index, replace
ds hhid missscool_hh_index, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(missscool_hh_index)

ds miss_school_nbdays_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label variable `varstub'`i' "`l_`varstub''"
}
}

egen absent_school_amt = rowtotal(miss_school_nbdays_*), missing 
label variable absent_school_amt "total number of school days missed for children in the household"

save "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-d_edu_labor-grp_edu-rpt_miss_school_wide.dta", replace

********

**-------- Prepare "midline - cohorte1-f_ag_livestock-agriculture-plots-rpt_plots" -------**

********

use "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-f_ag_livestock-agriculture-plots-rpt_plots.dta", clear
drop if missing(hhid)

destring plot_pos, replace
sort hhid plot_pos plot_name, stable
drop if missing(plot_size)

* convert hectares to meter squared
replace plot_size = plot_size*10000 if plot_size_u == 1
replace plot_size_u = 2 if plot_size_u == 1
label variable plot_size "Plot size in metre squared"

foreach var in plot_size {
    winsor2 `var', replace cuts(0 98)
}

by hhid: egen avgplotsize = mean(plot_size)
label variable avgplotsize "\makecell{Avg. plot \\ size}"

by hhid: egen totalplotsize = total(plot_size)
label variable totalplotsize "\makecell{Total plot size}"

sort hhid, stable
by hhid: gen nrainyplots = _N
label variable nrainyplots "\# of plots"

keep hhid avgplotsize nrainyplots totalplotsize
duplicates drop

save "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-f_ag_livestock-agriculture-plots-rpt_plots_wide.dta", replace


/*

local dta_files : dir "${midline_raw}/cohort${cohort}" files "*.dta"

foreach dta_file in `dta_files' {
    display as error "`dta_file'"
}

clear
use "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-f_ag_livestock-agriculture-crops_rpt.dta"
drop calc_rcrop_harv_u

rename crops_name rcrop2name

encode rcrop2name, gen(cropid)
label values cropid .
isid hhid cropid
order hhid cropid
sort hhid cropid, stable
drop crop_id
tab rcrop_harv

replace rcrop_harv = rcrop_harv*0.75 if rcrop_harv_u == 4
replace rcrop_harv = rcrop_harv*2.37 if rcrop_harv_u == 5
replace rcrop_harv = rcrop_harv*50 if rcrop_harv_u == 7
replace rcrop_harv = rcrop_harv*100 if rcrop_harv_u == 8

recode rcrop_harv_u (4 5 7 8 = 1)

replace rcrop_harv = . if rcrop_harv_u != 1
replace rcrop2name = "" if missing(rcrop_harv)

levelsof cropid, local(cropid)

foreach i of local cropid {
foreach var in rcrop_harv {
    winsor2 `var' if cropid == `i', replace cuts(0 98)
}    
}

drop rcrop_harv_u_o

sort hhid, stable

by hhid: egen rcropqtyharvest = total(rcrop_harv), missing
label variable rcropqtyharvest "Qty harvested"

*/

********

**-------- Prepare "midline - cohorte${cohort}-y_coping_strategies-r_coping_strg" -------**

********


use "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-y_coping_strategies-r_coping_strg.dta", clear
drop if missing(hhid)

*coping strategies
replace coping_strg_used=.r if coping_strg_used==-66
replace coping_strg_used=.d if coping_strg_used==-99

*reshape to wide format (houshold level)
ds hhid coping_strg_index, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

destring coping_strg_index, replace
ds hhid coping_strg_index, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(coping_strg_index)

ds coping_strg_used_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label variable `varstub'`i' "`l_`varstub''"
}
}

***Agregate at a household level*** 
label variable coping_strg_used_1 "used coping strategy reduced food consumption"
label variable coping_strg_used_2 "used coping strategy spend savings"
label variable coping_strg_used_3 "used coping strategy sell livestock"
label variable coping_strg_used_4 "used coping strategy sell foodstocks"
label variable coping_strg_used_5 "used coping strategy withdraw children from school"


save "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-y_coping_strategies-r_coping_strg_wide.dta" ,    replace


********

**-------- Prepare "midline - cohorte${cohort}-c_hh_roster-hh_unconf" -------**

********


use "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-c_hh_roster-hh_unconf.dta", clear

drop if missing(hhid)

*Number of members of household that moved 

duplicates tag hhid, gen(duphhid)
gen nummemmove = duphhid + 1 if !missing(hhid)
label variable nummemmove "number of members that have left the household"

*Store values to work out propostion of people who moved for a particular reason 

summ hhid 
global nmmv_cohort${cohort} = `r(N)'

//number moved for work 
count if hh_unconf_why== 4 | hh_unconf_why== 5 | hh_unconf_why== 6 | hh_unconf_why== 7 | hh_unconf_why== 8 | hh_unconf_why== 9
global nmlvwk_cohort${cohort} = `r(N)'

//number moved for reasons other than marrige/divorse/death  
count if hh_unconf_reason== 3
global nmlvlng_cohort${cohort} = `r(N)'

//number moved outside commune but withing Niger

count if hh_unconf_where== 3 | hh_unconf_where== 4
global nmlvNiger_cohort${cohort} = `r(N)'

//number moved outside Niger

count if hh_unconf_where== 5
global nmlvoutNiger_cohort${cohort} = `r(N)'

*reshape to wide format (houshold level)
ds hhid hh_unconf_index, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

destring hh_unconf_index, replace
ds hhid hh_unconf_index, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(hh_unconf_index)

ds hh_unconf_why_o_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label variable `varstub'`i' "`l_`varstub''"
}
}

rename nummemmove_1 nummemmove
foreach var of varlist nummemmove_* {
drop `var'
}



save "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-c_hh_roster-hh_unconf_wide.dta" ,    replace


********

**-------- Prepare "midline - cohorte${cohort}-X_shocks-r_shocks" -------**

********


use "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-X_shocks-r_shocks.dta", clear

drop if missing(hhid)


*reshape to wide format (houshold level)
ds hhid shock_index, not

foreach var in `r(varlist)' {
ren `var' `var'_
local l_`var'_ : variable label `var'_
}

destring shock_index, replace
ds hhid shock_index, not
local stubnames "`r(varlist)'"
reshape wide `r(varlist)', i(hhid) j(shock_index)

ds shock_occur_*
local count = wordcount("`r(varlist)'")
di "`count'"

forvalues i = 1 / `count' {
foreach varstub in `stubnames' {
di "display variable: `varstub'`i'"
di "display label: `varstub'`i'"
label variable `varstub'`i' "`l_`varstub''"
}
}



*agregate at a household level 
label define shocksev 1 "more severe" 2 "moderatly severe" 3 "less severe"

label variable shock_occur_1 "shock drought occurred"
label variable shock_sev_1 "severity of drought"
label values shock_sev_1 shocksev
label variable shock_occur_2 "shock floods occurred"
label variable shock_sev_2 "severity of flood"
label values shock_sev_2 shocksev
label variable shock_occur_3 "shock crop disease occurred"
label variable shock_sev_3 "severity of crop disease"
label values shock_sev_3 shocksev
label variable shock_occur_4 "shock animal disease occurred"
label variable shock_sev_4 "severity of animal disease"
label values shock_sev_4 shocksev
label variable shock_occur_5 "shock price drop occurred"
label variable shock_sev_5 "severity of price drop"
label values shock_sev_5 shocksev
label variable shock_occur_6 "shock high agricularal input prices occurred"
label variable shock_sev_6 "severity of high agri prices"
label values shock_sev_6 shocksev
label variable shock_occur_7 "shock end of transfers from occurred"
label variable shock_sev_7 "severity of end of transfers"
label values shock_sev_7 shocksev
label variable shock_occur_8 "shock loss of non agri income occurred"
label variable shock_sev_8 "severity of loss of non agri income"
label values shock_sev_8 shocksev
label variable shock_occur_9 "shock bankrupcy of non agri business occurred"
label variable shock_sev_9 "severity of bankrupcy"
label values shock_sev_9 shocksev
label variable shock_occur_10 "shock loss of salary income occurred"
label variable shock_sev_10 "severity of loss of salary income"
label values shock_sev_10 shocksev
label variable shock_occur_11 "shock loss of paid employment occurred"
label variable shock_sev_11 "severity of loss of paid employment"
label values shock_sev_11 shocksev
label variable shock_occur_12 "shock serious accident or illness occurred"
label variable shock_sev_12 "severity of accident or illness"
label values shock_sev_12 shocksev

save "${midline_intermediate}/cohort${cohort}/midline - cohorte${cohort}-X_shocks-r_shocks_wide.dta" , replace

