version 18.0

clear all
set varabbrev off
set more off
mac drop _all
set maxvar      120000			//phyllisa april 30 2025


global projectfolder "C:/Users/wb614536/Documents/GitHub/sahel-shocks"
global github_sahel "C:/Users/wb614536/Documents/GitHub/sahel-shocks"
global dataWorkFolder "$projectfolder/data"

sysdir set PLUS "$projectfolder/ado"


* install packages
/*
local user_commands distinct winsor2 estout reghdfe

foreach command of local user_commands {
cap which `command'
if _rc == 111 {
ssc install `command', replace
}
}
*/

* path to datasets

* endline
global endline "$dataWorkFolder/endline"
global endline_deidentified "$endline/deidentified" 
global endline_raw "$endline_deidentified/raw_data"
global endline_raw_admin "$endline_deidentified/raw_admin_data"
global endline_prepared "$endline_deidentified/prepared" 
global endline_intermediate "$endline/intermediate" 
global endline_final "$endline/final"

* midline
global midline "$dataWorkFolder/midline"
global midline_deidentified "$midline/deidentified"
global midline_raw "$midline_deidentified/raw_data"
global midline_raw_admin "$midline_deidentified/raw_admin_data"
global midline_prepared "$midline_intermediate"
global midline_intermediate "$midline/intermediate"
global midline_final "$midline/final"

* high frequency
global high_frequency "$dataWorkFolder/high_frequency"
global high_frequency_deidentified "$high_frequency/deidentified"
global high_frequency_raw "$high_frequency_deidentified/raw_data"
global high_frequency_raw_admin "$high_frequency_deidentified/raw_admin_data"
global high_frequency_prepared "$high_frequency/prepared"
global high_frequency_intermediate "$high_frequency/intermediate"
global high_frequency_final "$high_frequency/final"

* baseline
global baseline "$dataWorkFolder/baseline"
global baseline_deidentified "$baseline/deidentified" 
global baseline_raw "$baseline_deidentified/raw_data"
global baseline_raw_admin "$baseline_deidentified/raw_admin_data"
global baseline_prepared "$baseline_deidentified/prepared"
global baseline_intermediate "$baseline/intermediate"
global baseline_final "$baseline/final"

* community
global community "$dataWorkFolder/community"
global community_raw "$community/raw_data"
global community_final "$community/final"

* panel
global panel "$dataWorkFolder/panel"

* path to code
global do_cleaning "$github_sahel/cleaning"
global do_endline_cleaning "$do_cleaning/endline"
global do_midline_cleaning "$do_cleaning/midline"
global do_high_frequency_cleaning "$do_cleaning/high-frequency"
global do_baseline_cleaning "$do_cleaning/baseline"
global do_analysis "$github_sahel/analysis"

* how to impute median prices of foods
global impute_rule "region" // "village" OR "commune" OR "region"

* output tables and figures
global csae "$github_sahel/output"



cap program drop FDR_LATE
program define FDR_LATE // Use to adjust P-value in LATE analysis

quietly {

    tempfile full 
    sa `full'
    
    clear 
    
    svmat $group
    keep *4
    rename *4 A4
    drop if A4 ==.
    gen float pval = A4
    
    
* Collect the total number of p-values tested
quietly sum pval
local totalpvals = r(N)

* Sort the p-values in ascending order and generate a variable that codes each p-value's rank
quietly gen int original_sorting_order = _n
quietly sort pval
quietly gen int rank = _n if pval~=.

* Set the initial counter to 1
local qval = 1

* Generate the variable that will contain the BKY (2006) sharpened q-values
gen bky06_qval = 1 if pval~=.

* Set up a loop that begins by checking which hypotheses are rejected at q = 1.000, then checks which hypotheses are rejected at q = 0.999, then checks which hypotheses are rejected at q = 0.998, etc.  The loop ends by checking which hypotheses are rejected at q = 0.001.
while `qval' > 0 {
    * First Stage
    * Generate the adjusted first stage q level we are testing: q' = q/1+q
    local qval_adj = `qval'/(1+`qval')
    * Generate value q'*r/M
    gen fdr_temp1 = `qval_adj'*rank/`totalpvals'
    * Generate binary variable checking condition p(r) <= q'*r/M
    gen reject_temp1 = (fdr_temp1>=pval) if pval~=.
    * Generate variable containing p-value ranks for all p-values that meet above condition
    gen reject_rank1 = reject_temp1*rank
    * Record the rank of the largest p-value that meets above condition
    egen total_rejected1 = max(reject_rank1)

    * Second Stage
    * Generate the second stage q level that accounts for hypotheses rejected in first stage: q_2st = q'*(M/m0)
    local qval_2st = `qval_adj'*(`totalpvals'/(`totalpvals'-total_rejected1[1]))
    * Generate value q_2st*r/M
    gen fdr_temp2 = `qval_2st'*rank/`totalpvals'
    * Generate binary variable checking condition p(r) <= q_2st*r/M
    gen reject_temp2 = (fdr_temp2>=pval) if pval~=.
    * Generate variable containing p-value ranks for all p-values that meet above condition
    gen reject_rank2 = reject_temp2*rank
    * Record the rank of the largest p-value that meets above condition
    egen total_rejected2 = max(reject_rank2)

    * A p-value has been rejected at level q if its rank is less than or equal to the rank of the max p-value that meets the above condition
    replace bky06_qval = `qval' if rank <= total_rejected2 & rank~=.
    * Reduce q by 0.001 and repeat loop
    drop fdr_temp* reject_temp* reject_rank* total_rejected*
    local qval = `qval' - .001
}

quietly sort original_sorting_order
mkmat bky06_qval, matrix(Qval)
}

display "Code has completed."
display "Benjamini Krieger Yekutieli (2006) sharpened q-vals are in variable 'bky06_qval'"
mat list Qval
display    "Sorting order is the same as the original vector of p-values"
use "`full'", clear
end


timer on 1

* run code in order

do "$do_baseline_cleaning/00_clean_master.do"
do "$do_endline_cleaning/01-clean-construct.do"
do "$do_midline_cleaning/00_clean_master_mid.do"
do "$do_high_frequency_cleaning/00_clean_master_hfs.do"
do "$do_cleaning/create-panel.do"


do "$do_analysis/lasso-prep.do"
do "$do_analysis/1-fdr-within-rounds.do"
do "$do_analysis/2-heterogeneity.do"
do "$do_analysis/3-livelihood-indices.do"
do "$do_analysis/4-coefplots.do"
do "$do_analysis/5-food-cons-by-item.do"
do "$do_analysis/6-balance.do"
do "$do_analysis/7-price-graphs.do"

* additional analysis, some of which are in the main paper now

do "$do_analysis/additional-results.do"

* permanently delete temporary files

foreach path in ///
"$baseline_prepared" "$baseline_intermediate" ///
"$high_frequency/prepared/HFS1/cohort1" ///
"$high_frequency/prepared/HFS1/cohort2" ///
"$high_frequency/prepared/HFS1/cohort3" ///
"$high_frequency/prepared/HFS1/cohort4" ///
"$high_frequency/prepared/HFS2/cohort1" ///
"$high_frequency/prepared/HFS2/cohort2" ///
"$high_frequency/prepared/HFS2/cohort3" ///
"$high_frequency/prepared/HFS2/cohort4" ///
"$high_frequency/intermediate/HFS1/cohort1" ///
"$high_frequency/intermediate/HFS1/cohort2" ///
"$high_frequency/intermediate/HFS1/cohort3" ///
"$high_frequency/intermediate/HFS1/cohort4" ///
"$high_frequency/intermediate/HFS2/cohort1" ///
"$high_frequency/intermediate/HFS2/cohort2" ///
"$high_frequency/intermediate/HFS2/cohort3" ///
"$high_frequency/intermediate/HFS2/cohort4" ///
"$midline/intermediate/cohort1" ///
"$midline/intermediate/cohort2" ///
"$midline/intermediate/cohort3" ///
"$endline/intermediate/" ///
{

local tempfiles: dir "`path'" files "*.dta"

foreach f of local tempfiles {
    erase "`path'/`f'"
    }
}

timer off 1
timer list
