* import_niger_2023_Endline_Terrain.do
*
*     Imports and aggregates "Niger 2023- Shock Response- ENDLINE" (ID: niger_2023_Endline_Terrain) data.
*
*    Inputs:  "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE.csv"
*    Outputs: "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE.dta"
*
*    Output by SurveyCTO August 24, 2023 9:33 AM.

* initialize Stata
clear all
set more off
set mem 100m

* initialize workflow-specific parameters
*    Set overwrite_old_data to 1 if you use the review and correction
*    workflow and allow un-approving of submissions. If you do this,
*    incoming data will overwrite old data, so you won't want to make
*    changes to data in your local .dta file (such changes can be
*    overwritten with each new import).
local overwrite_old_data 0

* initialize form-specific parameters
local csvfile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE.csv"
local dtafile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE.dta"
local corrfile "/users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE_corrections.csv"
local note_fields1 ""
local text_fields1 "deviceid subscriberid simid devicephonenum allows_comments records_time start_intro phone_survey country_name region departement commune village hhid village_name region_name departement_name"
local text_fields2 "commune_name supervisor_o chefequipe_o chefequipe_nom surveyor_o surveyor_nom resp_name resp_name_pull f03d_class_hhhage_pull vill_sample_size id_pull e3_hh_primaryphone_pull e2_hhgps_pull currency"
local text_fields3 "hh_to_repeat_pull hh_to_repeat address_pull hameau_pull pull_mem_id_old_1 pull_mem_id_old_2 pull_mem_id_old_3 pull_mem_id_old_4 pull_mem_id_old_5 pull_mem_id_old_6 pull_mem_id_old_7 pull_mem_id_old_8"
local text_fields4 "pull_mem_id_old_9 pull_mem_id_old_10 pull_mem_id_old_11 pull_mem_id_old_12 pull_mem_id_old_13 pull_mem_id_old_14 pull_mem_id_old_15 pull_mem_id_old_16 pull_mem_id_old_17 pull_mem_id_old_18"
local text_fields5 "pull_mem_id_old_19 pull_mem_id_old_20 pull_mem_id_old_21 pull_mem_id_old_22 pull_mem_id_old_23 pull_mem_id_old_24 pull_mem_id_old_25 pull_mem_id_old_26 pull_mem_id_old_27 pull_mem_id_old_28"
local text_fields6 "pull_mem_id_old_29 pull_mem_id_old_30 pull_mem_id_old_31 pull_mem_id_old_32 pull_mem_id_old_33 pull_mem_id_old_34 pull_mem_id_old_35 pull_mem_id_old_36 pull_mem_id_old_37 pull_mem_id_old_38"
local text_fields7 "pull_mem_id_old_39 pull_mem_id_old_40 pull_mem_id_old_41 pull_mem_id_old_42 pull_mem_id_old_43 pull_mem_id_old_44 pull_mem_id_old_45 pull_mem_id_old_46 pull_mem_id_old_47 pull_mem_id_old_48"
local text_fields8 "pull_mem_id_old_49 pull_mem_id_old_50 pull_mem_id_old_51 pull_mem_id_old_52 pull_mem_id_old_53 pull_mem_id_old_54 pull_mem_id_old_55 pull_mem_id_old_56 pull_mem_id_old_57 pull_mem_id_old_58"
local text_fields9 "pull_mem_id_old_59 pull_mem_id_old_60 pull_fullname_1 pull_fullname_2 pull_fullname_3 pull_fullname_4 pull_fullname_5 pull_fullname_6 pull_fullname_7 pull_fullname_8 pull_fullname_9 pull_fullname_10"
local text_fields10 "pull_fullname_11 pull_fullname_12 pull_fullname_13 pull_fullname_14 pull_fullname_15 pull_fullname_16 pull_fullname_17 pull_fullname_18 pull_fullname_19 pull_fullname_20 pull_fullname_21"
local text_fields11 "pull_fullname_22 pull_fullname_23 pull_fullname_24 pull_fullname_25 pull_fullname_26 pull_fullname_27 pull_fullname_28 pull_fullname_29 pull_fullname_30 pull_fullname_31 pull_fullname_32"
local text_fields12 "pull_fullname_33 pull_fullname_34 pull_fullname_35 pull_fullname_36 pull_fullname_37 pull_fullname_38 pull_fullname_39 pull_fullname_40 pull_fullname_41 pull_fullname_42 pull_fullname_43"
local text_fields13 "pull_fullname_44 pull_fullname_45 pull_fullname_46 pull_fullname_47 pull_fullname_48 pull_fullname_49 pull_fullname_50 pull_fullname_51 pull_fullname_52 pull_fullname_53 pull_fullname_54"
local text_fields14 "pull_fullname_55 pull_fullname_56 pull_fullname_57 pull_fullname_58 pull_fullname_59 pull_fullname_60 pull_firstname_1 pull_firstname_2 pull_firstname_3 pull_firstname_4 pull_firstname_5"
local text_fields15 "pull_firstname_6 pull_firstname_7 pull_firstname_8 pull_firstname_9 pull_firstname_10 pull_firstname_11 pull_firstname_12 pull_firstname_13 pull_firstname_14 pull_firstname_15 pull_firstname_16"
local text_fields16 "pull_firstname_17 pull_firstname_18 pull_firstname_19 pull_firstname_20 pull_firstname_21 pull_firstname_22 pull_firstname_23 pull_firstname_24 pull_firstname_25 pull_firstname_26 pull_firstname_27"
local text_fields17 "pull_firstname_28 pull_firstname_29 pull_firstname_30 pull_firstname_31 pull_firstname_32 pull_firstname_33 pull_firstname_34 pull_firstname_35 pull_firstname_36 pull_firstname_37 pull_firstname_38"
local text_fields18 "pull_firstname_39 pull_firstname_40 pull_firstname_41 pull_firstname_42 pull_firstname_43 pull_firstname_44 pull_firstname_45 pull_firstname_46 pull_firstname_47 pull_firstname_48 pull_firstname_49"
local text_fields19 "pull_firstname_50 pull_firstname_51 pull_firstname_52 pull_firstname_53 pull_firstname_54 pull_firstname_55 pull_firstname_56 pull_firstname_57 pull_firstname_58 pull_firstname_59 pull_firstname_60"
local text_fields20 "pull_lastname_1 pull_lastname_2 pull_lastname_3 pull_lastname_4 pull_lastname_5 pull_lastname_6 pull_lastname_7 pull_lastname_8 pull_lastname_9 pull_lastname_10 pull_lastname_11 pull_lastname_12"
local text_fields21 "pull_lastname_13 pull_lastname_14 pull_lastname_15 pull_lastname_16 pull_lastname_17 pull_lastname_18 pull_lastname_19 pull_lastname_20 pull_lastname_21 pull_lastname_22 pull_lastname_23"
local text_fields22 "pull_lastname_24 pull_lastname_25 pull_lastname_26 pull_lastname_27 pull_lastname_28 pull_lastname_29 pull_lastname_30 pull_lastname_31 pull_lastname_32 pull_lastname_33 pull_lastname_34"
local text_fields23 "pull_lastname_35 pull_lastname_36 pull_lastname_37 pull_lastname_38 pull_lastname_39 pull_lastname_40 pull_lastname_41 pull_lastname_42 pull_lastname_43 pull_lastname_44 pull_lastname_45"
local text_fields24 "pull_lastname_46 pull_lastname_47 pull_lastname_48 pull_lastname_49 pull_lastname_50 pull_lastname_51 pull_lastname_52 pull_lastname_53 pull_lastname_54 pull_lastname_55 pull_lastname_56"
local text_fields25 "pull_lastname_57 pull_lastname_58 pull_lastname_59 pull_lastname_60 pull_sex_1 pull_sex_2 pull_sex_3 pull_sex_4 pull_sex_5 pull_sex_6 pull_sex_7 pull_sex_8 pull_sex_9 pull_sex_10 pull_sex_11"
local text_fields26 "pull_sex_12 pull_sex_13 pull_sex_14 pull_sex_15 pull_sex_16 pull_sex_17 pull_sex_18 pull_sex_19 pull_sex_20 pull_sex_21 pull_sex_22 pull_sex_23 pull_sex_24 pull_sex_25 pull_sex_26 pull_sex_27"
local text_fields27 "pull_sex_28 pull_sex_29 pull_sex_30 pull_sex_31 pull_sex_32 pull_sex_33 pull_sex_34 pull_sex_35 pull_sex_36 pull_sex_37 pull_sex_38 pull_sex_39 pull_sex_40 pull_sex_41 pull_sex_42 pull_sex_43"
local text_fields28 "pull_sex_44 pull_sex_45 pull_sex_46 pull_sex_47 pull_sex_48 pull_sex_49 pull_sex_50 pull_sex_51 pull_sex_52 pull_sex_53 pull_sex_54 pull_sex_55 pull_sex_56 pull_sex_57 pull_sex_58 pull_sex_59"
local text_fields29 "pull_sex_60 pull_age_1 pull_age_2 pull_age_3 pull_age_4 pull_age_5 pull_age_6 pull_age_7 pull_age_8 pull_age_9 pull_age_10 pull_age_11 pull_age_12 pull_age_13 pull_age_14 pull_age_15 pull_age_16"
local text_fields30 "pull_age_17 pull_age_18 pull_age_19 pull_age_20 pull_age_21 pull_age_22 pull_age_23 pull_age_24 pull_age_25 pull_age_26 pull_age_27 pull_age_28 pull_age_29 pull_age_30 pull_age_31 pull_age_32"
local text_fields31 "pull_age_33 pull_age_34 pull_age_35 pull_age_36 pull_age_37 pull_age_38 pull_age_39 pull_age_40 pull_age_41 pull_age_42 pull_age_43 pull_age_44 pull_age_45 pull_age_46 pull_age_47 pull_age_48"
local text_fields32 "pull_age_49 pull_age_50 pull_age_51 pull_age_52 pull_age_53 pull_age_54 pull_age_55 pull_age_56 pull_age_57 pull_age_58 pull_age_59 pull_age_60 pull_rel_to_hhh_1 pull_rel_to_hhh_2 pull_rel_to_hhh_3"
local text_fields33 "pull_rel_to_hhh_4 pull_rel_to_hhh_5 pull_rel_to_hhh_6 pull_rel_to_hhh_7 pull_rel_to_hhh_8 pull_rel_to_hhh_9 pull_rel_to_hhh_10 pull_rel_to_hhh_11 pull_rel_to_hhh_12 pull_rel_to_hhh_13"
local text_fields34 "pull_rel_to_hhh_14 pull_rel_to_hhh_15 pull_rel_to_hhh_16 pull_rel_to_hhh_17 pull_rel_to_hhh_18 pull_rel_to_hhh_19 pull_rel_to_hhh_20 pull_rel_to_hhh_21 pull_rel_to_hhh_22 pull_rel_to_hhh_23"
local text_fields35 "pull_rel_to_hhh_24 pull_rel_to_hhh_25 pull_rel_to_hhh_26 pull_rel_to_hhh_27 pull_rel_to_hhh_28 pull_rel_to_hhh_29 pull_rel_to_hhh_30 pull_rel_to_hhh_31 pull_rel_to_hhh_32 pull_rel_to_hhh_33"
local text_fields36 "pull_rel_to_hhh_34 pull_rel_to_hhh_35 pull_rel_to_hhh_36 pull_rel_to_hhh_37 pull_rel_to_hhh_38 pull_rel_to_hhh_39 pull_rel_to_hhh_40 pull_rel_to_hhh_41 pull_rel_to_hhh_42 pull_rel_to_hhh_43"
local text_fields37 "pull_rel_to_hhh_44 pull_rel_to_hhh_45 pull_rel_to_hhh_46 pull_rel_to_hhh_47 pull_rel_to_hhh_48 pull_rel_to_hhh_49 pull_rel_to_hhh_50 pull_rel_to_hhh_51 pull_rel_to_hhh_52 pull_rel_to_hhh_53"
local text_fields38 "pull_rel_to_hhh_54 pull_rel_to_hhh_55 pull_rel_to_hhh_56 pull_rel_to_hhh_57 pull_rel_to_hhh_58 pull_rel_to_hhh_59 pull_rel_to_hhh_60 end_intro start_consent survey_firm poly nconsentx raison_demenage"
local text_fields39 "raison_voyage village_actuel num_membre num_reference end_consent start_roster oldlist hh_confirmed_num hh_unconfirmed_num hh_unconf_count hh_to_repeat_enter max_hh_repeat hh_roster_new_count"
local text_fields40 "mother_list adult_list adultresp_list count_chefs current_list rpt_caregiver_count count_children hh_currentlist fullname1 fullname2 fullname3 fullname4 fullname5 fullname6 fullname7 fullname8"
local text_fields41 "fullname9 fullname10 fullname11 fullname12 fullname13 fullname14 fullname15 fullname16 fullname17 fullname18 fullname19 fullname20 fullname21 fullname22 fullname23 fullname24 fullname25 fullname26"
local text_fields42 "fullname27 fullname28 fullname29 fullname30 fullname31 fullname32 fullname33 fullname34 fullname35 fullname36 fullname37 fullname38 fullname39 fullname40 fullname41 fullname42 fullname43 fullname44"
local text_fields43 "fullname45 fullname46 fullname47 fullname48 fullname49 fullname50 fullname51 fullname52 fullname53 fullname54 fullname55 fullname56 fullname57 fullname58 fullname59 fullname60 age_1 age_2 age_3 age_4"
local text_fields44 "age_5 age_6 age_7 age_8 age_9 age_10 age_11 age_12 age_13 age_14 age_15 age_16 age_17 age_18 age_19 age_20 age_21 age_22 age_23 age_24 age_25 age_26 age_27 age_28 age_29 age_30 age_31 age_32 age_33"
local text_fields45 "age_34 age_35 age_36 age_37 age_38 age_39 age_40 age_41 age_42 age_43 age_44 age_45 age_46 age_47 age_48 age_49 age_50 age_51 age_52 age_53 age_54 age_55 age_56 age_57 age_58 age_59 age_60 sex_1 sex_2"
local text_fields46 "sex_3 sex_4 sex_5 sex_6 sex_7 sex_8 sex_9 sex_10 sex_11 sex_12 sex_13 sex_14 sex_15 sex_16 sex_17 sex_18 sex_19 sex_20 sex_21 sex_22 sex_23 sex_24 sex_25 sex_26 sex_27 sex_28 sex_29 sex_30 sex_31"
local text_fields47 "sex_32 sex_33 sex_34 sex_35 sex_36 sex_37 sex_38 sex_39 sex_40 sex_41 sex_42 sex_43 sex_44 sex_45 sex_46 sex_47 sex_48 sex_49 sex_50 sex_51 sex_52 sex_53 sex_54 sex_55 sex_56 sex_57 sex_58 sex_59"
local text_fields48 "sex_60 sleep_who sleep_count s_hh_sleep_count end_roster firstname_mem1 firstname_mem2 firstname_mem3 firstname_mem4 firstname_mem5 firstname_mem6 firstname_mem7 firstname_mem8 firstname_mem9"
local text_fields49 "firstname_mem10 firstname_mem11 firstname_mem12 firstname_mem13 firstname_mem14 firstname_mem15 firstname_mem16 firstname_mem17 firstname_mem18 firstname_mem19 firstname_mem20 firstname_mem21"
local text_fields50 "firstname_mem22 firstname_mem23 firstname_mem24 firstname_mem25 firstname_mem26 firstname_mem27 firstname_mem28 firstname_mem29 firstname_mem30 firstname_mem31 firstname_mem32 firstname_mem33"
local text_fields51 "firstname_mem34 firstname_mem35 firstname_mem36 firstname_mem37 firstname_mem38 firstname_mem39 firstname_mem40 firstname_mem41 firstname_mem42 firstname_mem43 firstname_mem44 firstname_mem45"
local text_fields52 "firstname_mem46 firstname_mem47 firstname_mem48 firstname_mem49 firstname_mem50 firstname_mem51 firstname_mem52 firstname_mem53 firstname_mem54 firstname_mem55 firstname_mem56 firstname_mem57"
local text_fields53 "firstname_mem58 firstname_mem59 firstname_mem60 age_mem1 age_mem2 age_mem3 age_mem4 age_mem5 age_mem6 age_mem7 age_mem8 age_mem9 age_mem10 age_mem11 age_mem12 age_mem13 age_mem14 age_mem15 age_mem16"
local text_fields54 "age_mem17 age_mem18 age_mem19 age_mem20 age_mem21 age_mem22 age_mem23 age_mem24 age_mem25 age_mem26 age_mem27 age_mem28 age_mem29 age_mem30 age_mem31 age_mem32 age_mem33 age_mem34 age_mem35 age_mem36"
local text_fields55 "age_mem37 age_mem38 age_mem39 age_mem40 age_mem41 age_mem42 age_mem43 age_mem44 age_mem45 age_mem46 age_mem47 age_mem48 age_mem49 age_mem50 age_mem51 age_mem52 age_mem53 age_mem54 age_mem55 age_mem56"
local text_fields56 "age_mem57 age_mem58 age_mem59 age_mem60 baby_pos_list random_num under_24_count random_baby_posinlist random_baby_pos random_baby_name random_baby_mom_pos random_baby_carer_pos random_baby_mom_name1"
local text_fields57 "random_baby_carer_name random_baby_mom_name child2_pos_list random_num2 between24_180 random_child2_posinlist random_child2_pos random_child2_name random_child2_mom_pos random_child2_carer_pos"
local text_fields58 "random_child2_mom_name1 random_child2_carer_name random_child2_mom_name start_santeeduc end_santeeduc resp_santeeduc start_emploi rpt_wrk_count employment_hh_mems d_hh_wage_labor_count rpt_empl_count"
local text_fields59 "end_emploi start_na rpt_agr_enum_count list_abandon list_managers list_owners list_ownersmanagers ben_max ben_total end_na start_agriculture start_plots plot_name1 plot_name2 plot_name3 plot_name4"
local text_fields60 "plot_name5 plot_name6 plot_name7 plot_name8 plot_name9 plot_name10 plot_name11 plot_name12 plot_name13 plot_name14 plot_name15 plot_name16 plot_name17 plot_name18 plot_name19 plot_name20 plot_name21"
local text_fields61 "plot_name22 plot_name23 plot_name24 plot_name25 plot_name26 plot_name27 plot_name28 plot_name29 plot_name30 rpt_plots_count list_israinandkey list_isdryandkey resp_plot end_plots start_cropsrain1"
local text_fields62 "rpt_plotrain_count list_rain_grew list_rain_harv list_rain_sold rcrops_ask_n end_cropsrain1 rcrops_show start_cropsrain2 rpt_rcrops2_count end_cropsrain2 start_inputs end_inputs start_ag30"
local text_fields63 "rpt_plots30_count plot_size30_count end_plots30 crops_rpt30_count ag_hh_mem_work f_hh_ag_labor_count mutual_support end_ag30 start_cropsdry1 rpt_plotdry_count list_dry_harv list_dry_sold dcrops_ask_n"
local text_fields64 "end_cropsdry1 dcrops_show start_cropsdry2 rpt_dcrops2_count end_cropsdry2 resp_agriculture end_agriculture start_livestock who_fourleg r_four_count who_twoleg rpt_ani1_count end_livestock fish_who"
local text_fields65 "resp_livestock start_security start_scale end_scale end_security start_foodconsumption rpt_consum1_count rpt_consum2_count eat_out_who resp_consum end_foodconsumption start_nfconsumption"
local text_fields66 "start_celebrations rpt_cel1_count rpt_cel2_count end_celebrations start_nonfood rpt_nonfood_count resp_nonfood end_nfconsumption end_nonfood start_assets rpt_ag_ass_count rpt_hh_ass_count resp_ass"
local text_fields67 "end_assets start_finance start_othersav sav_loc gp_savemoreinfo_count end_othersav start_credit cred_o rpt_cred_count end_credit resp_finance end_finance start_mental start_vignettes start_stairs1"
local text_fields68 "end_stairs2 end_stairs1 start_stairs2 start_stairs3 end_stairs3 start_stairs4 end_stairs4 start_stairs5 end_stairs5 end_vignettes start_agrees end_agrees start_stones end_stones start_newsocial"
local text_fields69 "ment_who_present end_newsocial end_mental start_att end_att start_pref start_pref1 end_pref1 start_pref2 end_pref2 start_pref3 pref_prog_why_o end_pref3 end_pref start_risk end_risk start_programs"
local text_fields70 "prog_o rpt_prog_count resp_prog end_programs start_cashtrans ctrans_whoelse ctrans_reason_o resp_ctrans end_cashtrans start_transfers rpt_trans_count rpt_trans_send_count resp_trans end_transfers"
local text_fields71 "start_shocks shock_o shock_n calc_shock1 calc_shock2 calc_shock3 calc_shock4 calc_shock5 calc_shock6 calc_shock7 calc_shock8 calc_shock9 calc_shock10 calc_shock11 calc_shock12 calc_shock13 shock_list"
local text_fields72 "resp_shock end_shocks start_strategy choc_strategy18_o strategy_n calc_strategy1u calc_strategy2u calc_strategy3u calc_strategy4u calc_strategy5u calc_strategy6u calc_strategy7u calc_strategy8u"
local text_fields73 "calc_strategy9u calc_strategy10u calc_strategy11u calc_strategy12u calc_strategy13u calc_strategy14u calc_strategy15u calc_strategy16u calc_strategy18u calc_strategy19u strat_list strat_best1_o"
local text_fields74 "strat_best2_o resp_strategy end_strategy language language_o gps_turnoff instanceid instancename"
local date_fields1 "today ctrans_when_start ctrans_when_last"
local datetime_fields1 "submissiondate starttime endtime"

disp
disp "Starting import of: `csvfile'"
disp

* import data from primary .csv file
insheet using "`csvfile'", names clear

* drop extra table-list columns
cap drop reserved_name_for_field_*
cap drop generated_table_list_lab*

* continue only if there's at least one row of data to import
if _N>0 {
    * drop note fields (since they don't contain any real data)
    forvalues i = 1/100 {
        if "`note_fields`i''" ~= "" {
            drop `note_fields`i''
        }
    }
    
    * format date and date/time fields
    forvalues i = 1/100 {
        if "`datetime_fields`i''" ~= "" {
            foreach dtvarlist in `datetime_fields`i'' {
                cap unab dtvarlist : `dtvarlist'
                if _rc==0 {
                    foreach dtvar in `dtvarlist' {
                        tempvar tempdtvar
                        rename `dtvar' `tempdtvar'
                        gen double `dtvar'=.
                        cap replace `dtvar'=clock(`tempdtvar',"DMYhms",2025)
                        * automatically try without seconds, just in case
                        cap replace `dtvar'=clock(`tempdtvar',"DMYhm",2025) if `dtvar'==. & `tempdtvar'~=""
                        format %tc `dtvar'
                        drop `tempdtvar'
                    }
                }
            }
        }
        if "`date_fields`i''" ~= "" {
            foreach dtvarlist in `date_fields`i'' {
                cap unab dtvarlist : `dtvarlist'
                if _rc==0 {
                    foreach dtvar in `dtvarlist' {
                        tempvar tempdtvar
                        rename `dtvar' `tempdtvar'
                        gen double `dtvar'=.
                        cap replace `dtvar'=date(`tempdtvar',"DMY",2025)
                        format %td `dtvar'
                        drop `tempdtvar'
                    }
                }
            }
        }
    }

    * ensure that text fields are always imported as strings (with "" for missing values)
    * (note that we treat "calculate" fields as text; you can destring later if you wish)
    tempvar ismissingvar
    quietly: gen `ismissingvar'=.
    forvalues i = 1/100 {
        if "`text_fields`i''" ~= "" {
            foreach svarlist in `text_fields`i'' {
                cap unab svarlist : `svarlist'
                if _rc==0 {
                    foreach stringvar in `svarlist' {
                        quietly: replace `ismissingvar'=.
                        quietly: cap replace `ismissingvar'=1 if `stringvar'==.
                        cap tostring `stringvar', format(%100.0g) replace
                        cap replace `stringvar'="" if `ismissingvar'==1
                    }
                }
            }
        }
    }
    quietly: drop `ismissingvar'


    * consolidate unique ID into "key" variable
    replace key=instanceid if key==""
    drop instanceid


    * label variables
    label variable key "Unique submission ID"
    cap label variable submissiondate "Date/time submitted"
    cap label variable formdef_version "Form version used on device"
    cap label variable review_status "Review status"
    cap label variable review_comments "Comments made during review"
    cap label variable review_corrections "Corrections made during review"


    label variable country "A1: [Enquêteur: Dans quel pays vous trouvez-vous?]"
    note country: "A1: [Enquêteur: Dans quel pays vous trouvez-vous?]"
    label define country 1 "Niger" 2 "Sénégal" 3 "Mauritanie"
    label values country country

    label variable region "Région"
    note region: "Région"

    label variable departement "A2: Département"
    note departement: "A2: Département"

    label variable commune "Commune"
    note commune: "Commune"

    label variable village "A3: Village"
    note village: "A3: Village"

    label variable hhid "A4: Sélectionnez le numéro d'identification du répondant"
    note hhid: "A4: Sélectionnez le numéro d'identification du répondant"

    label variable hhid_enter "A4: Pour confirmer, entrez le numéro d'identification du ménage"
    note hhid_enter: "A4: Pour confirmer, entrez le numéro d'identification du ménage"

    label variable supervisor "A6.1: Enquêteur: Quel est le nom et prénom de votre Superviseur?"
    note supervisor: "A6.1: Enquêteur: Quel est le nom et prénom de votre Superviseur?"
    label define supervisor 1 "ELH AYOUBA BACHIR" 2 "ABDOU GARBA DAOUDA" 3 "ZAKOU MOUMOUNI ABOUBACAR" 4 "AMADOU SEYNI NAFISSATOU" -777 "Autre superviseur"
    label values supervisor supervisor

    label variable supervisor_o "Enquêteur: Précisez Autre Superviseur (Nom de famille, prénom)"
    note supervisor_o: "Enquêteur: Précisez Autre Superviseur (Nom de famille, prénom)"

    label variable chefequipe "Enquêteur: Quel est le nom et prénom de votre Chef d'équipe ?"
    note chefequipe: "Enquêteur: Quel est le nom et prénom de votre Chef d'équipe ?"
    label define chefequipe 5 "HAMADOU SOULEY ASSOUMANE" 6 "ABDOURAHAMANE MOHAMED ABDALLAH" 7 "BOUBACAR HASSANE NAWADA" 8 "MAIGUIZO OUSMANE MAKIGOUDOU" 9 "ABDOULKARIM YAYE" 10 "ABDOUL RAZAK ADAMOU BOUBACAR" 11 "ISSOUFOU GEORGES HABSATOU DÉSIRÉE" 12 "IBRAHIM AOUSSOUCK ALMOUSTAPHA" 13 "YACOUBA ALI BIRGUI" 14 "MOHAMED ABDOULAYE" -777 "Autre"
    label values chefequipe chefequipe

    label variable chefequipe_o "Enquêteur: Précisez Autre Chef d'équipe (Nom de famille, prénom)"
    note chefequipe_o: "Enquêteur: Précisez Autre Chef d'équipe (Nom de famille, prénom)"

    label variable surveyor "Enquêteur: Quel est votre nom et prénom ?"
    note surveyor: "Enquêteur: Quel est votre nom et prénom ?"
    label define surveyor 5 "HAMADOU SOULEY ASSOUMANE" 15 "MOUSSA BONKANO ALI" 16 "BOUBACAR DJIBO ISMAEL" 17 "ADAMOU MOUMOUNI ALI" 18 "AMADOU IBRAHIMA YACOUBA" 19 "BOUBACAR ADAMOU MOUSSA" 6 "ABDOURAHAMANE MOHAMED ABDALLAH" 20 "SITTA MOUNKAILA ABOUBACAR" 21 "HAMANI ALFARI ABDOUL MOUNIROU" 22 "ISSIFI BOUBACAR SAMIRATOU" 23 "IBRAHIM IDI MARKA" 24 "HAMISSOU MOHAMADOU" 7 "BOUBACAR HASSANE NAWADA" 25 "DARI MAIDADJI BELLO" 26 "SALIFOU SOULEY SEYNI" 27 "SAFIATOU DIAKITÉ ALHASSANE" 28 "YASMINA BOUBACAR HAROUNA" 29 "HAMADOU BOUREIMA ISMAËL" 8 "MAIGUIZO OUSMANE" 30 "DARI MAIDADJI ABDOULAYE" 31 "SOULEY BELLO ALI" 32 "ABDOUL RAZAK ADAMOU MOSSI" 33 "LAMOUDI BENYOUA MIMBOUABA" 34 "BOUBACAR ISSOUFOU ROUMANATOU" 9 "ABDOULKARIM YAYE" 35 "ALFARI MADOUGOU MAIMOUNA" 36 "MOUSSA SALEY RAHINATOU" 37 "TAWEY TOUDOU NASSER" 38 "IDE INTAHAMOU SOUMAILA" 39 "OUSSEINI IBRAHIM HAMIDO" 10 "ABDOUL RAZAK ADAMOU BOUBACAR" 40 "ABDOUL RAZAK MAMANE MOURTALA" 41 "MANSSAOUDOU MAHAMADOU JILIP" 42 "AMADOU BOUZOU ISMAEL" 43 "HALIDOU HASSANE SALAMATOU" 44 "HABSATOU CHAIBOU MIKIAI" 11 "ISSOUFOU GEORGES HABSATOU DÉSIRÉE" 45 "SEYDINA ABOUBACAR OUSMANE" 46 "ISSA ALHASSANE SOULEYMANE" 47 "HASSANE MAHAMADOU HALDI" 48 "SOURADJIBINE SOUMANA ZAKOU" 49 "YAHAYA MAMAN LEYLA" 12 "IBRAHIM AOUSSOUCK ALMOUSTAPHA" 50 "SALMOU HIMA" 51 "HIMA SAIBOU ALI" 52 "ALI AMADOU ADAMOU" 53 "GAMATIE ABDOU RAKIATOU" 54 "OUSSEINI IDRISSA MOUSSA" 13 "YACOUBA ALI BIRGUI" 55 "BOUNYAMINOU IBRAHIM ABDOULAYE" 56 "BOUBACAR MANGA ABDOUL KADER" 57 "ISSA ZEINI NAFISSATOU" 58 "MOSSI ADAMOU" 59 "SAMIRA DAOUDA IDRISSA" 14 "MOHAMED ABDOULAYE" 60 "OUMAROU SOULEYMANE ALHOUSSEINI" 61 "ALI SOUMAILA AISSATA" 62 "MOUSSA SOULEYMANE ABDOUL KARIM" 63 "ALMOUSTAPHA SOUMANA HASSANE" 64 "IBRAHIM MOUSSA YAOU" -777 "Autre"
    label values surveyor surveyor

    label variable surveyor_o "Enquêteur: Précisez Autre Enquêteur (Nom de famille, prénom)"
    note surveyor_o: "Enquêteur: Précisez Autre Enquêteur (Nom de famille, prénom)"

    label variable resp_name "A8: Sélectionnez le répondant"
    note resp_name: "A8: Sélectionnez le répondant"

    label variable resp_confirm "A9: Vous avez sélectionné: Village: \${village_name} Nom: \${resp_name_pull} Âge"
    note resp_confirm: "A9: Vous avez sélectionné: Village: \${village_name} Nom: \${resp_name_pull} Âge: \${f03d_class_hhhage_pull} Taille du ménage: \${hh_to_repeat_pull} Numéro de téléphone: \${e3_hh_primaryphone_pull} Adresse: \${address_pull} Hameau: \${hameau_pull} Confirmez s'il s'agit du bon répondant."
    label define resp_confirm 1 "oui" 0 "non"
    label values resp_confirm resp_confirm

    label variable resp_wrong "A10: Vous avez indiqué que ceci n'est pas le bon répondant. Le bon répondant app"
    note resp_wrong: "A10: Vous avez indiqué que ceci n'est pas le bon répondant. Le bon répondant apparaît-il sur la tablette?"
    label define resp_wrong 1 "oui" 0 "non"
    label values resp_wrong resp_wrong

    label variable survey_resp_avail "B1: \${resp_name} est-il/elle disponible?"
    note survey_resp_avail: "B1: \${resp_name} est-il/elle disponible?"
    label define survey_resp_avail 1 "oui" 0 "non"
    label values survey_resp_avail survey_resp_avail

    label variable other_resp_avail "B1a: Un autre membre adulte du ménage est-il disponible ?"
    note other_resp_avail: "B1a: Un autre membre adulte du ménage est-il disponible ?"
    label define other_resp_avail 1 "oui" 0 "non"
    label values other_resp_avail other_resp_avail

    label variable other_resp "B1b: À quel membre du ménage parlez-vous?"
    note other_resp: "B1b: À quel membre du ménage parlez-vous?"
    label define other_resp 1 "\${pull_fullname_1}" 2 "\${pull_fullname_2}" 3 "\${pull_fullname_3}" 4 "\${pull_fullname_4}" 5 "\${pull_fullname_5}" 6 "\${pull_fullname_6}" 7 "\${pull_fullname_7}" 8 "\${pull_fullname_8}" 9 "\${pull_fullname_9}" 10 "\${pull_fullname_10}" 11 "\${pull_fullname_11}" 12 "\${pull_fullname_12}" 13 "\${pull_fullname_13}" 14 "\${pull_fullname_14}" 15 "\${pull_fullname_15}" 16 "\${pull_fullname_16}" 17 "\${pull_fullname_17}" 18 "\${pull_fullname_18}" 19 "\${pull_fullname_19}" 20 "\${pull_fullname_20}" 21 "\${pull_fullname_21}" 22 "\${pull_fullname_22}" 23 "\${pull_fullname_23}" 24 "\${pull_fullname_24}" 25 "\${pull_fullname_25}" 26 "\${pull_fullname_26}" 27 "\${pull_fullname_27}" 28 "\${pull_fullname_28}" 29 "\${pull_fullname_29}" 30 "\${pull_fullname_30}" 31 "\${pull_fullname_31}" 32 "\${pull_fullname_32}" 33 "\${pull_fullname_33}" 34 "\${pull_fullname_34}" 35 "\${pull_fullname_35}" 36 "\${pull_fullname_36}" 37 "\${pull_fullname_37}" 38 "\${pull_fullname_38}" 39 "\${pull_fullname_39}" 40 "\${pull_fullname_40}" 41 "\${pull_fullname_41}" 42 "\${pull_fullname_42}" 43 "\${pull_fullname_43}" 44 "\${pull_fullname_44}" 45 "\${pull_fullname_45}" 46 "\${pull_fullname_46}" 47 "\${pull_fullname_47}" 48 "\${pull_fullname_48}" 49 "\${pull_fullname_49}" 50 "\${pull_fullname_50}" 51 "\${pull_fullname_51}" 52 "\${pull_fullname_52}" 53 "\${pull_fullname_53}" 54 "\${pull_fullname_54}" 55 "\${pull_fullname_55}" 56 "\${pull_fullname_56}" 57 "\${pull_fullname_57}" 58 "\${pull_fullname_58}" 59 "\${pull_fullname_59}" 60 "\${pull_fullname_60}"
    label values other_resp other_resp

    label variable consent "B2: Acceptez-vous de participer ?"
    note consent: "B2: Acceptez-vous de participer ?"
    label define consent 1 "oui" 0 "non"
    label values consent consent

    label variable nconsent "B3: Veuillez sélectionner la raison pour laquelle l'entretien ne peut être mené."
    note nconsent: "B3: Veuillez sélectionner la raison pour laquelle l'entretien ne peut être mené."
    label define nconsent 1 "Refuser l'entrée du ménage" 2 "Le répondant sélectionné dans le ménage refuse d'être interviewé" 3 "Le répondant a voyagé" 4 "Incapacité à localiser le ménage" 5 "A déménagé" 6 "Vit dans une zone d’insécurité" 7 "Est indisposé" -88 "Autre, préciser"
    label values nconsent nconsent

    label variable nconsentx "B3.88: Veuillez précisez l'autre raison"
    note nconsentx: "B3.88: Veuillez précisez l'autre raison"

    label variable raison_demenage "B4.1: Pour quelle raison le ménage a déménagé de son village pour un autre villa"
    note raison_demenage: "B4.1: Pour quelle raison le ménage a déménagé de son village pour un autre village ou pays ?"

    label variable raison_voyage "B4.2: Pour quelle raison le ménage a voyagé ?"
    note raison_voyage: "B4.2: Pour quelle raison le ménage a voyagé ?"

    label variable periode_retour "B4.3: Dans combien de semaine le ménage reviendra dans le ménage ?"
    note periode_retour: "B4.3: Dans combien de semaine le ménage reviendra dans le ménage ?"
    label define periode_retour 1 "Moins d’une semaine" 2 "Une semaine" 3 "Entre 2 et 3 semaines" 4 "Un mois" 5 "Plus d’un mois" 6 "Ne sait pas"
    label values periode_retour periode_retour

    label variable pays_actuel "B4.4: Pays de résidence actuel du répondant"
    note pays_actuel: "B4.4: Pays de résidence actuel du répondant"
    label define pays_actuel 1 "Niger" 2 "Autre pays"
    label values pays_actuel pays_actuel

    label variable region_actuelle "B4.5: Dans quelle région du Niger réside actuelle le ménage ?"
    note region_actuelle: "B4.5: Dans quelle région du Niger réside actuelle le ménage ?"
    label define region_actuelle 1 "Agadez" 2 "Dosso" 3 "Maradi" 4 "Tahoua" 5 "Tillabéry" 6 "Zinder" 7 "Diffa" 8 "Niamey"
    label values region_actuelle region_actuelle

    label variable village_actuel "B4.6: Dans quel village du Niger réside actuelle le ménage ?"
    note village_actuel: "B4.6: Dans quel village du Niger réside actuelle le ménage ?"

    label variable num_membre "B4.7: Renseignez le numéro d’un membre du ménage par lequel on peut joindre le m"
    note num_membre: "B4.7: Renseignez le numéro d’un membre du ménage par lequel on peut joindre le ménage dans son village de résidence actuel"

    label variable num_reference "B4.8: Renseignez le numéro d’une personne de référence par lequel on peut joindr"
    note num_reference: "B4.8: Renseignez le numéro d’une personne de référence par lequel on peut joindre le dans son village de résidence actuel"

    label variable oldlist "C1: Confirmez les membres du ménage de l'enquête de base qui sont encore dans le"
    note oldlist: "C1: Confirmez les membres du ménage de l'enquête de base qui sont encore dans le ménage ."

    label variable new_hh_members "C3: Combien de nouveaux membres du ménage y a-t-il?"
    note new_hh_members: "C3: Combien de nouveaux membres du ménage y a-t-il?"

    label variable sleep "C2a: Au cours des 30 derniers jours, un membre du ménage a-t-il dormi hors du vi"
    note sleep: "C2a: Au cours des 30 derniers jours, un membre du ménage a-t-il dormi hors du village au moins une nuit pour une raison quelconque : travailler, aller à l'école / collège, visiter des parents, vacances ou maladie, etc. ?"
    label define sleep 1 "oui" 0 "non"
    label values sleep sleep

    label variable sleep_who "C2a_1: Qui a dormi en dehors du village au cours des 30 derniers jours ?"
    note sleep_who: "C2a_1: Qui a dormi en dehors du village au cours des 30 derniers jours ?"

    label variable health_a_has "15.01a: Votre ménage a-t-il fait face à des dépenses comme [frais de consultatio"
    note health_a_has: "15.01a: Votre ménage a-t-il fait face à des dépenses comme [frais de consultation d'un médecin hors hospitalisation] au cours des 4 dernières semaines ?"
    label define health_a_has 1 "oui" 0 "non"
    label values health_a_has health_a_has

    label variable health_a_amt "15.02a: Quel a été le montant des dépenses pour [frais de consultation d'un méde"
    note health_a_amt: "15.02a: Quel a été le montant des dépenses pour [frais de consultation d'un médecin hors hospitalisation] au cours des 4 dernières semaines ?"

    label variable health_b_has "15.03b: Votre ménage a-t-il fait face à des depenses comme [frais des examens mé"
    note health_b_has: "15.03b: Votre ménage a-t-il fait face à des depenses comme [frais des examens médicaux hors hospitalisation] au cours des 4 dernières semaines ?"
    label define health_b_has 1 "oui" 0 "non"
    label values health_b_has health_b_has

    label variable health_b_amt "15.04b: Quel a été le montant des dépenses pour [frais des examens médicaux hors"
    note health_b_amt: "15.04b: Quel a été le montant des dépenses pour [frais des examens médicaux hors hospitalisation] au cours des 4 dernières semaines ?"

    label variable health_c_has "15.05c: Votre ménage a-t-il fait face à des depenses comme [frais des examens mé"
    note health_c_has: "15.05c: Votre ménage a-t-il fait face à des depenses comme [frais des examens médicaux et des soins hors hospitalisation] au cours des 4 dernières semaines ?"
    label define health_c_has 1 "oui" 0 "non"
    label values health_c_has health_c_has

    label variable health_c_amt "15.06c: Quel a été le montant des dépenses pour [frais de médicaments hors hospi"
    note health_c_amt: "15.06c: Quel a été le montant des dépenses pour [frais de médicaments hors hospitalisation] au cours des 4 dernières semaines ?"

    label variable health_d_has "15.07d: Votre ménage a-t-il fait face à des depenses comme [frais d'hospitalisat"
    note health_d_has: "15.07d: Votre ménage a-t-il fait face à des depenses comme [frais d'hospitalisation] au cours des 6 derniers mois ?"
    label define health_d_has 1 "oui" 0 "non"
    label values health_d_has health_d_has

    label variable health_d_amt "15.08d: Quel a été le montant des dépenses pour [frais d'hospitalisation] au cou"
    note health_d_amt: "15.08d: Quel a été le montant des dépenses pour [frais d'hospitalisation] au cours des 6 derniers mois ?"

    label variable health_e_has "15.09e: Votre ménage a-t-il fait face à des depenses comme [autres dépenses de s"
    note health_e_has: "15.09e: Votre ménage a-t-il fait face à des depenses comme [autres dépenses de santé (automédication, consultation à titre préventif, achat de médicaments à titre préventif, frais de circoncision, etc.)] au cours des 6 derniers mois ?"
    label define health_e_has 1 "oui" 0 "non"
    label values health_e_has health_e_has

    label variable health_e_amt "15.10e: Quel a été le montant des dépenses pour [autres dépenses de santé (autom"
    note health_e_amt: "15.10e: Quel a été le montant des dépenses pour [autres dépenses de santé (automédication, consultation à titre préventif, achat de médicaments à titre péventif, frais de circoncision, etc.)] au cours des 6 derniers mois ?"

    label variable health_f_has "15.11f: Votre ménage a-t-il fait face à des depenses comme [dépenses de vaccinat"
    note health_f_has: "15.11f: Votre ménage a-t-il fait face à des depenses comme [dépenses de vaccination] au cours des 6 derniers mois ?"
    label define health_f_has 1 "oui" 0 "non"
    label values health_f_has health_f_has

    label variable health_f_amt "15.12f: Quel a été le montant des dépenses pour [dépenses de vaccination] au cou"
    note health_f_amt: "15.12f: Quel a été le montant des dépenses pour [dépenses de vaccination] au cours des 6 derniers mois ?"

    label variable health_g_has "15.13g: Votre ménage a-t-il fait face à des depenses comme [frais médicaux penda"
    note health_g_has: "15.13g: Votre ménage a-t-il fait face à des depenses comme [frais médicaux pendant la grossesse ou accouchement ] au cours des 6 derniers mois ?"
    label define health_g_has 1 "oui" 0 "non"
    label values health_g_has health_g_has

    label variable health_g_amt "15.14g: Quel a été le montant des dépenses pour [frais médicaux pendant la gross"
    note health_g_amt: "15.14g: Quel a été le montant des dépenses pour [frais médicaux pendant la grossesse ou accouchement ] au cours des 6 derniers mois ?"

    label variable edu_fee1 "15.05_1: Quel est le montant total des frais de scolarité (y compris les frais d"
    note edu_fee1: "15.05_1: Quel est le montant total des frais de scolarité (y compris les frais d'inscription et les cotisations) pour l'année scolaire 2022/2023 ?"

    label variable edu_fee2 "15.05_2: Quel est le montant total des frais de fournitures (livres, cahiers, un"
    note edu_fee2: "15.05_2: Quel est le montant total des frais de fournitures (livres, cahiers, uniformes, etc.) pour l'année scolaire 2022/2023?"

    label variable edu_fee3 "15.05_3: Quel est le montant des frais d'hébergement scolaire ou universitaire p"
    note edu_fee3: "15.05_3: Quel est le montant des frais d'hébergement scolaire ou universitaire pour l'année scolaire 2022/2023 ?"

    label variable edu_fee4 "15.05_4: Quel est le montant des frais de cantine scolaire ou de restauration po"
    note edu_fee4: "15.05_4: Quel est le montant des frais de cantine scolaire ou de restauration pour l'année scolaire 2022/2023?"

    label variable edu_fee5 "15.05_5: Quel est le montant des frais de transport pour l'année scolaire 2022/2"
    note edu_fee5: "15.05_5: Quel est le montant des frais de transport pour l'année scolaire 2022/2023 ?"

    label variable edu_fee6 "15.05_6: Quel est le montant des bourses/allocations au cours des 12 derniers mo"
    note edu_fee6: "15.05_6: Quel est le montant des bourses/allocations au cours des 12 derniers mois ?"

    label variable resp_santeeduc "Agent Enqueteur : Qui était le répondant pour cette section ?"
    note resp_santeeduc: "Agent Enqueteur : Qui était le répondant pour cette section ?"

    label variable important_activity "F10.13: Laquelle de ces activités a été la plus importante pour votre ménage au "
    note important_activity: "F10.13: Laquelle de ces activités a été la plus importante pour votre ménage au cours des 30 derniers jours ?"
    label define important_activity 1 "Agriculture" 2 "Élevage" 3 "Emploi salarié" 4 "Autres activités génératrices de revenus" 0 "Aucune" -888 "ne sait pas" -999 "refus"
    label values important_activity important_activity

    label variable any_employment "D5: À un moment donné au cours des 30 derniers jours, est-ce qu'un membre du mén"
    note any_employment: "D5: À un moment donné au cours des 30 derniers jours, est-ce qu'un membre du ménage a exercé un emploi rémunéré (sur ou hors de la ferme, à l'exception de travaux indépendants ou de travaux sur votre propre ferme) ?"
    label define any_employment 1 "Oui" 0 "Non" -66 "-66 (Refus de répondre)" -99 "-99 (Ne sait pas)"
    label values any_employment any_employment

    label variable employment_hh_mems "D6: Quels membres du ménage ?"
    note employment_hh_mems: "D6: Quels membres du ménage ?"

    label variable hasplots "12.00: Est-ce qu'au moins un membre du ménage a cultivé des terres (y compris le"
    note hasplots: "12.00: Est-ce qu'au moins un membre du ménage a cultivé des terres (y compris les cultures pérennes), lui appartenant ou non, au cours des 12 derniers mois? (prendre en compte toutes les terres cultivées en saison sèche et en saison pluvieuse)"
    label define hasplots 1 "oui" 0 "non"
    label values hasplots hasplots

    label variable plot_n "12,01: Combien de parcelles ont étés cultivées par le ménage au cours des 12 der"
    note plot_n: "12,01: Combien de parcelles ont étés cultivées par le ménage au cours des 12 derniers mois?"

    label variable plot_name1 "Nom (Lieu dit) 1"
    note plot_name1: "Nom (Lieu dit) 1"

    label variable plot_name2 "Nom (Lieu dit) 2"
    note plot_name2: "Nom (Lieu dit) 2"

    label variable plot_name3 "Nom (Lieu dit) 3"
    note plot_name3: "Nom (Lieu dit) 3"

    label variable plot_name4 "Nom (Lieu dit) 4"
    note plot_name4: "Nom (Lieu dit) 4"

    label variable plot_name5 "Nom (Lieu dit) 5"
    note plot_name5: "Nom (Lieu dit) 5"

    label variable plot_name6 "Nom (Lieu dit) 6"
    note plot_name6: "Nom (Lieu dit) 6"

    label variable plot_name7 "Nom (Lieu dit) 7"
    note plot_name7: "Nom (Lieu dit) 7"

    label variable plot_name8 "Nom (Lieu dit) 8"
    note plot_name8: "Nom (Lieu dit) 8"

    label variable plot_name9 "Nom (Lieu dit) 9"
    note plot_name9: "Nom (Lieu dit) 9"

    label variable plot_name10 "Nom (Lieu dit) 10"
    note plot_name10: "Nom (Lieu dit) 10"

    label variable plot_name11 "Nom (Lieu dit) 11"
    note plot_name11: "Nom (Lieu dit) 11"

    label variable plot_name12 "Nom (Lieu dit) 12"
    note plot_name12: "Nom (Lieu dit) 12"

    label variable plot_name13 "Nom (Lieu dit) 13"
    note plot_name13: "Nom (Lieu dit) 13"

    label variable plot_name14 "Nom (Lieu dit) 14"
    note plot_name14: "Nom (Lieu dit) 14"

    label variable plot_name15 "Nom (Lieu dit) 15"
    note plot_name15: "Nom (Lieu dit) 15"

    label variable plot_name16 "Nom (Lieu dit) 16"
    note plot_name16: "Nom (Lieu dit) 16"

    label variable plot_name17 "Nom (Lieu dit) 17"
    note plot_name17: "Nom (Lieu dit) 17"

    label variable plot_name18 "Nom (Lieu dit) 18"
    note plot_name18: "Nom (Lieu dit) 18"

    label variable plot_name19 "Nom (Lieu dit) 19"
    note plot_name19: "Nom (Lieu dit) 19"

    label variable plot_name20 "Nom (Lieu dit) 20"
    note plot_name20: "Nom (Lieu dit) 20"

    label variable plot_name21 "Nom (Lieu dit) 21"
    note plot_name21: "Nom (Lieu dit) 21"

    label variable plot_name22 "Nom (Lieu dit) 22"
    note plot_name22: "Nom (Lieu dit) 22"

    label variable plot_name23 "Nom (Lieu dit) 23"
    note plot_name23: "Nom (Lieu dit) 23"

    label variable plot_name24 "Nom (Lieu dit) 24"
    note plot_name24: "Nom (Lieu dit) 24"

    label variable plot_name25 "Nom (Lieu dit) 25"
    note plot_name25: "Nom (Lieu dit) 25"

    label variable plot_name26 "Nom (Lieu dit) 26"
    note plot_name26: "Nom (Lieu dit) 26"

    label variable plot_name27 "Nom (Lieu dit) 27"
    note plot_name27: "Nom (Lieu dit) 27"

    label variable plot_name28 "Nom (Lieu dit) 28"
    note plot_name28: "Nom (Lieu dit) 28"

    label variable plot_name29 "Nom (Lieu dit) 29"
    note plot_name29: "Nom (Lieu dit) 29"

    label variable plot_name30 "Nom (Lieu dit) 30"
    note plot_name30: "Nom (Lieu dit) 30"

    label variable resp_plot "12.10: Agent Enqueteur : Qui était le répondant pour cette section ?"
    note resp_plot: "12.10: Agent Enqueteur : Qui était le répondant pour cette section ?"

    label variable rcrops_show "Voici les cultures récoltées pendant la saison des pluies."
    note rcrops_show: "Voici les cultures récoltées pendant la saison des pluies."

    label variable inp_comp "12.28 [Toutes les parcelles] : Avez-vous utilisé des ordures ménagères et autres"
    note inp_comp: "12.28 [Toutes les parcelles] : Avez-vous utilisé des ordures ménagères et autres sur les parcelles au cours de la saison des pluies ?"
    label define inp_comp 1 "oui" 0 "non"
    label values inp_comp inp_comp

    label variable inp_fert "12.29 [Toutes les parcelles] : Avez-vous utilisé de l’engrais inorganique/ chimi"
    note inp_fert: "12.29 [Toutes les parcelles] : Avez-vous utilisé de l’engrais inorganique/ chimique sur les parcelles au cours de la saison des pluies ?"
    label define inp_fert 1 "oui" 0 "non"
    label values inp_fert inp_fert

    label variable fert_purch "12.30 [Toutes les parcelles] : Au cours de la saison des pluies de 2022, combien"
    note fert_purch: "12.30 [Toutes les parcelles] : Au cours de la saison des pluies de 2022, combien avez-vous dépensé au total sur toutes les parcelles pour [l'engrais chimique] ?"

    label variable inp_prod "12.31 [Toutes les parcelles] : Avez-vous utilisé des produits phytosanitaires su"
    note inp_prod: "12.31 [Toutes les parcelles] : Avez-vous utilisé des produits phytosanitaires sur cette parcelle au cours de la saison des pluies ?"
    label define inp_prod 1 "oui" 0 "non"
    label values inp_prod inp_prod

    label variable prod_purch "12.32 [Toutes les parcelles] : Au cours de la saison des pluies de 2022 combien "
    note prod_purch: "12.32 [Toutes les parcelles] : Au cours de la saison des pluies de 2022 combien avez-vous dépensé au total sur toutes les parcelles pour [Les produits phytosanitaires? (Y compris les pesticides, fongicides, herbicides et autres produits) ]"

    label variable inp_group "12.33 [Toutes les parcelles ] : Avez-vous utilisé une main-d'œuvre dans le cadre"
    note inp_group: "12.33 [Toutes les parcelles ] : Avez-vous utilisé une main-d'œuvre dans le cadre de l'entraide (Gayya, Bogou) sur les parcelles au cours de la saison des pluies ?"
    label define inp_group 1 "oui" 0 "non"
    label values inp_group inp_group

    label variable inp_paidlab "12.34 [Toutes les parcelles ] : Avez-vous utilisé une main-d'œuvre rénumerée (en"
    note inp_paidlab: "12.34 [Toutes les parcelles ] : Avez-vous utilisé une main-d'œuvre rénumerée (en argent ou en nature) sur les parcelles au cours de la saison des pluies ?"
    label define inp_paidlab 1 "oui" 0 "non"
    label values inp_paidlab inp_paidlab

    label variable inp_paidlabamt "12.35 [Toutes les parcelles ] : Au total, combien avez-vous payé pour le main-d'"
    note inp_paidlabamt: "12.35 [Toutes les parcelles ] : Au total, combien avez-vous payé pour le main-d'oeuvre renuméré sur toutes les parcelles ?"

    label variable hasplots30 "F1.1: Est-ce qu'au moins un membre du ménage a cultivé des terres (y compris les"
    note hasplots30: "F1.1: Est-ce qu'au moins un membre du ménage a cultivé des terres (y compris les cultures pérennes), lui appartenant ou non, au cours des 30 derniers jours ?"
    label define hasplots30 1 "oui" 0 "non"
    label values hasplots30 hasplots30

    label variable plot_n30 "F1.2: Combien de parcelles ont étés cultivées par le ménage au cours des 30 dern"
    note plot_n30: "F1.2: Combien de parcelles ont étés cultivées par le ménage au cours des 30 derniers jours ?"

    label variable ag_hh_mem_work "F2.1: Au cours des 30 derniers jours, quels membres du ménage ont travaillé à cu"
    note ag_hh_mem_work: "F2.1: Au cours des 30 derniers jours, quels membres du ménage ont travaillé à cultiver des terres pour l'agriculture, pour toutes les cultures et tâches?"

    label variable mutual_labor "F4.10: Avez-vous utilisé une main-d'œuvre dans le cadre de l'entraide (\${mutual"
    note mutual_labor: "F4.10: Avez-vous utilisé une main-d'œuvre dans le cadre de l'entraide (\${mutual_support}) au cours des 30 derniers jours?"
    label define mutual_labor 1 "oui" 0 "non"
    label values mutual_labor mutual_labor

    label variable paid_labor30 "F4.11: Avez-vous utilisé une main-d'œuvre rémunérée (en argent ou en nature) au "
    note paid_labor30: "F4.11: Avez-vous utilisé une main-d'œuvre rémunérée (en argent ou en nature) au cours des 30 derniers jours?"
    label define paid_labor30 1 "oui" 0 "non"
    label values paid_labor30 paid_labor30

    label variable paid_labor_daily30 "F4.12a: Combien avez-vous payé pour le travail rémunéré PAR JOUR en moyenne au c"
    note paid_labor_daily30: "F4.12a: Combien avez-vous payé pour le travail rémunéré PAR JOUR en moyenne au cours des 30 derniers jours? (Si payé en nature, indiquez une valeur en \${currency})"

    label variable paid_labor_total30 "F4.12b: Au total, combien avez-vous payé pour le travail rémunéré cours des 30 d"
    note paid_labor_total30: "F4.12b: Au total, combien avez-vous payé pour le travail rémunéré cours des 30 derniers jours ? (Si payé en nature, donner une valeur en \${currency})"

    label variable crop_didsell30 "F4.13a: Une partie de votre production de cultures a-t-elle été vendue au cours "
    note crop_didsell30: "F4.13a: Une partie de votre production de cultures a-t-elle été vendue au cours des 30 derniers jours ?"
    label define crop_didsell30 1 "oui" 0 "non"
    label values crop_didsell30 crop_didsell30

    label variable crop_didsell_amt30 "F4.13b: Quel a été le montant tiré de cette vente ? (donner une valeur en \${cur"
    note crop_didsell_amt30: "F4.13b: Quel a été le montant tiré de cette vente ? (donner une valeur en \${currency})"

    label variable crop_seed30 "F4.14: Au cours des 30 derniers jours, avez-vous effectué des dépenses pour des "
    note crop_seed30: "F4.14: Au cours des 30 derniers jours, avez-vous effectué des dépenses pour des semences ?"
    label define crop_seed30 1 "oui" 0 "non"
    label values crop_seed30 crop_seed30

    label variable crop_seed_purch30 "F4.14a: Au cours des 30 derniers jours, combien avez-vous dépensé pour les semen"
    note crop_seed_purch30: "F4.14a: Au cours des 30 derniers jours, combien avez-vous dépensé pour les semences ?"

    label variable crop_seed_kind30 "F4.14b: Quel type de semences avez-vous principalement utilisé ?"
    note crop_seed_kind30: "F4.14b: Quel type de semences avez-vous principalement utilisé ?"
    label define crop_seed_kind30 1 "Locales" 2 "Améliorées" -888 "Ne sait pas"
    label values crop_seed_kind30 crop_seed_kind30

    label variable crop_fert30 "F4.15: Au cours des 30 derniers jours, avez-vous effectué des dépenses pour engr"
    note crop_fert30: "F4.15: Au cours des 30 derniers jours, avez-vous effectué des dépenses pour engrais inorganique/chimique ?"
    label define crop_fert30 1 "oui" 0 "non"
    label values crop_fert30 crop_fert30

    label variable crop_fert_purch30 "F4.15a: Au cours des 30 derniers jours, combien avez-vous dépensé pour engrais c"
    note crop_fert_purch30: "F4.15a: Au cours des 30 derniers jours, combien avez-vous dépensé pour engrais chimique ? En \${currency}"

    label variable dcrops_show "Voici les cultures récoltées pendant la saison sèche 2022 - 2023."
    note dcrops_show: "Voici les cultures récoltées pendant la saison sèche 2022 - 2023."

    label variable subsist_recolte "Extra1: Pendant combien de mois au cours des 12 derniers mois la production agri"
    note subsist_recolte: "Extra1: Pendant combien de mois au cours des 12 derniers mois la production agricole du ménage a suffi à nourrir tout le ménage ?"

    label variable aire_culture "Extra2: Quelle est la superficie totale (en hectare) des parcelles que votre mén"
    note aire_culture: "Extra2: Quelle est la superficie totale (en hectare) des parcelles que votre ménage a cultivées durant les 12 derniers mois, y compris les parcelles exploitées par les femmes et les autres membres du ménage?"

    label variable x_certain10b "Vous avez indiqué une superficie supérieure à 10 hectares. Voulez-vous continuer"
    note x_certain10b: "Vous avez indiqué une superficie supérieure à 10 hectares. Voulez-vous continuer?"
    label define x_certain10b 1 "oui" 0 "non"
    label values x_certain10b x_certain10b

    label variable resp_agriculture "Agent Enqueteur : Qui était le répondant pour cette section ?"
    note resp_agriculture: "Agent Enqueteur : Qui était le répondant pour cette section ?"

    label variable own_livestock "13.01A : Au cours des 30 derniers jours, est-ce qu'un membre du ménage a possédé"
    note own_livestock: "13.01A : Au cours des 30 derniers jours, est-ce qu'un membre du ménage a possédé des animaux (bétail, volaille) ou élevé des animaux ne lui appartenant pas ?"
    label define own_livestock 1 "oui" 0 "non"
    label values own_livestock own_livestock

    label variable has_livestock "13.01B : Au cours des 12 derniers mois, est-ce qu'un membre du ménage a possédé "
    note has_livestock: "13.01B : Au cours des 12 derniers mois, est-ce qu'un membre du ménage a possédé des animaux (bétail, volaille) ou élevé des animaux ne lui appartenant pas ?"
    label define has_livestock 1 "oui" 0 "non"
    label values has_livestock has_livestock

    label variable who_fourleg "13.02 : Quels sont les membres du ménage qui s'occuppent de l'entretien de bétai"
    note who_fourleg: "13.02 : Quels sont les membres du ménage qui s'occuppent de l'entretien de bétail dans le ménage ?"

    label variable who_twoleg "13.04 Quels sont les membres du ménage qui s'occuppent de l'entretien de volaill"
    note who_twoleg: "13.04 Quels sont les membres du ménage qui s'occuppent de l'entretien de volaille dans le ménage ?"

    label variable fish "13,23: Est-ce que quelqu'un dans le ménage pratique la pêche?"
    note fish: "13,23: Est-ce que quelqu'un dans le ménage pratique la pêche?"
    label define fish 1 "oui" 0 "non"
    label values fish fish

    label variable fish_who "13,24: Qui dans le ménage pratique la pêche?"
    note fish_who: "13,24: Qui dans le ménage pratique la pêche?"

    label variable resp_livestock "Agent Enqueteur : Qui était le répondant pour cette section ?"
    note resp_livestock: "Agent Enqueteur : Qui était le répondant pour cette section ?"

    label variable food1 "6.01: Au cours des 12 derniers mois, est-ce que vous ou d'autres membres de votr"
    note food1: "6.01: Au cours des 12 derniers mois, est-ce que vous ou d'autres membres de votre ménage avez été inquiets de ne pas avoir suffisament de nourriture par manque de ressources ? DJERMA: Handu way cindi hinka bandey wo, ni wala ni almayaalo ra, boro yaà jaà me àwaari arzaka jaàay se ? HAOUSSA: Cikin watanni goma sha biyu da suka wuce, ku ko wasu da ga cikin gidan ku, kun samu damuwa ta ƙaramcin abinci don rishin hali?"
    label define food1 1 "oui" 0 "non"
    label values food1 food1

    label variable food2 "6.02: Au cours des 12 derniers mois, est-ce que vous ou d'autres membres du ména"
    note food2: "6.02: Au cours des 12 derniers mois, est-ce que vous ou d'autres membres du ménage n’avez pas pu manger une nourriture saine et nutritive par manque d’argent ou d’autres ressources? DJERMA: Handu way cindi hinka bandey wo ra, ni wala ni almayaalo ra bora yaà mana àwaari nafante àwa, nooro jaàay se ? HAOUSSA: Cikin watanni goma sha biyu da suka wuce, ku ko wani da ga cikin gidan ku, kun rasa lahiyayyen abinci mai gina jiki don ƙaramcin hali?"
    label define food2 1 "oui" 0 "non"
    label values food2 food2

    label variable food3 "6.03: Au cours des 12 derniers mois, est-ce que vous ou d'autres membres du ména"
    note food3: "6.03: Au cours des 12 derniers mois, est-ce que vous ou d'autres membres du ménage avez mangé une nourriture peu variée par manque d’argent ou d’autres ressources? DJERMA: Handu way cindi hinka bandey wo ra, ni wala ni almayaalo ra boro yaà mana àwaari dumi-dumey àwa nooru jaàay se ? HAOUSSA: Cikin watanni goma sha biyu da suka wuce, ku ko wani da ga cikin gidan ku, ko ba ku samu sauya kalar abinci ba don ƙaramcin hali?"
    label define food3 1 "oui" 0 "non"
    label values food3 food3

    label variable food4 "6.04: Au cours des 12 derniers mois, est-ce que vous ou d'autres membres du ména"
    note food4: "6.04: Au cours des 12 derniers mois, est-ce que vous ou d'autres membres du ménage avez du sauter un repas parce que vous n’aviez pas assez d’argent ou d’autres ressources pour vous procurer à manger? DJERMA: HHandu way cindi hinka bandey wo ra, ni wala ni almayaalo ra boro yaà mana àwa alwaato fo ra zaari ra ? HAOUSSA: Cikin watanni goma sha biyu da suka wuce, ku ko wani da ga cikin gidan ku, ko kun tsallake cin abinci don ƙaramcin halin sayen abincin?"
    label define food4 1 "oui" 0 "non"
    label values food4 food4

    label variable food5 "6.05: Au cours des 12 derniers mois, est-ce que vous ou d'autres membres du ména"
    note food5: "6.05: Au cours des 12 derniers mois, est-ce que vous ou d'autres membres du ménage avez mangé moins que ce que vous pensiez que vous auriez du manger à cause d’un manque d’argent ou d’autres ressources? DJERMA: Handu way cindi hinka bandey wo ra, ni wala ni almayaalo ra boro yaà, mana du àwaaro kaà i anniya ngey ma àwa nooru jaàay se ? HAOUSSA: Cikin watanni goma sha biyu da suka wuce, ku ko wani da ga cikin gidan ku, ko ba ku samu cin isasshen abinci ba kamar yanda ya kamata don ƙaramcin hali?"
    label define food5 1 "oui" 0 "non"
    label values food5 food5

    label variable food6 "6.06: Au cours des 12 derniers mois, est-ce que votre ménage n’avait plus de nou"
    note food6: "6.06: Au cours des 12 derniers mois, est-ce que votre ménage n’avait plus de nourriture parce qu’il n’y avait pas assez d’argent ou d’autres ressources? DJERMA: Handu way cindi hinka bandey wo ra, ni wala ni almayaalo ra boro yaà, sinda me-àwaari zama se a sinda nooro ? HAOUSSA: Cikin watanni goma sha biyu da suka wuce, ko an rasa abinci sam sam ko da kwana ɗaya ne a gidan ku don ƙaramcin hali?"
    label define food6 1 "oui" 0 "non"
    label values food6 food6

    label variable food7 "6.07: Au cours des 12 derniers mois, est-ce que vous ou d'autres membres de votr"
    note food7: "6.07: Au cours des 12 derniers mois, est-ce que vous ou d'autres membres de votre ménage avez eu faim mais vous n’avez pas mangé parce qu’il n’y avait pas assez d’argent ou d’autres ressources pour vous procurer à manger? DJERMA: Handu way cindi hinka bandey wo ra, ni wala ni almayaalo ra boro yaà haray zama se I sinda nooru kaà ga àwaari day ? HAOUSSA: Cikin watanni goma sha biyu da suka wuce, ku ko wani da ga cikin gidan ku, kun ji yinwa amma ba ku samu cin abinci ba, don ƙaramcin halin sayen abincin?"
    label define food7 1 "oui" 0 "non"
    label values food7 food7

    label variable food7b "6.07b: Au cours des 12 derniers mois, est-il souvent arrivé que vous ou d'autres"
    note food7b: "6.07b: Au cours des 12 derniers mois, est-il souvent arrivé que vous ou d'autres membres du ménage ayez faim mais que vous n'avez pas mangé parce qu'il n'y avait pas suffisament d'argent ou de ressources pour la nourriture? Cela est- il arrivé une ou deux fois, pendant quelques mois mais pas tous les mois, ou presque tous les mois ? DJERMA: Handu way cindi hinka bandey wo ra, ni wala ni almayaalo ra boro yaà, mana àwa zama se i sinda nooro kaà ga àwaari da ? sor fo wala ihinka; handu yan; handicap kul? HAOUSSA: Sau nawa wannan ya faru? sau ɗaya ko sau biyu? a cikin wasu watanni ne amma ba dukkan watanni ba ne ko kuwa yawancin watnni ne ?"
    label define food7b 1 "Seulement une ou deux fois" 2 "Quelques mois, mais pas tous les mois" 3 "Presque tous les mois"
    label values food7b food7b

    label variable food8 "6.08: Au cours des 12 derniers mois, est-ce que vous ou d'autres membres de votr"
    note food8: "6.08: Au cours des 12 derniers mois, est-ce que vous ou d'autres membres de votre ménage avez passé toute une journée sans manger par manque d’argent ou d’autres ressources? DJERMA: Handu way cindi hinka bandey wo ni wala ni almayaako ra boro yaà te zaari fo kaà I mana àwa nooru jaàay se ? HAOUSSA: Cikin watanni goma sha biyu da suka wuce, ku ko wani daga cikin gidan ku, ya wuni bai ci abinci sam sam ba don ƙaramcin halin sayen abincin?"
    label define food8 1 "oui" 0 "non"
    label values food8 food8

    label variable food8b "6.08b: Au cours des 12 derniers mois, est-il souvent arrivé que vous ou d'autres"
    note food8b: "6.08b: Au cours des 12 derniers mois, est-il souvent arrivé que vous ou d'autres membres de votre ménage ayez passé toute une journée sans manger par manque d’argent ou d’autres ressources? Cela est- il arrivé une ou deux fois, pendant quelques mois mais pas tous les mois, ou presque tous les mois? DJERMA: Handu way cindi hinka bandey wo, alwaati te kaà ni almayaalo mana àwa zaari ra, nooru jaàay se ? Sorro fo wala ihinka no a te handu bandey wo ra wala handey kulu ra. HAOUSSA: Sau nawa wannan ya faru, sau ɗaya ko sau biyu, a cikin wasu watanni ne amma ba dukkan watanni ba ne ko kuwa yawancin watanni ne ?"
    label define food8b 1 "Seulement une ou deux fois" 2 "Quelques mois, mais pas tous les mois" 3 "Presque tous les mois"
    label values food8b food8b

    label variable food8c "6.08c:Combien de jours vous ou d'autres membres de votre ménage avez passé toute"
    note food8c: "6.08c:Combien de jours vous ou d'autres membres de votre ménage avez passé toute une journée sans manger par manque d’argent ou d’autres ressources?"

    label variable food10 "6.09: Lorsque vous manquez de nourriture (c’est-à-dire lorsqu’il n’y a pas assez"
    note food10: "6.09: Lorsque vous manquez de nourriture (c’est-à-dire lorsqu’il n’y a pas assez à manger pour tout le monde), dans quel ordre les membres du ménage se servent-ils ? Classez les groupes suivants dans l’ordre :"
    label define food10 1 "1" 2 "2" 3 "3" 4 "4" -666 "Non applicable"
    label values food10 food10

    label variable food_men "Les hommes adultes"
    note food_men: "Les hommes adultes"
    label define food_men 1 "1" 2 "2" 3 "3" 4 "4" -666 "Non applicable"
    label values food_men food_men

    label variable food_women "Les femmes adultes"
    note food_women: "Les femmes adultes"
    label define food_women 1 "1" 2 "2" 3 "3" 4 "4" -666 "Non applicable"
    label values food_women food_women

    label variable food_boys "Les garçons (enfants)"
    note food_boys: "Les garçons (enfants)"
    label define food_boys 1 "1" 2 "2" 3 "3" 4 "4" -666 "Non applicable"
    label values food_boys food_boys

    label variable food_girls "Les filles (enfants)"
    note food_girls: "Les filles (enfants)"
    label define food_girls 1 "1" 2 "2" 3 "3" 4 "4" -666 "Non applicable"
    label values food_girls food_girls

    label variable food11 "6.09ext: Au cours des 12 prochains mois, quelle est la probabilité pour vous ou "
    note food11: "6.09ext: Au cours des 12 prochains mois, quelle est la probabilité pour vous ou d’autres membres de votre ménage de passer toute une journée sans manger ?"
    label define food11 1 "Très probable" 2 "Assez probable" 3 "Peu probable" 4 "Pas du tout probable"
    label values food11 food11

    label variable div_cereal "Céréales, grains, racines ou tubercules : riz, pâtes, pain/galette (non sucrés),"
    note div_cereal: "Céréales, grains, racines ou tubercules : riz, pâtes, pain/galette (non sucrés), sorgho, mil, maïs, fonio, pomme de terre, igname, manioc, gari / tapioca, patate douce blanche, taros."

    label variable div_pulse "Légumineuses / noix : haricots (niébé), arachides, lentilles, noix, soja, pois d"
    note div_pulse: "Légumineuses / noix : haricots (niébé), arachides, lentilles, noix, soja, pois d'Angole et / ou autres noix, petits pois"

    label variable div_milk "Lait ou d'autres produits laitiers : Lait frais, lait en poudre, lait concentré "
    note div_milk: "Lait ou d'autres produits laitiers : Lait frais, lait en poudre, lait concentré (sucré ou non), yaourt, fromage, crème fraîche, Lait fermenté (sauf margarine / beurre ou petites quantites de lait pour le thé/ café)"

    label variable div_meat "Viande, poisson ou oeufs : chèvre, boeuf, poulet, porc, sang, poisson, y compris"
    note div_meat: "Viande, poisson ou oeufs : chèvre, boeuf, poulet, porc, sang, poisson, y compris le thon en conserve, escargot, et/ou autres fruits de mer, oeufs (viande et poisson consommés en grande quantités et non comme condiment)"

    label variable div_meat2 "Viande de chair : boeuf, porc, agneau, chèvre, lapin, poulet, canard, autres ois"
    note div_meat2: "Viande de chair : boeuf, porc, agneau, chèvre, lapin, poulet, canard, autres oiseaux, insectes"

    label variable div_meat_org "Organes de viande : foie, rein, cœur et/ou autres organes de viande (tripes, int"
    note div_meat_org: "Organes de viande : foie, rein, cœur et/ou autres organes de viande (tripes, intestins etc.)"

    label variable div_fish "Poisson/mollusques : poisson frais, poisson fumé, salé, saches, y compris le tho"
    note div_fish: "Poisson/mollusques : poisson frais, poisson fumé, salé, saches, y compris le thon en conserve, les escargots et/ou d'autres fruits de mer (poisson en grande quantites et non comme condiment)."

    label variable div_egg "Oeufs (de poule, pintade, caille, de canard, de dinde etc.)"
    note div_egg: "Oeufs (de poule, pintade, caille, de canard, de dinde etc.)"

    label variable div_veg "Légumes et feuilles : Epinards, oignons, tomates, carottes, poivrons, haricots v"
    note div_veg: "Légumes et feuilles : Epinards, oignons, tomates, carottes, poivrons, haricots verts, laitue, Oseille, amarante, salade, feuilles de baobab, feuilles d'oignon, feuilles de haricot, feuilles de manioc, feuilles de patates douces, etc."

    label variable div_veg_vita "Légumes oranges (légumes riches en vitamine A) : carotte, poivron rouge, potiron"
    note div_veg_vita: "Légumes oranges (légumes riches en vitamine A) : carotte, poivron rouge, potiron, patate douce orange, Courge"

    label variable div_vega "Légumes à feuilles vertes : Épinards, brocolis, amarante et / ou autres feuilles"
    note div_vega: "Légumes à feuilles vertes : Épinards, brocolis, amarante et / ou autres feuilles vert foncé, feuilles de manioc"

    label variable div_fruit "Fruits : Ananas, banane, goyave, dattes, pastèque, papaye, canne à sucre, pomme "
    note div_fruit: "Fruits : Ananas, banane, goyave, dattes, pastèque, papaye, canne à sucre, pomme cannelle, orange, citron, raisins, fruits sauvages (tamarin, ...), fruit de baobab etc."

    label variable div_fruit_vita "Fruits orange (Fruits riches en vitamine A): mangue, papaye, abricot, pêche, mel"
    note div_fruit_vita: "Fruits orange (Fruits riches en vitamine A): mangue, papaye, abricot, pêche, melon"

    label variable div_oil "Huile / graisse / beurre : huile végétale, huile de palme, beurre de karité, mar"
    note div_oil: "Huile / graisse / beurre : huile végétale, huile de palme, beurre de karité, margarine, autres graisses / huile"

    label variable div_sugar "Sucre, ou sucreries : Sucre en poudre ou en morceaux , sucreries (sucreries, bis"
    note div_sugar: "Sucre, ou sucreries : Sucre en poudre ou en morceaux , sucreries (sucreries, bissap, jus, jus industriels), lait concentre sucre, miel, confiture, bonbons, gateau sucre, biscuits, patisseries"

    label variable div_spice "Condiments / Epices : the, cafe / cacao, sel, ail, epices, levure / poudre à lev"
    note div_spice: "Condiments / Epices : the, cafe / cacao, sel, ail, epices, levure / poudre à lever, concentre de tomates, piment, poudre de poisson, sel, cube maggi, viande ou poisson comme condiment, condiments incluant une petite quantité de lait / thé café."

    label variable note_food_childq "6.11: Pendant la journée d'hier, \${random_baby_name} a-t-il/elle consommé les p"
    note note_food_childq: "6.11: Pendant la journée d'hier, \${random_baby_name} a-t-il/elle consommé les produits suivants ?"
    label define note_food_childq 1 "oui" 0 "non"
    label values note_food_childq note_food_childq

    label variable div_milk_mat_child "Lait maternel"
    note div_milk_mat_child: "Lait maternel"
    label define div_milk_mat_child 1 "oui" 0 "non"
    label values div_milk_mat_child div_milk_mat_child

    label variable div_cereal_child "Grains, racines et tubercules : Sorgho, millet, maïs, blé, riz, pâtes, fonio, pa"
    note div_cereal_child: "Grains, racines et tubercules : Sorgho, millet, maïs, blé, riz, pâtes, fonio, pain, biscuits, crêpes, beignets de céréales ; pomme de terre, igname, manioc, autres tubercules"
    label define div_cereal_child 1 "oui" 0 "non"
    label values div_cereal_child div_cereal_child

    label variable div_pulse_child "Légumineuses et noix : Pois, niébés, arachides, lentilles, haricots, sésame, aut"
    note div_pulse_child: "Légumineuses et noix : Pois, niébés, arachides, lentilles, haricots, sésame, autres fruits à coque"
    label define div_pulse_child 1 "oui" 0 "non"
    label values div_pulse_child div_pulse_child

    label variable div_milk_child "Produits laitiers : Lait frais/ caillé, yaourt, fromage, verres de lait en poudr"
    note div_milk_child: "Produits laitiers : Lait frais/ caillé, yaourt, fromage, verres de lait en poudre, autres produits laitiers SAUF margarine / beurre ou petites quantités de lait pour le thé / café"
    label define div_milk_child 1 "oui" 0 "non"
    label values div_milk_child div_milk_child

    label variable div_meat_child "Viande, poisson ou volaille : Bœuf, porc, agneau, chèvre, lapin, poulet, canard,"
    note div_meat_child: "Viande, poisson ou volaille : Bœuf, porc, agneau, chèvre, lapin, poulet, canard, autres oiseaux, insectes"
    label define div_meat_child 1 "oui" 0 "non"
    label values div_meat_child div_meat_child

    label variable div_egg_child "Oeufs"
    note div_egg_child: "Oeufs"
    label define div_egg_child 1 "oui" 0 "non"
    label values div_egg_child div_egg_child

    label variable div_fruit_vita_child "Fruits et légumes riches en vitamine A : Mangue, papaye, carotte, poivron rouge,"
    note div_fruit_vita_child: "Fruits et légumes riches en vitamine A : Mangue, papaye, carotte, poivron rouge, citrouille, patate douce orange"
    label define div_fruit_vita_child 1 "oui" 0 "non"
    label values div_fruit_vita_child div_fruit_vita_child

    label variable div_fruit_child "Autres fruits et légumes : Banane, pomme, citron, abricot, pêche, oignon, tomate"
    note div_fruit_child: "Autres fruits et légumes : Banane, pomme, citron, abricot, pêche, oignon, tomate, poivron, carotte, haricot vert, laitue, etc."
    label define div_fruit_child 1 "oui" 0 "non"
    label values div_fruit_child div_fruit_child

    label variable note_food_momq "6.12: Pendant la journée d'hier, \${random_baby_mom_name} a-t-il/elle consommé l"
    note note_food_momq: "6.12: Pendant la journée d'hier, \${random_baby_mom_name} a-t-il/elle consommé les produits suivants ?"
    label define note_food_momq 1 "oui" 0 "non"
    label values note_food_momq note_food_momq

    label variable div_cereal_mom "Céréales - Sorgho, millet, maïs, blé, riz, pâtes, fonio, pain, biscuits, crêpes,"
    note div_cereal_mom: "Céréales - Sorgho, millet, maïs, blé, riz, pâtes, fonio, pain, biscuits, crêpes, beignets de céréales Tubercules - Pomme de terre, Igname, Manioc, Autres tubercules"
    label define div_cereal_mom 1 "oui" 0 "non"
    label values div_cereal_mom div_cereal_mom

    label variable div_pulse_mom "Pois, niébés, lentilles, haricots"
    note div_pulse_mom: "Pois, niébés, lentilles, haricots"
    label define div_pulse_mom 1 "oui" 0 "non"
    label values div_pulse_mom div_pulse_mom

    label variable div_pulse2_mom "Cacahuètes, sésame, autres fruits à coque et graines"
    note div_pulse2_mom: "Cacahuètes, sésame, autres fruits à coque et graines"
    label define div_pulse2_mom 1 "oui" 0 "non"
    label values div_pulse2_mom div_pulse2_mom

    label variable div_milk_mom "Lait frais/ caillé, yaourt, fromage, verres de lait en poudre, autres produits l"
    note div_milk_mom: "Lait frais/ caillé, yaourt, fromage, verres de lait en poudre, autres produits laitiers SAUF margarine / beurre ou petites quantités de lait pour le thé / café"
    label define div_milk_mom 1 "oui" 0 "non"
    label values div_milk_mom div_milk_mom

    label variable div_meat_mom "Bœuf, porc, agneau, chèvre, lapin, poulet, canard, autres oiseaux, insectes"
    note div_meat_mom: "Bœuf, porc, agneau, chèvre, lapin, poulet, canard, autres oiseaux, insectes"
    label define div_meat_mom 1 "oui" 0 "non"
    label values div_meat_mom div_meat_mom

    label variable div_egg_mom "Oeufs"
    note div_egg_mom: "Oeufs"
    label define div_egg_mom 1 "oui" 0 "non"
    label values div_egg_mom div_egg_mom

    label variable div_veg_mom "Légumes à feuilles vertes : épinards, brocolis, amarante et / ou autres feuilles"
    note div_veg_mom: "Légumes à feuilles vertes : épinards, brocolis, amarante et / ou autres feuilles vert foncé, feuilles de manioc"
    label define div_veg_mom 1 "oui" 0 "non"
    label values div_veg_mom div_veg_mom

    label variable div_fruit1_mom "Mangue, papaye"
    note div_fruit1_mom: "Mangue, papaye"
    label define div_fruit1_mom 1 "oui" 0 "non"
    label values div_fruit1_mom div_fruit1_mom

    label variable div_veg_vita_mom "Oignon, tomates, poivrons, carottes, haricots verts, laitue, etc."
    note div_veg_vita_mom: "Oignon, tomates, poivrons, carottes, haricots verts, laitue, etc."
    label define div_veg_vita_mom 1 "oui" 0 "non"
    label values div_veg_vita_mom div_veg_vita_mom

    label variable div_fruit_mom "Banane, pomme, citron, abricot, pêche, etc."
    note div_fruit_mom: "Banane, pomme, citron, abricot, pêche, etc."
    label define div_fruit_mom 1 "oui" 0 "non"
    label values div_fruit_mom div_fruit_mom

    label variable note_food_child2q "0.01: Pendant la journée d'hier, \${random_child2_name} a-t-il/elle consommé les"
    note note_food_child2q: "0.01: Pendant la journée d'hier, \${random_child2_name} a-t-il/elle consommé les produits suivants ?"
    label define note_food_child2q 1 "oui" 0 "non"
    label values note_food_child2q note_food_child2q

    label variable div_cereal_child2 "Céréales - Sorgho, millet, maïs, blé, riz, pâtes, fonio, pain, biscuits, crêpes,"
    note div_cereal_child2: "Céréales - Sorgho, millet, maïs, blé, riz, pâtes, fonio, pain, biscuits, crêpes, beignets de céréales Tubercules - Pomme de terre, Igname, Manioc, Autres tubercules"
    label define div_cereal_child2 1 "oui" 0 "non"
    label values div_cereal_child2 div_cereal_child2

    label variable div_pulse_child2 "Pois, niébés, lentilles, haricots"
    note div_pulse_child2: "Pois, niébés, lentilles, haricots"
    label define div_pulse_child2 1 "oui" 0 "non"
    label values div_pulse_child2 div_pulse_child2

    label variable div_pulse2_child2 "Cacahuètes, sésame, autres fruits à coque et graines"
    note div_pulse2_child2: "Cacahuètes, sésame, autres fruits à coque et graines"
    label define div_pulse2_child2 1 "oui" 0 "non"
    label values div_pulse2_child2 div_pulse2_child2

    label variable div_milk_child2 "Lait frais/ caillé, yaourt, fromage, verres de lait en poudre, autres produits l"
    note div_milk_child2: "Lait frais/ caillé, yaourt, fromage, verres de lait en poudre, autres produits laitiers SAUF margarine / beurre ou petites quantités de lait pour le thé / café"
    label define div_milk_child2 1 "oui" 0 "non"
    label values div_milk_child2 div_milk_child2

    label variable div_meat_child2 "Bœuf, porc, agneau, chèvre, lapin, poulet, canard, autres oiseaux, insectes"
    note div_meat_child2: "Bœuf, porc, agneau, chèvre, lapin, poulet, canard, autres oiseaux, insectes"
    label define div_meat_child2 1 "oui" 0 "non"
    label values div_meat_child2 div_meat_child2

    label variable div_egg_child2 "Oeufs"
    note div_egg_child2: "Oeufs"
    label define div_egg_child2 1 "oui" 0 "non"
    label values div_egg_child2 div_egg_child2

    label variable div_veg_child2 "Légumes à feuilles vertes : épinards, brocolis, amarante et / ou autres feuilles"
    note div_veg_child2: "Légumes à feuilles vertes : épinards, brocolis, amarante et / ou autres feuilles vert foncé, feuilles de manioc"
    label define div_veg_child2 1 "oui" 0 "non"
    label values div_veg_child2 div_veg_child2

    label variable div_fruit1_child2 "Mangue, papaye"
    note div_fruit1_child2: "Mangue, papaye"
    label define div_fruit1_child2 1 "oui" 0 "non"
    label values div_fruit1_child2 div_fruit1_child2

    label variable div_veg_vita_child2 "Oignon, tomates, poivrons, carottes, haricots verts, laitue, etc."
    note div_veg_vita_child2: "Oignon, tomates, poivrons, carottes, haricots verts, laitue, etc."
    label define div_veg_vita_child2 1 "oui" 0 "non"
    label values div_veg_vita_child2 div_veg_vita_child2

    label variable div_fruit_child2 "Banane, pomme, citron, abricot, pêche, etc."
    note div_fruit_child2: "Banane, pomme, citron, abricot, pêche, etc."
    label define div_fruit_child2 1 "oui" 0 "non"
    label values div_fruit_child2 div_fruit_child2

    label variable resp_food "Agent Enqueteur : Qui était le répondant pour cette Section ?"
    note resp_food: "Agent Enqueteur : Qui était le répondant pour cette Section ?"
    label define resp_food -5 "[décédé.e]" -4 "[ne fait pas partie du ménage]" -2 "Personne" -1 "Tous les membres du ménage" 0 "Personnes hors du ménage" 1 "\${fullname1} (Age: \${age_1} , pos 1)" 2 "\${fullname2} (Age: \${age_2} , pos 2)" 3 "\${fullname3} (Age: \${age_3} , pos 3)" 4 "\${fullname4} (Age: \${age_4} , pos 4)" 5 "\${fullname5} (Age: \${age_5} , pos 5)" 6 "\${fullname6} (Age: \${age_6} , pos 6)" 7 "\${fullname7} (Age: \${age_7} , pos 7)" 8 "\${fullname8} (Age: \${age_8} , pos 8)" 9 "\${fullname9} (Age: \${age_9} , pos 9)" 10 "\${fullname10} (Age: \${age_10} , pos 10)" 11 "\${fullname11} (Age: \${age_11} , pos 11)" 12 "\${fullname12} (Age: \${age_12} , pos 12)" 13 "\${fullname13} (Age: \${age_13} , pos 13)" 14 "\${fullname14} (Age: \${age_14} , pos 14)" 15 "\${fullname15} (Age: \${age_15} , pos 15)" 16 "\${fullname16} (Age: \${age_16} , pos 16)" 17 "\${fullname17} (Age: \${age_17} , pos 17)" 18 "\${fullname18} (Age: \${age_18} , pos 18)" 19 "\${fullname19} (Age: \${age_19} , pos 19)" 20 "\${fullname20} (Age: \${age_20} , pos 20)" 21 "\${fullname21} (Age: \${age_21} , pos 21)" 22 "\${fullname22} (Age: \${age_22} , pos 22)" 23 "\${fullname23} (Age: \${age_23} , pos 23)" 24 "\${fullname24} (Age: \${age_24} , pos 24)" 25 "\${fullname25} (Age: \${age_25} , pos 25)" 26 "\${fullname26} (Age: \${age_26} , pos 26)" 27 "\${fullname27} (Age: \${age_27} , pos 27)" 28 "\${fullname28} (Age: \${age_28} , pos 28)" 29 "\${fullname29} (Age: \${age_29} , pos 29)" 30 "\${fullname30} (Age: \${age_30} , pos 30)" 31 "\${fullname31} (Age: \${age_31} , pos 31)" 32 "\${fullname32} (Age: \${age_32} , pos 32)" 33 "\${fullname33} (Age: \${age_33} , pos 33)" 34 "\${fullname34} (Age: \${age_34} , pos 34)" 35 "\${fullname35} (Age: \${age_35} , pos 35)" 36 "\${fullname36} (Age: \${age_36} , pos 36)" 37 "\${fullname37} (Age: \${age_37} , pos 37)" 38 "\${fullname38} (Age: \${age_38} , pos 38)" 39 "\${fullname39} (Age: \${age_39} , pos 39)" 40 "\${fullname40} (Age: \${age_40} , pos 40)" 41 "\${fullname41} (Age: \${age_41} , pos 41)" 42 "\${fullname42} (Age: \${age_42} , pos 42)" 43 "\${fullname43} (Age: \${age_43} , pos 43)" 44 "\${fullname44} (Age: \${age_44} , pos 44)" 45 "\${fullname45} (Age: \${age_45} , pos 45)" 46 "\${fullname46} (Age: \${age_46} , pos 46)" 47 "\${fullname47} (Age: \${age_47} , pos 47)" 48 "\${fullname48} (Age: \${age_48} , pos 48)" 49 "\${fullname49} (Age: \${age_49} , pos 49)" 50 "\${fullname50} (Age: \${age_50} , pos 50)" 51 "\${fullname51} (Age: \${age_51} , pos 51)" 52 "\${fullname52} (Age: \${age_52} , pos 52)" 53 "\${fullname53} (Age: \${age_53} , pos 53)" 54 "\${fullname54} (Age: \${age_54} , pos 54)" 55 "\${fullname55} (Age: \${age_55} , pos 55)" 56 "\${fullname56} (Age: \${age_56} , pos 56)" 57 "\${fullname57} (Age: \${age_57} , pos 57)" 58 "\${fullname58} (Age: \${age_58} , pos 58)" 59 "\${fullname59} (Age: \${age_59} , pos 59)" 60 "\${fullname60} (Age: \${age_60} , pos 60)"
    label values resp_food resp_food

    label variable eat_out "11.09: Au cours des sept derniers jours, un membre du ménage a-t-il mangé à l'ex"
    note eat_out: "11.09: Au cours des sept derniers jours, un membre du ménage a-t-il mangé à l'extérieur du ménage (restaurant etc) ?"
    label define eat_out 1 "oui" 0 "non"
    label values eat_out eat_out

    label variable eat_out_who "11.10 : Qui ?"
    note eat_out_who: "11.10 : Qui ?"

    label variable eat_out_xof "11.11 : Environ combien d'argent au total a été dépensé en repas à l'extérieur d"
    note eat_out_xof: "11.11 : Environ combien d'argent au total a été dépensé en repas à l'extérieur du ménage au cours des sept derniers jours ?"

    label variable eat_share "11.12 Au cours des 7 derniers jours, est-ce qu'une personne non membre du ménage"
    note eat_share: "11.12 Au cours des 7 derniers jours, est-ce qu'une personne non membre du ménage a -t-il mangé au moins un repas du ménage?"
    label define eat_share 1 "oui" 0 "non"
    label values eat_share eat_share

    label variable eat_kids_days "11.13: Au cours des 7 derniers jours, combien de jours un repas a été partagé av"
    note eat_kids_days: "11.13: Au cours des 7 derniers jours, combien de jours un repas a été partagé avec des personnes non membres du ménage, enfants 0-14 ?"

    label variable eat_kids_meals "11.14: Au cours des 7 derniers jours, combien de repas ont été partagés avec des"
    note eat_kids_meals: "11.14: Au cours des 7 derniers jours, combien de repas ont été partagés avec des personnes non membres du ménage, enfants 0-14 ?"

    label variable eat_adults_days "11.13a: Au cours des 7 derniers jours, combien de jours un repas a été partagé a"
    note eat_adults_days: "11.13a: Au cours des 7 derniers jours, combien de jours un repas a été partagé avec des personnes non membres du ménage, adults 15+ ?"

    label variable eat_adults_meals "11.14b: Au cours des 7 derniers jours, combien de repas ont été partagés avec de"
    note eat_adults_meals: "11.14b: Au cours des 7 derniers jours, combien de repas ont été partagés avec des personnes non membres du ménage, adults 15+ ?"

    label variable resp_consum "Agent Enqueteur : Qui était le répondant pour cette section ?"
    note resp_consum: "Agent Enqueteur : Qui était le répondant pour cette section ?"

    label variable resp_nonfood "Agent Enqueteur : Qui était le répondant pour cette section ?"
    note resp_nonfood: "Agent Enqueteur : Qui était le répondant pour cette section ?"

    label variable resp_ass "Agent Enqueteur : Qui était le répondant pour cette section ?"
    note resp_ass: "Agent Enqueteur : Qui était le répondant pour cette section ?"

    label variable sav_loc "4.01: Au cours des 12 dernières mois, as-tu déjà mis de l'argent de côté auprès "
    note sav_loc: "4.01: Au cours des 12 dernières mois, as-tu déjà mis de l'argent de côté auprès des structures suivantes :"

    label variable save_loc1 "Dans une Banque, Caisse d'épargne ou autre institution formelle"
    note save_loc1: "Dans une Banque, Caisse d'épargne ou autre institution formelle"
    label define save_loc1 1 "oui" 0 "non"
    label values save_loc1 save_loc1

    label variable save_loc2 "dans un groupe d'épargne"
    note save_loc2: "dans un groupe d'épargne"
    label define save_loc2 1 "oui" 0 "non"
    label values save_loc2 save_loc2

    label variable save_loc3 "Cash ou argent (liquide) avec famille hors du ménage"
    note save_loc3: "Cash ou argent (liquide) avec famille hors du ménage"
    label define save_loc3 1 "oui" 0 "non"
    label values save_loc3 save_loc3

    label variable save_loc4 "Cash ou argent (liquide) avec voisins ou amis"
    note save_loc4: "Cash ou argent (liquide) avec voisins ou amis"
    label define save_loc4 1 "oui" 0 "non"
    label values save_loc4 save_loc4

    label variable save_loc5 "avec un commerçant, fournisseur"
    note save_loc5: "avec un commerçant, fournisseur"
    label define save_loc5 1 "oui" 0 "non"
    label values save_loc5 save_loc5

    label variable save_loc6 "Cash ou argent (liquide) dans une boîte ou dans un sac à la maison"
    note save_loc6: "Cash ou argent (liquide) dans une boîte ou dans un sac à la maison"
    label define save_loc6 1 "oui" 0 "non"
    label values save_loc6 save_loc6

    label variable save_loc7 "en espèce ou argent (liquide) sur vous ?"
    note save_loc7: "en espèce ou argent (liquide) sur vous ?"
    label define save_loc7 1 "oui" 0 "non"
    label values save_loc7 save_loc7

    label variable save_loc8 "avec des billets, cartes, ou auprès d'un collecteur d'épargne"
    note save_loc8: "avec des billets, cartes, ou auprès d'un collecteur d'épargne"
    label define save_loc8 1 "oui" 0 "non"
    label values save_loc8 save_loc8

    label variable save_loc9 "Coopérative agricole"
    note save_loc9: "Coopérative agricole"
    label define save_loc9 1 "oui" 0 "non"
    label values save_loc9 save_loc9

    label variable save_loc10 "Téléphonie Mobile Money"
    note save_loc10: "Téléphonie Mobile Money"
    label define save_loc10 1 "oui" 0 "non"
    label values save_loc10 save_loc10

    label variable save_loc11 "Bijoux ou autre bien durable (huile rouge)"
    note save_loc11: "Bijoux ou autre bien durable (huile rouge)"
    label define save_loc11 1 "oui" 0 "non"
    label values save_loc11 save_loc11

    label variable cred "4.07: Au cours des 12 derniers mois, as-tu personellement contracté un prêt aupr"
    note cred: "4.07: Au cours des 12 derniers mois, as-tu personellement contracté un prêt auprès de :"
    label define cred 1 "oui" 0 "non"
    label values cred cred

    label variable cred_1 "association/groupe d'épargne (hors tontines)"
    note cred_1: "association/groupe d'épargne (hors tontines)"
    label define cred_1 1 "oui" 0 "non"
    label values cred_1 cred_1

    label variable cred_2 "un ami / voisin"
    note cred_2: "un ami / voisin"
    label define cred_2 1 "oui" 0 "non"
    label values cred_2 cred_2

    label variable cred_3 "famille hors du ménage"
    note cred_3: "famille hors du ménage"
    label define cred_3 1 "oui" 0 "non"
    label values cred_3 cred_3

    label variable cred_4 "un prêteur / usurier"
    note cred_4: "un prêteur / usurier"
    label define cred_4 1 "oui" 0 "non"
    label values cred_4 cred_4

    label variable cred_5 "un commerçant"
    note cred_5: "un commerçant"
    label define cred_5 1 "oui" 0 "non"
    label values cred_5 cred_5

    label variable cred_6 "une banque / une institution de microcrédit / une ONG / autre institution formel"
    note cred_6: "une banque / une institution de microcrédit / une ONG / autre institution formelle"
    label define cred_6 1 "oui" 0 "non"
    label values cred_6 cred_6

    label variable cred_7 "Autre personne ou groupe à spécifier (hors tontines)"
    note cred_7: "Autre personne ou groupe à spécifier (hors tontines)"
    label define cred_7 1 "oui" 0 "non"
    label values cred_7 cred_7

    label variable cred_o "Quel autre crediteur :"
    note cred_o: "Quel autre crediteur :"

    label variable cred_no "4.12: Au cours des 12 derniers mois, as-tu demandé un prêt qui a été refusé ?"
    note cred_no: "4.12: Au cours des 12 derniers mois, as-tu demandé un prêt qui a été refusé ?"
    label define cred_no 1 "oui" 0 "non"
    label values cred_no cred_no

    label variable lend_mem "4.15: Au cours des 6 derniers mois, as-tu personnellement prêté de l'argent à un"
    note lend_mem: "4.15: Au cours des 6 derniers mois, as-tu personnellement prêté de l'argent à un membre du ménage ? (un membre du ménage a emprunté de toi)"
    label define lend_mem 1 "oui" 0 "non"
    label values lend_mem lend_mem

    label variable lend_mem_still "4.17: Combien d'argent les membres du ménage te doivent encore aujourd'hui ?"
    note lend_mem_still: "4.17: Combien d'argent les membres du ménage te doivent encore aujourd'hui ?"

    label variable lend_out "4.18: Au cours des 6 derniers mois, as-tu personnellement prêté de l'argent à un"
    note lend_out: "4.18: Au cours des 6 derniers mois, as-tu personnellement prêté de l'argent à un ami ou à un membre de ta famille à l'extérieur du ménage ? (Quelqu'un te a emprunté)"
    label define lend_out 1 "oui" 0 "non"
    label values lend_out lend_out

    label variable lend_out_still "4.20: Combien d'argent les gens à l'extérieur du ménage te doivent encore aujour"
    note lend_out_still: "4.20: Combien d'argent les gens à l'extérieur du ménage te doivent encore aujourd'hui ?"

    label variable ask_mon "a: à ta mère ?"
    note ask_mon: "a: à ta mère ?"
    label define ask_mon 1 "oui" 0 "non" -666 "Non applicable"
    label values ask_mon ask_mon

    label variable ask_dad "b: à ton père ?"
    note ask_dad: "b: à ton père ?"
    label define ask_dad 1 "oui" 0 "non" -666 "Non applicable"
    label values ask_dad ask_dad

    label variable ask_siblings "c: à tes frères et sœurs ? Si oui, à combien de frères et sœurs peut-tu demander"
    note ask_siblings: "c: à tes frères et sœurs ? Si oui, à combien de frères et sœurs peut-tu demander de l’aide financière ?"

    label variable ask_otherfam "d: à membres de ta famille hors du ménage ? Si oui, à combien d'autres membres d"
    note ask_otherfam: "d: à membres de ta famille hors du ménage ? Si oui, à combien d'autres membres de ta famille hors du ménage peut-tu demander de l’aide financière ?"

    label variable ask_friends "e: à tes Amis ?"
    note ask_friends: "e: à tes Amis ?"

    label variable ask_otherknown "f: à autres connaissances ? Si oui, à combien d'autres connaissances peut-tu dem"
    note ask_otherknown: "f: à autres connaissances ? Si oui, à combien d'autres connaissances peut-tu demander de l’aide financière ?"

    label variable accesstofunds "4.22: A votre avis, quelle est la probabilité que tu puisses réunir une somme de"
    note accesstofunds: "4.22: A votre avis, quelle est la probabilité que tu puisses réunir une somme de 30,000 CFA au cours du prochain mois :"
    label define accesstofunds 1 "Très probable" 2 "Assez probable" 3 "Peu probable" 4 "Pas du tout probable"
    label values accesstofunds accesstofunds

    label variable revenu "Le chef de ménage ou l'enquêté doit évaluer le revenu de l'ensemble des membres "
    note revenu: "Le chef de ménage ou l'enquêté doit évaluer le revenu de l'ensemble des membres du ménage. Attention, les revenus en nature ne sont pas pris en compte!!Quel est le revenu (cash) obtenu par le ménage au cours des 12 derniers mois?"

    label variable resp_finance "4.23: : Agent Enqueteur : Qui était le répondant pour cette section ?"
    note resp_finance: "4.23: : Agent Enqueteur : Qui était le répondant pour cette section ?"

    label variable stair_satis_today "7.2.1: Et vous, pouvez-vous me pointer sur quelle marche de l’escalier vous êtes"
    note stair_satis_today: "7.2.1: Et vous, pouvez-vous me pointer sur quelle marche de l’escalier vous êtes ces jours-ci ? DJERMA: Jirbi bandey wo, kaarimo dake fo boà no ni go ? HAOUSSA: To ko za ku iya nuna inda ku ke bisa wannan kurangar cikin wannan kwanakin?"
    label define stair_satis_today 10 "10 = Plus haut" 9 "9" 8 "8" 7 "7" 6 "6" 5 "5" 4 "4" 3 "3" 2 "2" 1 "1" 0 "0 = Plus Bas"
    label values stair_satis_today stair_satis_today

    label variable stair_satis_future "7.2.2: Dans deux ans, pensez-vous que votre satisfaction avec la vie va monter, "
    note stair_satis_future: "7.2.2: Dans deux ans, pensez-vous que votre satisfaction avec la vie va monter, descendre, ou rester la même? Sur quelle marche serez-vous dans deux ans? DJERMA: Ni ga miile kaà ne nda jiiri hinka, ni baafuna ga ziji ga zumbu wala a ga goro nga nango ra ? Kaarimi fo boà no i ga to ne nda jiiri hinka ? HAOUSSA:Cikin shekaru biyu masu zuwa, ku na ganin gamsuwarku za ta yi sama, ko za ta sabko ko kuwa za ta tsaya a yanda take yanzu? Wane matsayi za ku koma cikin shekara biyu? TAMACHEK: arat wataré atou tigriwa digh indouniate"
    label define stair_satis_future 10 "10 = Plus haut" 9 "9" 8 "8" 7 "7" 6 "6" 5 "5" 4 "4" 3 "3" 2 "2" 1 "1" 0 "0 = Plus Bas"
    label values stair_satis_future stair_satis_future

    label variable stair_status_today "7.1.1: Et vous, pouvez-vous me pointer sur quelle marche de l’escalier vous êtes"
    note stair_status_today: "7.1.1: Et vous, pouvez-vous me pointer sur quelle marche de l’escalier vous êtes ces jours-ci ? DJERMA Ni ga hin ga ci nangu kaà cine no ni go ga ni boà laasaabu nduààa baafuna ra ? HAOUSSATo ku, za ku iya nuna mini matsayin ku a wannan kurangar cikin kwanakin nan? TAMACHEK: kam, tifregan ajitiskana innar edag wa tahé fel issoufoutan emerda ?"
    label define stair_status_today 10 "10 = Plus haut" 9 "9" 8 "8" 7 "7" 6 "6" 5 "5" 4 "4" 3 "3" 2 "2" 1 "1" 0 "0 = Plus Bas"
    label values stair_status_today stair_status_today

    label variable stair_status_future "7.1.2: Dans deux ans, pensez-vous que votre position va monter, descendre, ou re"
    note stair_status_future: "7.1.2: Dans deux ans, pensez-vous que votre position va monter, descendre, ou rester la même? Sur quelle marche serez-vous dans deux ans? DJERMA: Ni diiyaào ga, ne nda jiiri hinka, ni baafuna ga boori, booro ga zabu wala hari kulu si barmay a ga ? HAOUSSA: Cikin shekaru biyu masu zuwa, ku na ganin matsayinku za ta yi sama, ko za ta sabko ko kuwa ta tsaya ayande takeyanzu? Wane matsayi za ku koma cikin shekara biyu? TAMACHEK: Digh ichinyelan orgazne, todman san edag watahede attatchou, agifnis beri ghass war ze yizri? Minde ze tiggiza ?"
    label define stair_status_future 10 "10 = Plus haut" 9 "9" 8 "8" 7 "7" 6 "6" 5 "5" 4 "4" 3 "3" 2 "2" 1 "1" 0 "0 = Plus Bas"
    label values stair_status_future stair_status_future

    label variable stair_good_today "7.3.1: Pouvez-vous me pointer sur quelle marche de l’escalier vous êtes? DJERMA:"
    note stair_good_today: "7.3.1: Pouvez-vous me pointer sur quelle marche de l’escalier vous êtes? DJERMA: Ni ga hin ga ci seelo gagari kaà boà ni go ? HAOUSSA: to ko za kou iya nuna muna inda ku ke bisa wannan kurangar cikin wannan kwanakin TAMACHEK: awedin yolaghan"
    label define stair_good_today 10 "10 = Plus haut" 9 "9" 8 "8" 7 "7" 6 "6" 5 "5" 4 "4" 3 "3" 2 "2" 1 "1" 0 "0 = Plus Bas"
    label values stair_good_today stair_good_today

    label variable stair_respect_new "7.4.1: Pouvez-vous me pointer sur quelle marche de l’escalier vous êtes ces jour"
    note stair_respect_new: "7.4.1: Pouvez-vous me pointer sur quelle marche de l’escalier vous êtes ces jours-ci? DJERMA: Seelo gagani fo boà no ni go jirbey wo ra ? HAOUSSA: Ko ku na iya nuna mini bisa wane matsayi ku ke cikin wannan kwanakin TAMACHEK: aladabe"
    label define stair_respect_new 10 "10 = Plus haut" 9 "9" 8 "8" 7 "7" 6 "6" 5 "5" 4 "4" 3 "3" 2 "2" 1 "1" 0 "0 = Plus Bas"
    label values stair_respect_new stair_respect_new

    label variable stair_opinion_new "7.5.1: Pouvez-vous me pointer sur quelle marche de l’escalier vous êtes ces jour"
    note stair_opinion_new: "7.5.1: Pouvez-vous me pointer sur quelle marche de l’escalier vous êtes ces jours-ci? DJERMA: Seelo gagari fo boà no ni go jirbi bandey wo ? HAOUSSA: Ko ku na iya nuna mini bisa wane matsayi ku ke cikin wannan kwanakin TAMACHEK: tilam tunna dagh akalnauwan"
    label define stair_opinion_new 10 "10 = Plus haut" 9 "9" 8 "8" 7 "7" 6 "6" 5 "5" 4 "4" 3 "3" 2 "2" 1 "1" 0 "0 = Plus Bas"
    label values stair_opinion_new stair_opinion_new

    label variable ce3_new "7.6.1: Vous pouvez compter sur les gens de votre village pour vous aider financi"
    note ce3_new: "7.6.1: Vous pouvez compter sur les gens de votre village pour vous aider financièrement si vous faites face à des difficultés. Etes-vous d’accord? DJERMA: aran ga hini ga kaba aran koira borey bon watekan aran fouro norou sandey ra Aran yarda? HAOUSSA: Ku na iya dogaro da mutanen garin ku don su taimaka muku ta fanin kuddi in ku na fuskantar matsaloli. Kun yarda? TAMACHEK: Tilante"
    label define ce3_new 5 "Non pas du tout / aa ko kadan / Aa ba keina" 6 "Non / aa" 7 "Oui / ii / Oho" 8 "Oui tout à fait / Ii korai kuwa / Oho yadin deyno"
    label values ce3_new ce3_new

    label variable worktogether_new "7.6.2: Je travaille régulièrement avec d’autres membres de ma communauté pour at"
    note worktogether_new: "7.6.2: Je travaille régulièrement avec d’autres membres de ma communauté pour atteindre des objectifs communs qui améliorent nos vies. Etes-vous d’accord? DJERMA: irgin koiyan fondora ay ga goy da koira borey Aran yarda? HAOUSSA: Ina aika kai a kai tare da wasu mutane daga cikin al umma ta don cimma gurin mu masu gyara rayuwarmu. Kun yarda? TAMACHEK: ikanmara koullou"
    label define worktogether_new 5 "Non pas du tout / aa ko kadan / Aa ba keina" 6 "Non / aa" 7 "Oui / ii / Oho" 8 "Oui tout à fait / Ii korai kuwa / Oho yadin deyno"
    label values worktogether_new worktogether_new

    label variable aff_ieff "7.6.3: Vous pouvez compter sur l'aide des femmes de votre village quand vous ave"
    note aff_ieff: "7.6.3: Vous pouvez compter sur l'aide des femmes de votre village quand vous avez de difficultés. Êtes-vous d'accord ? DJERMA: >Ni ga sanka sambu ni kwaara wayborey boà kaà i ga ni gaakasinay da ni du sanday. Ni yadda ? HAOUSSA: Za ku iya dogara bisa taimakon matan garin ku idan ku na da matsala? Kun yarda? TAMACHEK: Tilate intidodin alkale"
    label define aff_ieff 5 "Non pas du tout / aa ko kadan / Aa ba keina" 6 "Non / aa" 7 "Oui / ii / Oho" 8 "Oui tout à fait / Ii korai kuwa / Oho yadin deyno"
    label values aff_ieff aff_ieff

    label variable los1 "7.7.1: Je voudrais maintenant vous demander comment vous vous sentez proche par "
    note los1: "7.7.1: Je voudrais maintenant vous demander comment vous vous sentez proche par rapport à votre communauté. Cette main vous représente, et l’autre représente votre communauté. Par rapport à votre communauté, est-ce que vous vous sentez plutôt : - indépendant , comme cela [écarter les mains plus largement que vos épaules] - proche , comme cela [écarter les mains à la largeur de vos épaules] - uni , comme cela [placer les mains un peu plus proches] ou intégré , comme cela [mains jointes] Veiller à ne pas laisser les mains dans l’une des positions décrites DJERMA: Aygaba Aye min ha maté kan nida koara borey gora gotéda. Je voudrais maintenant vous demander comment proche vous vous sentez par rapport à votre communauté. Kanbé fa Aran no, Kanbé hinkata Aran koara Borey. Nida Aran koara Borey : Cette main vous représente, et l’autre représente votre communauté. Par rapport à votre communauté, est-ce que vous vous sentez plutôt : - Waran harakaye si tcharassé (indépendant) HAOUSSA: [écarter les mains plus largement que vos épaules] Yanzu Ina son in tambaye ku ko yaya ku ke jin kusantar ku tare da al’ummar ku. Je voudrais maintenant vous demander comment proche vous vous sentez par rapport à votre communauté. Wannan hannun kamar ku ne, wancen kuma kamar al’ummar ku ce. Tare da al,ummar ku ko ku na jin ku masu: Cette main vous représente, et l’autre représente votre communauté. Par rapport à votre communauté, est-ce que vous vous sentez plutôt : - Ƴanci ne, kamar haka/Cin gashin kai/ cin bida (indépendant) [écarter les mains plus largement que vos épaules] - Kusa ne, kamar haka (proche) [écarter les mains à la largeur de vos épaules] -A haɗe ne , kamar haka (uni) [placer les mains un peu plus proches] -A cuɗe ne, kamar haka (intégré) [mains jointes] Veiller à ne pas laisser les mains dans l’une des positions décrites"
    label define los1 1 "Position 1 = indépendant," 2 "Position 2 = proche," 3 "Position 3 =uni," 4 "Position 4 = intégré"
    label values los1 los1

    label variable cd1 "7.8.1: Dites-moi, au cours des sept derniers jours, combien de jours avez-vous s"
    note cd1: "7.8.1: Dites-moi, au cours des sept derniers jours, combien de jours avez-vous senti que : Les détails de la vie quotidienne vous ont dérangé plus que d'habitude. DJERMA: Djirbi Iyyo Kan bissa ra Djirbi mardjé no nima kan: andoun gna missa nin zaga key ga bissa watoukoul HAOUSSA: Cikin kwanaki bakwai na ƙarshe kwana nawa kuka ji : Abubuwa na rayuwar yau da kullum sun damiku hiye da yanda ku ka saba. ? TAMACHEK: Imili, Digh issa yadan win izgaran de, manekete ijilan astislam san: tchikhawchawan idinate ikhalan fel lame achchawacha fel ijil koule."
    label define cd1 0 "0 jours / pierres" 1 "1 jour / pierre" 2 "2 jours / pierres" 3 "3 jours / pierres" 4 "4 jours / pierres" 5 "5 jours / pierres" 6 "6 jours / pierres" 7 "7 jours / pierres"
    label values cd1 cd1

    label variable cd2 "7.8.2: Maintenant, au cours des sept derniers jours, combien de jours avez-vous "
    note cd2: "7.8.2: Maintenant, au cours des sept derniers jours, combien de jours avez-vous senti que : Vous avez eu du mal à vous concentrer sur ce que vous faisiez DJERMA: Djirbi Iyyo Kan bissa ra Djirbi mardjé no nima kan: nima hini guine lakalo yé hayakan nigoté ga. HAOUSSA: Cikin kwanaki bakwai na ƙarshe, kwanaki nawa Ku ka ji : Ku ka ji rishin nitsuwa bisa abinda ku ka saba yi. : TAMACHEK: Emarda, Digh issa yadan win izgaran de, manekete ijilan astislam san: Wirtigrawa ataga ichikhilan inka yin mikanate."
    label define cd2 0 "0 jours / pierres" 1 "1 jour / pierre" 2 "2 jours / pierres" 3 "3 jours / pierres" 4 "4 jours / pierres" 5 "5 jours / pierres" 6 "6 jours / pierres" 7 "7 jours / pierres"
    label values cd2 cd2

    label variable cd3_new "7.8.3: Au cours des sept derniers jours, combien de jours avez-vous senti que : "
    note cd3_new: "7.8.3: Au cours des sept derniers jours, combien de jours avez-vous senti que : Vous vous êtes sentie triste. DJERMA: Djirbi Iyyo Kan bissa ra Djirbi mardjé no nima kan: nissi ga faran han HAOUSSA: Cikin kwanaki bakwai na ƙarshe, kwana nawa ku ka ji ku cikin ɓacin rai: TAMACHEK: Digh issa yadan win izgaran de, manekete ijilan astislam san: Astislam aghachan man."
    label define cd3_new 0 "0 jours / pierres" 1 "1 jour / pierre" 2 "2 jours / pierres" 3 "3 jours / pierres" 4 "4 jours / pierres" 5 "5 jours / pierres" 6 "6 jours / pierres" 7 "7 jours / pierres"
    label values cd3_new cd3_new

    label variable cd4 "7.8.4: Au cours des sept derniers jours, combien de jours avez-vous senti que : "
    note cd4: "7.8.4: Au cours des sept derniers jours, combien de jours avez-vous senti que : Vous avez senti que tout ce que vous faisiez a pris toute votre énergie DJERMA: Djirbi Iyyo Kan bissa ra Djirbi mardjé no nima kan: haya koul kan nigogate nin londey wi HAOUSSA: Cikin kwanaki bakwai na ƙarshe, kwana nawa ku ka ji abin da ku ke yi ya ɗauke muku dukan kuzari. TAMACHEK: Digh issa yadan win izgaran de, manekete ijilan astislam san: Arate wa titagga yikale tchighouran name koule."
    label define cd4 0 "0 jours / pierres" 1 "1 jour / pierre" 2 "2 jours / pierres" 3 "3 jours / pierres" 4 "4 jours / pierres" 5 "5 jours / pierres" 6 "6 jours / pierres" 7 "7 jours / pierres"
    label values cd4 cd4

    label variable cd5 "7.8.5: Au cours des sept derniers jours, combien de jours avez-vous senti que : "
    note cd5: "7.8.5: Au cours des sept derniers jours, combien de jours avez-vous senti que : Vous avez été confiante en l’avenir DJERMA: Djirbi Iyyo Kan bissa ra Djirbi mardjé no nima kan: Ni naney hankan ga hani ga ka ga HAOUSSA: bakwai na ƙarshe, kwana nawa ku ka ji: kun amince da gobe/ku ka amince da abinda zai faruwa nan gaba/kun yi imani TAMACHEK: Digh issa yadan win izgaran de, manekete ijilan astislam san: Tirde fel manam dikh arate waze dassin."
    label define cd5 0 "0 jours / pierres" 1 "1 jour / pierre" 2 "2 jours / pierres" 3 "3 jours / pierres" 4 "4 jours / pierres" 5 "5 jours / pierres" 6 "6 jours / pierres" 7 "7 jours / pierres"
    label values cd5 cd5

    label variable cd6_new "7.8.6: Au cours des sept derniers jours, combien de jours avez-vous senti que : "
    note cd6_new: "7.8.6: Au cours des sept derniers jours, combien de jours avez-vous senti que : Vous êtes-vous sentie nerveuse, tendue ou inquiète. DJERMA: Djirbi Iyyo Kan bissa ra Djirbi mardjé no nima kan: ni ma bin touney da gabouney HAOUSSA: bakwai na ƙarshe, kwana nawa ku ka ji: kuka ji juyayi da damuwa. TAMACHEK: Digh issa yadan win izgaran de, manekete ijilan astislam san: Tissalim aghachadin man meda ach-chawacha."
    label define cd6_new 0 "0 jours / pierres" 1 "1 jour / pierre" 2 "2 jours / pierres" 3 "3 jours / pierres" 4 "4 jours / pierres" 5 "5 jours / pierres" 6 "6 jours / pierres" 7 "7 jours / pierres"
    label values cd6_new cd6_new

    label variable cd7 "7.8.7: Au cours des sept derniers jours, combien de jours avez-vous senti que : "
    note cd7: "7.8.7: Au cours des sept derniers jours, combien de jours avez-vous senti que : Vous avez eu du mal à dormir paisiblement DJERMA: Djirbi Iyyo Kan bissa ra Djirbi mardjé no nima kan: niman guirbi gama kani HAOUSSA: Cikin kwanaki bakwai na ƙarshe, kwana nawa ku ka ji: kun samu matsala wajen yin barci lahiyayye TAMACHEK: Digh issa yadan win izgaran de, manekete ijilan astislam san: Wirtifraga ediss ikan yiminkanan."
    label define cd7 0 "0 jours / pierres" 1 "1 jour / pierre" 2 "2 jours / pierres" 3 "3 jours / pierres" 4 "4 jours / pierres" 5 "5 jours / pierres" 6 "6 jours / pierres" 7 "7 jours / pierres"
    label values cd7 cd7

    label variable cd8 "7.8.8: Au cours des sept derniers jours, combien de jours avez-vous senti que : "
    note cd8: "7.8.8: Au cours des sept derniers jours, combien de jours avez-vous senti que : Vous avez été heureuse DJERMA: Djirbi Iyyo Kan bissa ra Djirbi mardjé no nima kan: Ni Farehan HAOUSSA: Cikin kwanaki bakwai na ƙarshe, kwana nawa ku ka ji: Ku ka ji ku cikin murna TAMACHEK: Digh issa yadan win izgaran de, manekete ijilan astislam san: Iman name yiknan."
    label define cd8 0 "0 jours / pierres" 1 "1 jour / pierre" 2 "2 jours / pierres" 3 "3 jours / pierres" 4 "4 jours / pierres" 5 "5 jours / pierres" 6 "6 jours / pierres" 7 "7 jours / pierres"
    label values cd8 cd8

    label variable cd9 "7.8.9: Au cours des sept derniers jours, combien de jours avez-vous senti que : "
    note cd9: "7.8.9: Au cours des sept derniers jours, combien de jours avez-vous senti que : Vous vous êtes sentie seule DJERMA: Djirbi Iyyo Kan bissa ra Djirbi mardjé no nima kan: Nima kan ni go ni hiney HAOUSSA: Cikin kwanaki bakwai na ƙarshe, kwana nawa ku ka ji: Kaɗaici TAMACHEK: Digh issa yadan win izgaran de, manekete ijilan astislam san: Tissala oussouf."
    label define cd9 0 "0 jours / pierres" 1 "1 jour / pierre" 2 "2 jours / pierres" 3 "3 jours / pierres" 4 "4 jours / pierres" 5 "5 jours / pierres" 6 "6 jours / pierres" 7 "7 jours / pierres"
    label values cd9 cd9

    label variable cd10_new "7.8.10: Au cours des sept derniers jours, combien de jours avez-vous senti que :"
    note cd10_new: "7.8.10: Au cours des sept derniers jours, combien de jours avez-vous senti que : Vous étiez si fatiguée que vous ne pouviez rien entreprendre. DJERMA: Djirbi Iyyo Kan bissa ra Djirbi mardjé no nima kan: Ni ma fargaye lalo kal nissi hinga haye koul te HAOUSSA: Cikin kwanaki bakwai na ƙarshe, kwana nawa kuka ji: kun gaji har ba za ku dauki niyyar yin komai ba. TAMACHEK: Digh issa yadan win izgaran de, manekete ijilan astislam san: Tiddeza wirtifrega igin artchiyan."
    label define cd10_new 0 "0 jours / pierres" 1 "1 jour / pierre" 2 "2 jours / pierres" 3 "3 jours / pierres" 4 "4 jours / pierres" 5 "5 jours / pierres" 6 "6 jours / pierres" 7 "7 jours / pierres"
    label values cd10_new cd10_new

    label variable useless "7.8.11: Au cours des sept derniers jours, combien de jours avez-vous : Vous vous"
    note useless: "7.8.11: Au cours des sept derniers jours, combien de jours avez-vous : Vous vous êtes sentie inutile. DJERMA: Djirbi Iyyo Kan bissa ra Djirbi mardjé no nima kan: Ni ma kan nissi ga haye koul djara HAOUSSA: Cikin kwanaki bakwai na ƙarshe, kwana nawa ku ka ji: baku da amfani/ ku ka ji ba ku iya ɓarkata komai TAMACHEK: Ibane taunfat"
    label define useless 0 "0 jours / pierres" 1 "1 jour / pierre" 2 "2 jours / pierres" 3 "3 jours / pierres" 4 "4 jours / pierres" 5 "5 jours / pierres" 6 "6 jours / pierres" 7 "7 jours / pierres"
    label values useless useless

    label variable partic "7.8.12: Participez-vous à des groupes ou des associations ces jours-ci au cours "
    note partic: "7.8.12: Participez-vous à des groupes ou des associations ces jours-ci au cours des 2 derniers mois , comme par exemple une association de jeunes, association de femmes, de tontines, AVEC ou groupement de commerçants, etc...? Combien de groupes ?"

    label variable soc_post "7.8.13: Au cours des 12 derniers mois , avez-vous occupé un poste de responsabil"
    note soc_post: "7.8.13: Au cours des 12 derniers mois , avez-vous occupé un poste de responsabilité dans un groupe, comme par exemple président/chef, secrétaire, trésorier, ou autre ? Combien de postes (dans différents groupes ) au cours des 12 derniers mois?"

    label variable aut_fond "7.8.14: Avez-vous donné de l’argent à un fond pour des projets communautaires au"
    note aut_fond: "7.8.14: Avez-vous donné de l’argent à un fond pour des projets communautaires au cours de deux derniers mois ? [SI NON, ECRIVEZ '0'] [SI OUI…] Combien avez-vous donné au cours de deux derniers mois ? DJERMA: Handu hinka bandey kaà bisa, ni na nooru daà al’umma satey se ? [Da abada no, hantum « 0 »] [Da Oho no…..] jirbi marje no ni te handu hinka bandey kaà bisa ra. HAOUSSA: Ko, kun bada kuɗi ga wani asusu don wasu puroje na al’umma cikin watanni biyu naƙarshe? Nawa ku kabadacikin watanni biyu naƙarshe?"

    label variable aut_volu "7.8.15: Avez-vous donné du temps aux activités communautaires au cours des deux "
    note aut_volu: "7.8.15: Avez-vous donné du temps aux activités communautaires au cours des deux derniers mois ? [SI NON, ECRIVEZ '0'] [SI OUI…] Combien de jours avez-vous consacré aux activités communautaire au cours des deux derniers mois ? DJERMA: handu hinkay kan bisara ni goy al umma satey ra HAOUSSA: Ko kun yi wani aikin al’umma cikin watanni biyu naƙarshe? Tsawon kwana nawa ku ka yi, ku na ma al’umma aiki?"

    label variable for_trust_1 "7.8.16: Sur 10 personnes dans village, combien sont des personnes honnêtes et di"
    note for_trust_1: "7.8.16: Sur 10 personnes dans village, combien sont des personnes honnêtes et dignes de confiance? DJERMA: Ni diiyaào ga, boro way (10) boà sambu ni gallo ra boro marje no ga ti adilante, alkawali toonandiko, boro marje ga no i mana hima ga naanay ? HAOUSSA: A tunani ku, mutum nawa cikin goma na jahar ku su ke da adalci, za’a iya yarda da su, kuma nawa ba su da adalci baza’a yarda da su ba? TAMACHEK: Dikh maraw aytedan dikh akale nawan, manekete aytedan san tirdan fellassan?"
    label define for_trust_1 1 "1 est digne de confiance, 9 indignes de confiance" 2 "2 sont dignes de confiance , 8 indignes de confiance" 3 "3 sont dignes de confiance, 7 indignes de confiance" 4 "4 sont dignes de confiance, 6 indignes de confiance" 5 "5 sont dignes de confiance, 5 indignes de confiance" 6 "6 sont dignes de confiance, 4 indignes de confiance" 7 "7 sont dignes de confiance, 3 indignes de confiance" 8 "8 sont dignes de confiance, 2 indignes de confiance" 9 "9 sont dignes de confiance, 1 indigne de confiance" 10 "10 sont dignes de confiance, 0 indigne de confiance"
    label values for_trust_1 for_trust_1

    label variable enemy "7.8.17: Y a-t-il des gens qui vous détestent, personnellement, au point de souha"
    note enemy: "7.8.17: Y a-t-il des gens qui vous détestent, personnellement, au point de souhaiter votre échec ou d'essayer de saboter votre progression ou succès ? DJERMA: Boro yaà go no kaà konnamay go araà game kaà kala i si ba ni ma wadaata/zaada ? HAOUSSA: KO akoi mutanen da suke ƙin (suka tsane) ku har ma su na son rishin cin nasarar ku ko ma su nemi ɓata ci gaban ku ko cin nasarar ku? TAMACHEK: Digh yadan winde illatou aytedan win wirkounaran ara dazoudan edagg wan san aran iban nawan meda a digmiyan ada win aghchida tarete tchitchiyate nawan?"
    label define enemy 0 "non - personne" 1 "oui, un ou deux" 2 "oui, quelqus-uns" 3 "oui, beaucoup"
    label values enemy enemy

    label variable tens_comm "7.8.18: Chaque communauté a des tensions qui perturbent la paix de temps en temp"
    note tens_comm: "7.8.18: Chaque communauté a des tensions qui perturbent la paix de temps en temps. Au cours des 6 derniers mois, y a-t-il de la tension entre les membres de votre communauté ? ZERMA: kwara kulu gonda fitina kanga lakkal tunai dan djama game lokaci ga lokaci.handu lddu kan bisa ga ka lokaco wo fitina fono furo aran gamara? HAOUSSA: Kowace al'umma tana da tashin hankali wanda ke damun zaman lafiyanta lokaci zuwa lokaci. A cikin watanni 6 da suka gabata, an sami tashin hankali tsakanin ƴan karkarar ku ? TAMACHECK:Ighiwan koule yilan achachawachan nete win igaddalin tegawarin alkher alakh alakhe, digh sigiss tchilila win izgernete tigrewa achchawacha gareme daytedan nighiwan"
    label define tens_comm 0 "Non, pas du tout" 1 "Oui, un peu" 2 "Oui, moderée" 3 "Oui, beaucoup"
    label values tens_comm tens_comm

    label variable ten_tension "W3: Combien de femmes sur 10 connaissent des tensions dans leur ménage ?"
    note ten_tension: "W3: Combien de femmes sur 10 connaissent des tensions dans leur ménage ?"

    label variable vill_burn "W4: Dans ce village, est-il courant que les maris battent leur femme si elles br"
    note vill_burn: "W4: Dans ce village, est-il courant que les maris battent leur femme si elles brûlent la nourriture : DJERMA: Sohon ay gonda aran se hayan aran koira bafuna bon hankan aran tu ay se mo borkulu si mara HAOUSSA: Yanzu ina da tambaya da zani muku akan garinga naku kuma duka ansa da zaku bada ba wanda zai jinka TAMACHECK:Aregh Imirida adawanaga arat in issistanan fil tassak netedan dagh akal wanawan . Aljawab nawan wirzisan falas awedan wiliyan . iggmad achak as adikil isir garena"
    label define vill_burn 4 "très courant" 3 "courant" 2 "pourrait se produire" 1 "non"
    label values vill_burn vill_burn

    label variable tens "W5: Chaque communauté a des tensions qui perturbent la paix de temps en temps. A"
    note tens: "W5: Chaque communauté a des tensions qui perturbent la paix de temps en temps. Au cours des 30 derniers jours, avez-vous ou votre ménage eu des tensions avec d'autres membres de votre communauté ? ZERMA: Aran koira wo ra aga te da bayan kurgne ma wande kar dana haoro tone / Aran koiro ra ni diyan go kurgney ga wandey fitina da i n'a gwari daké à di HAOUSSA: a wan nan garin yana faruwa miji ya ba matarshi kashi don ta kone abunci / A wannan kauye ya zama ruwan dare mazaje suna dukan matansu idan sun kona abinci TAMACHEK: kouloun tochete imaltou dahas iban nimissisigra idasan alkher alwaq iyan . Dagh talit tatizrayat imaltou garek kay made Aghewan nak iban nimissisigra id etedan nawan sahadan ?"
    label define tens 1 "oui" 0 "non"
    label values tens tens

    label variable institution1 "7.8.19: Si un membre de votre famille a une urgence médicale, pouvez-vous accéde"
    note institution1: "7.8.19: Si un membre de votre famille a une urgence médicale, pouvez-vous accéder à un centre de santé où il sera soigné ? ZERMA: da lokotoro koira mouradu ka aren wala aren boro manu ga ,aren ga du safarey alwaiti ra ? HAOUSSA: idan wani daga cikin danginku yana da gaggawar likita,za ku iya samun zuwa cibiyar lafiya inda za a yi mishi magani ?"
    label define institution1 1 "oui" 0 "non"
    label values institution1 institution1

    label variable institution2 "7.8.20: S’il y a un délit dans votre village, comme un vol ou une aggression, po"
    note institution2: "7.8.20: S’il y a un délit dans votre village, comme un vol ou une aggression, pouvez-vous compter sur la police ou d'autres forces de l’ordre pour intervenir ? ZERMA: xda taali tey aren koira ra sanda zeytarey wala koutouney ,aren ga du faba koi yi dans koyei ga ? HAOUSSA: Idan akwai wani laifi a ƙauyenku, kamar sata ko cin zarafi, shin za ku iya dogara ga ‘yan sanda ko wasu jami’an tsaro su sa baki ? TAMACHEK: Oumoss yille michkila yate digh akale nawan,inkin tchik-ra meda tikma, tifragam atichigidam oulkhoukoum meda wiyade oulkhoumate adiggizan?"
    label define institution2 1 "oui" 0 "non"
    label values institution2 institution2

    label variable ment_who_present "7.8.21: Agent Enqueteur :Qui était présent pendant la section en plus du réponda"
    note ment_who_present: "7.8.21: Agent Enqueteur :Qui était présent pendant la section en plus du répondant ? Si le répondant était seul, cochez la première option."

    label variable resp_mental "Agent Enqueteur : Qui était le répondant pour cette section ?"
    note resp_mental: "Agent Enqueteur : Qui était le répondant pour cette section ?"
    label define resp_mental -5 "[décédé.e]" -4 "[ne fait pas partie du ménage]" -2 "Personne" -1 "Tous les membres du ménage" 0 "Personnes hors du ménage" 1 "\${fullname1} (Age: \${age_1} , pos 1)" 2 "\${fullname2} (Age: \${age_2} , pos 2)" 3 "\${fullname3} (Age: \${age_3} , pos 3)" 4 "\${fullname4} (Age: \${age_4} , pos 4)" 5 "\${fullname5} (Age: \${age_5} , pos 5)" 6 "\${fullname6} (Age: \${age_6} , pos 6)" 7 "\${fullname7} (Age: \${age_7} , pos 7)" 8 "\${fullname8} (Age: \${age_8} , pos 8)" 9 "\${fullname9} (Age: \${age_9} , pos 9)" 10 "\${fullname10} (Age: \${age_10} , pos 10)" 11 "\${fullname11} (Age: \${age_11} , pos 11)" 12 "\${fullname12} (Age: \${age_12} , pos 12)" 13 "\${fullname13} (Age: \${age_13} , pos 13)" 14 "\${fullname14} (Age: \${age_14} , pos 14)" 15 "\${fullname15} (Age: \${age_15} , pos 15)" 16 "\${fullname16} (Age: \${age_16} , pos 16)" 17 "\${fullname17} (Age: \${age_17} , pos 17)" 18 "\${fullname18} (Age: \${age_18} , pos 18)" 19 "\${fullname19} (Age: \${age_19} , pos 19)" 20 "\${fullname20} (Age: \${age_20} , pos 20)" 21 "\${fullname21} (Age: \${age_21} , pos 21)" 22 "\${fullname22} (Age: \${age_22} , pos 22)" 23 "\${fullname23} (Age: \${age_23} , pos 23)" 24 "\${fullname24} (Age: \${age_24} , pos 24)" 25 "\${fullname25} (Age: \${age_25} , pos 25)" 26 "\${fullname26} (Age: \${age_26} , pos 26)" 27 "\${fullname27} (Age: \${age_27} , pos 27)" 28 "\${fullname28} (Age: \${age_28} , pos 28)" 29 "\${fullname29} (Age: \${age_29} , pos 29)" 30 "\${fullname30} (Age: \${age_30} , pos 30)" 31 "\${fullname31} (Age: \${age_31} , pos 31)" 32 "\${fullname32} (Age: \${age_32} , pos 32)" 33 "\${fullname33} (Age: \${age_33} , pos 33)" 34 "\${fullname34} (Age: \${age_34} , pos 34)" 35 "\${fullname35} (Age: \${age_35} , pos 35)" 36 "\${fullname36} (Age: \${age_36} , pos 36)" 37 "\${fullname37} (Age: \${age_37} , pos 37)" 38 "\${fullname38} (Age: \${age_38} , pos 38)" 39 "\${fullname39} (Age: \${age_39} , pos 39)" 40 "\${fullname40} (Age: \${age_40} , pos 40)" 41 "\${fullname41} (Age: \${age_41} , pos 41)" 42 "\${fullname42} (Age: \${age_42} , pos 42)" 43 "\${fullname43} (Age: \${age_43} , pos 43)" 44 "\${fullname44} (Age: \${age_44} , pos 44)" 45 "\${fullname45} (Age: \${age_45} , pos 45)" 46 "\${fullname46} (Age: \${age_46} , pos 46)" 47 "\${fullname47} (Age: \${age_47} , pos 47)" 48 "\${fullname48} (Age: \${age_48} , pos 48)" 49 "\${fullname49} (Age: \${age_49} , pos 49)" 50 "\${fullname50} (Age: \${age_50} , pos 50)" 51 "\${fullname51} (Age: \${age_51} , pos 51)" 52 "\${fullname52} (Age: \${age_52} , pos 52)" 53 "\${fullname53} (Age: \${age_53} , pos 53)" 54 "\${fullname54} (Age: \${age_54} , pos 54)" 55 "\${fullname55} (Age: \${age_55} , pos 55)" 56 "\${fullname56} (Age: \${age_56} , pos 56)" 57 "\${fullname57} (Age: \${age_57} , pos 57)" 58 "\${fullname58} (Age: \${age_58} , pos 58)" 59 "\${fullname59} (Age: \${age_59} , pos 59)" 60 "\${fullname60} (Age: \${age_60} , pos 60)"
    label values resp_mental resp_mental

    label variable att_meteo "8.1: Dans quelle mesure les conditions météorologiques ont-elles été favorables "
    note att_meteo: "8.1: Dans quelle mesure les conditions météorologiques ont-elles été favorables à l'agriculture au cours de la dernière saison des pluies (2021-2022) ? ZERMA: xmissali fo no ga tchabey aren say kan hino kaidiya a ga bori ? HAOUSSA: Yaya kyawun yanayi ya kasance ga noma a cikin watanni 12 da suka gabata ?"
    label define att_meteo 10 "10 = La meilleure condition météorologique que vous n'ayez jamais eue" 9 "9" 8 "8" 7 "7" 6 "6" 5 "5" 4 "4" 3 "3" 2 "2" 1 "1 = La pire condition météorologique que vous n'ayez jamais eue"
    label values att_meteo att_meteo

    label variable att_meteo_esp "8.2: Si Dieu vous donne la chance de cultiver cette année, dans quelle mesure pr"
    note att_meteo_esp: "8.2: Si Dieu vous donne la chance de cultiver cette année, dans quelle mesure prédisez-vous que les conditions météorologiques seront favorables à l'agriculture cette année ? ZERMA: da irkoye tay kaidiya kan bissa aren douma ,missali fo no ga tchabey aren se kan kaidiya kan ga ka ga bori ? HAOUSSA: Idan Allah ya baku daman noma a bana, yaya kuke hasashen (ko kuke ganin) yanayin noman zai kasance a bana ?"
    label define att_meteo_esp 10 "10 = La meilleure récolte que vous ayez jamais eue" 9 "9" 8 "8" 7 "7" 6 "6" 5 "5" 4 "4" 3 "3" 2 "2" 1 "1 = La pire récolte que vous ayez jamais eue"
    label values att_meteo_esp att_meteo_esp

    label variable att_last_crop "8.3: Comment vous évaluez-vous la dernière récolte ? ZERMA: mate na raan ga manm"
    note att_last_crop: "8.3: Comment vous évaluez-vous la dernière récolte ? ZERMA: mate na raan ga manman kaidiya nessi da ? HAOUSSA: Yaya kuke ganin girbi na ƙarshe ya kasance ?"
    label define att_last_crop 10 "10 = La meilleure récolte que vous ayez jamais eue" 9 "9" 8 "8" 7 "7" 6 "6" 5 "5" 4 "4" 3 "3" 2 "2" 1 "1 = La pire récolte que vous ayez jamais eue"
    label values att_last_crop att_last_crop

    label variable att_next_crop "8.4: Comment pensez-vous que la prochaine récolte sera?"
    note att_next_crop: "8.4: Comment pensez-vous que la prochaine récolte sera?"
    label define att_next_crop 10 "10 = La meilleure récolte que vous ayez jamais eue" 9 "9" 8 "8" 7 "7" 6 "6" 5 "5" 4 "4" 3 "3" 2 "2" 1 "1 = La pire récolte que vous ayez jamais eue"
    label values att_next_crop att_next_crop

    label variable att_other_bus "8.5: En dehors de l’agriculture, vous ou un membre de votre ménage exerce d’autr"
    note att_other_bus: "8.5: En dehors de l’agriculture, vous ou un membre de votre ménage exerce d’autres activités ?"
    label define att_other_bus 1 "oui" 0 "non"
    label values att_other_bus att_other_bus

    label variable att_last_rev "8.6: Comment évaluez-vous les revenus en espèces provenant d'activités non agric"
    note att_last_rev: "8.6: Comment évaluez-vous les revenus en espèces provenant d'activités non agricoles [AGR, pas de vente de récoltes] qui ont servis à votre ménage au cours des 12 derniers mois ? ZERMA: xdedandiga mate nos aren dy aren arzaka ka aren du aren goy goy ra kan mati dans kaydiya albarka kan nafa da aren windero ? HAOUSSA: Ta yaya za ku kimanta kuɗin da kuke samu daga ayyukan da ba na noma ba [ ba siyar da amfanin gona ba] waɗanda aka yi amfani da su a gidanku a cikin watanni 12 da suka gabata ?"
    label define att_last_rev 10 "10 = Le meilleur revenu que vous ayez jamais eu" 9 "9" 8 "8" 7 "7" 6 "6" 5 "5" 4 "4" 3 "3" 2 "2" 1 "1 = Le pire revenu que vous ayez jamais eu" 0 "Non applicable"
    label values att_last_rev att_last_rev

    label variable att_next_rev "8.7: A quel point prédisez-vous que votre génération de revenus non-agricoles se"
    note att_next_rev: "8.7: A quel point prédisez-vous que votre génération de revenus non-agricoles sera bonne cette année ? ZERMA: dedendi ga matey no aren ga tey ga bey kan arzaka kan aren ga du kan manti kaidiya hana ga bori haran ? HAOUSSA: Yaya ku ke hasashen kudaden da kuke samu wanda ba na noma ba zasu kasance a bana ?"
    label define att_next_rev 10 "10 = Le meilleur revenu que vous ayez jamais eu" 9 "9" 8 "8" 7 "7" 6 "6" 5 "5" 4 "4" 3 "3" 2 "2" 1 "1 = Le pire revenu que vous ayez jamais eu" 0 "Non applicable"
    label values att_next_rev att_next_rev

    label variable att_govhelp "8.8: Avec quelle probabilité vous penser recevoir une aide du gouvernement cette"
    note att_govhelp: "8.8: Avec quelle probabilité vous penser recevoir une aide du gouvernement cette année ? ZERMA: aren diyan ga aren ga milla kan gomnanto borey , ga hin ga kandey aren sey gakasiney haran ? HAOUSSA: Yaya kuke tsammanin yiwuwar samun taimakon gwamnati a wannan shekara ?"
    label define att_govhelp 1 "Très probable" 2 "Assez probable" 3 "Peu probable" 4 "Pas du tout probable"
    label values att_govhelp att_govhelp

    label variable att_govhelp_amt "8.9: Combien ?"
    note att_govhelp_amt: "8.9: Combien ?"
    label define att_govhelp_amt 1 "Entre 500 FCFA et 5000 FCFA" 2 "Entre 5000 FCFA et 10000 FCFA" 3 "Entre 10000 FCFA et 20000 FCFA" 4 "Entre 20000 FCFA et 50000 FCFA" 5 "Entre 50000 FCFA et 100000 FCFA" 6 "Plus de 100000 FCFA"
    label values att_govhelp_amt att_govhelp_amt

    label variable pref_renonce "9.1: Par rapport aux autres, êtes-vous une personne généralement prête à renonce"
    note pref_renonce: "9.1: Par rapport aux autres, êtes-vous une personne généralement prête à renoncer à de l'argent aujourd'hui afin d'en bénéficier dans le futur ou n'êtes-vous pas prêt à le faire ? ZERMA: xi ga hin gyn kabou borey kan ga nee inga si ba noyan houn kouna in ga ga batou soubey zama souba wana ba da hounkouna ,wala ni si borey din ra ? HAOUSSA: Idan aka kwatanta da wasu, shin gabaɗaya a shirye kuke ku bar kuɗi a yau don ku amfana a nan gaba, ko ba a shiye kuke ba ?"
    label define pref_renonce 10 "10 = Très prêt à prendre des risques aujourdhui" 9 "9" 8 "8" 7 "7" 6 "6" 5 "5" 4 "4" 3 "3" 2 "2" 1 "1 = Absolument pas prêt à prendre des risques aujourdhui"
    label values pref_renonce pref_renonce

    label variable pref_1_19000f "9.2.1: Préférez vous 19.000 CFA aujourd'hui ou 20.000 CFA (de façon certaine) da"
    note pref_1_19000f: "9.2.1: Préférez vous 19.000 CFA aujourd'hui ou 20.000 CFA (de façon certaine) dans 1 mois ?"
    label define pref_1_19000f 1 "Aujourd'hui" 2 "Dans 1 mois"
    label values pref_1_19000f pref_1_19000f

    label variable pref_1_18000f "9.2.2: Préférez vous 18.000 CFA aujourd'hui ou 20.000 CFA (de façon certaine) da"
    note pref_1_18000f: "9.2.2: Préférez vous 18.000 CFA aujourd'hui ou 20.000 CFA (de façon certaine) dans 1 mois ?"
    label define pref_1_18000f 1 "Aujourd'hui" 2 "Dans 1 mois"
    label values pref_1_18000f pref_1_18000f

    label variable pref_1_16000f "9.2.3: Préférez vous 16.000 CFA aujourd'hui ou 20.000 CFA (de façon certaine) da"
    note pref_1_16000f: "9.2.3: Préférez vous 16.000 CFA aujourd'hui ou 20.000 CFA (de façon certaine) dans 1 mois ?"
    label define pref_1_16000f 1 "Aujourd'hui" 2 "Dans 1 mois"
    label values pref_1_16000f pref_1_16000f

    label variable pref_1_14000f "9.2.4: Préférez vous 14.000 CFA aujourd'hui ou 20.000 CFA (de façon certaine) da"
    note pref_1_14000f: "9.2.4: Préférez vous 14.000 CFA aujourd'hui ou 20.000 CFA (de façon certaine) dans 1 mois ?"
    label define pref_1_14000f 1 "Aujourd'hui" 2 "Dans 1 mois"
    label values pref_1_14000f pref_1_14000f

    label variable pref_1_11000f "9.2.5: Préférez vous 11.000 CFA aujourd'hui ou 20.000 CFA (de façon certaine) da"
    note pref_1_11000f: "9.2.5: Préférez vous 11.000 CFA aujourd'hui ou 20.000 CFA (de façon certaine) dans 1 mois ?"
    label define pref_1_11000f 1 "Aujourd'hui" 2 "Dans 1 mois"
    label values pref_1_11000f pref_1_11000f

    label variable pref_1_8000f "9.2.6: Préférez vous 8.000 CFA aujourd'hui ou 20.000 CFA (de façon certaine) dan"
    note pref_1_8000f: "9.2.6: Préférez vous 8.000 CFA aujourd'hui ou 20.000 CFA (de façon certaine) dans 1 mois ?"
    label define pref_1_8000f 1 "Aujourd'hui" 2 "Dans 1 mois"
    label values pref_1_8000f pref_1_8000f

    label variable pref_1_5000f "9.2.7: Préférez vous 5.000 CFA aujourd'hui ou 20.000 CFA (de façon certaine) dan"
    note pref_1_5000f: "9.2.7: Préférez vous 5.000 CFA aujourd'hui ou 20.000 CFA (de façon certaine) dans 1 mois ?"
    label define pref_1_5000f 1 "Aujourd'hui" 2 "Dans 1 mois"
    label values pref_1_5000f pref_1_5000f

    label variable pref_1_500f "9.2.8: Préférez vous 500 CFA aujourd'hui ou 20.000 CFA (de façon certaine) dans "
    note pref_1_500f: "9.2.8: Préférez vous 500 CFA aujourd'hui ou 20.000 CFA (de façon certaine) dans 1 mois ?"
    label define pref_1_500f 1 "Aujourd'hui" 2 "Dans 1 mois"
    label values pref_1_500f pref_1_500f

    label variable pref_2_19000f "9.3.1: Préférez vous 19.000 CFA (de façon certaine) dans 1 mois ou 20.000 CFA (d"
    note pref_2_19000f: "9.3.1: Préférez vous 19.000 CFA (de façon certaine) dans 1 mois ou 20.000 CFA (de façon certaine) dans 2 mois ?"
    label define pref_2_19000f 1 "Dans 1 mois" 2 "Dans 2 mois"
    label values pref_2_19000f pref_2_19000f

    label variable pref_2_18000f "9.3.2: Préférez vous 18.000 CFA (de façon certaine) dans 1 mois ou 20.000 CFA (d"
    note pref_2_18000f: "9.3.2: Préférez vous 18.000 CFA (de façon certaine) dans 1 mois ou 20.000 CFA (de façon certaine) dans 2 mois ?"
    label define pref_2_18000f 1 "Dans 1 mois" 2 "Dans 2 mois"
    label values pref_2_18000f pref_2_18000f

    label variable pref_2_16000f "9.3.3: Préférez vous 16.000 CFA (de façon certaine) dans 1 mois ou 20.000 CFA (d"
    note pref_2_16000f: "9.3.3: Préférez vous 16.000 CFA (de façon certaine) dans 1 mois ou 20.000 CFA (de façon certaine) dans 2 mois ?"
    label define pref_2_16000f 1 "Dans 1 mois" 2 "Dans 2 mois"
    label values pref_2_16000f pref_2_16000f

    label variable pref_2_14000f "9.3.4: Préférez vous 14.000 CFA (de façon certaine) dans 1 mois ou 20.000 CFA (d"
    note pref_2_14000f: "9.3.4: Préférez vous 14.000 CFA (de façon certaine) dans 1 mois ou 20.000 CFA (de façon certaine) dans 2 mois ?"
    label define pref_2_14000f 1 "Dans 1 mois" 2 "Dans 2 mois"
    label values pref_2_14000f pref_2_14000f

    label variable pref_2_11000f "9.3.5: Préférez vous 11.000 CFA (de façon certaine) dans 1 mois ou 20.000 CFA (d"
    note pref_2_11000f: "9.3.5: Préférez vous 11.000 CFA (de façon certaine) dans 1 mois ou 20.000 CFA (de façon certaine) dans 2 mois ?"
    label define pref_2_11000f 1 "Dans 1 mois" 2 "Dans 2 mois"
    label values pref_2_11000f pref_2_11000f

    label variable pref_2_8000f "9.3.6: Préférez vous 8.000 CFA (de façon certaine) dans 1 mois ou 20.000 CFA (de"
    note pref_2_8000f: "9.3.6: Préférez vous 8.000 CFA (de façon certaine) dans 1 mois ou 20.000 CFA (de façon certaine) dans 2 mois ?"
    label define pref_2_8000f 1 "Dans 1 mois" 2 "Dans 2 mois"
    label values pref_2_8000f pref_2_8000f

    label variable pref_2_5000f "9.3.7: Préférez vous 5.000 CFA (de façon certaine) dans 1 mois ou 20.000 CFA (de"
    note pref_2_5000f: "9.3.7: Préférez vous 5.000 CFA (de façon certaine) dans 1 mois ou 20.000 CFA (de façon certaine) dans 2 mois ?"
    label define pref_2_5000f 1 "Dans 1 mois" 2 "Dans 2 mois"
    label values pref_2_5000f pref_2_5000f

    label variable pref_2_500f "9.3.8: Préférez vous 500 CFA (de façon certaine) dans 1 mois ou 20.000 CFA (de f"
    note pref_2_500f: "9.3.8: Préférez vous 500 CFA (de façon certaine) dans 1 mois ou 20.000 CFA (de façon certaine) dans 2 mois ?"
    label define pref_2_500f 1 "Dans 1 mois" 2 "Dans 2 mois"
    label values pref_2_500f pref_2_500f

    label variable pref_prog "9.4: Supposons qu'un programme existe, qui fournira une distribution d'argent de"
    note pref_prog: "9.4: Supposons qu'un programme existe, qui fournira une distribution d'argent de 120 000 FCFA. Si vous receviez ce montant, que préfériez-vous ?"
    label define pref_prog 1 "Recevoir la totalité du transfert (120 000 FCFA) d'un seul coup" 2 "Recevoir la moitié du transfert d'abord, et l'autre moitié après six mois" 3 "Recevoir un transfert de 20 000 FCFA chaque deux mois pendant une année"
    label values pref_prog pref_prog

    label variable pref_prog_why "9.5: Pourquoi préférez-vous cette option pour la distribution d'argent ?"
    note pref_prog_why: "9.5: Pourquoi préférez-vous cette option pour la distribution d'argent ?"
    label define pref_prog_why 1 "Besoin d'un montant suffisant pour faire un investissement" 2 "Il est risqué d'attendre d'autres transferts car ils pourraient ne pas se produi" 3 "Demande trop de temps et d'effort pour obtenir le transfert" 4 "Autres (à préciser)"
    label values pref_prog_why pref_prog_why

    label variable pref_prog_why_o "9.5b: Préciser"
    note pref_prog_why_o: "9.5b: Préciser"

    label variable risk_take "10.1: Veuillez me dire, en général, dans quelle mesure vous êtes prêt(e) ou non "
    note risk_take: "10.1: Veuillez me dire, en général, dans quelle mesure vous êtes prêt(e) ou non à prendre des risques. ZERMA: Nine wo borno kan ga si, daga ba amante wala niman djan a koulou ? Wala ni si te yadin HAOUSSA: zaku iya gayamini,in a shirye kuka ku daki kassada ko a'a ?"
    label define risk_take 10 "10 = Très prêt à prendre des risques" 9 "9" 8 "8" 7 "7" 6 "6" 5 "5" 4 "4" 3 "3" 2 "2" 1 "1 = Absolument pas prêt à prendre des risques"
    label values risk_take risk_take

    label variable risk_conf_poeple "10.2: D'une manière générale, diriez-vous que l'on peut faire confiance à la plu"
    note risk_conf_poeple: "10.2: D'une manière générale, diriez-vous que l'on peut faire confiance à la plupart des gens ou qu'il faut être très prudent dans ses relations avec les autres ? ZERMA: xrean diyan ga boro ma na ney da bora koulou waley boro ma hagoy da afo yan ? HAOUSSA: a jimilce,za a iya amincewa da yawancin mutane ko kuma a mai da hankali sosai wajen mu’amala da wasu ?"
    label define risk_conf_poeple 1 "On peut faire confiance à la plupart des gens" 2 "Je n’en sais rien" 3 "Il faut être très prudent"
    label values risk_conf_poeple risk_conf_poeple

    label variable risk_conf_gov "10.3: Dans quelle mesure avez-vous confiance que le gouvernement aidera les pers"
    note risk_conf_gov: "10.3: Dans quelle mesure avez-vous confiance que le gouvernement aidera les personnes qui sont dans le besoin ? ZERMA: yaada da fo no aren ga gomnanto no da ney inga kan dey gwazantey sey gagasiney ? HAOUSSA: Wane tabbaci kuke da shi wajen cewa gwamnati za ta taimaka wa mabukata ?"
    label define risk_conf_gov 10 "10 = Confiance totale" 9 "9" 8 "8" 7 "7" 6 "6" 5 "5" 4 "4" 3 "3" 2 "2" 1 "1 = Aucune confiance"
    label values risk_conf_gov risk_conf_gov

    label variable prog_note "17.01: Au cours des 12 derniers mois, le ménage ou un de ses membres a-t-il béné"
    note prog_note: "17.01: Au cours des 12 derniers mois, le ménage ou un de ses membres a-t-il bénéficié du … ?"
    label define prog_note 1 "oui" 0 "non"
    label values prog_note prog_note

    label variable prog_1 "a. Don de céréales (mil, sorgho, maïs, blé) ou de farines de céréales (semoule)"
    note prog_1: "a. Don de céréales (mil, sorgho, maïs, blé) ou de farines de céréales (semoule)"
    label define prog_1 1 "oui" 0 "non"
    label values prog_1 prog_1

    label variable prog_2 "b. Nourriture ou argent contre travail (Travaux publics à haute intensité de mai"
    note prog_2: "b. Nourriture ou argent contre travail (Travaux publics à haute intensité de main-d’œuvre); Cash for Work"
    label define prog_2 1 "oui" 0 "non"
    label values prog_2 prog_2

    label variable prog_3 "c. Don de nourriture pour les enfants (y compris à l'école)"
    note prog_3: "c. Don de nourriture pour les enfants (y compris à l'école)"
    label define prog_3 1 "oui" 0 "non"
    label values prog_3 prog_3

    label variable prog_4 "d. Projet Filets Sociaux: cash transferts ou mesures productives"
    note prog_4: "d. Projet Filets Sociaux: cash transferts ou mesures productives"
    label define prog_4 1 "oui" 0 "non"
    label values prog_4 prog_4

    label variable prog_5 "e. Cash transferts autre institution / ONG (hors Filets Sociaux"
    note prog_5: "e. Cash transferts autre institution / ONG (hors Filets Sociaux"
    label define prog_5 1 "oui" 0 "non"
    label values prog_5 prog_5

    label variable prog_6 "f. Programme de soutien à l’entrepreneuriat (création ou gestion d’une activité "
    note prog_6: "f. Programme de soutien à l’entrepreneuriat (création ou gestion d’une activité à son compte / AGR, etc) hors Filets Sociaux (after d)"
    label define prog_6 1 "oui" 0 "non"
    label values prog_6 prog_6

    label variable prog_7 "g. Assurance contre la mauvaise récolte / assurance basé sur un indice de précip"
    note prog_7: "g. Assurance contre la mauvaise récolte / assurance basé sur un indice de précipitations"
    label define prog_7 1 "oui" 0 "non"
    label values prog_7 prog_7

    label variable prog_8 "h. Programme santé (hors Filet sociaux)"
    note prog_8: "h. Programme santé (hors Filet sociaux)"
    label define prog_8 1 "oui" 0 "non"
    label values prog_8 prog_8

    label variable prog_9 "i. Assurance santé"
    note prog_9: "i. Assurance santé"
    label define prog_9 1 "oui" 0 "non"
    label values prog_9 prog_9

    label variable prog_10 "j. Programme d’aide à l’épargne et à la bancarisation (hors Filets Sociaux)"
    note prog_10: "j. Programme d’aide à l’épargne et à la bancarisation (hors Filets Sociaux)"
    label define prog_10 1 "oui" 0 "non"
    label values prog_10 prog_10

    label variable prog_11 "k. Programme nutrition (hors Filets Sociaux)"
    note prog_11: "k. Programme nutrition (hors Filets Sociaux)"
    label define prog_11 1 "oui" 0 "non"
    label values prog_11 prog_11

    label variable prog_12 "l. Autre à spécifier"
    note prog_12: "l. Autre à spécifier"
    label define prog_12 1 "oui" 0 "non"
    label values prog_12 prog_12

    label variable prog_o "Quel autre programme ?"
    note prog_o: "Quel autre programme ?"

    label variable resp_prog "17,05: Agent Enqueteur : Qui a répondu ?"
    note resp_prog: "17,05: Agent Enqueteur : Qui a répondu ?"

    label variable ctrans_d "18.01 : Est-ce que vous ou quelqu'un d'autre dans le ménage avez reçu des transf"
    note ctrans_d: "18.01 : Est-ce que vous ou quelqu'un d'autre dans le ménage avez reçu des transferts périodiques du programme filets sociaux au cours des deux dernières années ?"
    label define ctrans_d 1 "oui" 0 "non"
    label values ctrans_d ctrans_d

    label variable ctrans_others "18.02 : En plus du bénéficiaire, y a-t-il d'autres bénéficiaires du cash transfe"
    note ctrans_others: "18.02 : En plus du bénéficiaire, y a-t-il d'autres bénéficiaires du cash transfert dans le ménage ?"
    label define ctrans_others 1 "oui" 0 "non"
    label values ctrans_others ctrans_others

    label variable ctrans_whoelse "18.02b Qui d'autre reçois (a reçu) des transferts ?"
    note ctrans_whoelse: "18.02b Qui d'autre reçois (a reçu) des transferts ?"

    label variable ctrans_when_start "18.03 : Quand le transfert en espèces a-t-il commencé ?"
    note ctrans_when_start: "18.03 : Quand le transfert en espèces a-t-il commencé ?"

    label variable ctrans_when_last "18.04 : Quand avez-vous reçu le dernier transfert ?"
    note ctrans_when_last: "18.04 : Quand avez-vous reçu le dernier transfert ?"

    label variable ctrans_amt "18.05 : Quel était le montant que vous avez (a-t-elle] reçu la dernière fois ? ("
    note ctrans_amt: "18.05 : Quel était le montant que vous avez (a-t-elle] reçu la dernière fois ? (hors subvention productive)"

    label variable ctrans_reason "18.06 : Quel a été la raison principale pour ce programme ?"
    note ctrans_reason: "18.06 : Quel a été la raison principale pour ce programme ?"
    label define ctrans_reason 1 "Pour soutenir les plus vulnérables ménages" 2 "Pour répondre à la sécheresse" 3 "Pour accompagner une période de soudure difficile" -777 "Autre (à préciser)"
    label values ctrans_reason ctrans_reason

    label variable ctrans_reason_o "18.06b : Préciser autre raison"
    note ctrans_reason_o: "18.06b : Préciser autre raison"

    label variable ctrans_paid "18.07 : Avez-vous dû payer quelqu'un pour accéder au transfert d'argent ?"
    note ctrans_paid: "18.07 : Avez-vous dû payer quelqu'un pour accéder au transfert d'argent ?"
    label define ctrans_paid 1 "oui" 0 "non"
    label values ctrans_paid ctrans_paid

    label variable ctrans_paid_amt "18.08 : Combien avez-vous dû payer ?"
    note ctrans_paid_amt: "18.08 : Combien avez-vous dû payer ?"

    label variable resp_ctrans "18.08 Agent Enqueteur :Qui était le répondant pour cette section ?"
    note resp_ctrans: "18.08 Agent Enqueteur :Qui était le répondant pour cette section ?"

    label variable trans_fam "19,01: Au cours des 6 derniers mois, le ménage ou un de ses membres a-t-il reçu "
    note trans_fam: "19,01: Au cours des 6 derniers mois, le ménage ou un de ses membres a-t-il reçu de l’argent, des produits ou des biens provenant tout autre personne non-membre du ménage (y compris d'un autre membre de la famille n'habitant pas le ménage)?"
    label define trans_fam 1 "oui" 0 "non"
    label values trans_fam trans_fam

    label variable trans_n "19,02: Combien de différents transferts le ménage a t-il reçu au total au cours "
    note trans_n: "19,02: Combien de différents transferts le ménage a t-il reçu au total au cours des 6 derniers mois?"

    label variable trans_fam_send "19,08: Au cours des 6 derniers mois, le ménage ou un de ses membres a-t-il envoy"
    note trans_fam_send: "19,08: Au cours des 6 derniers mois, le ménage ou un de ses membres a-t-il envoyé de l'argent, des produits ou des biens à autre personne non-membre du ménage (y compris d'un autre membre de la famille n'habitant pas le ménage)?"
    label define trans_fam_send 1 "oui" 0 "non"
    label values trans_fam_send trans_fam_send

    label variable trans_n_send "19,09: Combien de différents transferts le ménage a t-il envoyé au total au cour"
    note trans_n_send: "19,09: Combien de différents transferts le ménage a t-il envoyé au total au cours des 6 derniers mois?"

    label variable resp_trans "19,03: Agent Enqueteur : Qui était le répondant pour cette section ?"
    note resp_trans: "19,03: Agent Enqueteur : Qui était le répondant pour cette section ?"

    label variable shock_has "20.00 : Au cours 12 derniers mois, le ménage a-t-il été négativement affecté par"
    note shock_has: "20.00 : Au cours 12 derniers mois, le ménage a-t-il été négativement affecté par le problème suivant ?"
    label define shock_has 1 "oui" 0 "non"
    label values shock_has shock_has

    label variable shock1 "Choc 1: 'Sécheresse/Pluies irrégulières'?"
    note shock1: "Choc 1: 'Sécheresse/Pluies irrégulières'?"
    label define shock1 1 "oui" 0 "non"
    label values shock1 shock1

    label variable shock2 "Choc 2: 'Inondations' ?"
    note shock2: "Choc 2: 'Inondations' ?"
    label define shock2 1 "oui" 0 "non"
    label values shock2 shock2

    label variable shock3 "Choc 3: 'Maladies des cultures'?"
    note shock3: "Choc 3: 'Maladies des cultures'?"
    label define shock3 1 "oui" 0 "non"
    label values shock3 shock3

    label variable shock4 "Choc 4: 'Maladies des animaux'?"
    note shock4: "Choc 4: 'Maladies des animaux'?"
    label define shock4 1 "oui" 0 "non"
    label values shock4 shock4

    label variable shock5 "Choc 5: 'Hausse des prix des intrants agricoles'?"
    note shock5: "Choc 5: 'Hausse des prix des intrants agricoles'?"
    label define shock5 1 "oui" 0 "non"
    label values shock5 shock5

    label variable shock6 "Choc 6: 'Baisse du prix des produits agricoles'?"
    note shock6: "Choc 6: 'Baisse du prix des produits agricoles'?"
    label define shock6 1 "oui" 0 "non"
    label values shock6 shock6

    label variable shock7 "Choc 7: 'Hausse des prix des produits alimentaires'?"
    note shock7: "Choc 7: 'Hausse des prix des produits alimentaires'?"
    label define shock7 1 "oui" 0 "non"
    label values shock7 shock7

    label variable shock8 "Choc 8: 'Perte importante du revenu non agricole du ménage (non liée à un accide"
    note shock8: "Choc 8: 'Perte importante du revenu non agricole du ménage (non liée à un accident ou une maladie)'?"
    label define shock8 1 "oui" 0 "non"
    label values shock8 shock8

    label variable shock9 "Choc 9: 'Maladie grave ou accident d'un membre du ménage'?"
    note shock9: "Choc 9: 'Maladie grave ou accident d'un membre du ménage'?"
    label define shock9 1 "oui" 0 "non"
    label values shock9 shock9

    label variable shock10 "Choc 10 : 'Décès d'un membre du ménage'?"
    note shock10: "Choc 10 : 'Décès d'un membre du ménage'?"
    label define shock10 1 "oui" 0 "non"
    label values shock10 shock10

    label variable shock11 "Choc 11: 'Divorce, séparation'?"
    note shock11: "Choc 11: 'Divorce, séparation'?"
    label define shock11 1 "oui" 0 "non"
    label values shock11 shock11

    label variable shock12 "Choc 12: 'Vol d'argent, de biens ou de récolte'?"
    note shock12: "Choc 12: 'Vol d'argent, de biens ou de récolte'?"
    label define shock12 1 "oui" 0 "non"
    label values shock12 shock12

    label variable shock13 "Choc 13: 'Autre (précisez)'?"
    note shock13: "Choc 13: 'Autre (précisez)'?"
    label define shock13 1 "oui" 0 "non"
    label values shock13 shock13

    label variable shock_o "Quel autre problème ?"
    note shock_o: "Quel autre problème ?"

    label variable shock_affect "20.01 : Le choc suivant a-t-il été négativement affecté pendant la période de So"
    note shock_affect: "20.01 : Le choc suivant a-t-il été négativement affecté pendant la période de Soudure (Juillet-Septembre) ?"
    label define shock_affect 1 "oui" 0 "non"
    label values shock_affect shock_affect

    label variable shock1b "Choc 1: 'Sécheresse/Pluies irrégulières'?"
    note shock1b: "Choc 1: 'Sécheresse/Pluies irrégulières'?"
    label define shock1b 1 "oui" 0 "non"
    label values shock1b shock1b

    label variable shock2b "Choc 2: 'Inondations' ?"
    note shock2b: "Choc 2: 'Inondations' ?"
    label define shock2b 1 "oui" 0 "non"
    label values shock2b shock2b

    label variable shock3b "Choc 3: 'Maladies des cultures'?"
    note shock3b: "Choc 3: 'Maladies des cultures'?"
    label define shock3b 1 "oui" 0 "non"
    label values shock3b shock3b

    label variable shock4b "Choc 4: 'Maladies des animaux'?"
    note shock4b: "Choc 4: 'Maladies des animaux'?"
    label define shock4b 1 "oui" 0 "non"
    label values shock4b shock4b

    label variable shock5b "Choc 5: 'Hausse des prix des intrants agricoles'?"
    note shock5b: "Choc 5: 'Hausse des prix des intrants agricoles'?"
    label define shock5b 1 "oui" 0 "non"
    label values shock5b shock5b

    label variable shock6b "Choc 6: 'Baisse du prix des produits agricoles'?"
    note shock6b: "Choc 6: 'Baisse du prix des produits agricoles'?"
    label define shock6b 1 "oui" 0 "non"
    label values shock6b shock6b

    label variable shock7b "Choc 7: 'Hausse des prix des produits alimentaires'?"
    note shock7b: "Choc 7: 'Hausse des prix des produits alimentaires'?"
    label define shock7b 1 "oui" 0 "non"
    label values shock7b shock7b

    label variable shock8b "Choc 8: 'Perte importante du revenu non agricole du ménage (non liée à un accide"
    note shock8b: "Choc 8: 'Perte importante du revenu non agricole du ménage (non liée à un accident ou une maladie)'?"
    label define shock8b 1 "oui" 0 "non"
    label values shock8b shock8b

    label variable shock9b "Choc 9: 'Maladie grave ou accident d'un membre du ménage'?"
    note shock9b: "Choc 9: 'Maladie grave ou accident d'un membre du ménage'?"
    label define shock9b 1 "oui" 0 "non"
    label values shock9b shock9b

    label variable shock10b "Choc 10 : 'Décès d'un membre du ménage'?"
    note shock10b: "Choc 10 : 'Décès d'un membre du ménage'?"
    label define shock10b 1 "oui" 0 "non"
    label values shock10b shock10b

    label variable shock11b "Choc 11: 'Divorce, séparation'?"
    note shock11b: "Choc 11: 'Divorce, séparation'?"
    label define shock11b 1 "oui" 0 "non"
    label values shock11b shock11b

    label variable shock12b "Choc 12: 'Vol d'argent, de biens ou de récolte'?"
    note shock12b: "Choc 12: 'Vol d'argent, de biens ou de récolte'?"
    label define shock12b 1 "oui" 0 "non"
    label values shock12b shock12b

    label variable shock13b "\${shock_o}"
    note shock13b: "\${shock_o}"
    label define shock13b 1 "oui" 0 "non"
    label values shock13b shock13b

    label variable shock_rank1 "1 (le plus sévère)"
    note shock_rank1: "1 (le plus sévère)"
    label define shock_rank1 1 "Sécheresse/Pluies irrégulières" 2 "Inondations" 3 "Maladies des cultures" 4 "Maladies des animaux" 5 "Hausse des prix des intrants agricoles" 6 "Baisse du prix des produits agricoles" 7 "Hausse des prix des produits alimentaires" 8 "Perte importante du revenu non agricole du ménage (non liée à un accident ou une" 9 "Maladie grave ou accident d'un membre du ménage" 10 "Décès d'un membre du ménage" 11 "Divorce, séparation" 12 "Vol d'argent, de biens ou de récolte" 13 "\${shock_o}"
    label values shock_rank1 shock_rank1

    label variable shock_rank2 "2"
    note shock_rank2: "2"
    label define shock_rank2 1 "Sécheresse/Pluies irrégulières" 2 "Inondations" 3 "Maladies des cultures" 4 "Maladies des animaux" 5 "Hausse des prix des intrants agricoles" 6 "Baisse du prix des produits agricoles" 7 "Hausse des prix des produits alimentaires" 8 "Perte importante du revenu non agricole du ménage (non liée à un accident ou une" 9 "Maladie grave ou accident d'un membre du ménage" 10 "Décès d'un membre du ménage" 11 "Divorce, séparation" 12 "Vol d'argent, de biens ou de récolte" 13 "\${shock_o}"
    label values shock_rank2 shock_rank2

    label variable shock_rank3 "3 (le moins sévère)"
    note shock_rank3: "3 (le moins sévère)"
    label define shock_rank3 1 "Sécheresse/Pluies irrégulières" 2 "Inondations" 3 "Maladies des cultures" 4 "Maladies des animaux" 5 "Hausse des prix des intrants agricoles" 6 "Baisse du prix des produits agricoles" 7 "Hausse des prix des produits alimentaires" 8 "Perte importante du revenu non agricole du ménage (non liée à un accident ou une" 9 "Maladie grave ou accident d'un membre du ménage" 10 "Décès d'un membre du ménage" 11 "Divorce, séparation" 12 "Vol d'argent, de biens ou de récolte" 13 "\${shock_o}"
    label values shock_rank3 shock_rank3

    label variable resp_shock "Agent Enqueteur : Qui était le répondant pour cette section ?"
    note resp_shock: "Agent Enqueteur : Qui était le répondant pour cette section ?"

    label variable note_choc_strategy "20,03: Quelles stratégies avez-vous utilisé en réponse à ces chocs au cours des "
    note note_choc_strategy: "20,03: Quelles stratégies avez-vous utilisé en réponse à ces chocs au cours des 12 derniers mois ?"
    label define note_choc_strategy 1 "oui" 0 "non"
    label values note_choc_strategy note_choc_strategy

    label variable choc_strategy1 "Vente de bétail"
    note choc_strategy1: "Vente de bétail"
    label define choc_strategy1 1 "oui" 0 "non"
    label values choc_strategy1 choc_strategy1

    label variable choc_strategy2 "Vent de stock de produits alimentaires"
    note choc_strategy2: "Vent de stock de produits alimentaires"
    label define choc_strategy2 1 "oui" 0 "non"
    label values choc_strategy2 choc_strategy2

    label variable choc_strategy3 "Utilisation de l’épargne"
    note choc_strategy3: "Utilisation de l’épargne"
    label define choc_strategy3 1 "oui" 0 "non"
    label values choc_strategy3 choc_strategy3

    label variable choc_strategy4 "Réduction des dépenses alimentaires ou changement des habitudes de consommation "
    note choc_strategy4: "Réduction des dépenses alimentaires ou changement des habitudes de consommation d’aliment"
    label define choc_strategy4 1 "oui" 0 "non"
    label values choc_strategy4 choc_strategy4

    label variable choc_strategy5 "Vente d’actifs productifs"
    note choc_strategy5: "Vente d’actifs productifs"
    label define choc_strategy5 1 "oui" 0 "non"
    label values choc_strategy5 choc_strategy5

    label variable choc_strategy6 "Réduction des dépenses de santé/education"
    note choc_strategy6: "Réduction des dépenses de santé/education"
    label define choc_strategy6 1 "oui" 0 "non"
    label values choc_strategy6 choc_strategy6

    label variable choc_strategy7 "Réduction des dépenses non alimentaires"
    note choc_strategy7: "Réduction des dépenses non alimentaires"
    label define choc_strategy7 1 "oui" 0 "non"
    label values choc_strategy7 choc_strategy7

    label variable choc_strategy8 "Vente de biens durables du ménage"
    note choc_strategy8: "Vente de biens durables du ménage"
    label define choc_strategy8 1 "oui" 0 "non"
    label values choc_strategy8 choc_strategy8

    label variable choc_strategy9 "Crédit"
    note choc_strategy9: "Crédit"
    label define choc_strategy9 1 "oui" 0 "non"
    label values choc_strategy9 choc_strategy9

    label variable choc_strategy10 "Des membres du ménage ont pris des activités supplémentaires"
    note choc_strategy10: "Des membres du ménage ont pris des activités supplémentaires"
    label define choc_strategy10 1 "oui" 0 "non"
    label values choc_strategy10 choc_strategy10

    label variable choc_strategy11 "Exode"
    note choc_strategy11: "Exode"
    label define choc_strategy11 1 "oui" 0 "non"
    label values choc_strategy11 choc_strategy11

    label variable choc_strategy12 "Aide de parents ou d’amis"
    note choc_strategy12: "Aide de parents ou d’amis"
    label define choc_strategy12 1 "oui" 0 "non"
    label values choc_strategy12 choc_strategy12

    label variable choc_strategy13 "Aide du gouvernment/Etat"
    note choc_strategy13: "Aide du gouvernment/Etat"
    label define choc_strategy13 1 "oui" 0 "non"
    label values choc_strategy13 choc_strategy13

    label variable choc_strategy14 "Aide d’ONG"
    note choc_strategy14: "Aide d’ONG"
    label define choc_strategy14 1 "oui" 0 "non"
    label values choc_strategy14 choc_strategy14

    label variable choc_strategy15 "Aide d’organisations religieuses"
    note choc_strategy15: "Aide d’organisations religieuses"
    label define choc_strategy15 1 "oui" 0 "non"
    label values choc_strategy15 choc_strategy15

    label variable choc_strategy16 "Dieu"
    note choc_strategy16: "Dieu"
    label define choc_strategy16 1 "oui" 0 "non"
    label values choc_strategy16 choc_strategy16

    label variable choc_strategy17 "Aucune stratégie"
    note choc_strategy17: "Aucune stratégie"
    label define choc_strategy17 1 "oui" 0 "non"
    label values choc_strategy17 choc_strategy17

    label variable choc_strategy19 "Adapatation de comportement agricole (comme jardinnage)"
    note choc_strategy19: "Adapatation de comportement agricole (comme jardinnage)"
    label define choc_strategy19 1 "oui" 0 "non"
    label values choc_strategy19 choc_strategy19

    label variable choc_strategy18 "Autre stratégie (préciser)"
    note choc_strategy18: "Autre stratégie (préciser)"
    label define choc_strategy18 1 "oui" 0 "non"
    label values choc_strategy18 choc_strategy18

    label variable choc_strategy18_o "préciser autre stratégie"
    note choc_strategy18_o: "préciser autre stratégie"

    label variable note_choc_strategyu "20,04: Avez-vous utilisé cette stratégie pendant la période de soudure (Juillet-"
    note note_choc_strategyu: "20,04: Avez-vous utilisé cette stratégie pendant la période de soudure (Juillet-Septembre 2021) ?"
    label define note_choc_strategyu 1 "oui" 0 "non"
    label values note_choc_strategyu note_choc_strategyu

    label variable choc_strategy1u "Vente de bétail"
    note choc_strategy1u: "Vente de bétail"
    label define choc_strategy1u 1 "oui" 0 "non"
    label values choc_strategy1u choc_strategy1u

    label variable choc_strategy2u "Vente de stock de produits alimentaires"
    note choc_strategy2u: "Vente de stock de produits alimentaires"
    label define choc_strategy2u 1 "oui" 0 "non"
    label values choc_strategy2u choc_strategy2u

    label variable choc_strategy3u "Utilisation de l’épargne"
    note choc_strategy3u: "Utilisation de l’épargne"
    label define choc_strategy3u 1 "oui" 0 "non"
    label values choc_strategy3u choc_strategy3u

    label variable choc_strategy4u "Réduction des dépenses alimentaires ou changement des habitudes de consommation "
    note choc_strategy4u: "Réduction des dépenses alimentaires ou changement des habitudes de consommation d’aliment"
    label define choc_strategy4u 1 "oui" 0 "non"
    label values choc_strategy4u choc_strategy4u

    label variable choc_strategy5u "Vente d’actifs productifs"
    note choc_strategy5u: "Vente d’actifs productifs"
    label define choc_strategy5u 1 "oui" 0 "non"
    label values choc_strategy5u choc_strategy5u

    label variable choc_strategy6u "Réduction des dépenses de santé/éducation"
    note choc_strategy6u: "Réduction des dépenses de santé/éducation"
    label define choc_strategy6u 1 "oui" 0 "non"
    label values choc_strategy6u choc_strategy6u

    label variable choc_strategy7u "Réduction des dépenses non alimentaires"
    note choc_strategy7u: "Réduction des dépenses non alimentaires"
    label define choc_strategy7u 1 "oui" 0 "non"
    label values choc_strategy7u choc_strategy7u

    label variable choc_strategy8u "Vente de biens durables du ménage"
    note choc_strategy8u: "Vente de biens durables du ménage"
    label define choc_strategy8u 1 "oui" 0 "non"
    label values choc_strategy8u choc_strategy8u

    label variable choc_strategy9u "Crédit"
    note choc_strategy9u: "Crédit"
    label define choc_strategy9u 1 "oui" 0 "non"
    label values choc_strategy9u choc_strategy9u

    label variable choc_strategy10u "Des membres du ménage ont pris des activités supplémentaires"
    note choc_strategy10u: "Des membres du ménage ont pris des activités supplémentaires"
    label define choc_strategy10u 1 "oui" 0 "non"
    label values choc_strategy10u choc_strategy10u

    label variable choc_strategy11u "Exode"
    note choc_strategy11u: "Exode"
    label define choc_strategy11u 1 "oui" 0 "non"
    label values choc_strategy11u choc_strategy11u

    label variable choc_strategy12u "Aide de parents ou d’amis"
    note choc_strategy12u: "Aide de parents ou d’amis"
    label define choc_strategy12u 1 "oui" 0 "non"
    label values choc_strategy12u choc_strategy12u

    label variable choc_strategy13u "Aide du gouvernment/Etat"
    note choc_strategy13u: "Aide du gouvernment/Etat"
    label define choc_strategy13u 1 "oui" 0 "non"
    label values choc_strategy13u choc_strategy13u

    label variable choc_strategy14u "Aide d’ONG"
    note choc_strategy14u: "Aide d’ONG"
    label define choc_strategy14u 1 "oui" 0 "non"
    label values choc_strategy14u choc_strategy14u

    label variable choc_strategy15u "Aide d’organisations religieuses"
    note choc_strategy15u: "Aide d’organisations religieuses"
    label define choc_strategy15u 1 "oui" 0 "non"
    label values choc_strategy15u choc_strategy15u

    label variable choc_strategy16u "Dieu"
    note choc_strategy16u: "Dieu"
    label define choc_strategy16u 1 "oui" 0 "non"
    label values choc_strategy16u choc_strategy16u

    label variable choc_strategy19u "Adapatation de comportement agricole (comme jardinnage)"
    note choc_strategy19u: "Adapatation de comportement agricole (comme jardinnage)"
    label define choc_strategy19u 1 "oui" 0 "non"
    label values choc_strategy19u choc_strategy19u

    label variable choc_strategy18u "\${choc_strategy18_o}"
    note choc_strategy18u: "\${choc_strategy18_o}"
    label define choc_strategy18u 1 "oui" 0 "non"
    label values choc_strategy18u choc_strategy18u

    label variable strat_best1 "meilleure stratégie"
    note strat_best1: "meilleure stratégie"
    label define strat_best1 1 "Vente de bétail" 2 "Vente de stock de produits alimentaires" 3 "Utilisation de l’epargne" 4 "Réduction des depenses alimentaires ou changement des habitudes de consommation " 5 "Vente d’actifs productifs" 6 "Réduction des depenses de sante/education" 7 "Réduction des depenses non alimentaires" 8 "Vente de biens durables du menage" 9 "Crédit" 10 "Des membres du menage ont pris des activites supplentaires" 11 "Exode" 12 "Aide de parents ou d’amis" 13 "Aide du gouvernment/etat" 14 "Aide d’ONG" 15 "Aide d’organisations religieuses" 16 "Dieu" 19 "Adapatation de comportement agricole (comme jardinnage)" 0 "Aucune stratégie" 18 "\${choc_strategy18_o}"
    label values strat_best1 strat_best1

    label variable strat_best2 "Deuxième stratégie"
    note strat_best2: "Deuxième stratégie"
    label define strat_best2 1 "Vente de bétail" 2 "Vente de stock de produits alimentaires" 3 "Utilisation de l’epargne" 4 "Réduction des depenses alimentaires ou changement des habitudes de consommation " 5 "Vente d’actifs productifs" 6 "Réduction des depenses de sante/education" 7 "Réduction des depenses non alimentaires" 8 "Vente de biens durables du menage" 9 "Crédit" 10 "Des membres du menage ont pris des activites supplentaires" 11 "Exode" 12 "Aide de parents ou d’amis" 13 "Aide du gouvernment/etat" 14 "Aide d’ONG" 15 "Aide d’organisations religieuses" 16 "Dieu" 19 "Adapatation de comportement agricole (comme jardinnage)" 0 "Aucune stratégie" 18 "\${choc_strategy18_o}"
    label values strat_best2 strat_best2

    label variable strat_best1_o "Quelle autre strategie ?"
    note strat_best1_o: "Quelle autre strategie ?"

    label variable strat_best2_o "Quelle autre strategie ?"
    note strat_best2_o: "Quelle autre strategie ?"

    label variable resp_strategy "Agent Enqueteur : Qui était le répondant pour cette section ?"
    note resp_strategy: "Agent Enqueteur : Qui était le répondant pour cette section ?"

    label variable language "Agent Enqueteur : Quelle(s) langue(s) ont été utilisées lors de cette enquête ?"
    note language: "Agent Enqueteur : Quelle(s) langue(s) ont été utilisées lors de cette enquête ?"

    label variable language_o "Quelle autre langue ?"
    note language_o: "Quelle autre langue ?"

    label variable gps_infolatitude "Prendre les coordonées GPS (latitude)"
    note gps_infolatitude: "Prendre les coordonées GPS (latitude)"

    label variable gps_infolongitude "Prendre les coordonées GPS (longitude)"
    note gps_infolongitude: "Prendre les coordonées GPS (longitude)"

    label variable gps_infoaltitude "Prendre les coordonées GPS (altitude)"
    note gps_infoaltitude: "Prendre les coordonées GPS (altitude)"

    label variable gps_infoaccuracy "Prendre les coordonées GPS (accuracy)"
    note gps_infoaccuracy: "Prendre les coordonées GPS (accuracy)"

    label variable gps_turnoff "Assurez-vous d'éteindre les données de localisation."
    note gps_turnoff: "Assurez-vous d'éteindre les données de localisation."






    * append old, previously-imported data (if any)
    cap confirm file "`dtafile'"
    if _rc == 0 {
        * mark all new data before merging with old data
        gen new_data_row=1
        
        * pull in old data
        append using "`dtafile'"
        
        * drop duplicates in favor of old, previously-imported data if overwrite_old_data is 0
        * (alternatively drop in favor of new data if overwrite_old_data is 1)
        sort key
        by key: gen num_for_key = _N
        drop if num_for_key > 1 & ((`overwrite_old_data' == 0 & new_data_row == 1) | (`overwrite_old_data' == 1 & new_data_row ~= 1))
        drop num_for_key

        * drop new-data flag
        drop new_data_row
    }
    
    * save data to Stata format
    save "`dtafile'", replace


}

disp
disp "Finished import of: `csvfile'"
disp

* OPTIONAL: LOCALLY-APPLIED STATA CORRECTIONS
*
* Rather than using SurveyCTO's review and correction workflow, the code below can apply a list of corrections
* listed in a local .csv file. Feel free to use, ignore, or delete this code.
*
*   Corrections file path and filename:  /users/rongmondeka/desktop/long/Niger 2023- Shock Response- ENDLINE_corrections.csv
*
*   Corrections file columns (in order): key, fieldname, value, notes

capture confirm file "`corrfile'"
if _rc==0 {
    disp
    disp "Starting application of corrections in: `corrfile'"
    disp

    * save primary data in memory
    preserve

    * load corrections
    insheet using "`corrfile'", names clear
    
    if _N>0 {
        * number all rows (with +1 offset so that it matches row numbers in Excel)
        gen rownum=_n+1
        
        * drop notes field (for information only)
        drop notes
        
        * make sure that all values are in string format to start
        gen origvalue=value
        tostring value, format(%100.0g) replace
        cap replace value="" if origvalue==.
        drop origvalue
        replace value=trim(value)
        
        * correct field names to match Stata field names (lowercase, drop -'s and .'s)
        replace fieldname=lower(subinstr(subinstr(fieldname,"-","",.),".","",.))
        
        * format date and date/time fields (taking account of possible wildcards for repeat groups)
        forvalues i = 1/100 {
            if "`datetime_fields`i''" ~= "" {
                foreach dtvar in `datetime_fields`i'' {
                    * skip fields that aren't yet in the data
                    cap unab dtvarignore : `dtvar'
                    if _rc==0 {
                        gen origvalue=value
                        replace value=string(clock(value,"DMYhms",2025),"%25.0g") if strmatch(fieldname,"`dtvar'")
                        * allow for cases where seconds haven't been specified
                        replace value=string(clock(origvalue,"DMYhm",2025),"%25.0g") if strmatch(fieldname,"`dtvar'") & value=="." & origvalue~="."
                        drop origvalue
                    }
                }
            }
            if "`date_fields`i''" ~= "" {
                foreach dtvar in `date_fields`i'' {
                    * skip fields that aren't yet in the data
                    cap unab dtvarignore : `dtvar'
                    if _rc==0 {
                        replace value=string(clock(value,"DMY",2025),"%25.0g") if strmatch(fieldname,"`dtvar'")
                    }
                }
            }
        }

        * write out a temp file with the commands necessary to apply each correction
        tempfile tempdo
        file open dofile using "`tempdo'", write replace
        local N = _N
        forvalues i = 1/`N' {
            local fieldnameval=fieldname[`i']
            local valueval=value[`i']
            local keyval=key[`i']
            local rownumval=rownum[`i']
            file write dofile `"cap replace `fieldnameval'="`valueval'" if key=="`keyval'""' _n
            file write dofile `"if _rc ~= 0 {"' _n
            if "`valueval'" == "" {
                file write dofile _tab `"cap replace `fieldnameval'=. if key=="`keyval'""' _n
            }
            else {
                file write dofile _tab `"cap replace `fieldnameval'=`valueval' if key=="`keyval'""' _n
            }
            file write dofile _tab `"if _rc ~= 0 {"' _n
            file write dofile _tab _tab `"disp"' _n
            file write dofile _tab _tab `"disp "CAN'T APPLY CORRECTION IN ROW #`rownumval'""' _n
            file write dofile _tab _tab `"disp"' _n
            file write dofile _tab `"}"' _n
            file write dofile `"}"' _n
        }
        file close dofile
    
        * restore primary data
        restore
        
        * execute the .do file to actually apply all corrections
        do "`tempdo'"

        * re-save data
        save "`dtafile'", replace
    }
    else {
        * restore primary data        
        restore
    }

    disp
    disp "Finished applying corrections in: `corrfile'"
    disp
}


* launch .do files to process repeat groups

do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-gp_drykeycond-rpt_dcrops.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-gp_empl_cond-rpt_sal.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-gp_rainkeycond-rpt_rcrops.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-SECTION_AGR_NA-SECTION_emploi-d_hh_wage_labor.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-SECTION_AGR_NA-SECTION_emploi-rpt_empl.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-SECTION_AGR_NA-SECTION_emploi-rpt_wrk.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-SECTION_AGR_NA-SECTION_na-rpt_agr_enum.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-SECTION_assets-rpt_ag_ass.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-SECTION_assets-rpt_hh_ass.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-SECTION_finance-PART_credit-rpt_cred.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-SECTION_finance-PART_othersave-gp_savemoreinfo.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-SECTION_foodconsumption-rpt_consum1.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-SECTION_foodconsumption-rpt_consum2.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-SECTION_nfconsumption-gp_cel-rpt_cel1.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-SECTION_nfconsumption-gp_cel-rpt_cel2.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-SECTION_nfconsumption-gp_nonfood-rpt_nonfood.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-SECTION_programs-rpt_prog.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-SECTION_transfers-rpt_trans.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-SECTION_transfers-rpt_trans_send.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_cropsdry1-rpt_plotdry.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_cropsdry2-rpt_dcrops2.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_cropsrain1-rpt_plotrain.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_cropsrain2-rpt_rcrops2.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-mod_agriculture-SECTION_agriculture-SECTION_plot-rpt_plots.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-mod_agriculture-SECTION_agriculture-mod_f_ag_livestock-agriculture30-SECTION_plots30-rpt_plots30.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-mod_agriculture-SECTION_agriculture-mod_f_ag_livestock-agriculture30-crops_rpt30.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-mod_agriculture-SECTION_agriculture-mod_f_ag_livestock-agriculture30-f_hh_ag_labor.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-mod_agriculture-SECTION_livestock-gp_haslivestock-r_four.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-mod_agriculture-SECTION_livestock-gp_haslivestock-rpt_ani1.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-mod_c_hh_roster-hh_roster_new.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-mod_c_hh_roster-hh_unconf.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-mod_c_hh_roster-rpt_caregiver.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-informed_consent-mod_c_hh_roster-s_hh_sleep.do"
do "$endline_cleaning/stata_template_long/import_niger_2023_Endline_Terrain-rpt_activitylist.do"
